var ev=(t,e)=>()=>(e||t((e={exports:{}}).exports,e),e.exports);var LS=ev((BS,An)=>{(function(){const e=document.createElement("link").relList;if(e&&e.supports&&e.supports("modulepreload"))return;for(const i of document.querySelectorAll('link[rel="modulepreload"]'))r(i);new MutationObserver(i=>{for(const s of i)if(s.type==="childList")for(const o of s.addedNodes)o.tagName==="LINK"&&o.rel==="modulepreload"&&r(o)}).observe(document,{childList:!0,subtree:!0});function u(i){const s={};return i.integrity&&(s.integrity=i.integrity),i.referrerPolicy&&(s.referrerPolicy=i.referrerPolicy),i.crossOrigin==="use-credentials"?s.credentials="include":i.crossOrigin==="anonymous"?s.credentials="omit":s.credentials="same-origin",s}function r(i){if(i.ep)return;i.ep=!0;const s=u(i);fetch(i.href,s)}})();var yr=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{};function zn(t){return t&&t.__esModule&&Object.prototype.hasOwnProperty.call(t,"default")?t.default:t}function tv(t){if(t.__esModule)return t;var e=t.default;if(typeof e=="function"){var u=function r(){if(this instanceof r){var i=[null];i.push.apply(i,arguments);var s=Function.bind.apply(e,i);return new s}return e.apply(this,arguments)};u.prototype=e.prototype}else u={};return Object.defineProperty(u,"__esModule",{value:!0}),Object.keys(t).forEach(function(r){var i=Object.getOwnPropertyDescriptor(t,r);Object.defineProperty(u,r,i.get?i:{enumerable:!0,get:function(){return t[r]}})}),u}var ea={exports:{}};/*!
 * jQuery JavaScript Library v3.5.1
 * https://jquery.com/
 *
 * Includes Sizzle.js
 * https://sizzlejs.com/
 *
 * Copyright JS Foundation and other contributors
 * Released under the MIT license
 * https://jquery.org/license
 *
 * Date: 2020-05-04T22:49Z
 */var dd;function cc(){return dd||(dd=1,function(t){(function(e,u){t.exports=e.document?u(e,!0):function(r){if(!r.document)throw new Error("jQuery requires a window with a document");return u(r)}})(typeof window<"u"?window:yr,function(e,u){var r=[],i=Object.getPrototypeOf,s=r.slice,o=r.flat?function(y){return r.flat.call(y)}:function(y){return r.concat.apply([],y)},f=r.push,n=r.indexOf,h={},g=h.toString,d=h.hasOwnProperty,l=d.toString,c=l.call(Object),a={},F=function(D){return typeof D=="function"&&typeof D.nodeType!="number"},p=function(D){return D!=null&&D===D.window},m=e.document,b={type:!0,src:!0,nonce:!0,noModule:!0};function C(y,D,$){$=$||m;var H,J,X=$.createElement("script");if(X.text=y,D)for(H in b)J=D[H]||D.getAttribute&&D.getAttribute(H),J&&X.setAttribute(H,J);$.head.appendChild(X).parentNode.removeChild(X)}function k(y){return y==null?y+"":typeof y=="object"||typeof y=="function"?h[g.call(y)]||"object":typeof y}var T="3.5.1",w=function(y,D){return new w.fn.init(y,D)};w.fn=w.prototype={jquery:T,constructor:w,length:0,toArray:function(){return s.call(this)},get:function(y){return y==null?s.call(this):y<0?this[y+this.length]:this[y]},pushStack:function(y){var D=w.merge(this.constructor(),y);return D.prevObject=this,D},each:function(y){return w.each(this,y)},map:function(y){return this.pushStack(w.map(this,function(D,$){return y.call(D,$,D)}))},slice:function(){return this.pushStack(s.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},even:function(){return this.pushStack(w.grep(this,function(y,D){return(D+1)%2}))},odd:function(){return this.pushStack(w.grep(this,function(y,D){return D%2}))},eq:function(y){var D=this.length,$=+y+(y<0?D:0);return this.pushStack($>=0&&$<D?[this[$]]:[])},end:function(){return this.prevObject||this.constructor()},push:f,sort:r.sort,splice:r.splice},w.extend=w.fn.extend=function(){var y,D,$,H,J,X,te=arguments[0]||{},we=1,Ce=arguments.length,_e=!1;for(typeof te=="boolean"&&(_e=te,te=arguments[we]||{},we++),typeof te!="object"&&!F(te)&&(te={}),we===Ce&&(te=this,we--);we<Ce;we++)if((y=arguments[we])!=null)for(D in y)H=y[D],!(D==="__proto__"||te===H)&&(_e&&H&&(w.isPlainObject(H)||(J=Array.isArray(H)))?($=te[D],J&&!Array.isArray($)?X=[]:!J&&!w.isPlainObject($)?X={}:X=$,J=!1,te[D]=w.extend(_e,X,H)):H!==void 0&&(te[D]=H));return te},w.extend({expando:"jQuery"+(T+Math.random()).replace(/\D/g,""),isReady:!0,error:function(y){throw new Error(y)},noop:function(){},isPlainObject:function(y){var D,$;return!y||g.call(y)!=="[object Object]"?!1:(D=i(y),D?($=d.call(D,"constructor")&&D.constructor,typeof $=="function"&&l.call($)===c):!0)},isEmptyObject:function(y){var D;for(D in y)return!1;return!0},globalEval:function(y,D,$){C(y,{nonce:D&&D.nonce},$)},each:function(y,D){var $,H=0;if(A(y))for($=y.length;H<$&&D.call(y[H],H,y[H])!==!1;H++);else for(H in y)if(D.call(y[H],H,y[H])===!1)break;return y},makeArray:function(y,D){var $=D||[];return y!=null&&(A(Object(y))?w.merge($,typeof y=="string"?[y]:y):f.call($,y)),$},inArray:function(y,D,$){return D==null?-1:n.call(D,y,$)},merge:function(y,D){for(var $=+D.length,H=0,J=y.length;H<$;H++)y[J++]=D[H];return y.length=J,y},grep:function(y,D,$){for(var H,J=[],X=0,te=y.length,we=!$;X<te;X++)H=!D(y[X],X),H!==we&&J.push(y[X]);return J},map:function(y,D,$){var H,J,X=0,te=[];if(A(y))for(H=y.length;X<H;X++)J=D(y[X],X,$),J!=null&&te.push(J);else for(X in y)J=D(y[X],X,$),J!=null&&te.push(J);return o(te)},guid:1,support:a}),typeof Symbol=="function"&&(w.fn[Symbol.iterator]=r[Symbol.iterator]),w.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),function(y,D){h["[object "+D+"]"]=D.toLowerCase()});function A(y){var D=!!y&&"length"in y&&y.length,$=k(y);return F(y)||p(y)?!1:$==="array"||D===0||typeof D=="number"&&D>0&&D-1 in y}var M=function(y){var D,$,H,J,X,te,we,Ce,_e,Re,qe,Te,Oe,ot,yt,at,o0,i0,B0,Lt="sizzle"+1*new Date,wt=y.document,S0=0,Mt=0,Yt=Gs(),Ku=Gs(),qs=Gs(),I0=Gs(),yi=function(ie,be){return ie===be&&(qe=!0),0},Ci={}.hasOwnProperty,_0=[],Vr=_0.pop,V0=_0.push,Gr=_0.push,rd=_0.slice,Ei=function(ie,be){for(var je=0,$e=ie.length;je<$e;je++)if(ie[je]===be)return je;return-1},Vo="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",Tt="[\\x20\\t\\r\\n\\f]",Ai="(?:\\\\[\\da-fA-F]{1,6}"+Tt+"?|\\\\[^\\r\\n\\f]|[\\w-]|[^\0-\\x7f])+",id="\\["+Tt+"*("+Ai+")(?:"+Tt+"*([*^$|!~]?=)"+Tt+`*(?:'((?:\\\\.|[^\\\\'])*)'|"((?:\\\\.|[^\\\\"])*)"|(`+Ai+"))|)"+Tt+"*\\]",Go=":("+Ai+`)(?:\\((('((?:\\\\.|[^\\\\'])*)'|"((?:\\\\.|[^\\\\"])*)")|((?:\\\\.|[^\\\\()[\\]]|`+id+")*)|.*)\\)|)",Nm=new RegExp(Tt+"+","g"),zs=new RegExp("^"+Tt+"+|((?:^|[^\\\\])(?:\\\\.)*)"+Tt+"+$","g"),Wm=new RegExp("^"+Tt+"*,"+Tt+"*"),ud=new RegExp("^"+Tt+"*([>+~]|"+Tt+")"+Tt+"*"),Hm=new RegExp(Tt+"|>"),Um=new RegExp(Go),qm=new RegExp("^"+Ai+"$"),Vs={ID:new RegExp("^#("+Ai+")"),CLASS:new RegExp("^\\.("+Ai+")"),TAG:new RegExp("^("+Ai+"|[*])"),ATTR:new RegExp("^"+id),PSEUDO:new RegExp("^"+Go),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\("+Tt+"*(even|odd|(([+-]|)(\\d*)n|)"+Tt+"*(?:([+-]|)"+Tt+"*(\\d+)|))"+Tt+"*\\)|)","i"),bool:new RegExp("^(?:"+Vo+")$","i"),needsContext:new RegExp("^"+Tt+"*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\("+Tt+"*((?:-\\d)?\\d*)"+Tt+"*\\)|)(?=[^-]|$)","i")},zm=/HTML$/i,Vm=/^(?:input|select|textarea|button)$/i,Gm=/^h\d$/i,Yu=/^[^{]+\{\s*\[native \w/,Km=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,Ko=/[+~]/,Pr=new RegExp("\\\\[\\da-fA-F]{1,6}"+Tt+"?|\\\\([^\\r\\n\\f])","g"),Lr=function(ie,be){var je="0x"+ie.slice(1)-65536;return be||(je<0?String.fromCharCode(je+65536):String.fromCharCode(je>>10|55296,je&1023|56320))},sd=/([\0-\x1f\x7f]|^-?\d)|^-$|[^\0-\x1f\x7f-\uFFFF\w-]/g,nd=function(ie,be){return be?ie==="\0"?"�":ie.slice(0,-1)+"\\"+ie.charCodeAt(ie.length-1).toString(16)+" ":"\\"+ie},od=function(){Te()},Ym=Ys(function(ie){return ie.disabled===!0&&ie.nodeName.toLowerCase()==="fieldset"},{dir:"parentNode",next:"legend"});try{Gr.apply(_0=rd.call(wt.childNodes),wt.childNodes),_0[wt.childNodes.length].nodeType}catch{Gr={apply:_0.length?function(be,je){V0.apply(be,rd.call(je))}:function(be,je){for(var $e=be.length,De=0;be[$e++]=je[De++];);be.length=$e-1}}}function Ot(ie,be,je,$e){var De,Ne,We,Ye,Qe,ht,dt,pt=be&&be.ownerDocument,Ct=be?be.nodeType:9;if(je=je||[],typeof ie!="string"||!ie||Ct!==1&&Ct!==9&&Ct!==11)return je;if(!$e&&(Te(be),be=be||Oe,yt)){if(Ct!==11&&(Qe=Km.exec(ie)))if(De=Qe[1]){if(Ct===9)if(We=be.getElementById(De)){if(We.id===De)return je.push(We),je}else return je;else if(pt&&(We=pt.getElementById(De))&&B0(be,We)&&We.id===De)return je.push(We),je}else{if(Qe[2])return Gr.apply(je,be.getElementsByTagName(ie)),je;if((De=Qe[3])&&$.getElementsByClassName&&be.getElementsByClassName)return Gr.apply(je,be.getElementsByClassName(De)),je}if($.qsa&&!I0[ie+" "]&&(!at||!at.test(ie))&&(Ct!==1||be.nodeName.toLowerCase()!=="object")){if(dt=ie,pt=be,Ct===1&&(Hm.test(ie)||ud.test(ie))){for(pt=Ko.test(ie)&&Jo(be.parentNode)||be,(pt!==be||!$.scope)&&((Ye=be.getAttribute("id"))?Ye=Ye.replace(sd,nd):be.setAttribute("id",Ye=Lt)),ht=te(ie),Ne=ht.length;Ne--;)ht[Ne]=(Ye?"#"+Ye:":scope")+" "+Ks(ht[Ne]);dt=ht.join(",")}try{return Gr.apply(je,pt.querySelectorAll(dt)),je}catch{I0(ie,!0)}finally{Ye===Lt&&be.removeAttribute("id")}}}return Ce(ie.replace(zs,"$1"),be,je,$e)}function Gs(){var ie=[];function be(je,$e){return ie.push(je+" ")>H.cacheLength&&delete be[ie.shift()],be[je+" "]=$e}return be}function ur(ie){return ie[Lt]=!0,ie}function sr(ie){var be=Oe.createElement("fieldset");try{return!!ie(be)}catch{return!1}finally{be.parentNode&&be.parentNode.removeChild(be),be=null}}function Yo(ie,be){for(var je=ie.split("|"),$e=je.length;$e--;)H.attrHandle[je[$e]]=be}function ad(ie,be){var je=be&&ie,$e=je&&ie.nodeType===1&&be.nodeType===1&&ie.sourceIndex-be.sourceIndex;if($e)return $e;if(je){for(;je=je.nextSibling;)if(je===be)return-1}return ie?1:-1}function Jm(ie){return function(be){var je=be.nodeName.toLowerCase();return je==="input"&&be.type===ie}}function Qm(ie){return function(be){var je=be.nodeName.toLowerCase();return(je==="input"||je==="button")&&be.type===ie}}function cd(ie){return function(be){return"form"in be?be.parentNode&&be.disabled===!1?"label"in be?"label"in be.parentNode?be.parentNode.disabled===ie:be.disabled===ie:be.isDisabled===ie||be.isDisabled!==!ie&&Ym(be)===ie:be.disabled===ie:"label"in be?be.disabled===ie:!1}}function xi(ie){return ur(function(be){return be=+be,ur(function(je,$e){for(var De,Ne=ie([],je.length,be),We=Ne.length;We--;)je[De=Ne[We]]&&(je[De]=!($e[De]=je[De]))})})}function Jo(ie){return ie&&typeof ie.getElementsByTagName<"u"&&ie}$=Ot.support={},X=Ot.isXML=function(ie){var be=ie.namespaceURI,je=(ie.ownerDocument||ie).documentElement;return!zm.test(be||je&&je.nodeName||"HTML")},Te=Ot.setDocument=function(ie){var be,je,$e=ie?ie.ownerDocument||ie:wt;return $e==Oe||$e.nodeType!==9||!$e.documentElement||(Oe=$e,ot=Oe.documentElement,yt=!X(Oe),wt!=Oe&&(je=Oe.defaultView)&&je.top!==je&&(je.addEventListener?je.addEventListener("unload",od,!1):je.attachEvent&&je.attachEvent("onunload",od)),$.scope=sr(function(De){return ot.appendChild(De).appendChild(Oe.createElement("div")),typeof De.querySelectorAll<"u"&&!De.querySelectorAll(":scope fieldset div").length}),$.attributes=sr(function(De){return De.className="i",!De.getAttribute("className")}),$.getElementsByTagName=sr(function(De){return De.appendChild(Oe.createComment("")),!De.getElementsByTagName("*").length}),$.getElementsByClassName=Yu.test(Oe.getElementsByClassName),$.getById=sr(function(De){return ot.appendChild(De).id=Lt,!Oe.getElementsByName||!Oe.getElementsByName(Lt).length}),$.getById?(H.filter.ID=function(De){var Ne=De.replace(Pr,Lr);return function(We){return We.getAttribute("id")===Ne}},H.find.ID=function(De,Ne){if(typeof Ne.getElementById<"u"&&yt){var We=Ne.getElementById(De);return We?[We]:[]}}):(H.filter.ID=function(De){var Ne=De.replace(Pr,Lr);return function(We){var Ye=typeof We.getAttributeNode<"u"&&We.getAttributeNode("id");return Ye&&Ye.value===Ne}},H.find.ID=function(De,Ne){if(typeof Ne.getElementById<"u"&&yt){var We,Ye,Qe,ht=Ne.getElementById(De);if(ht){if(We=ht.getAttributeNode("id"),We&&We.value===De)return[ht];for(Qe=Ne.getElementsByName(De),Ye=0;ht=Qe[Ye++];)if(We=ht.getAttributeNode("id"),We&&We.value===De)return[ht]}return[]}}),H.find.TAG=$.getElementsByTagName?function(De,Ne){if(typeof Ne.getElementsByTagName<"u")return Ne.getElementsByTagName(De);if($.qsa)return Ne.querySelectorAll(De)}:function(De,Ne){var We,Ye=[],Qe=0,ht=Ne.getElementsByTagName(De);if(De==="*"){for(;We=ht[Qe++];)We.nodeType===1&&Ye.push(We);return Ye}return ht},H.find.CLASS=$.getElementsByClassName&&function(De,Ne){if(typeof Ne.getElementsByClassName<"u"&&yt)return Ne.getElementsByClassName(De)},o0=[],at=[],($.qsa=Yu.test(Oe.querySelectorAll))&&(sr(function(De){var Ne;ot.appendChild(De).innerHTML="<a id='"+Lt+"'></a><select id='"+Lt+"-\r\\' msallowcapture=''><option selected=''></option></select>",De.querySelectorAll("[msallowcapture^='']").length&&at.push("[*^$]="+Tt+`*(?:''|"")`),De.querySelectorAll("[selected]").length||at.push("\\["+Tt+"*(?:value|"+Vo+")"),De.querySelectorAll("[id~="+Lt+"-]").length||at.push("~="),Ne=Oe.createElement("input"),Ne.setAttribute("name",""),De.appendChild(Ne),De.querySelectorAll("[name='']").length||at.push("\\["+Tt+"*name"+Tt+"*="+Tt+`*(?:''|"")`),De.querySelectorAll(":checked").length||at.push(":checked"),De.querySelectorAll("a#"+Lt+"+*").length||at.push(".#.+[+~]"),De.querySelectorAll("\\\f"),at.push("[\\r\\n\\f]")}),sr(function(De){De.innerHTML="<a href='' disabled='disabled'></a><select disabled='disabled'><option/></select>";var Ne=Oe.createElement("input");Ne.setAttribute("type","hidden"),De.appendChild(Ne).setAttribute("name","D"),De.querySelectorAll("[name=d]").length&&at.push("name"+Tt+"*[*^$|!~]?="),De.querySelectorAll(":enabled").length!==2&&at.push(":enabled",":disabled"),ot.appendChild(De).disabled=!0,De.querySelectorAll(":disabled").length!==2&&at.push(":enabled",":disabled"),De.querySelectorAll("*,:x"),at.push(",.*:")})),($.matchesSelector=Yu.test(i0=ot.matches||ot.webkitMatchesSelector||ot.mozMatchesSelector||ot.oMatchesSelector||ot.msMatchesSelector))&&sr(function(De){$.disconnectedMatch=i0.call(De,"*"),i0.call(De,"[s!='']:x"),o0.push("!=",Go)}),at=at.length&&new RegExp(at.join("|")),o0=o0.length&&new RegExp(o0.join("|")),be=Yu.test(ot.compareDocumentPosition),B0=be||Yu.test(ot.contains)?function(De,Ne){var We=De.nodeType===9?De.documentElement:De,Ye=Ne&&Ne.parentNode;return De===Ye||!!(Ye&&Ye.nodeType===1&&(We.contains?We.contains(Ye):De.compareDocumentPosition&&De.compareDocumentPosition(Ye)&16))}:function(De,Ne){if(Ne){for(;Ne=Ne.parentNode;)if(Ne===De)return!0}return!1},yi=be?function(De,Ne){if(De===Ne)return qe=!0,0;var We=!De.compareDocumentPosition-!Ne.compareDocumentPosition;return We||(We=(De.ownerDocument||De)==(Ne.ownerDocument||Ne)?De.compareDocumentPosition(Ne):1,We&1||!$.sortDetached&&Ne.compareDocumentPosition(De)===We?De==Oe||De.ownerDocument==wt&&B0(wt,De)?-1:Ne==Oe||Ne.ownerDocument==wt&&B0(wt,Ne)?1:Re?Ei(Re,De)-Ei(Re,Ne):0:We&4?-1:1)}:function(De,Ne){if(De===Ne)return qe=!0,0;var We,Ye=0,Qe=De.parentNode,ht=Ne.parentNode,dt=[De],pt=[Ne];if(!Qe||!ht)return De==Oe?-1:Ne==Oe?1:Qe?-1:ht?1:Re?Ei(Re,De)-Ei(Re,Ne):0;if(Qe===ht)return ad(De,Ne);for(We=De;We=We.parentNode;)dt.unshift(We);for(We=Ne;We=We.parentNode;)pt.unshift(We);for(;dt[Ye]===pt[Ye];)Ye++;return Ye?ad(dt[Ye],pt[Ye]):dt[Ye]==wt?-1:pt[Ye]==wt?1:0}),Oe},Ot.matches=function(ie,be){return Ot(ie,null,null,be)},Ot.matchesSelector=function(ie,be){if(Te(ie),$.matchesSelector&&yt&&!I0[be+" "]&&(!o0||!o0.test(be))&&(!at||!at.test(be)))try{var je=i0.call(ie,be);if(je||$.disconnectedMatch||ie.document&&ie.document.nodeType!==11)return je}catch{I0(be,!0)}return Ot(be,Oe,null,[ie]).length>0},Ot.contains=function(ie,be){return(ie.ownerDocument||ie)!=Oe&&Te(ie),B0(ie,be)},Ot.attr=function(ie,be){(ie.ownerDocument||ie)!=Oe&&Te(ie);var je=H.attrHandle[be.toLowerCase()],$e=je&&Ci.call(H.attrHandle,be.toLowerCase())?je(ie,be,!yt):void 0;return $e!==void 0?$e:$.attributes||!yt?ie.getAttribute(be):($e=ie.getAttributeNode(be))&&$e.specified?$e.value:null},Ot.escape=function(ie){return(ie+"").replace(sd,nd)},Ot.error=function(ie){throw new Error("Syntax error, unrecognized expression: "+ie)},Ot.uniqueSort=function(ie){var be,je=[],$e=0,De=0;if(qe=!$.detectDuplicates,Re=!$.sortStable&&ie.slice(0),ie.sort(yi),qe){for(;be=ie[De++];)be===ie[De]&&($e=je.push(De));for(;$e--;)ie.splice(je[$e],1)}return Re=null,ie},J=Ot.getText=function(ie){var be,je="",$e=0,De=ie.nodeType;if(De){if(De===1||De===9||De===11){if(typeof ie.textContent=="string")return ie.textContent;for(ie=ie.firstChild;ie;ie=ie.nextSibling)je+=J(ie)}else if(De===3||De===4)return ie.nodeValue}else for(;be=ie[$e++];)je+=J(be);return je},H=Ot.selectors={cacheLength:50,createPseudo:ur,match:Vs,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(ie){return ie[1]=ie[1].replace(Pr,Lr),ie[3]=(ie[3]||ie[4]||ie[5]||"").replace(Pr,Lr),ie[2]==="~="&&(ie[3]=" "+ie[3]+" "),ie.slice(0,4)},CHILD:function(ie){return ie[1]=ie[1].toLowerCase(),ie[1].slice(0,3)==="nth"?(ie[3]||Ot.error(ie[0]),ie[4]=+(ie[4]?ie[5]+(ie[6]||1):2*(ie[3]==="even"||ie[3]==="odd")),ie[5]=+(ie[7]+ie[8]||ie[3]==="odd")):ie[3]&&Ot.error(ie[0]),ie},PSEUDO:function(ie){var be,je=!ie[6]&&ie[2];return Vs.CHILD.test(ie[0])?null:(ie[3]?ie[2]=ie[4]||ie[5]||"":je&&Um.test(je)&&(be=te(je,!0))&&(be=je.indexOf(")",je.length-be)-je.length)&&(ie[0]=ie[0].slice(0,be),ie[2]=je.slice(0,be)),ie.slice(0,3))}},filter:{TAG:function(ie){var be=ie.replace(Pr,Lr).toLowerCase();return ie==="*"?function(){return!0}:function(je){return je.nodeName&&je.nodeName.toLowerCase()===be}},CLASS:function(ie){var be=Yt[ie+" "];return be||(be=new RegExp("(^|"+Tt+")"+ie+"("+Tt+"|$)"))&&Yt(ie,function(je){return be.test(typeof je.className=="string"&&je.className||typeof je.getAttribute<"u"&&je.getAttribute("class")||"")})},ATTR:function(ie,be,je){return function($e){var De=Ot.attr($e,ie);return De==null?be==="!=":be?(De+="",be==="="?De===je:be==="!="?De!==je:be==="^="?je&&De.indexOf(je)===0:be==="*="?je&&De.indexOf(je)>-1:be==="$="?je&&De.slice(-je.length)===je:be==="~="?(" "+De.replace(Nm," ")+" ").indexOf(je)>-1:be==="|="?De===je||De.slice(0,je.length+1)===je+"-":!1):!0}},CHILD:function(ie,be,je,$e,De){var Ne=ie.slice(0,3)!=="nth",We=ie.slice(-4)!=="last",Ye=be==="of-type";return $e===1&&De===0?function(Qe){return!!Qe.parentNode}:function(Qe,ht,dt){var pt,Ct,$t,gt,a0,m0,O0=Ne!==We?"nextSibling":"previousSibling",Gt=Qe.parentNode,Ju=Ye&&Qe.nodeName.toLowerCase(),Qu=!dt&&!Ye,$0=!1;if(Gt){if(Ne){for(;O0;){for(gt=Qe;gt=gt[O0];)if(Ye?gt.nodeName.toLowerCase()===Ju:gt.nodeType===1)return!1;m0=O0=ie==="only"&&!m0&&"nextSibling"}return!0}if(m0=[We?Gt.firstChild:Gt.lastChild],We&&Qu){for(gt=Gt,$t=gt[Lt]||(gt[Lt]={}),Ct=$t[gt.uniqueID]||($t[gt.uniqueID]={}),pt=Ct[ie]||[],a0=pt[0]===S0&&pt[1],$0=a0&&pt[2],gt=a0&&Gt.childNodes[a0];gt=++a0&&gt&&gt[O0]||($0=a0=0)||m0.pop();)if(gt.nodeType===1&&++$0&&gt===Qe){Ct[ie]=[S0,a0,$0];break}}else if(Qu&&(gt=Qe,$t=gt[Lt]||(gt[Lt]={}),Ct=$t[gt.uniqueID]||($t[gt.uniqueID]={}),pt=Ct[ie]||[],a0=pt[0]===S0&&pt[1],$0=a0),$0===!1)for(;(gt=++a0&&gt&&gt[O0]||($0=a0=0)||m0.pop())&&!((Ye?gt.nodeName.toLowerCase()===Ju:gt.nodeType===1)&&++$0&&(Qu&&($t=gt[Lt]||(gt[Lt]={}),Ct=$t[gt.uniqueID]||($t[gt.uniqueID]={}),Ct[ie]=[S0,$0]),gt===Qe)););return $0-=De,$0===$e||$0%$e===0&&$0/$e>=0}}},PSEUDO:function(ie,be){var je,$e=H.pseudos[ie]||H.setFilters[ie.toLowerCase()]||Ot.error("unsupported pseudo: "+ie);return $e[Lt]?$e(be):$e.length>1?(je=[ie,ie,"",be],H.setFilters.hasOwnProperty(ie.toLowerCase())?ur(function(De,Ne){for(var We,Ye=$e(De,be),Qe=Ye.length;Qe--;)We=Ei(De,Ye[Qe]),De[We]=!(Ne[We]=Ye[Qe])}):function(De){return $e(De,0,je)}):$e}},pseudos:{not:ur(function(ie){var be=[],je=[],$e=we(ie.replace(zs,"$1"));return $e[Lt]?ur(function(De,Ne,We,Ye){for(var Qe,ht=$e(De,null,Ye,[]),dt=De.length;dt--;)(Qe=ht[dt])&&(De[dt]=!(Ne[dt]=Qe))}):function(De,Ne,We){return be[0]=De,$e(be,null,We,je),be[0]=null,!je.pop()}}),has:ur(function(ie){return function(be){return Ot(ie,be).length>0}}),contains:ur(function(ie){return ie=ie.replace(Pr,Lr),function(be){return(be.textContent||J(be)).indexOf(ie)>-1}}),lang:ur(function(ie){return qm.test(ie||"")||Ot.error("unsupported lang: "+ie),ie=ie.replace(Pr,Lr).toLowerCase(),function(be){var je;do if(je=yt?be.lang:be.getAttribute("xml:lang")||be.getAttribute("lang"))return je=je.toLowerCase(),je===ie||je.indexOf(ie+"-")===0;while((be=be.parentNode)&&be.nodeType===1);return!1}}),target:function(ie){var be=y.location&&y.location.hash;return be&&be.slice(1)===ie.id},root:function(ie){return ie===ot},focus:function(ie){return ie===Oe.activeElement&&(!Oe.hasFocus||Oe.hasFocus())&&!!(ie.type||ie.href||~ie.tabIndex)},enabled:cd(!1),disabled:cd(!0),checked:function(ie){var be=ie.nodeName.toLowerCase();return be==="input"&&!!ie.checked||be==="option"&&!!ie.selected},selected:function(ie){return ie.parentNode&&ie.parentNode.selectedIndex,ie.selected===!0},empty:function(ie){for(ie=ie.firstChild;ie;ie=ie.nextSibling)if(ie.nodeType<6)return!1;return!0},parent:function(ie){return!H.pseudos.empty(ie)},header:function(ie){return Gm.test(ie.nodeName)},input:function(ie){return Vm.test(ie.nodeName)},button:function(ie){var be=ie.nodeName.toLowerCase();return be==="input"&&ie.type==="button"||be==="button"},text:function(ie){var be;return ie.nodeName.toLowerCase()==="input"&&ie.type==="text"&&((be=ie.getAttribute("type"))==null||be.toLowerCase()==="text")},first:xi(function(){return[0]}),last:xi(function(ie,be){return[be-1]}),eq:xi(function(ie,be,je){return[je<0?je+be:je]}),even:xi(function(ie,be){for(var je=0;je<be;je+=2)ie.push(je);return ie}),odd:xi(function(ie,be){for(var je=1;je<be;je+=2)ie.push(je);return ie}),lt:xi(function(ie,be,je){for(var $e=je<0?je+be:je>be?be:je;--$e>=0;)ie.push($e);return ie}),gt:xi(function(ie,be,je){for(var $e=je<0?je+be:je;++$e<be;)ie.push($e);return ie})}},H.pseudos.nth=H.pseudos.eq;for(D in{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})H.pseudos[D]=Jm(D);for(D in{submit:!0,reset:!0})H.pseudos[D]=Qm(D);function ld(){}ld.prototype=H.filters=H.pseudos,H.setFilters=new ld,te=Ot.tokenize=function(ie,be){var je,$e,De,Ne,We,Ye,Qe,ht=Ku[ie+" "];if(ht)return be?0:ht.slice(0);for(We=ie,Ye=[],Qe=H.preFilter;We;){(!je||($e=Wm.exec(We)))&&($e&&(We=We.slice($e[0].length)||We),Ye.push(De=[])),je=!1,($e=ud.exec(We))&&(je=$e.shift(),De.push({value:je,type:$e[0].replace(zs," ")}),We=We.slice(je.length));for(Ne in H.filter)($e=Vs[Ne].exec(We))&&(!Qe[Ne]||($e=Qe[Ne]($e)))&&(je=$e.shift(),De.push({value:je,type:Ne,matches:$e}),We=We.slice(je.length));if(!je)break}return be?We.length:We?Ot.error(ie):Ku(ie,Ye).slice(0)};function Ks(ie){for(var be=0,je=ie.length,$e="";be<je;be++)$e+=ie[be].value;return $e}function Ys(ie,be,je){var $e=be.dir,De=be.next,Ne=De||$e,We=je&&Ne==="parentNode",Ye=Mt++;return be.first?function(Qe,ht,dt){for(;Qe=Qe[$e];)if(Qe.nodeType===1||We)return ie(Qe,ht,dt);return!1}:function(Qe,ht,dt){var pt,Ct,$t,gt=[S0,Ye];if(dt){for(;Qe=Qe[$e];)if((Qe.nodeType===1||We)&&ie(Qe,ht,dt))return!0}else for(;Qe=Qe[$e];)if(Qe.nodeType===1||We)if($t=Qe[Lt]||(Qe[Lt]={}),Ct=$t[Qe.uniqueID]||($t[Qe.uniqueID]={}),De&&De===Qe.nodeName.toLowerCase())Qe=Qe[$e]||Qe;else{if((pt=Ct[Ne])&&pt[0]===S0&&pt[1]===Ye)return gt[2]=pt[2];if(Ct[Ne]=gt,gt[2]=ie(Qe,ht,dt))return!0}return!1}}function Qo(ie){return ie.length>1?function(be,je,$e){for(var De=ie.length;De--;)if(!ie[De](be,je,$e))return!1;return!0}:ie[0]}function Xm(ie,be,je){for(var $e=0,De=be.length;$e<De;$e++)Ot(ie,be[$e],je);return je}function Js(ie,be,je,$e,De){for(var Ne,We=[],Ye=0,Qe=ie.length,ht=be!=null;Ye<Qe;Ye++)(Ne=ie[Ye])&&(!je||je(Ne,$e,De))&&(We.push(Ne),ht&&be.push(Ye));return We}function Xo(ie,be,je,$e,De,Ne){return $e&&!$e[Lt]&&($e=Xo($e)),De&&!De[Lt]&&(De=Xo(De,Ne)),ur(function(We,Ye,Qe,ht){var dt,pt,Ct,$t=[],gt=[],a0=Ye.length,m0=We||Xm(be||"*",Qe.nodeType?[Qe]:Qe,[]),O0=ie&&(We||!be)?Js(m0,$t,ie,Qe,ht):m0,Gt=je?De||(We?ie:a0||$e)?[]:Ye:O0;if(je&&je(O0,Gt,Qe,ht),$e)for(dt=Js(Gt,gt),$e(dt,[],Qe,ht),pt=dt.length;pt--;)(Ct=dt[pt])&&(Gt[gt[pt]]=!(O0[gt[pt]]=Ct));if(We){if(De||ie){if(De){for(dt=[],pt=Gt.length;pt--;)(Ct=Gt[pt])&&dt.push(O0[pt]=Ct);De(null,Gt=[],dt,ht)}for(pt=Gt.length;pt--;)(Ct=Gt[pt])&&(dt=De?Ei(We,Ct):$t[pt])>-1&&(We[dt]=!(Ye[dt]=Ct))}}else Gt=Js(Gt===Ye?Gt.splice(a0,Gt.length):Gt),De?De(null,Ye,Gt,ht):Gr.apply(Ye,Gt)})}function Zo(ie){for(var be,je,$e,De=ie.length,Ne=H.relative[ie[0].type],We=Ne||H.relative[" "],Ye=Ne?1:0,Qe=Ys(function(pt){return pt===be},We,!0),ht=Ys(function(pt){return Ei(be,pt)>-1},We,!0),dt=[function(pt,Ct,$t){var gt=!Ne&&($t||Ct!==_e)||((be=Ct).nodeType?Qe(pt,Ct,$t):ht(pt,Ct,$t));return be=null,gt}];Ye<De;Ye++)if(je=H.relative[ie[Ye].type])dt=[Ys(Qo(dt),je)];else{if(je=H.filter[ie[Ye].type].apply(null,ie[Ye].matches),je[Lt]){for($e=++Ye;$e<De&&!H.relative[ie[$e].type];$e++);return Xo(Ye>1&&Qo(dt),Ye>1&&Ks(ie.slice(0,Ye-1).concat({value:ie[Ye-2].type===" "?"*":""})).replace(zs,"$1"),je,Ye<$e&&Zo(ie.slice(Ye,$e)),$e<De&&Zo(ie=ie.slice($e)),$e<De&&Ks(ie))}dt.push(je)}return Qo(dt)}function Zm(ie,be){var je=be.length>0,$e=ie.length>0,De=function(Ne,We,Ye,Qe,ht){var dt,pt,Ct,$t=0,gt="0",a0=Ne&&[],m0=[],O0=_e,Gt=Ne||$e&&H.find.TAG("*",ht),Ju=S0+=O0==null?1:Math.random()||.1,Qu=Gt.length;for(ht&&(_e=We==Oe||We||ht);gt!==Qu&&(dt=Gt[gt])!=null;gt++){if($e&&dt){for(pt=0,!We&&dt.ownerDocument!=Oe&&(Te(dt),Ye=!yt);Ct=ie[pt++];)if(Ct(dt,We||Oe,Ye)){Qe.push(dt);break}ht&&(S0=Ju)}je&&((dt=!Ct&&dt)&&$t--,Ne&&a0.push(dt))}if($t+=gt,je&&gt!==$t){for(pt=0;Ct=be[pt++];)Ct(a0,m0,We,Ye);if(Ne){if($t>0)for(;gt--;)a0[gt]||m0[gt]||(m0[gt]=Vr.call(Qe));m0=Js(m0)}Gr.apply(Qe,m0),ht&&!Ne&&m0.length>0&&$t+be.length>1&&Ot.uniqueSort(Qe)}return ht&&(S0=Ju,_e=O0),a0};return je?ur(De):De}return we=Ot.compile=function(ie,be){var je,$e=[],De=[],Ne=qs[ie+" "];if(!Ne){for(be||(be=te(ie)),je=be.length;je--;)Ne=Zo(be[je]),Ne[Lt]?$e.push(Ne):De.push(Ne);Ne=qs(ie,Zm(De,$e)),Ne.selector=ie}return Ne},Ce=Ot.select=function(ie,be,je,$e){var De,Ne,We,Ye,Qe,ht=typeof ie=="function"&&ie,dt=!$e&&te(ie=ht.selector||ie);if(je=je||[],dt.length===1){if(Ne=dt[0]=dt[0].slice(0),Ne.length>2&&(We=Ne[0]).type==="ID"&&be.nodeType===9&&yt&&H.relative[Ne[1].type]){if(be=(H.find.ID(We.matches[0].replace(Pr,Lr),be)||[])[0],be)ht&&(be=be.parentNode);else return je;ie=ie.slice(Ne.shift().value.length)}for(De=Vs.needsContext.test(ie)?0:Ne.length;De--&&(We=Ne[De],!H.relative[Ye=We.type]);)if((Qe=H.find[Ye])&&($e=Qe(We.matches[0].replace(Pr,Lr),Ko.test(Ne[0].type)&&Jo(be.parentNode)||be))){if(Ne.splice(De,1),ie=$e.length&&Ks(Ne),!ie)return Gr.apply(je,$e),je;break}}return(ht||we(ie,dt))($e,be,!yt,je,!be||Ko.test(ie)&&Jo(be.parentNode)||be),je},$.sortStable=Lt.split("").sort(yi).join("")===Lt,$.detectDuplicates=!!qe,Te(),$.sortDetached=sr(function(ie){return ie.compareDocumentPosition(Oe.createElement("fieldset"))&1}),sr(function(ie){return ie.innerHTML="<a href='#'></a>",ie.firstChild.getAttribute("href")==="#"})||Yo("type|href|height|width",function(ie,be,je){if(!je)return ie.getAttribute(be,be.toLowerCase()==="type"?1:2)}),(!$.attributes||!sr(function(ie){return ie.innerHTML="<input/>",ie.firstChild.setAttribute("value",""),ie.firstChild.getAttribute("value")===""}))&&Yo("value",function(ie,be,je){if(!je&&ie.nodeName.toLowerCase()==="input")return ie.defaultValue}),sr(function(ie){return ie.getAttribute("disabled")==null})||Yo(Vo,function(ie,be,je){var $e;if(!je)return ie[be]===!0?be.toLowerCase():($e=ie.getAttributeNode(be))&&$e.specified?$e.value:null}),Ot}(e);w.find=M,w.expr=M.selectors,w.expr[":"]=w.expr.pseudos,w.uniqueSort=w.unique=M.uniqueSort,w.text=M.getText,w.isXMLDoc=M.isXML,w.contains=M.contains,w.escapeSelector=M.escape;var x=function(y,D,$){for(var H=[],J=$!==void 0;(y=y[D])&&y.nodeType!==9;)if(y.nodeType===1){if(J&&w(y).is($))break;H.push(y)}return H},R=function(y,D){for(var $=[];y;y=y.nextSibling)y.nodeType===1&&y!==D&&$.push(y);return $},N=w.expr.match.needsContext;function j(y,D){return y.nodeName&&y.nodeName.toLowerCase()===D.toLowerCase()}var B=/^<([a-z][^\/\0>:\x20\t\r\n\f]*)[\x20\t\r\n\f]*\/?>(?:<\/\1>|)$/i;function q(y,D,$){return F(D)?w.grep(y,function(H,J){return!!D.call(H,J,H)!==$}):D.nodeType?w.grep(y,function(H){return H===D!==$}):typeof D!="string"?w.grep(y,function(H){return n.call(D,H)>-1!==$}):w.filter(D,y,$)}w.filter=function(y,D,$){var H=D[0];return $&&(y=":not("+y+")"),D.length===1&&H.nodeType===1?w.find.matchesSelector(H,y)?[H]:[]:w.find.matches(y,w.grep(D,function(J){return J.nodeType===1}))},w.fn.extend({find:function(y){var D,$,H=this.length,J=this;if(typeof y!="string")return this.pushStack(w(y).filter(function(){for(D=0;D<H;D++)if(w.contains(J[D],this))return!0}));for($=this.pushStack([]),D=0;D<H;D++)w.find(y,J[D],$);return H>1?w.uniqueSort($):$},filter:function(y){return this.pushStack(q(this,y||[],!1))},not:function(y){return this.pushStack(q(this,y||[],!0))},is:function(y){return!!q(this,typeof y=="string"&&N.test(y)?w(y):y||[],!1).length}});var U,Z=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]+))$/,re=w.fn.init=function(y,D,$){var H,J;if(!y)return this;if($=$||U,typeof y=="string")if(y[0]==="<"&&y[y.length-1]===">"&&y.length>=3?H=[null,y,null]:H=Z.exec(y),H&&(H[1]||!D))if(H[1]){if(D=D instanceof w?D[0]:D,w.merge(this,w.parseHTML(H[1],D&&D.nodeType?D.ownerDocument||D:m,!0)),B.test(H[1])&&w.isPlainObject(D))for(H in D)F(this[H])?this[H](D[H]):this.attr(H,D[H]);return this}else return J=m.getElementById(H[2]),J&&(this[0]=J,this.length=1),this;else return!D||D.jquery?(D||$).find(y):this.constructor(D).find(y);else{if(y.nodeType)return this[0]=y,this.length=1,this;if(F(y))return $.ready!==void 0?$.ready(y):y(w)}return w.makeArray(y,this)};re.prototype=w.fn,U=w(m);var le=/^(?:parents|prev(?:Until|All))/,ce={children:!0,contents:!0,next:!0,prev:!0};w.fn.extend({has:function(y){var D=w(y,this),$=D.length;return this.filter(function(){for(var H=0;H<$;H++)if(w.contains(this,D[H]))return!0})},closest:function(y,D){var $,H=0,J=this.length,X=[],te=typeof y!="string"&&w(y);if(!N.test(y)){for(;H<J;H++)for($=this[H];$&&$!==D;$=$.parentNode)if($.nodeType<11&&(te?te.index($)>-1:$.nodeType===1&&w.find.matchesSelector($,y))){X.push($);break}}return this.pushStack(X.length>1?w.uniqueSort(X):X)},index:function(y){return y?typeof y=="string"?n.call(w(y),this[0]):n.call(this,y.jquery?y[0]:y):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(y,D){return this.pushStack(w.uniqueSort(w.merge(this.get(),w(y,D))))},addBack:function(y){return this.add(y==null?this.prevObject:this.prevObject.filter(y))}});function de(y,D){for(;(y=y[D])&&y.nodeType!==1;);return y}w.each({parent:function(y){var D=y.parentNode;return D&&D.nodeType!==11?D:null},parents:function(y){return x(y,"parentNode")},parentsUntil:function(y,D,$){return x(y,"parentNode",$)},next:function(y){return de(y,"nextSibling")},prev:function(y){return de(y,"previousSibling")},nextAll:function(y){return x(y,"nextSibling")},prevAll:function(y){return x(y,"previousSibling")},nextUntil:function(y,D,$){return x(y,"nextSibling",$)},prevUntil:function(y,D,$){return x(y,"previousSibling",$)},siblings:function(y){return R((y.parentNode||{}).firstChild,y)},children:function(y){return R(y.firstChild)},contents:function(y){return y.contentDocument!=null&&i(y.contentDocument)?y.contentDocument:(j(y,"template")&&(y=y.content||y),w.merge([],y.childNodes))}},function(y,D){w.fn[y]=function($,H){var J=w.map(this,D,$);return y.slice(-5)!=="Until"&&(H=$),H&&typeof H=="string"&&(J=w.filter(H,J)),this.length>1&&(ce[y]||w.uniqueSort(J),le.test(y)&&J.reverse()),this.pushStack(J)}});var he=/[^\x20\t\r\n\f]+/g;function Fe(y){var D={};return w.each(y.match(he)||[],function($,H){D[H]=!0}),D}w.Callbacks=function(y){y=typeof y=="string"?Fe(y):w.extend({},y);var D,$,H,J,X=[],te=[],we=-1,Ce=function(){for(J=J||y.once,H=D=!0;te.length;we=-1)for($=te.shift();++we<X.length;)X[we].apply($[0],$[1])===!1&&y.stopOnFalse&&(we=X.length,$=!1);y.memory||($=!1),D=!1,J&&($?X=[]:X="")},_e={add:function(){return X&&($&&!D&&(we=X.length-1,te.push($)),function Re(qe){w.each(qe,function(Te,Oe){F(Oe)?(!y.unique||!_e.has(Oe))&&X.push(Oe):Oe&&Oe.length&&k(Oe)!=="string"&&Re(Oe)})}(arguments),$&&!D&&Ce()),this},remove:function(){return w.each(arguments,function(Re,qe){for(var Te;(Te=w.inArray(qe,X,Te))>-1;)X.splice(Te,1),Te<=we&&we--}),this},has:function(Re){return Re?w.inArray(Re,X)>-1:X.length>0},empty:function(){return X&&(X=[]),this},disable:function(){return J=te=[],X=$="",this},disabled:function(){return!X},lock:function(){return J=te=[],!$&&!D&&(X=$=""),this},locked:function(){return!!J},fireWith:function(Re,qe){return J||(qe=qe||[],qe=[Re,qe.slice?qe.slice():qe],te.push(qe),D||Ce()),this},fire:function(){return _e.fireWith(this,arguments),this},fired:function(){return!!H}};return _e};function ge(y){return y}function ye(y){throw y}function Y(y,D,$,H){var J;try{y&&F(J=y.promise)?J.call(y).done(D).fail($):y&&F(J=y.then)?J.call(y,D,$):D.apply(void 0,[y].slice(H))}catch(X){$.apply(void 0,[X])}}w.extend({Deferred:function(y){var D=[["notify","progress",w.Callbacks("memory"),w.Callbacks("memory"),2],["resolve","done",w.Callbacks("once memory"),w.Callbacks("once memory"),0,"resolved"],["reject","fail",w.Callbacks("once memory"),w.Callbacks("once memory"),1,"rejected"]],$="pending",H={state:function(){return $},always:function(){return J.done(arguments).fail(arguments),this},catch:function(X){return H.then(null,X)},pipe:function(){var X=arguments;return w.Deferred(function(te){w.each(D,function(we,Ce){var _e=F(X[Ce[4]])&&X[Ce[4]];J[Ce[1]](function(){var Re=_e&&_e.apply(this,arguments);Re&&F(Re.promise)?Re.promise().progress(te.notify).done(te.resolve).fail(te.reject):te[Ce[0]+"With"](this,_e?[Re]:arguments)})}),X=null}).promise()},then:function(X,te,we){var Ce=0;function _e(Re,qe,Te,Oe){return function(){var ot=this,yt=arguments,at=function(){var i0,B0;if(!(Re<Ce)){if(i0=Te.apply(ot,yt),i0===qe.promise())throw new TypeError("Thenable self-resolution");B0=i0&&(typeof i0=="object"||typeof i0=="function")&&i0.then,F(B0)?Oe?B0.call(i0,_e(Ce,qe,ge,Oe),_e(Ce,qe,ye,Oe)):(Ce++,B0.call(i0,_e(Ce,qe,ge,Oe),_e(Ce,qe,ye,Oe),_e(Ce,qe,ge,qe.notifyWith))):(Te!==ge&&(ot=void 0,yt=[i0]),(Oe||qe.resolveWith)(ot,yt))}},o0=Oe?at:function(){try{at()}catch(i0){w.Deferred.exceptionHook&&w.Deferred.exceptionHook(i0,o0.stackTrace),Re+1>=Ce&&(Te!==ye&&(ot=void 0,yt=[i0]),qe.rejectWith(ot,yt))}};Re?o0():(w.Deferred.getStackHook&&(o0.stackTrace=w.Deferred.getStackHook()),e.setTimeout(o0))}}return w.Deferred(function(Re){D[0][3].add(_e(0,Re,F(we)?we:ge,Re.notifyWith)),D[1][3].add(_e(0,Re,F(X)?X:ge)),D[2][3].add(_e(0,Re,F(te)?te:ye))}).promise()},promise:function(X){return X!=null?w.extend(X,H):H}},J={};return w.each(D,function(X,te){var we=te[2],Ce=te[5];H[te[1]]=we.add,Ce&&we.add(function(){$=Ce},D[3-X][2].disable,D[3-X][3].disable,D[0][2].lock,D[0][3].lock),we.add(te[3].fire),J[te[0]]=function(){return J[te[0]+"With"](this===J?void 0:this,arguments),this},J[te[0]+"With"]=we.fireWith}),H.promise(J),y&&y.call(J,J),J},when:function(y){var D=arguments.length,$=D,H=Array($),J=s.call(arguments),X=w.Deferred(),te=function(we){return function(Ce){H[we]=this,J[we]=arguments.length>1?s.call(arguments):Ce,--D||X.resolveWith(H,J)}};if(D<=1&&(Y(y,X.done(te($)).resolve,X.reject,!D),X.state()==="pending"||F(J[$]&&J[$].then)))return X.then();for(;$--;)Y(J[$],te($),X.reject);return X.promise()}});var ue=/^(Eval|Internal|Range|Reference|Syntax|Type|URI)Error$/;w.Deferred.exceptionHook=function(y,D){e.console&&e.console.warn&&y&&ue.test(y.name)&&e.console.warn("jQuery.Deferred exception: "+y.message,y.stack,D)},w.readyException=function(y){e.setTimeout(function(){throw y})};var Ee=w.Deferred();w.fn.ready=function(y){return Ee.then(y).catch(function(D){w.readyException(D)}),this},w.extend({isReady:!1,readyWait:1,ready:function(y){(y===!0?--w.readyWait:w.isReady)||(w.isReady=!0,!(y!==!0&&--w.readyWait>0)&&Ee.resolveWith(m,[w]))}}),w.ready.then=Ee.then;function ne(){m.removeEventListener("DOMContentLoaded",ne),e.removeEventListener("load",ne),w.ready()}m.readyState==="complete"||m.readyState!=="loading"&&!m.documentElement.doScroll?e.setTimeout(w.ready):(m.addEventListener("DOMContentLoaded",ne),e.addEventListener("load",ne));var me=function(y,D,$,H,J,X,te){var we=0,Ce=y.length,_e=$==null;if(k($)==="object"){J=!0;for(we in $)me(y,D,we,$[we],!0,X,te)}else if(H!==void 0&&(J=!0,F(H)||(te=!0),_e&&(te?(D.call(y,H),D=null):(_e=D,D=function(Re,qe,Te){return _e.call(w(Re),Te)})),D))for(;we<Ce;we++)D(y[we],$,te?H:H.call(y[we],we,D(y[we],$)));return J?y:_e?D.call(y):Ce?D(y[0],$):X},se=/^-ms-/,ve=/-([a-z])/g;function Pe(y,D){return D.toUpperCase()}function Ie(y){return y.replace(se,"ms-").replace(ve,Pe)}var z=function(y){return y.nodeType===1||y.nodeType===9||!+y.nodeType};function G(){this.expando=w.expando+G.uid++}G.uid=1,G.prototype={cache:function(y){var D=y[this.expando];return D||(D={},z(y)&&(y.nodeType?y[this.expando]=D:Object.defineProperty(y,this.expando,{value:D,configurable:!0}))),D},set:function(y,D,$){var H,J=this.cache(y);if(typeof D=="string")J[Ie(D)]=$;else for(H in D)J[Ie(H)]=D[H];return J},get:function(y,D){return D===void 0?this.cache(y):y[this.expando]&&y[this.expando][Ie(D)]},access:function(y,D,$){return D===void 0||D&&typeof D=="string"&&$===void 0?this.get(y,D):(this.set(y,D,$),$!==void 0?$:D)},remove:function(y,D){var $,H=y[this.expando];if(H!==void 0){if(D!==void 0)for(Array.isArray(D)?D=D.map(Ie):(D=Ie(D),D=D in H?[D]:D.match(he)||[]),$=D.length;$--;)delete H[D[$]];(D===void 0||w.isEmptyObject(H))&&(y.nodeType?y[this.expando]=void 0:delete y[this.expando])}},hasData:function(y){var D=y[this.expando];return D!==void 0&&!w.isEmptyObject(D)}};var O=new G,I=new G,v=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,E=/[A-Z]/g;function L(y){return y==="true"?!0:y==="false"?!1:y==="null"?null:y===+y+""?+y:v.test(y)?JSON.parse(y):y}function S(y,D,$){var H;if($===void 0&&y.nodeType===1)if(H="data-"+D.replace(E,"-$&").toLowerCase(),$=y.getAttribute(H),typeof $=="string"){try{$=L($)}catch{}I.set(y,D,$)}else $=void 0;return $}w.extend({hasData:function(y){return I.hasData(y)||O.hasData(y)},data:function(y,D,$){return I.access(y,D,$)},removeData:function(y,D){I.remove(y,D)},_data:function(y,D,$){return O.access(y,D,$)},_removeData:function(y,D){O.remove(y,D)}}),w.fn.extend({data:function(y,D){var $,H,J,X=this[0],te=X&&X.attributes;if(y===void 0){if(this.length&&(J=I.get(X),X.nodeType===1&&!O.get(X,"hasDataAttrs"))){for($=te.length;$--;)te[$]&&(H=te[$].name,H.indexOf("data-")===0&&(H=Ie(H.slice(5)),S(X,H,J[H])));O.set(X,"hasDataAttrs",!0)}return J}return typeof y=="object"?this.each(function(){I.set(this,y)}):me(this,function(we){var Ce;if(X&&we===void 0)return Ce=I.get(X,y),Ce!==void 0||(Ce=S(X,y),Ce!==void 0)?Ce:void 0;this.each(function(){I.set(this,y,we)})},null,D,arguments.length>1,null,!0)},removeData:function(y){return this.each(function(){I.remove(this,y)})}}),w.extend({queue:function(y,D,$){var H;if(y)return D=(D||"fx")+"queue",H=O.get(y,D),$&&(!H||Array.isArray($)?H=O.access(y,D,w.makeArray($)):H.push($)),H||[]},dequeue:function(y,D){D=D||"fx";var $=w.queue(y,D),H=$.length,J=$.shift(),X=w._queueHooks(y,D),te=function(){w.dequeue(y,D)};J==="inprogress"&&(J=$.shift(),H--),J&&(D==="fx"&&$.unshift("inprogress"),delete X.stop,J.call(y,te,X)),!H&&X&&X.empty.fire()},_queueHooks:function(y,D){var $=D+"queueHooks";return O.get(y,$)||O.access(y,$,{empty:w.Callbacks("once memory").add(function(){O.remove(y,[D+"queue",$])})})}}),w.fn.extend({queue:function(y,D){var $=2;return typeof y!="string"&&(D=y,y="fx",$--),arguments.length<$?w.queue(this[0],y):D===void 0?this:this.each(function(){var H=w.queue(this,y,D);w._queueHooks(this,y),y==="fx"&&H[0]!=="inprogress"&&w.dequeue(this,y)})},dequeue:function(y){return this.each(function(){w.dequeue(this,y)})},clearQueue:function(y){return this.queue(y||"fx",[])},promise:function(y,D){var $,H=1,J=w.Deferred(),X=this,te=this.length,we=function(){--H||J.resolveWith(X,[X])};for(typeof y!="string"&&(D=y,y=void 0),y=y||"fx";te--;)$=O.get(X[te],y+"queueHooks"),$&&$.empty&&(H++,$.empty.add(we));return we(),J.promise(D)}});var P=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,W=new RegExp("^(?:([+-])=|)("+P+")([a-z%]*)$","i"),K=["Top","Right","Bottom","Left"],V=m.documentElement,ee=function(y){return w.contains(y.ownerDocument,y)},Q={composed:!0};V.getRootNode&&(ee=function(y){return w.contains(y.ownerDocument,y)||y.getRootNode(Q)===y.ownerDocument});var fe=function(y,D){return y=D||y,y.style.display==="none"||y.style.display===""&&ee(y)&&w.css(y,"display")==="none"};function oe(y,D,$,H){var J,X,te=20,we=H?function(){return H.cur()}:function(){return w.css(y,D,"")},Ce=we(),_e=$&&$[3]||(w.cssNumber[D]?"":"px"),Re=y.nodeType&&(w.cssNumber[D]||_e!=="px"&&+Ce)&&W.exec(w.css(y,D));if(Re&&Re[3]!==_e){for(Ce=Ce/2,_e=_e||Re[3],Re=+Ce||1;te--;)w.style(y,D,Re+_e),(1-X)*(1-(X=we()/Ce||.5))<=0&&(te=0),Re=Re/X;Re=Re*2,w.style(y,D,Re+_e),$=$||[]}return $&&(Re=+Re||+Ce||0,J=$[1]?Re+($[1]+1)*$[2]:+$[2],H&&(H.unit=_e,H.start=Re,H.end=J)),J}var pe={};function ae(y){var D,$=y.ownerDocument,H=y.nodeName,J=pe[H];return J||(D=$.body.appendChild($.createElement(H)),J=w.css(D,"display"),D.parentNode.removeChild(D),J==="none"&&(J="block"),pe[H]=J,J)}function Ae(y,D){for(var $,H,J=[],X=0,te=y.length;X<te;X++)H=y[X],H.style&&($=H.style.display,D?($==="none"&&(J[X]=O.get(H,"display")||null,J[X]||(H.style.display="")),H.style.display===""&&fe(H)&&(J[X]=ae(H))):$!=="none"&&(J[X]="none",O.set(H,"display",$)));for(X=0;X<te;X++)J[X]!=null&&(y[X].style.display=J[X]);return y}w.fn.extend({show:function(){return Ae(this,!0)},hide:function(){return Ae(this)},toggle:function(y){return typeof y=="boolean"?y?this.show():this.hide():this.each(function(){fe(this)?w(this).show():w(this).hide()})}});var Se=/^(?:checkbox|radio)$/i,ze=/<([a-z][^\/\0>\x20\t\r\n\f]*)/i,Ve=/^$|^module$|\/(?:java|ecma)script/i;(function(){var y=m.createDocumentFragment(),D=y.appendChild(m.createElement("div")),$=m.createElement("input");$.setAttribute("type","radio"),$.setAttribute("checked","checked"),$.setAttribute("name","t"),D.appendChild($),a.checkClone=D.cloneNode(!0).cloneNode(!0).lastChild.checked,D.innerHTML="<textarea>x</textarea>",a.noCloneChecked=!!D.cloneNode(!0).lastChild.defaultValue,D.innerHTML="<option></option>",a.option=!!D.lastChild})();var Me={thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};Me.tbody=Me.tfoot=Me.colgroup=Me.caption=Me.thead,Me.th=Me.td,a.option||(Me.optgroup=Me.option=[1,"<select multiple='multiple'>","</select>"]);function Le(y,D){var $;return typeof y.getElementsByTagName<"u"?$=y.getElementsByTagName(D||"*"):typeof y.querySelectorAll<"u"?$=y.querySelectorAll(D||"*"):$=[],D===void 0||D&&j(y,D)?w.merge([y],$):$}function Be(y,D){for(var $=0,H=y.length;$<H;$++)O.set(y[$],"globalEval",!D||O.get(D[$],"globalEval"))}var Je=/<|&#?\w+;/;function Ue(y,D,$,H,J){for(var X,te,we,Ce,_e,Re,qe=D.createDocumentFragment(),Te=[],Oe=0,ot=y.length;Oe<ot;Oe++)if(X=y[Oe],X||X===0)if(k(X)==="object")w.merge(Te,X.nodeType?[X]:X);else if(!Je.test(X))Te.push(D.createTextNode(X));else{for(te=te||qe.appendChild(D.createElement("div")),we=(ze.exec(X)||["",""])[1].toLowerCase(),Ce=Me[we]||Me._default,te.innerHTML=Ce[1]+w.htmlPrefilter(X)+Ce[2],Re=Ce[0];Re--;)te=te.lastChild;w.merge(Te,te.childNodes),te=qe.firstChild,te.textContent=""}for(qe.textContent="",Oe=0;X=Te[Oe++];){if(H&&w.inArray(X,H)>-1){J&&J.push(X);continue}if(_e=ee(X),te=Le(qe.appendChild(X),"script"),_e&&Be(te),$)for(Re=0;X=te[Re++];)Ve.test(X.type||"")&&$.push(X)}return qe}var Ge=/^key/,lt=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,et=/^([^.]*)(?:\.(.+)|)/;function vt(){return!0}function Ft(){return!1}function bt(y,D){return y===Ht()==(D==="focus")}function Ht(){try{return m.activeElement}catch{}}function kt(y,D,$,H,J,X){var te,we;if(typeof D=="object"){typeof $!="string"&&(H=H||$,$=void 0);for(we in D)kt(y,we,$,H,D[we],X);return y}if(H==null&&J==null?(J=$,H=$=void 0):J==null&&(typeof $=="string"?(J=H,H=void 0):(J=H,H=$,$=void 0)),J===!1)J=Ft;else if(!J)return y;return X===1&&(te=J,J=function(Ce){return w().off(Ce),te.apply(this,arguments)},J.guid=te.guid||(te.guid=w.guid++)),y.each(function(){w.event.add(this,D,J,H,$)})}w.event={global:{},add:function(y,D,$,H,J){var X,te,we,Ce,_e,Re,qe,Te,Oe,ot,yt,at=O.get(y);if(z(y))for($.handler&&(X=$,$=X.handler,J=X.selector),J&&w.find.matchesSelector(V,J),$.guid||($.guid=w.guid++),(Ce=at.events)||(Ce=at.events=Object.create(null)),(te=at.handle)||(te=at.handle=function(o0){return typeof w<"u"&&w.event.triggered!==o0.type?w.event.dispatch.apply(y,arguments):void 0}),D=(D||"").match(he)||[""],_e=D.length;_e--;)we=et.exec(D[_e])||[],Oe=yt=we[1],ot=(we[2]||"").split(".").sort(),Oe&&(qe=w.event.special[Oe]||{},Oe=(J?qe.delegateType:qe.bindType)||Oe,qe=w.event.special[Oe]||{},Re=w.extend({type:Oe,origType:yt,data:H,handler:$,guid:$.guid,selector:J,needsContext:J&&w.expr.match.needsContext.test(J),namespace:ot.join(".")},X),(Te=Ce[Oe])||(Te=Ce[Oe]=[],Te.delegateCount=0,(!qe.setup||qe.setup.call(y,H,ot,te)===!1)&&y.addEventListener&&y.addEventListener(Oe,te)),qe.add&&(qe.add.call(y,Re),Re.handler.guid||(Re.handler.guid=$.guid)),J?Te.splice(Te.delegateCount++,0,Re):Te.push(Re),w.event.global[Oe]=!0)},remove:function(y,D,$,H,J){var X,te,we,Ce,_e,Re,qe,Te,Oe,ot,yt,at=O.hasData(y)&&O.get(y);if(!(!at||!(Ce=at.events))){for(D=(D||"").match(he)||[""],_e=D.length;_e--;){if(we=et.exec(D[_e])||[],Oe=yt=we[1],ot=(we[2]||"").split(".").sort(),!Oe){for(Oe in Ce)w.event.remove(y,Oe+D[_e],$,H,!0);continue}for(qe=w.event.special[Oe]||{},Oe=(H?qe.delegateType:qe.bindType)||Oe,Te=Ce[Oe]||[],we=we[2]&&new RegExp("(^|\\.)"+ot.join("\\.(?:.*\\.|)")+"(\\.|$)"),te=X=Te.length;X--;)Re=Te[X],(J||yt===Re.origType)&&(!$||$.guid===Re.guid)&&(!we||we.test(Re.namespace))&&(!H||H===Re.selector||H==="**"&&Re.selector)&&(Te.splice(X,1),Re.selector&&Te.delegateCount--,qe.remove&&qe.remove.call(y,Re));te&&!Te.length&&((!qe.teardown||qe.teardown.call(y,ot,at.handle)===!1)&&w.removeEvent(y,Oe,at.handle),delete Ce[Oe])}w.isEmptyObject(Ce)&&O.remove(y,"handle events")}},dispatch:function(y){var D,$,H,J,X,te,we=new Array(arguments.length),Ce=w.event.fix(y),_e=(O.get(this,"events")||Object.create(null))[Ce.type]||[],Re=w.event.special[Ce.type]||{};for(we[0]=Ce,D=1;D<arguments.length;D++)we[D]=arguments[D];if(Ce.delegateTarget=this,!(Re.preDispatch&&Re.preDispatch.call(this,Ce)===!1)){for(te=w.event.handlers.call(this,Ce,_e),D=0;(J=te[D++])&&!Ce.isPropagationStopped();)for(Ce.currentTarget=J.elem,$=0;(X=J.handlers[$++])&&!Ce.isImmediatePropagationStopped();)(!Ce.rnamespace||X.namespace===!1||Ce.rnamespace.test(X.namespace))&&(Ce.handleObj=X,Ce.data=X.data,H=((w.event.special[X.origType]||{}).handle||X.handler).apply(J.elem,we),H!==void 0&&(Ce.result=H)===!1&&(Ce.preventDefault(),Ce.stopPropagation()));return Re.postDispatch&&Re.postDispatch.call(this,Ce),Ce.result}},handlers:function(y,D){var $,H,J,X,te,we=[],Ce=D.delegateCount,_e=y.target;if(Ce&&_e.nodeType&&!(y.type==="click"&&y.button>=1)){for(;_e!==this;_e=_e.parentNode||this)if(_e.nodeType===1&&!(y.type==="click"&&_e.disabled===!0)){for(X=[],te={},$=0;$<Ce;$++)H=D[$],J=H.selector+" ",te[J]===void 0&&(te[J]=H.needsContext?w(J,this).index(_e)>-1:w.find(J,this,null,[_e]).length),te[J]&&X.push(H);X.length&&we.push({elem:_e,handlers:X})}}return _e=this,Ce<D.length&&we.push({elem:_e,handlers:D.slice(Ce)}),we},addProp:function(y,D){Object.defineProperty(w.Event.prototype,y,{enumerable:!0,configurable:!0,get:F(D)?function(){if(this.originalEvent)return D(this.originalEvent)}:function(){if(this.originalEvent)return this.originalEvent[y]},set:function($){Object.defineProperty(this,y,{enumerable:!0,configurable:!0,writable:!0,value:$})}})},fix:function(y){return y[w.expando]?y:new w.Event(y)},special:{load:{noBubble:!0},click:{setup:function(y){var D=this||y;return Se.test(D.type)&&D.click&&j(D,"input")&&Bt(D,"click",vt),!1},trigger:function(y){var D=this||y;return Se.test(D.type)&&D.click&&j(D,"input")&&Bt(D,"click"),!0},_default:function(y){var D=y.target;return Se.test(D.type)&&D.click&&j(D,"input")&&O.get(D,"click")||j(D,"a")}},beforeunload:{postDispatch:function(y){y.result!==void 0&&y.originalEvent&&(y.originalEvent.returnValue=y.result)}}}};function Bt(y,D,$){if(!$){O.get(y,D)===void 0&&w.event.add(y,D,vt);return}O.set(y,D,!1),w.event.add(y,D,{namespace:!1,handler:function(H){var J,X,te=O.get(this,D);if(H.isTrigger&1&&this[D]){if(te.length)(w.event.special[D]||{}).delegateType&&H.stopPropagation();else if(te=s.call(arguments),O.set(this,D,te),J=$(this,D),this[D](),X=O.get(this,D),te!==X||J?O.set(this,D,!1):X={},te!==X)return H.stopImmediatePropagation(),H.preventDefault(),X.value}else te.length&&(O.set(this,D,{value:w.event.trigger(w.extend(te[0],w.Event.prototype),te.slice(1),this)}),H.stopImmediatePropagation())}})}w.removeEvent=function(y,D,$){y.removeEventListener&&y.removeEventListener(D,$)},w.Event=function(y,D){if(!(this instanceof w.Event))return new w.Event(y,D);y&&y.type?(this.originalEvent=y,this.type=y.type,this.isDefaultPrevented=y.defaultPrevented||y.defaultPrevented===void 0&&y.returnValue===!1?vt:Ft,this.target=y.target&&y.target.nodeType===3?y.target.parentNode:y.target,this.currentTarget=y.currentTarget,this.relatedTarget=y.relatedTarget):this.type=y,D&&w.extend(this,D),this.timeStamp=y&&y.timeStamp||Date.now(),this[w.expando]=!0},w.Event.prototype={constructor:w.Event,isDefaultPrevented:Ft,isPropagationStopped:Ft,isImmediatePropagationStopped:Ft,isSimulated:!1,preventDefault:function(){var y=this.originalEvent;this.isDefaultPrevented=vt,y&&!this.isSimulated&&y.preventDefault()},stopPropagation:function(){var y=this.originalEvent;this.isPropagationStopped=vt,y&&!this.isSimulated&&y.stopPropagation()},stopImmediatePropagation:function(){var y=this.originalEvent;this.isImmediatePropagationStopped=vt,y&&!this.isSimulated&&y.stopImmediatePropagation(),this.stopPropagation()}},w.each({altKey:!0,bubbles:!0,cancelable:!0,changedTouches:!0,ctrlKey:!0,detail:!0,eventPhase:!0,metaKey:!0,pageX:!0,pageY:!0,shiftKey:!0,view:!0,char:!0,code:!0,charCode:!0,key:!0,keyCode:!0,button:!0,buttons:!0,clientX:!0,clientY:!0,offsetX:!0,offsetY:!0,pointerId:!0,pointerType:!0,screenX:!0,screenY:!0,targetTouches:!0,toElement:!0,touches:!0,which:function(y){var D=y.button;return y.which==null&&Ge.test(y.type)?y.charCode!=null?y.charCode:y.keyCode:!y.which&&D!==void 0&&lt.test(y.type)?D&1?1:D&2?3:D&4?2:0:y.which}},w.event.addProp),w.each({focus:"focusin",blur:"focusout"},function(y,D){w.event.special[y]={setup:function(){return Bt(this,y,bt),!1},trigger:function(){return Bt(this,y),!0},delegateType:D}}),w.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},function(y,D){w.event.special[y]={delegateType:D,bindType:D,handle:function($){var H,J=this,X=$.relatedTarget,te=$.handleObj;return(!X||X!==J&&!w.contains(J,X))&&($.type=te.origType,H=te.handler.apply(this,arguments),$.type=D),H}}}),w.fn.extend({on:function(y,D,$,H){return kt(this,y,D,$,H)},one:function(y,D,$,H){return kt(this,y,D,$,H,1)},off:function(y,D,$){var H,J;if(y&&y.preventDefault&&y.handleObj)return H=y.handleObj,w(y.delegateTarget).off(H.namespace?H.origType+"."+H.namespace:H.origType,H.selector,H.handler),this;if(typeof y=="object"){for(J in y)this.off(J,D,y[J]);return this}return(D===!1||typeof D=="function")&&($=D,D=void 0),$===!1&&($=Ft),this.each(function(){w.event.remove(this,y,$,D)})}});var st=/<script|<style|<link/i,Vt=/checked\s*(?:[^=]|=\s*.checked.)/i,it=/^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g;function St(y,D){return j(y,"table")&&j(D.nodeType!==11?D:D.firstChild,"tr")&&w(y).children("tbody")[0]||y}function It(y){return y.type=(y.getAttribute("type")!==null)+"/"+y.type,y}function Dt(y){return(y.type||"").slice(0,5)==="true/"?y.type=y.type.slice(5):y.removeAttribute("type"),y}function Uu(y,D){var $,H,J,X,te,we,Ce;if(D.nodeType===1){if(O.hasData(y)&&(X=O.get(y),Ce=X.events,Ce)){O.remove(D,"handle events");for(J in Ce)for($=0,H=Ce[J].length;$<H;$++)w.event.add(D,J,Ce[J][$])}I.hasData(y)&&(te=I.access(y),we=w.extend({},te),I.set(D,we))}}function Dr(y,D){var $=D.nodeName.toLowerCase();$==="input"&&Se.test(y.type)?D.checked=y.checked:($==="input"||$==="textarea")&&(D.defaultValue=y.defaultValue)}function tr(y,D,$,H){D=o(D);var J,X,te,we,Ce,_e,Re=0,qe=y.length,Te=qe-1,Oe=D[0],ot=F(Oe);if(ot||qe>1&&typeof Oe=="string"&&!a.checkClone&&Vt.test(Oe))return y.each(function(yt){var at=y.eq(yt);ot&&(D[0]=Oe.call(this,yt,at.html())),tr(at,D,$,H)});if(qe&&(J=Ue(D,y[0].ownerDocument,!1,y,H),X=J.firstChild,J.childNodes.length===1&&(J=X),X||H)){for(te=w.map(Le(J,"script"),It),we=te.length;Re<qe;Re++)Ce=J,Re!==Te&&(Ce=w.clone(Ce,!0,!0),we&&w.merge(te,Le(Ce,"script"))),$.call(y[Re],Ce,Re);if(we)for(_e=te[te.length-1].ownerDocument,w.map(te,Dt),Re=0;Re<we;Re++)Ce=te[Re],Ve.test(Ce.type||"")&&!O.access(Ce,"globalEval")&&w.contains(_e,Ce)&&(Ce.src&&(Ce.type||"").toLowerCase()!=="module"?w._evalUrl&&!Ce.noModule&&w._evalUrl(Ce.src,{nonce:Ce.nonce||Ce.getAttribute("nonce")},_e):C(Ce.textContent.replace(it,""),Ce,_e))}return y}function h0(y,D,$){for(var H,J=D?w.filter(D,y):y,X=0;(H=J[X])!=null;X++)!$&&H.nodeType===1&&w.cleanData(Le(H)),H.parentNode&&($&&ee(H)&&Be(Le(H,"script")),H.parentNode.removeChild(H));return y}w.extend({htmlPrefilter:function(y){return y},clone:function(y,D,$){var H,J,X,te,we=y.cloneNode(!0),Ce=ee(y);if(!a.noCloneChecked&&(y.nodeType===1||y.nodeType===11)&&!w.isXMLDoc(y))for(te=Le(we),X=Le(y),H=0,J=X.length;H<J;H++)Dr(X[H],te[H]);if(D)if($)for(X=X||Le(y),te=te||Le(we),H=0,J=X.length;H<J;H++)Uu(X[H],te[H]);else Uu(y,we);return te=Le(we,"script"),te.length>0&&Be(te,!Ce&&Le(y,"script")),we},cleanData:function(y){for(var D,$,H,J=w.event.special,X=0;($=y[X])!==void 0;X++)if(z($)){if(D=$[O.expando]){if(D.events)for(H in D.events)J[H]?w.event.remove($,H):w.removeEvent($,H,D.handle);$[O.expando]=void 0}$[I.expando]&&($[I.expando]=void 0)}}}),w.fn.extend({detach:function(y){return h0(this,y,!0)},remove:function(y){return h0(this,y)},text:function(y){return me(this,function(D){return D===void 0?w.text(this):this.empty().each(function(){(this.nodeType===1||this.nodeType===11||this.nodeType===9)&&(this.textContent=D)})},null,y,arguments.length)},append:function(){return tr(this,arguments,function(y){if(this.nodeType===1||this.nodeType===11||this.nodeType===9){var D=St(this,y);D.appendChild(y)}})},prepend:function(){return tr(this,arguments,function(y){if(this.nodeType===1||this.nodeType===11||this.nodeType===9){var D=St(this,y);D.insertBefore(y,D.firstChild)}})},before:function(){return tr(this,arguments,function(y){this.parentNode&&this.parentNode.insertBefore(y,this)})},after:function(){return tr(this,arguments,function(y){this.parentNode&&this.parentNode.insertBefore(y,this.nextSibling)})},empty:function(){for(var y,D=0;(y=this[D])!=null;D++)y.nodeType===1&&(w.cleanData(Le(y,!1)),y.textContent="");return this},clone:function(y,D){return y=y??!1,D=D??y,this.map(function(){return w.clone(this,y,D)})},html:function(y){return me(this,function(D){var $=this[0]||{},H=0,J=this.length;if(D===void 0&&$.nodeType===1)return $.innerHTML;if(typeof D=="string"&&!st.test(D)&&!Me[(ze.exec(D)||["",""])[1].toLowerCase()]){D=w.htmlPrefilter(D);try{for(;H<J;H++)$=this[H]||{},$.nodeType===1&&(w.cleanData(Le($,!1)),$.innerHTML=D);$=0}catch{}}$&&this.empty().append(D)},null,y,arguments.length)},replaceWith:function(){var y=[];return tr(this,arguments,function(D){var $=this.parentNode;w.inArray(this,y)<0&&(w.cleanData(Le(this)),$&&$.replaceChild(D,this))},y)}}),w.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(y,D){w.fn[y]=function($){for(var H,J=[],X=w($),te=X.length-1,we=0;we<=te;we++)H=we===te?this:this.clone(!0),w(X[we])[D](H),f.apply(J,H.get());return this.pushStack(J)}});var k0=new RegExp("^("+P+")(?!px)[a-z%]+$","i"),Mr=function(y){var D=y.ownerDocument.defaultView;return(!D||!D.opener)&&(D=e),D.getComputedStyle(y)},rr=function(y,D,$){var H,J,X={};for(J in D)X[J]=y.style[J],y.style[J]=D[J];H=$.call(y);for(J in D)y.style[J]=X[J];return H},R0=new RegExp(K.join("|"),"i");(function(){function y(){if(_e){Ce.style.cssText="position:absolute;left:-11111px;width:60px;margin-top:1px;padding:0;border:0",_e.style.cssText="position:relative;display:block;box-sizing:border-box;overflow:scroll;margin:auto;border:1px;padding:1px;width:60%;top:1%",V.appendChild(Ce).appendChild(_e);var Re=e.getComputedStyle(_e);$=Re.top!=="1%",we=D(Re.marginLeft)===12,_e.style.right="60%",X=D(Re.right)===36,H=D(Re.width)===36,_e.style.position="absolute",J=D(_e.offsetWidth/3)===12,V.removeChild(Ce),_e=null}}function D(Re){return Math.round(parseFloat(Re))}var $,H,J,X,te,we,Ce=m.createElement("div"),_e=m.createElement("div");_e.style&&(_e.style.backgroundClip="content-box",_e.cloneNode(!0).style.backgroundClip="",a.clearCloneStyle=_e.style.backgroundClip==="content-box",w.extend(a,{boxSizingReliable:function(){return y(),H},pixelBoxStyles:function(){return y(),X},pixelPosition:function(){return y(),$},reliableMarginLeft:function(){return y(),we},scrollboxSize:function(){return y(),J},reliableTrDimensions:function(){var Re,qe,Te,Oe;return te==null&&(Re=m.createElement("table"),qe=m.createElement("tr"),Te=m.createElement("div"),Re.style.cssText="position:absolute;left:-11111px",qe.style.height="1px",Te.style.height="9px",V.appendChild(Re).appendChild(qe).appendChild(Te),Oe=e.getComputedStyle(qe),te=parseInt(Oe.height)>3,V.removeChild(Re)),te}}))})();function zr(y,D,$){var H,J,X,te,we=y.style;return $=$||Mr(y),$&&(te=$.getPropertyValue(D)||$[D],te===""&&!ee(y)&&(te=w.style(y,D)),!a.pixelBoxStyles()&&k0.test(te)&&R0.test(D)&&(H=we.width,J=we.minWidth,X=we.maxWidth,we.minWidth=we.maxWidth=we.width=te,te=$.width,we.width=H,we.minWidth=J,we.maxWidth=X)),te!==void 0?te+"":te}function Tr(y,D){return{get:function(){if(y()){delete this.get;return}return(this.get=D).apply(this,arguments)}}}var f0=["Webkit","Moz","ms"],qu=m.createElement("div").style,$l={};function gm(y){for(var D=y[0].toUpperCase()+y.slice(1),$=f0.length;$--;)if(y=f0[$]+D,y in qu)return y}function Bo(y){var D=w.cssProps[y]||$l[y];return D||(y in qu?y:$l[y]=gm(y)||y)}var pm=/^(none|table(?!-c[ea]).+)/,Nl=/^--/,fm={position:"absolute",visibility:"hidden",display:"block"},Wl={letterSpacing:"0",fontWeight:"400"};function Hl(y,D,$){var H=W.exec(D);return H?Math.max(0,H[2]-($||0))+(H[3]||"px"):D}function Io(y,D,$,H,J,X){var te=D==="width"?1:0,we=0,Ce=0;if($===(H?"border":"content"))return 0;for(;te<4;te+=2)$==="margin"&&(Ce+=w.css(y,$+K[te],!0,J)),H?($==="content"&&(Ce-=w.css(y,"padding"+K[te],!0,J)),$!=="margin"&&(Ce-=w.css(y,"border"+K[te]+"Width",!0,J))):(Ce+=w.css(y,"padding"+K[te],!0,J),$!=="padding"?Ce+=w.css(y,"border"+K[te]+"Width",!0,J):we+=w.css(y,"border"+K[te]+"Width",!0,J));return!H&&X>=0&&(Ce+=Math.max(0,Math.ceil(y["offset"+D[0].toUpperCase()+D.slice(1)]-X-Ce-we-.5))||0),Ce}function Ul(y,D,$){var H=Mr(y),J=!a.boxSizingReliable()||$,X=J&&w.css(y,"boxSizing",!1,H)==="border-box",te=X,we=zr(y,D,H),Ce="offset"+D[0].toUpperCase()+D.slice(1);if(k0.test(we)){if(!$)return we;we="auto"}return(!a.boxSizingReliable()&&X||!a.reliableTrDimensions()&&j(y,"tr")||we==="auto"||!parseFloat(we)&&w.css(y,"display",!1,H)==="inline")&&y.getClientRects().length&&(X=w.css(y,"boxSizing",!1,H)==="border-box",te=Ce in y,te&&(we=y[Ce])),we=parseFloat(we)||0,we+Io(y,D,$||(X?"border":"content"),te,H,we)+"px"}w.extend({cssHooks:{opacity:{get:function(y,D){if(D){var $=zr(y,"opacity");return $===""?"1":$}}}},cssNumber:{animationIterationCount:!0,columnCount:!0,fillOpacity:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,gridArea:!0,gridColumn:!0,gridColumnEnd:!0,gridColumnStart:!0,gridRow:!0,gridRowEnd:!0,gridRowStart:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{},style:function(y,D,$,H){if(!(!y||y.nodeType===3||y.nodeType===8||!y.style)){var J,X,te,we=Ie(D),Ce=Nl.test(D),_e=y.style;if(Ce||(D=Bo(we)),te=w.cssHooks[D]||w.cssHooks[we],$!==void 0){if(X=typeof $,X==="string"&&(J=W.exec($))&&J[1]&&($=oe(y,D,J),X="number"),$==null||$!==$)return;X==="number"&&!Ce&&($+=J&&J[3]||(w.cssNumber[we]?"":"px")),!a.clearCloneStyle&&$===""&&D.indexOf("background")===0&&(_e[D]="inherit"),(!te||!("set"in te)||($=te.set(y,$,H))!==void 0)&&(Ce?_e.setProperty(D,$):_e[D]=$)}else return te&&"get"in te&&(J=te.get(y,!1,H))!==void 0?J:_e[D]}},css:function(y,D,$,H){var J,X,te,we=Ie(D),Ce=Nl.test(D);return Ce||(D=Bo(we)),te=w.cssHooks[D]||w.cssHooks[we],te&&"get"in te&&(J=te.get(y,!0,$)),J===void 0&&(J=zr(y,D,H)),J==="normal"&&D in Wl&&(J=Wl[D]),$===""||$?(X=parseFloat(J),$===!0||isFinite(X)?X||0:J):J}}),w.each(["height","width"],function(y,D){w.cssHooks[D]={get:function($,H,J){if(H)return pm.test(w.css($,"display"))&&(!$.getClientRects().length||!$.getBoundingClientRect().width)?rr($,fm,function(){return Ul($,D,J)}):Ul($,D,J)},set:function($,H,J){var X,te=Mr($),we=!a.scrollboxSize()&&te.position==="absolute",Ce=we||J,_e=Ce&&w.css($,"boxSizing",!1,te)==="border-box",Re=J?Io($,D,J,_e,te):0;return _e&&we&&(Re-=Math.ceil($["offset"+D[0].toUpperCase()+D.slice(1)]-parseFloat(te[D])-Io($,D,"border",!1,te)-.5)),Re&&(X=W.exec(H))&&(X[3]||"px")!=="px"&&($.style[D]=H,H=w.css($,D)),Hl($,H,Re)}}}),w.cssHooks.marginLeft=Tr(a.reliableMarginLeft,function(y,D){if(D)return(parseFloat(zr(y,"marginLeft"))||y.getBoundingClientRect().left-rr(y,{marginLeft:0},function(){return y.getBoundingClientRect().left}))+"px"}),w.each({margin:"",padding:"",border:"Width"},function(y,D){w.cssHooks[y+D]={expand:function($){for(var H=0,J={},X=typeof $=="string"?$.split(" "):[$];H<4;H++)J[y+K[H]+D]=X[H]||X[H-2]||X[0];return J}},y!=="margin"&&(w.cssHooks[y+D].set=Hl)}),w.fn.extend({css:function(y,D){return me(this,function($,H,J){var X,te,we={},Ce=0;if(Array.isArray(H)){for(X=Mr($),te=H.length;Ce<te;Ce++)we[H[Ce]]=w.css($,H[Ce],!1,X);return we}return J!==void 0?w.style($,H,J):w.css($,H)},y,D,arguments.length>1)}});function j0(y,D,$,H,J){return new j0.prototype.init(y,D,$,H,J)}w.Tween=j0,j0.prototype={constructor:j0,init:function(y,D,$,H,J,X){this.elem=y,this.prop=$,this.easing=J||w.easing._default,this.options=D,this.start=this.now=this.cur(),this.end=H,this.unit=X||(w.cssNumber[$]?"":"px")},cur:function(){var y=j0.propHooks[this.prop];return y&&y.get?y.get(this):j0.propHooks._default.get(this)},run:function(y){var D,$=j0.propHooks[this.prop];return this.options.duration?this.pos=D=w.easing[this.easing](y,this.options.duration*y,0,1,this.options.duration):this.pos=D=y,this.now=(this.end-this.start)*D+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),$&&$.set?$.set(this):j0.propHooks._default.set(this),this}},j0.prototype.init.prototype=j0.prototype,j0.propHooks={_default:{get:function(y){var D;return y.elem.nodeType!==1||y.elem[y.prop]!=null&&y.elem.style[y.prop]==null?y.elem[y.prop]:(D=w.css(y.elem,y.prop,""),!D||D==="auto"?0:D)},set:function(y){w.fx.step[y.prop]?w.fx.step[y.prop](y):y.elem.nodeType===1&&(w.cssHooks[y.prop]||y.elem.style[Bo(y.prop)]!=null)?w.style(y.elem,y.prop,y.now+y.unit):y.elem[y.prop]=y.now}}},j0.propHooks.scrollTop=j0.propHooks.scrollLeft={set:function(y){y.elem.nodeType&&y.elem.parentNode&&(y.elem[y.prop]=y.now)}},w.easing={linear:function(y){return y},swing:function(y){return .5-Math.cos(y*Math.PI)/2},_default:"swing"},w.fx=j0.prototype.init,w.fx.step={};var uu,Hs,mm=/^(?:toggle|show|hide)$/,vm=/queueHooks$/;function Oo(){Hs&&(m.hidden===!1&&e.requestAnimationFrame?e.requestAnimationFrame(Oo):e.setTimeout(Oo,w.fx.interval),w.fx.tick())}function ql(){return e.setTimeout(function(){uu=void 0}),uu=Date.now()}function Us(y,D){var $,H=0,J={height:y};for(D=D?1:0;H<4;H+=2-D)$=K[H],J["margin"+$]=J["padding"+$]=y;return D&&(J.opacity=J.width=y),J}function zl(y,D,$){for(var H,J=(ir.tweeners[D]||[]).concat(ir.tweeners["*"]),X=0,te=J.length;X<te;X++)if(H=J[X].call($,D,y))return H}function bm(y,D,$){var H,J,X,te,we,Ce,_e,Re,qe="width"in D||"height"in D,Te=this,Oe={},ot=y.style,yt=y.nodeType&&fe(y),at=O.get(y,"fxshow");$.queue||(te=w._queueHooks(y,"fx"),te.unqueued==null&&(te.unqueued=0,we=te.empty.fire,te.empty.fire=function(){te.unqueued||we()}),te.unqueued++,Te.always(function(){Te.always(function(){te.unqueued--,w.queue(y,"fx").length||te.empty.fire()})}));for(H in D)if(J=D[H],mm.test(J)){if(delete D[H],X=X||J==="toggle",J===(yt?"hide":"show"))if(J==="show"&&at&&at[H]!==void 0)yt=!0;else continue;Oe[H]=at&&at[H]||w.style(y,H)}if(Ce=!w.isEmptyObject(D),!(!Ce&&w.isEmptyObject(Oe))){qe&&y.nodeType===1&&($.overflow=[ot.overflow,ot.overflowX,ot.overflowY],_e=at&&at.display,_e==null&&(_e=O.get(y,"display")),Re=w.css(y,"display"),Re==="none"&&(_e?Re=_e:(Ae([y],!0),_e=y.style.display||_e,Re=w.css(y,"display"),Ae([y]))),(Re==="inline"||Re==="inline-block"&&_e!=null)&&w.css(y,"float")==="none"&&(Ce||(Te.done(function(){ot.display=_e}),_e==null&&(Re=ot.display,_e=Re==="none"?"":Re)),ot.display="inline-block")),$.overflow&&(ot.overflow="hidden",Te.always(function(){ot.overflow=$.overflow[0],ot.overflowX=$.overflow[1],ot.overflowY=$.overflow[2]})),Ce=!1;for(H in Oe)Ce||(at?"hidden"in at&&(yt=at.hidden):at=O.access(y,"fxshow",{display:_e}),X&&(at.hidden=!yt),yt&&Ae([y],!0),Te.done(function(){yt||Ae([y]),O.remove(y,"fxshow");for(H in Oe)w.style(y,H,Oe[H])})),Ce=zl(yt?at[H]:0,H,Te),H in at||(at[H]=Ce.start,yt&&(Ce.end=Ce.start,Ce.start=0))}}function wm(y,D){var $,H,J,X,te;for($ in y)if(H=Ie($),J=D[H],X=y[$],Array.isArray(X)&&(J=X[1],X=y[$]=X[0]),$!==H&&(y[H]=X,delete y[$]),te=w.cssHooks[H],te&&"expand"in te){X=te.expand(X),delete y[H];for($ in X)$ in y||(y[$]=X[$],D[$]=J)}else D[H]=J}function ir(y,D,$){var H,J,X=0,te=ir.prefilters.length,we=w.Deferred().always(function(){delete Ce.elem}),Ce=function(){if(J)return!1;for(var qe=uu||ql(),Te=Math.max(0,_e.startTime+_e.duration-qe),Oe=Te/_e.duration||0,ot=1-Oe,yt=0,at=_e.tweens.length;yt<at;yt++)_e.tweens[yt].run(ot);return we.notifyWith(y,[_e,ot,Te]),ot<1&&at?Te:(at||we.notifyWith(y,[_e,1,0]),we.resolveWith(y,[_e]),!1)},_e=we.promise({elem:y,props:w.extend({},D),opts:w.extend(!0,{specialEasing:{},easing:w.easing._default},$),originalProperties:D,originalOptions:$,startTime:uu||ql(),duration:$.duration,tweens:[],createTween:function(qe,Te){var Oe=w.Tween(y,_e.opts,qe,Te,_e.opts.specialEasing[qe]||_e.opts.easing);return _e.tweens.push(Oe),Oe},stop:function(qe){var Te=0,Oe=qe?_e.tweens.length:0;if(J)return this;for(J=!0;Te<Oe;Te++)_e.tweens[Te].run(1);return qe?(we.notifyWith(y,[_e,1,0]),we.resolveWith(y,[_e,qe])):we.rejectWith(y,[_e,qe]),this}}),Re=_e.props;for(wm(Re,_e.opts.specialEasing);X<te;X++)if(H=ir.prefilters[X].call(_e,y,Re,_e.opts),H)return F(H.stop)&&(w._queueHooks(_e.elem,_e.opts.queue).stop=H.stop.bind(H)),H;return w.map(Re,zl,_e),F(_e.opts.start)&&_e.opts.start.call(y,_e),_e.progress(_e.opts.progress).done(_e.opts.done,_e.opts.complete).fail(_e.opts.fail).always(_e.opts.always),w.fx.timer(w.extend(Ce,{elem:y,anim:_e,queue:_e.opts.queue})),_e}w.Animation=w.extend(ir,{tweeners:{"*":[function(y,D){var $=this.createTween(y,D);return oe($.elem,y,W.exec(D),$),$}]},tweener:function(y,D){F(y)?(D=y,y=["*"]):y=y.match(he);for(var $,H=0,J=y.length;H<J;H++)$=y[H],ir.tweeners[$]=ir.tweeners[$]||[],ir.tweeners[$].unshift(D)},prefilters:[bm],prefilter:function(y,D){D?ir.prefilters.unshift(y):ir.prefilters.push(y)}}),w.speed=function(y,D,$){var H=y&&typeof y=="object"?w.extend({},y):{complete:$||!$&&D||F(y)&&y,duration:y,easing:$&&D||D&&!F(D)&&D};return w.fx.off?H.duration=0:typeof H.duration!="number"&&(H.duration in w.fx.speeds?H.duration=w.fx.speeds[H.duration]:H.duration=w.fx.speeds._default),(H.queue==null||H.queue===!0)&&(H.queue="fx"),H.old=H.complete,H.complete=function(){F(H.old)&&H.old.call(this),H.queue&&w.dequeue(this,H.queue)},H},w.fn.extend({fadeTo:function(y,D,$,H){return this.filter(fe).css("opacity",0).show().end().animate({opacity:D},y,$,H)},animate:function(y,D,$,H){var J=w.isEmptyObject(y),X=w.speed(D,$,H),te=function(){var we=ir(this,w.extend({},y),X);(J||O.get(this,"finish"))&&we.stop(!0)};return te.finish=te,J||X.queue===!1?this.each(te):this.queue(X.queue,te)},stop:function(y,D,$){var H=function(J){var X=J.stop;delete J.stop,X($)};return typeof y!="string"&&($=D,D=y,y=void 0),D&&this.queue(y||"fx",[]),this.each(function(){var J=!0,X=y!=null&&y+"queueHooks",te=w.timers,we=O.get(this);if(X)we[X]&&we[X].stop&&H(we[X]);else for(X in we)we[X]&&we[X].stop&&vm.test(X)&&H(we[X]);for(X=te.length;X--;)te[X].elem===this&&(y==null||te[X].queue===y)&&(te[X].anim.stop($),J=!1,te.splice(X,1));(J||!$)&&w.dequeue(this,y)})},finish:function(y){return y!==!1&&(y=y||"fx"),this.each(function(){var D,$=O.get(this),H=$[y+"queue"],J=$[y+"queueHooks"],X=w.timers,te=H?H.length:0;for($.finish=!0,w.queue(this,y,[]),J&&J.stop&&J.stop.call(this,!0),D=X.length;D--;)X[D].elem===this&&X[D].queue===y&&(X[D].anim.stop(!0),X.splice(D,1));for(D=0;D<te;D++)H[D]&&H[D].finish&&H[D].finish.call(this);delete $.finish})}}),w.each(["toggle","show","hide"],function(y,D){var $=w.fn[D];w.fn[D]=function(H,J,X){return H==null||typeof H=="boolean"?$.apply(this,arguments):this.animate(Us(D,!0),H,J,X)}}),w.each({slideDown:Us("show"),slideUp:Us("hide"),slideToggle:Us("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(y,D){w.fn[y]=function($,H,J){return this.animate(D,$,H,J)}}),w.timers=[],w.fx.tick=function(){var y,D=0,$=w.timers;for(uu=Date.now();D<$.length;D++)y=$[D],!y()&&$[D]===y&&$.splice(D--,1);$.length||w.fx.stop(),uu=void 0},w.fx.timer=function(y){w.timers.push(y),w.fx.start()},w.fx.interval=13,w.fx.start=function(){Hs||(Hs=!0,Oo())},w.fx.stop=function(){Hs=null},w.fx.speeds={slow:600,fast:200,_default:400},w.fn.delay=function(y,D){return y=w.fx&&w.fx.speeds[y]||y,D=D||"fx",this.queue(D,function($,H){var J=e.setTimeout($,y);H.stop=function(){e.clearTimeout(J)}})},function(){var y=m.createElement("input"),D=m.createElement("select"),$=D.appendChild(m.createElement("option"));y.type="checkbox",a.checkOn=y.value!=="",a.optSelected=$.selected,y=m.createElement("input"),y.value="t",y.type="radio",a.radioValue=y.value==="t"}();var Vl,zu=w.expr.attrHandle;w.fn.extend({attr:function(y,D){return me(this,w.attr,y,D,arguments.length>1)},removeAttr:function(y){return this.each(function(){w.removeAttr(this,y)})}}),w.extend({attr:function(y,D,$){var H,J,X=y.nodeType;if(!(X===3||X===8||X===2)){if(typeof y.getAttribute>"u")return w.prop(y,D,$);if((X!==1||!w.isXMLDoc(y))&&(J=w.attrHooks[D.toLowerCase()]||(w.expr.match.bool.test(D)?Vl:void 0)),$!==void 0){if($===null){w.removeAttr(y,D);return}return J&&"set"in J&&(H=J.set(y,$,D))!==void 0?H:(y.setAttribute(D,$+""),$)}return J&&"get"in J&&(H=J.get(y,D))!==null?H:(H=w.find.attr(y,D),H??void 0)}},attrHooks:{type:{set:function(y,D){if(!a.radioValue&&D==="radio"&&j(y,"input")){var $=y.value;return y.setAttribute("type",D),$&&(y.value=$),D}}}},removeAttr:function(y,D){var $,H=0,J=D&&D.match(he);if(J&&y.nodeType===1)for(;$=J[H++];)y.removeAttribute($)}}),Vl={set:function(y,D,$){return D===!1?w.removeAttr(y,$):y.setAttribute($,$),$}},w.each(w.expr.match.bool.source.match(/\w+/g),function(y,D){var $=zu[D]||w.find.attr;zu[D]=function(H,J,X){var te,we,Ce=J.toLowerCase();return X||(we=zu[Ce],zu[Ce]=te,te=$(H,J,X)!=null?Ce:null,zu[Ce]=we),te}});var ym=/^(?:input|select|textarea|button)$/i,Cm=/^(?:a|area)$/i;w.fn.extend({prop:function(y,D){return me(this,w.prop,y,D,arguments.length>1)},removeProp:function(y){return this.each(function(){delete this[w.propFix[y]||y]})}}),w.extend({prop:function(y,D,$){var H,J,X=y.nodeType;if(!(X===3||X===8||X===2))return(X!==1||!w.isXMLDoc(y))&&(D=w.propFix[D]||D,J=w.propHooks[D]),$!==void 0?J&&"set"in J&&(H=J.set(y,$,D))!==void 0?H:y[D]=$:J&&"get"in J&&(H=J.get(y,D))!==null?H:y[D]},propHooks:{tabIndex:{get:function(y){var D=w.find.attr(y,"tabindex");return D?parseInt(D,10):ym.test(y.nodeName)||Cm.test(y.nodeName)&&y.href?0:-1}}},propFix:{for:"htmlFor",class:"className"}}),a.optSelected||(w.propHooks.selected={get:function(y){var D=y.parentNode;return D&&D.parentNode&&D.parentNode.selectedIndex,null},set:function(y){var D=y.parentNode;D&&(D.selectedIndex,D.parentNode&&D.parentNode.selectedIndex)}}),w.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],function(){w.propFix[this.toLowerCase()]=this});function bi(y){var D=y.match(he)||[];return D.join(" ")}function wi(y){return y.getAttribute&&y.getAttribute("class")||""}function $o(y){return Array.isArray(y)?y:typeof y=="string"?y.match(he)||[]:[]}w.fn.extend({addClass:function(y){var D,$,H,J,X,te,we,Ce=0;if(F(y))return this.each(function(_e){w(this).addClass(y.call(this,_e,wi(this)))});if(D=$o(y),D.length){for(;$=this[Ce++];)if(J=wi($),H=$.nodeType===1&&" "+bi(J)+" ",H){for(te=0;X=D[te++];)H.indexOf(" "+X+" ")<0&&(H+=X+" ");we=bi(H),J!==we&&$.setAttribute("class",we)}}return this},removeClass:function(y){var D,$,H,J,X,te,we,Ce=0;if(F(y))return this.each(function(_e){w(this).removeClass(y.call(this,_e,wi(this)))});if(!arguments.length)return this.attr("class","");if(D=$o(y),D.length){for(;$=this[Ce++];)if(J=wi($),H=$.nodeType===1&&" "+bi(J)+" ",H){for(te=0;X=D[te++];)for(;H.indexOf(" "+X+" ")>-1;)H=H.replace(" "+X+" "," ");we=bi(H),J!==we&&$.setAttribute("class",we)}}return this},toggleClass:function(y,D){var $=typeof y,H=$==="string"||Array.isArray(y);return typeof D=="boolean"&&H?D?this.addClass(y):this.removeClass(y):F(y)?this.each(function(J){w(this).toggleClass(y.call(this,J,wi(this),D),D)}):this.each(function(){var J,X,te,we;if(H)for(X=0,te=w(this),we=$o(y);J=we[X++];)te.hasClass(J)?te.removeClass(J):te.addClass(J);else(y===void 0||$==="boolean")&&(J=wi(this),J&&O.set(this,"__className__",J),this.setAttribute&&this.setAttribute("class",J||y===!1?"":O.get(this,"__className__")||""))})},hasClass:function(y){var D,$,H=0;for(D=" "+y+" ";$=this[H++];)if($.nodeType===1&&(" "+bi(wi($))+" ").indexOf(D)>-1)return!0;return!1}});var Em=/\r/g;w.fn.extend({val:function(y){var D,$,H,J=this[0];return arguments.length?(H=F(y),this.each(function(X){var te;this.nodeType===1&&(H?te=y.call(this,X,w(this).val()):te=y,te==null?te="":typeof te=="number"?te+="":Array.isArray(te)&&(te=w.map(te,function(we){return we==null?"":we+""})),D=w.valHooks[this.type]||w.valHooks[this.nodeName.toLowerCase()],(!D||!("set"in D)||D.set(this,te,"value")===void 0)&&(this.value=te))})):J?(D=w.valHooks[J.type]||w.valHooks[J.nodeName.toLowerCase()],D&&"get"in D&&($=D.get(J,"value"))!==void 0?$:($=J.value,typeof $=="string"?$.replace(Em,""):$??"")):void 0}}),w.extend({valHooks:{option:{get:function(y){var D=w.find.attr(y,"value");return D??bi(w.text(y))}},select:{get:function(y){var D,$,H,J=y.options,X=y.selectedIndex,te=y.type==="select-one",we=te?null:[],Ce=te?X+1:J.length;for(X<0?H=Ce:H=te?X:0;H<Ce;H++)if($=J[H],($.selected||H===X)&&!$.disabled&&(!$.parentNode.disabled||!j($.parentNode,"optgroup"))){if(D=w($).val(),te)return D;we.push(D)}return we},set:function(y,D){for(var $,H,J=y.options,X=w.makeArray(D),te=J.length;te--;)H=J[te],(H.selected=w.inArray(w.valHooks.option.get(H),X)>-1)&&($=!0);return $||(y.selectedIndex=-1),X}}}}),w.each(["radio","checkbox"],function(){w.valHooks[this]={set:function(y,D){if(Array.isArray(D))return y.checked=w.inArray(w(y).val(),D)>-1}},a.checkOn||(w.valHooks[this].get=function(y){return y.getAttribute("value")===null?"on":y.value})}),a.focusin="onfocusin"in e;var Gl=/^(?:focusinfocus|focusoutblur)$/,Kl=function(y){y.stopPropagation()};w.extend(w.event,{trigger:function(y,D,$,H){var J,X,te,we,Ce,_e,Re,qe,Te=[$||m],Oe=d.call(y,"type")?y.type:y,ot=d.call(y,"namespace")?y.namespace.split("."):[];if(X=qe=te=$=$||m,!($.nodeType===3||$.nodeType===8)&&!Gl.test(Oe+w.event.triggered)&&(Oe.indexOf(".")>-1&&(ot=Oe.split("."),Oe=ot.shift(),ot.sort()),Ce=Oe.indexOf(":")<0&&"on"+Oe,y=y[w.expando]?y:new w.Event(Oe,typeof y=="object"&&y),y.isTrigger=H?2:3,y.namespace=ot.join("."),y.rnamespace=y.namespace?new RegExp("(^|\\.)"+ot.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,y.result=void 0,y.target||(y.target=$),D=D==null?[y]:w.makeArray(D,[y]),Re=w.event.special[Oe]||{},!(!H&&Re.trigger&&Re.trigger.apply($,D)===!1))){if(!H&&!Re.noBubble&&!p($)){for(we=Re.delegateType||Oe,Gl.test(we+Oe)||(X=X.parentNode);X;X=X.parentNode)Te.push(X),te=X;te===($.ownerDocument||m)&&Te.push(te.defaultView||te.parentWindow||e)}for(J=0;(X=Te[J++])&&!y.isPropagationStopped();)qe=X,y.type=J>1?we:Re.bindType||Oe,_e=(O.get(X,"events")||Object.create(null))[y.type]&&O.get(X,"handle"),_e&&_e.apply(X,D),_e=Ce&&X[Ce],_e&&_e.apply&&z(X)&&(y.result=_e.apply(X,D),y.result===!1&&y.preventDefault());return y.type=Oe,!H&&!y.isDefaultPrevented()&&(!Re._default||Re._default.apply(Te.pop(),D)===!1)&&z($)&&Ce&&F($[Oe])&&!p($)&&(te=$[Ce],te&&($[Ce]=null),w.event.triggered=Oe,y.isPropagationStopped()&&qe.addEventListener(Oe,Kl),$[Oe](),y.isPropagationStopped()&&qe.removeEventListener(Oe,Kl),w.event.triggered=void 0,te&&($[Ce]=te)),y.result}},simulate:function(y,D,$){var H=w.extend(new w.Event,$,{type:y,isSimulated:!0});w.event.trigger(H,null,D)}}),w.fn.extend({trigger:function(y,D){return this.each(function(){w.event.trigger(y,D,this)})},triggerHandler:function(y,D){var $=this[0];if($)return w.event.trigger(y,D,$,!0)}}),a.focusin||w.each({focus:"focusin",blur:"focusout"},function(y,D){var $=function(H){w.event.simulate(D,H.target,w.event.fix(H))};w.event.special[D]={setup:function(){var H=this.ownerDocument||this.document||this,J=O.access(H,D);J||H.addEventListener(y,$,!0),O.access(H,D,(J||0)+1)},teardown:function(){var H=this.ownerDocument||this.document||this,J=O.access(H,D)-1;J?O.access(H,D,J):(H.removeEventListener(y,$,!0),O.remove(H,D))}}});var Vu=e.location,Yl={guid:Date.now()},No=/\?/;w.parseXML=function(y){var D;if(!y||typeof y!="string")return null;try{D=new e.DOMParser().parseFromString(y,"text/xml")}catch{D=void 0}return(!D||D.getElementsByTagName("parsererror").length)&&w.error("Invalid XML: "+y),D};var Am=/\[\]$/,Jl=/\r?\n/g,xm=/^(?:submit|button|image|reset|file)$/i,km=/^(?:input|select|textarea|keygen)/i;function Wo(y,D,$,H){var J;if(Array.isArray(D))w.each(D,function(X,te){$||Am.test(y)?H(y,te):Wo(y+"["+(typeof te=="object"&&te!=null?X:"")+"]",te,$,H)});else if(!$&&k(D)==="object")for(J in D)Wo(y+"["+J+"]",D[J],$,H);else H(y,D)}w.param=function(y,D){var $,H=[],J=function(X,te){var we=F(te)?te():te;H[H.length]=encodeURIComponent(X)+"="+encodeURIComponent(we??"")};if(y==null)return"";if(Array.isArray(y)||y.jquery&&!w.isPlainObject(y))w.each(y,function(){J(this.name,this.value)});else for($ in y)Wo($,y[$],D,J);return H.join("&")},w.fn.extend({serialize:function(){return w.param(this.serializeArray())},serializeArray:function(){return this.map(function(){var y=w.prop(this,"elements");return y?w.makeArray(y):this}).filter(function(){var y=this.type;return this.name&&!w(this).is(":disabled")&&km.test(this.nodeName)&&!xm.test(y)&&(this.checked||!Se.test(y))}).map(function(y,D){var $=w(this).val();return $==null?null:Array.isArray($)?w.map($,function(H){return{name:D.name,value:H.replace(Jl,`\r
`)}}):{name:D.name,value:$.replace(Jl,`\r
`)}}).get()}});var jm=/%20/g,Sm=/#.*$/,_m=/([?&])_=[^&]*/,Dm=/^(.*?):[ \t]*([^\r\n]*)$/mg,Mm=/^(?:about|app|app-storage|.+-extension|file|res|widget):$/,Tm=/^(?:GET|HEAD)$/,Pm=/^\/\//,Ql={},Ho={},Xl="*/".concat("*"),Uo=m.createElement("a");Uo.href=Vu.href;function Zl(y){return function(D,$){typeof D!="string"&&($=D,D="*");var H,J=0,X=D.toLowerCase().match(he)||[];if(F($))for(;H=X[J++];)H[0]==="+"?(H=H.slice(1)||"*",(y[H]=y[H]||[]).unshift($)):(y[H]=y[H]||[]).push($)}}function ed(y,D,$,H){var J={},X=y===Ho;function te(we){var Ce;return J[we]=!0,w.each(y[we]||[],function(_e,Re){var qe=Re(D,$,H);if(typeof qe=="string"&&!X&&!J[qe])return D.dataTypes.unshift(qe),te(qe),!1;if(X)return!(Ce=qe)}),Ce}return te(D.dataTypes[0])||!J["*"]&&te("*")}function qo(y,D){var $,H,J=w.ajaxSettings.flatOptions||{};for($ in D)D[$]!==void 0&&((J[$]?y:H||(H={}))[$]=D[$]);return H&&w.extend(!0,y,H),y}function Lm(y,D,$){for(var H,J,X,te,we=y.contents,Ce=y.dataTypes;Ce[0]==="*";)Ce.shift(),H===void 0&&(H=y.mimeType||D.getResponseHeader("Content-Type"));if(H){for(J in we)if(we[J]&&we[J].test(H)){Ce.unshift(J);break}}if(Ce[0]in $)X=Ce[0];else{for(J in $){if(!Ce[0]||y.converters[J+" "+Ce[0]]){X=J;break}te||(te=J)}X=X||te}if(X)return X!==Ce[0]&&Ce.unshift(X),$[X]}function Rm(y,D,$,H){var J,X,te,we,Ce,_e={},Re=y.dataTypes.slice();if(Re[1])for(te in y.converters)_e[te.toLowerCase()]=y.converters[te];for(X=Re.shift();X;)if(y.responseFields[X]&&($[y.responseFields[X]]=D),!Ce&&H&&y.dataFilter&&(D=y.dataFilter(D,y.dataType)),Ce=X,X=Re.shift(),X){if(X==="*")X=Ce;else if(Ce!=="*"&&Ce!==X){if(te=_e[Ce+" "+X]||_e["* "+X],!te){for(J in _e)if(we=J.split(" "),we[1]===X&&(te=_e[Ce+" "+we[0]]||_e["* "+we[0]],te)){te===!0?te=_e[J]:_e[J]!==!0&&(X=we[0],Re.unshift(we[1]));break}}if(te!==!0)if(te&&y.throws)D=te(D);else try{D=te(D)}catch(qe){return{state:"parsererror",error:te?qe:"No conversion from "+Ce+" to "+X}}}}return{state:"success",data:D}}w.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:Vu.href,type:"GET",isLocal:Mm.test(Vu.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":Xl,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":JSON.parse,"text xml":w.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(y,D){return D?qo(qo(y,w.ajaxSettings),D):qo(w.ajaxSettings,y)},ajaxPrefilter:Zl(Ql),ajaxTransport:Zl(Ho),ajax:function(y,D){typeof y=="object"&&(D=y,y=void 0),D=D||{};var $,H,J,X,te,we,Ce,_e,Re,qe,Te=w.ajaxSetup({},D),Oe=Te.context||Te,ot=Te.context&&(Oe.nodeType||Oe.jquery)?w(Oe):w.event,yt=w.Deferred(),at=w.Callbacks("once memory"),o0=Te.statusCode||{},i0={},B0={},Lt="canceled",wt={readyState:0,getResponseHeader:function(Mt){var Yt;if(Ce){if(!X)for(X={};Yt=Dm.exec(J);)X[Yt[1].toLowerCase()+" "]=(X[Yt[1].toLowerCase()+" "]||[]).concat(Yt[2]);Yt=X[Mt.toLowerCase()+" "]}return Yt==null?null:Yt.join(", ")},getAllResponseHeaders:function(){return Ce?J:null},setRequestHeader:function(Mt,Yt){return Ce==null&&(Mt=B0[Mt.toLowerCase()]=B0[Mt.toLowerCase()]||Mt,i0[Mt]=Yt),this},overrideMimeType:function(Mt){return Ce==null&&(Te.mimeType=Mt),this},statusCode:function(Mt){var Yt;if(Mt)if(Ce)wt.always(Mt[wt.status]);else for(Yt in Mt)o0[Yt]=[o0[Yt],Mt[Yt]];return this},abort:function(Mt){var Yt=Mt||Lt;return $&&$.abort(Yt),S0(0,Yt),this}};if(yt.promise(wt),Te.url=((y||Te.url||Vu.href)+"").replace(Pm,Vu.protocol+"//"),Te.type=D.method||D.type||Te.method||Te.type,Te.dataTypes=(Te.dataType||"*").toLowerCase().match(he)||[""],Te.crossDomain==null){we=m.createElement("a");try{we.href=Te.url,we.href=we.href,Te.crossDomain=Uo.protocol+"//"+Uo.host!=we.protocol+"//"+we.host}catch{Te.crossDomain=!0}}if(Te.data&&Te.processData&&typeof Te.data!="string"&&(Te.data=w.param(Te.data,Te.traditional)),ed(Ql,Te,D,wt),Ce)return wt;_e=w.event&&Te.global,_e&&w.active++===0&&w.event.trigger("ajaxStart"),Te.type=Te.type.toUpperCase(),Te.hasContent=!Tm.test(Te.type),H=Te.url.replace(Sm,""),Te.hasContent?Te.data&&Te.processData&&(Te.contentType||"").indexOf("application/x-www-form-urlencoded")===0&&(Te.data=Te.data.replace(jm,"+")):(qe=Te.url.slice(H.length),Te.data&&(Te.processData||typeof Te.data=="string")&&(H+=(No.test(H)?"&":"?")+Te.data,delete Te.data),Te.cache===!1&&(H=H.replace(_m,"$1"),qe=(No.test(H)?"&":"?")+"_="+Yl.guid+++qe),Te.url=H+qe),Te.ifModified&&(w.lastModified[H]&&wt.setRequestHeader("If-Modified-Since",w.lastModified[H]),w.etag[H]&&wt.setRequestHeader("If-None-Match",w.etag[H])),(Te.data&&Te.hasContent&&Te.contentType!==!1||D.contentType)&&wt.setRequestHeader("Content-Type",Te.contentType),wt.setRequestHeader("Accept",Te.dataTypes[0]&&Te.accepts[Te.dataTypes[0]]?Te.accepts[Te.dataTypes[0]]+(Te.dataTypes[0]!=="*"?", "+Xl+"; q=0.01":""):Te.accepts["*"]);for(Re in Te.headers)wt.setRequestHeader(Re,Te.headers[Re]);if(Te.beforeSend&&(Te.beforeSend.call(Oe,wt,Te)===!1||Ce))return wt.abort();if(Lt="abort",at.add(Te.complete),wt.done(Te.success),wt.fail(Te.error),$=ed(Ho,Te,D,wt),!$)S0(-1,"No Transport");else{if(wt.readyState=1,_e&&ot.trigger("ajaxSend",[wt,Te]),Ce)return wt;Te.async&&Te.timeout>0&&(te=e.setTimeout(function(){wt.abort("timeout")},Te.timeout));try{Ce=!1,$.send(i0,S0)}catch(Mt){if(Ce)throw Mt;S0(-1,Mt)}}function S0(Mt,Yt,Ku,qs){var I0,yi,Ci,_0,Vr,V0=Yt;Ce||(Ce=!0,te&&e.clearTimeout(te),$=void 0,J=qs||"",wt.readyState=Mt>0?4:0,I0=Mt>=200&&Mt<300||Mt===304,Ku&&(_0=Lm(Te,wt,Ku)),!I0&&w.inArray("script",Te.dataTypes)>-1&&(Te.converters["text script"]=function(){}),_0=Rm(Te,_0,wt,I0),I0?(Te.ifModified&&(Vr=wt.getResponseHeader("Last-Modified"),Vr&&(w.lastModified[H]=Vr),Vr=wt.getResponseHeader("etag"),Vr&&(w.etag[H]=Vr)),Mt===204||Te.type==="HEAD"?V0="nocontent":Mt===304?V0="notmodified":(V0=_0.state,yi=_0.data,Ci=_0.error,I0=!Ci)):(Ci=V0,(Mt||!V0)&&(V0="error",Mt<0&&(Mt=0))),wt.status=Mt,wt.statusText=(Yt||V0)+"",I0?yt.resolveWith(Oe,[yi,V0,wt]):yt.rejectWith(Oe,[wt,V0,Ci]),wt.statusCode(o0),o0=void 0,_e&&ot.trigger(I0?"ajaxSuccess":"ajaxError",[wt,Te,I0?yi:Ci]),at.fireWith(Oe,[wt,V0]),_e&&(ot.trigger("ajaxComplete",[wt,Te]),--w.active||w.event.trigger("ajaxStop")))}return wt},getJSON:function(y,D,$){return w.get(y,D,$,"json")},getScript:function(y,D){return w.get(y,void 0,D,"script")}}),w.each(["get","post"],function(y,D){w[D]=function($,H,J,X){return F(H)&&(X=X||J,J=H,H=void 0),w.ajax(w.extend({url:$,type:D,dataType:X,data:H,success:J},w.isPlainObject($)&&$))}}),w.ajaxPrefilter(function(y){var D;for(D in y.headers)D.toLowerCase()==="content-type"&&(y.contentType=y.headers[D]||"")}),w._evalUrl=function(y,D,$){return w.ajax({url:y,type:"GET",dataType:"script",cache:!0,async:!1,global:!1,converters:{"text script":function(){}},dataFilter:function(H){w.globalEval(H,D,$)}})},w.fn.extend({wrapAll:function(y){var D;return this[0]&&(F(y)&&(y=y.call(this[0])),D=w(y,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&D.insertBefore(this[0]),D.map(function(){for(var $=this;$.firstElementChild;)$=$.firstElementChild;return $}).append(this)),this},wrapInner:function(y){return F(y)?this.each(function(D){w(this).wrapInner(y.call(this,D))}):this.each(function(){var D=w(this),$=D.contents();$.length?$.wrapAll(y):D.append(y)})},wrap:function(y){var D=F(y);return this.each(function($){w(this).wrapAll(D?y.call(this,$):y)})},unwrap:function(y){return this.parent(y).not("body").each(function(){w(this).replaceWith(this.childNodes)}),this}}),w.expr.pseudos.hidden=function(y){return!w.expr.pseudos.visible(y)},w.expr.pseudos.visible=function(y){return!!(y.offsetWidth||y.offsetHeight||y.getClientRects().length)},w.ajaxSettings.xhr=function(){try{return new e.XMLHttpRequest}catch{}};var Bm={0:200,1223:204},Gu=w.ajaxSettings.xhr();a.cors=!!Gu&&"withCredentials"in Gu,a.ajax=Gu=!!Gu,w.ajaxTransport(function(y){var D,$;if(a.cors||Gu&&!y.crossDomain)return{send:function(H,J){var X,te=y.xhr();if(te.open(y.type,y.url,y.async,y.username,y.password),y.xhrFields)for(X in y.xhrFields)te[X]=y.xhrFields[X];y.mimeType&&te.overrideMimeType&&te.overrideMimeType(y.mimeType),!y.crossDomain&&!H["X-Requested-With"]&&(H["X-Requested-With"]="XMLHttpRequest");for(X in H)te.setRequestHeader(X,H[X]);D=function(we){return function(){D&&(D=$=te.onload=te.onerror=te.onabort=te.ontimeout=te.onreadystatechange=null,we==="abort"?te.abort():we==="error"?typeof te.status!="number"?J(0,"error"):J(te.status,te.statusText):J(Bm[te.status]||te.status,te.statusText,(te.responseType||"text")!=="text"||typeof te.responseText!="string"?{binary:te.response}:{text:te.responseText},te.getAllResponseHeaders()))}},te.onload=D(),$=te.onerror=te.ontimeout=D("error"),te.onabort!==void 0?te.onabort=$:te.onreadystatechange=function(){te.readyState===4&&e.setTimeout(function(){D&&$()})},D=D("abort");try{te.send(y.hasContent&&y.data||null)}catch(we){if(D)throw we}},abort:function(){D&&D()}}}),w.ajaxPrefilter(function(y){y.crossDomain&&(y.contents.script=!1)}),w.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(y){return w.globalEval(y),y}}}),w.ajaxPrefilter("script",function(y){y.cache===void 0&&(y.cache=!1),y.crossDomain&&(y.type="GET")}),w.ajaxTransport("script",function(y){if(y.crossDomain||y.scriptAttrs){var D,$;return{send:function(H,J){D=w("<script>").attr(y.scriptAttrs||{}).prop({charset:y.scriptCharset,src:y.url}).on("load error",$=function(X){D.remove(),$=null,X&&J(X.type==="error"?404:200,X.type)}),m.head.appendChild(D[0])},abort:function(){$&&$()}}}});var td=[],zo=/(=)\?(?=&|$)|\?\?/;w.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var y=td.pop()||w.expando+"_"+Yl.guid++;return this[y]=!0,y}}),w.ajaxPrefilter("json jsonp",function(y,D,$){var H,J,X,te=y.jsonp!==!1&&(zo.test(y.url)?"url":typeof y.data=="string"&&(y.contentType||"").indexOf("application/x-www-form-urlencoded")===0&&zo.test(y.data)&&"data");if(te||y.dataTypes[0]==="jsonp")return H=y.jsonpCallback=F(y.jsonpCallback)?y.jsonpCallback():y.jsonpCallback,te?y[te]=y[te].replace(zo,"$1"+H):y.jsonp!==!1&&(y.url+=(No.test(y.url)?"&":"?")+y.jsonp+"="+H),y.converters["script json"]=function(){return X||w.error(H+" was not called"),X[0]},y.dataTypes[0]="json",J=e[H],e[H]=function(){X=arguments},$.always(function(){J===void 0?w(e).removeProp(H):e[H]=J,y[H]&&(y.jsonpCallback=D.jsonpCallback,td.push(H)),X&&F(J)&&J(X[0]),X=J=void 0}),"script"}),a.createHTMLDocument=function(){var y=m.implementation.createHTMLDocument("").body;return y.innerHTML="<form></form><form></form>",y.childNodes.length===2}(),w.parseHTML=function(y,D,$){if(typeof y!="string")return[];typeof D=="boolean"&&($=D,D=!1);var H,J,X;return D||(a.createHTMLDocument?(D=m.implementation.createHTMLDocument(""),H=D.createElement("base"),H.href=m.location.href,D.head.appendChild(H)):D=m),J=B.exec(y),X=!$&&[],J?[D.createElement(J[1])]:(J=Ue([y],D,X),X&&X.length&&w(X).remove(),w.merge([],J.childNodes))},w.fn.load=function(y,D,$){var H,J,X,te=this,we=y.indexOf(" ");return we>-1&&(H=bi(y.slice(we)),y=y.slice(0,we)),F(D)?($=D,D=void 0):D&&typeof D=="object"&&(J="POST"),te.length>0&&w.ajax({url:y,type:J||"GET",dataType:"html",data:D}).done(function(Ce){X=arguments,te.html(H?w("<div>").append(w.parseHTML(Ce)).find(H):Ce)}).always($&&function(Ce,_e){te.each(function(){$.apply(this,X||[Ce.responseText,_e,Ce])})}),this},w.expr.pseudos.animated=function(y){return w.grep(w.timers,function(D){return y===D.elem}).length},w.offset={setOffset:function(y,D,$){var H,J,X,te,we,Ce,_e,Re=w.css(y,"position"),qe=w(y),Te={};Re==="static"&&(y.style.position="relative"),we=qe.offset(),X=w.css(y,"top"),Ce=w.css(y,"left"),_e=(Re==="absolute"||Re==="fixed")&&(X+Ce).indexOf("auto")>-1,_e?(H=qe.position(),te=H.top,J=H.left):(te=parseFloat(X)||0,J=parseFloat(Ce)||0),F(D)&&(D=D.call(y,$,w.extend({},we))),D.top!=null&&(Te.top=D.top-we.top+te),D.left!=null&&(Te.left=D.left-we.left+J),"using"in D?D.using.call(y,Te):(typeof Te.top=="number"&&(Te.top+="px"),typeof Te.left=="number"&&(Te.left+="px"),qe.css(Te))}},w.fn.extend({offset:function(y){if(arguments.length)return y===void 0?this:this.each(function(J){w.offset.setOffset(this,y,J)});var D,$,H=this[0];if(H)return H.getClientRects().length?(D=H.getBoundingClientRect(),$=H.ownerDocument.defaultView,{top:D.top+$.pageYOffset,left:D.left+$.pageXOffset}):{top:0,left:0}},position:function(){if(this[0]){var y,D,$,H=this[0],J={top:0,left:0};if(w.css(H,"position")==="fixed")D=H.getBoundingClientRect();else{for(D=this.offset(),$=H.ownerDocument,y=H.offsetParent||$.documentElement;y&&(y===$.body||y===$.documentElement)&&w.css(y,"position")==="static";)y=y.parentNode;y&&y!==H&&y.nodeType===1&&(J=w(y).offset(),J.top+=w.css(y,"borderTopWidth",!0),J.left+=w.css(y,"borderLeftWidth",!0))}return{top:D.top-J.top-w.css(H,"marginTop",!0),left:D.left-J.left-w.css(H,"marginLeft",!0)}}},offsetParent:function(){return this.map(function(){for(var y=this.offsetParent;y&&w.css(y,"position")==="static";)y=y.offsetParent;return y||V})}}),w.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},function(y,D){var $=D==="pageYOffset";w.fn[y]=function(H){return me(this,function(J,X,te){var we;if(p(J)?we=J:J.nodeType===9&&(we=J.defaultView),te===void 0)return we?we[D]:J[X];we?we.scrollTo($?we.pageXOffset:te,$?te:we.pageYOffset):J[X]=te},y,H,arguments.length)}}),w.each(["top","left"],function(y,D){w.cssHooks[D]=Tr(a.pixelPosition,function($,H){if(H)return H=zr($,D),k0.test(H)?w($).position()[D]+"px":H})}),w.each({Height:"height",Width:"width"},function(y,D){w.each({padding:"inner"+y,content:D,"":"outer"+y},function($,H){w.fn[H]=function(J,X){var te=arguments.length&&($||typeof J!="boolean"),we=$||(J===!0||X===!0?"margin":"border");return me(this,function(Ce,_e,Re){var qe;return p(Ce)?H.indexOf("outer")===0?Ce["inner"+y]:Ce.document.documentElement["client"+y]:Ce.nodeType===9?(qe=Ce.documentElement,Math.max(Ce.body["scroll"+y],qe["scroll"+y],Ce.body["offset"+y],qe["offset"+y],qe["client"+y])):Re===void 0?w.css(Ce,_e,we):w.style(Ce,_e,Re,we)},D,te?J:void 0,te)}})}),w.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],function(y,D){w.fn[D]=function($){return this.on(D,$)}}),w.fn.extend({bind:function(y,D,$){return this.on(y,null,D,$)},unbind:function(y,D){return this.off(y,null,D)},delegate:function(y,D,$,H){return this.on(D,y,$,H)},undelegate:function(y,D,$){return arguments.length===1?this.off(y,"**"):this.off(D,y||"**",$)},hover:function(y,D){return this.mouseenter(y).mouseleave(D||y)}}),w.each("blur focus focusin focusout resize scroll click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup contextmenu".split(" "),function(y,D){w.fn[D]=function($,H){return arguments.length>0?this.on(D,null,$,H):this.trigger(D)}});var Im=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g;w.proxy=function(y,D){var $,H,J;if(typeof D=="string"&&($=y[D],D=y,y=$),!!F(y))return H=s.call(arguments,2),J=function(){return y.apply(D||this,H.concat(s.call(arguments)))},J.guid=y.guid=y.guid||w.guid++,J},w.holdReady=function(y){y?w.readyWait++:w.ready(!0)},w.isArray=Array.isArray,w.parseJSON=JSON.parse,w.nodeName=j,w.isFunction=F,w.isWindow=p,w.camelCase=Ie,w.type=k,w.now=Date.now,w.isNumeric=function(y){var D=w.type(y);return(D==="number"||D==="string")&&!isNaN(y-parseFloat(y))},w.trim=function(y){return y==null?"":(y+"").replace(Im,"")};var Om=e.jQuery,$m=e.$;return w.noConflict=function(y){return e.$===w&&(e.$=$m),y&&e.jQuery===w&&(e.jQuery=Om),w},typeof u>"u"&&(e.jQuery=e.$=w),w})}(ea)),ea.exports}var rv=cc();const ke=zn(rv);var lc="1.13.6",Fd=typeof self=="object"&&self.self===self&&self||typeof global=="object"&&global.global===global&&global||Function("return this")()||{},Vn=Array.prototype,dc=Object.prototype,hd=typeof Symbol<"u"?Symbol.prototype:null,iv=Vn.push,Ts=Vn.slice,vs=dc.toString,uv=dc.hasOwnProperty,f2=typeof ArrayBuffer<"u",sv=typeof DataView<"u",nv=Array.isArray,gd=Object.keys,pd=Object.create,fd=f2&&ArrayBuffer.isView,ov=isNaN,av=isFinite,m2=!{toString:null}.propertyIsEnumerable("toString"),md=["valueOf","isPrototypeOf","toString","propertyIsEnumerable","hasOwnProperty","toLocaleString"],cv=Math.pow(2,53)-1;function E0(t,e){return e=e==null?t.length-1:+e,function(){for(var u=Math.max(arguments.length-e,0),r=Array(u),i=0;i<u;i++)r[i]=arguments[i+e];switch(e){case 0:return t.call(this,r);case 1:return t.call(this,arguments[0],r);case 2:return t.call(this,arguments[0],arguments[1],r)}var s=Array(e+1);for(i=0;i<e;i++)s[i]=arguments[i];return s[e]=r,t.apply(this,s)}}function ci(t){var e=typeof t;return e==="function"||e==="object"&&!!t}function v2(t){return t===null}function Fc(t){return t===void 0}function hc(t){return t===!0||t===!1||vs.call(t)==="[object Boolean]"}function b2(t){return!!(t&&t.nodeType===1)}function w0(t){var e="[object "+t+"]";return function(u){return vs.call(u)===e}}const Gn=w0("String"),gc=w0("Number"),w2=w0("Date"),y2=w0("RegExp"),C2=w0("Error"),pc=w0("Symbol"),fc=w0("ArrayBuffer");var E2=w0("Function"),lv=Fd.document&&Fd.document.childNodes;typeof/./!="function"&&typeof Int8Array!="object"&&typeof lv!="function"&&(E2=function(t){return typeof t=="function"||!1});const v0=E2,A2=w0("Object");var x2=sv&&A2(new DataView(new ArrayBuffer(8))),mc=typeof Map<"u"&&A2(new Map),dv=w0("DataView");function Fv(t){return t!=null&&v0(t.getInt8)&&fc(t.buffer)}const bs=x2?Fv:dv,li=nv||w0("Array");function di(t,e){return t!=null&&uv.call(t,e)}var Sa=w0("Arguments");(function(){Sa(arguments)||(Sa=function(t){return di(t,"callee")})})();const Kn=Sa;function k2(t){return!pc(t)&&av(t)&&!isNaN(parseFloat(t))}function vc(t){return gc(t)&&ov(t)}function bc(t){return function(){return t}}function j2(t){return function(e){var u=t(e);return typeof u=="number"&&u>=0&&u<=cv}}function S2(t){return function(e){return e==null?void 0:e[t]}}const xn=S2("byteLength"),hv=j2(xn);var gv=/\[object ((I|Ui)nt(8|16|32)|Float(32|64)|Uint8Clamped|Big(I|Ui)nt64)Array\]/;function pv(t){return fd?fd(t)&&!bs(t):hv(t)&&gv.test(vs.call(t))}const wc=f2?pv:bc(!1),P0=S2("length");function fv(t){for(var e={},u=t.length,r=0;r<u;++r)e[t[r]]=!0;return{contains:function(i){return e[i]===!0},push:function(i){return e[i]=!0,t.push(i)}}}function _2(t,e){e=fv(e);var u=md.length,r=t.constructor,i=v0(r)&&r.prototype||dc,s="constructor";for(di(t,s)&&!e.contains(s)&&e.push(s);u--;)s=md[u],s in t&&t[s]!==i[s]&&!e.contains(s)&&e.push(s)}function d0(t){if(!ci(t))return[];if(gd)return gd(t);var e=[];for(var u in t)di(t,u)&&e.push(u);return m2&&_2(t,e),e}function D2(t){if(t==null)return!0;var e=P0(t);return typeof e=="number"&&(li(t)||Gn(t)||Kn(t))?e===0:P0(d0(t))===0}function yc(t,e){var u=d0(e),r=u.length;if(t==null)return!r;for(var i=Object(t),s=0;s<r;s++){var o=u[s];if(e[o]!==i[o]||!(o in i))return!1}return!0}function Pt(t){if(t instanceof Pt)return t;if(!(this instanceof Pt))return new Pt(t);this._wrapped=t}Pt.VERSION=lc;Pt.prototype.value=function(){return this._wrapped};Pt.prototype.valueOf=Pt.prototype.toJSON=Pt.prototype.value;Pt.prototype.toString=function(){return String(this._wrapped)};function vd(t){return new Uint8Array(t.buffer||t,t.byteOffset||0,xn(t))}var bd="[object DataView]";function _a(t,e,u,r){if(t===e)return t!==0||1/t===1/e;if(t==null||e==null)return!1;if(t!==t)return e!==e;var i=typeof t;return i!=="function"&&i!=="object"&&typeof e!="object"?!1:M2(t,e,u,r)}function M2(t,e,u,r){t instanceof Pt&&(t=t._wrapped),e instanceof Pt&&(e=e._wrapped);var i=vs.call(t);if(i!==vs.call(e))return!1;if(x2&&i=="[object Object]"&&bs(t)){if(!bs(e))return!1;i=bd}switch(i){case"[object RegExp]":case"[object String]":return""+t==""+e;case"[object Number]":return+t!=+t?+e!=+e:+t==0?1/+t===1/e:+t==+e;case"[object Date]":case"[object Boolean]":return+t==+e;case"[object Symbol]":return hd.valueOf.call(t)===hd.valueOf.call(e);case"[object ArrayBuffer]":case bd:return M2(vd(t),vd(e),u,r)}var s=i==="[object Array]";if(!s&&wc(t)){var o=xn(t);if(o!==xn(e))return!1;if(t.buffer===e.buffer&&t.byteOffset===e.byteOffset)return!0;s=!0}if(!s){if(typeof t!="object"||typeof e!="object")return!1;var f=t.constructor,n=e.constructor;if(f!==n&&!(v0(f)&&f instanceof f&&v0(n)&&n instanceof n)&&"constructor"in t&&"constructor"in e)return!1}u=u||[],r=r||[];for(var h=u.length;h--;)if(u[h]===t)return r[h]===e;if(u.push(t),r.push(e),s){if(h=t.length,h!==e.length)return!1;for(;h--;)if(!_a(t[h],e[h],u,r))return!1}else{var g=d0(t),d;if(h=g.length,d0(e).length!==h)return!1;for(;h--;)if(d=g[h],!(di(e,d)&&_a(t[d],e[d],u,r)))return!1}return u.pop(),r.pop(),!0}function T2(t,e){return _a(t,e)}function Mu(t){if(!ci(t))return[];var e=[];for(var u in t)e.push(u);return m2&&_2(t,e),e}function Cc(t){var e=P0(t);return function(u){if(u==null)return!1;var r=Mu(u);if(P0(r))return!1;for(var i=0;i<e;i++)if(!v0(u[t[i]]))return!1;return t!==R2||!v0(u[Ec])}}var Ec="forEach",P2="has",Ac=["clear","delete"],L2=["get",P2,"set"],mv=Ac.concat(Ec,L2),R2=Ac.concat(L2),vv=["add"].concat(Ac,Ec,P2);const B2=mc?Cc(mv):w0("Map"),I2=mc?Cc(R2):w0("WeakMap"),O2=mc?Cc(vv):w0("Set"),$2=w0("WeakSet");function Yi(t){for(var e=d0(t),u=e.length,r=Array(u),i=0;i<u;i++)r[i]=t[e[i]];return r}function N2(t){for(var e=d0(t),u=e.length,r=Array(u),i=0;i<u;i++)r[i]=[e[i],t[e[i]]];return r}function xc(t){for(var e={},u=d0(t),r=0,i=u.length;r<i;r++)e[t[u[r]]]=u[r];return e}function ws(t){var e=[];for(var u in t)v0(t[u])&&e.push(u);return e.sort()}function kc(t,e){return function(u){var r=arguments.length;if(e&&(u=Object(u)),r<2||u==null)return u;for(var i=1;i<r;i++)for(var s=arguments[i],o=t(s),f=o.length,n=0;n<f;n++){var h=o[n];(!e||u[h]===void 0)&&(u[h]=s[h])}return u}}const jc=kc(Mu),Cu=kc(d0),Sc=kc(Mu,!0);function bv(){return function(){}}function W2(t){if(!ci(t))return{};if(pd)return pd(t);var e=bv();e.prototype=t;var u=new e;return e.prototype=null,u}function H2(t,e){var u=W2(t);return e&&Cu(u,e),u}function U2(t){return ci(t)?li(t)?t.slice():jc({},t):t}function q2(t,e){return e(t),t}function _c(t){return li(t)?t:[t]}Pt.toPath=_c;function Ps(t){return Pt.toPath(t)}function Dc(t,e){for(var u=e.length,r=0;r<u;r++){if(t==null)return;t=t[e[r]]}return u?t:void 0}function Mc(t,e,u){var r=Dc(t,Ps(e));return Fc(r)?u:r}function z2(t,e){e=Ps(e);for(var u=e.length,r=0;r<u;r++){var i=e[r];if(!di(t,i))return!1;t=t[i]}return!!u}function Yn(t){return t}function qi(t){return t=Cu({},t),function(e){return yc(e,t)}}function Jn(t){return t=Ps(t),function(e){return Dc(e,t)}}function Ls(t,e,u){if(e===void 0)return t;switch(u??3){case 1:return function(r){return t.call(e,r)};case 3:return function(r,i,s){return t.call(e,r,i,s)};case 4:return function(r,i,s,o){return t.call(e,r,i,s,o)}}return function(){return t.apply(e,arguments)}}function V2(t,e,u){return t==null?Yn:v0(t)?Ls(t,e,u):ci(t)&&!li(t)?qi(t):Jn(t)}function Qn(t,e){return V2(t,e,1/0)}Pt.iteratee=Qn;function L0(t,e,u){return Pt.iteratee!==Qn?Pt.iteratee(t,e):V2(t,e,u)}function G2(t,e,u){e=L0(e,u);for(var r=d0(t),i=r.length,s={},o=0;o<i;o++){var f=r[o];s[f]=e(t[f],f,t)}return s}function Tc(){}function K2(t){return t==null?Tc:function(e){return Mc(t,e)}}function Y2(t,e,u){var r=Array(Math.max(0,t));e=Ls(e,u,1);for(var i=0;i<t;i++)r[i]=e(i);return r}function kn(t,e){return e==null&&(e=t,t=0),t+Math.floor(Math.random()*(e-t+1))}const Eu=Date.now||function(){return new Date().getTime()};function J2(t){var e=function(s){return t[s]},u="(?:"+d0(t).join("|")+")",r=RegExp(u),i=RegExp(u,"g");return function(s){return s=s==null?"":""+s,r.test(s)?s.replace(i,e):s}}const Q2={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#x27;","`":"&#x60;"},X2=J2(Q2),wv=xc(Q2),Z2=J2(wv),eF=Pt.templateSettings={evaluate:/<%([\s\S]+?)%>/g,interpolate:/<%=([\s\S]+?)%>/g,escape:/<%-([\s\S]+?)%>/g};var ta=/(.)^/,yv={"'":"'","\\":"\\","\r":"r","\n":"n","\u2028":"u2028","\u2029":"u2029"},Cv=/\\|'|\r|\n|\u2028|\u2029/g;function Ev(t){return"\\"+yv[t]}var Av=/^\s*(\w|\$)+\s*$/;function tF(t,e,u){!e&&u&&(e=u),e=Sc({},e,Pt.templateSettings);var r=RegExp([(e.escape||ta).source,(e.interpolate||ta).source,(e.evaluate||ta).source].join("|")+"|$","g"),i=0,s="__p+='";t.replace(r,function(h,g,d,l,c){return s+=t.slice(i,c).replace(Cv,Ev),i=c+h.length,g?s+=`'+
((__t=(`+g+`))==null?'':_.escape(__t))+
'`:d?s+=`'+
((__t=(`+d+`))==null?'':__t)+
'`:l&&(s+=`';
`+l+`
__p+='`),h}),s+=`';
`;var o=e.variable;if(o){if(!Av.test(o))throw new Error("variable is not a bare identifier: "+o)}else s=`with(obj||{}){
`+s+`}
`,o="obj";s=`var __t,__p='',__j=Array.prototype.join,print=function(){__p+=__j.call(arguments,'');};
`+s+`return __p;
`;var f;try{f=new Function(o,"_",s)}catch(h){throw h.source=s,h}var n=function(h){return f.call(this,h,Pt)};return n.source="function("+o+`){
`+s+"}",n}function rF(t,e,u){e=Ps(e);var r=e.length;if(!r)return v0(u)?u.call(t):u;for(var i=0;i<r;i++){var s=t==null?void 0:t[e[i]];s===void 0&&(s=u,i=r),t=v0(s)?s.call(t):s}return t}var xv=0;function iF(t){var e=++xv+"";return t?t+e:e}function uF(t){var e=Pt(t);return e._chain=!0,e}function sF(t,e,u,r,i){if(!(r instanceof e))return t.apply(u,i);var s=W2(t.prototype),o=t.apply(s,i);return ci(o)?o:s}var Ji=E0(function(t,e){var u=Ji.placeholder,r=function(){for(var i=0,s=e.length,o=Array(s),f=0;f<s;f++)o[f]=e[f]===u?arguments[i++]:e[f];for(;i<arguments.length;)o.push(arguments[i++]);return sF(t,r,this,this,o)};return r});Ji.placeholder=Pt;const Pc=E0(function(t,e,u){if(!v0(t))throw new TypeError("Bind must be called on a function");var r=E0(function(i){return sF(t,r,e,this,u.concat(i))});return r}),H0=j2(P0);function Qi(t,e,u,r){if(r=r||[],!e&&e!==0)e=1/0;else if(e<=0)return r.concat(t);for(var i=r.length,s=0,o=P0(t);s<o;s++){var f=t[s];if(H0(f)&&(li(f)||Kn(f)))if(e>1)Qi(f,e-1,u,r),i=r.length;else for(var n=0,h=f.length;n<h;)r[i++]=f[n++];else u||(r[i++]=f)}return r}const nF=E0(function(t,e){e=Qi(e,!1,!1);var u=e.length;if(u<1)throw new Error("bindAll must be passed function names");for(;u--;){var r=e[u];t[r]=Pc(t[r],t)}return t});function oF(t,e){var u=function(r){var i=u.cache,s=""+(e?e.apply(this,arguments):r);return di(i,s)||(i[s]=t.apply(this,arguments)),i[s]};return u.cache={},u}const Lc=E0(function(t,e,u){return setTimeout(function(){return t.apply(null,u)},e)}),aF=Ji(Lc,Pt,1);function cF(t,e,u){var r,i,s,o,f=0;u||(u={});var n=function(){f=u.leading===!1?0:Eu(),r=null,o=t.apply(i,s),r||(i=s=null)},h=function(){var g=Eu();!f&&u.leading===!1&&(f=g);var d=e-(g-f);return i=this,s=arguments,d<=0||d>e?(r&&(clearTimeout(r),r=null),f=g,o=t.apply(i,s),r||(i=s=null)):!r&&u.trailing!==!1&&(r=setTimeout(n,d)),o};return h.cancel=function(){clearTimeout(r),f=0,r=i=s=null},h}function lF(t,e,u){var r,i,s,o,f,n=function(){var g=Eu()-i;e>g?r=setTimeout(n,e-g):(r=null,u||(o=t.apply(f,s)),r||(s=f=null))},h=E0(function(g){return f=this,s=g,i=Eu(),r||(r=setTimeout(n,e),u&&(o=t.apply(f,s))),o});return h.cancel=function(){clearTimeout(r),r=s=f=null},h}function dF(t,e){return Ji(e,t)}function Xn(t){return function(){return!t.apply(this,arguments)}}function FF(){var t=arguments,e=t.length-1;return function(){for(var u=e,r=t[e].apply(this,arguments);u--;)r=t[u].call(this,r);return r}}function hF(t,e){return function(){if(--t<1)return e.apply(this,arguments)}}function Rc(t,e){var u;return function(){return--t>0&&(u=e.apply(this,arguments)),t<=1&&(e=null),u}}const gF=Ji(Rc,2);function Bc(t,e,u){e=L0(e,u);for(var r=d0(t),i,s=0,o=r.length;s<o;s++)if(i=r[s],e(t[i],i,t))return i}function pF(t){return function(e,u,r){u=L0(u,r);for(var i=P0(e),s=t>0?0:i-1;s>=0&&s<i;s+=t)if(u(e[s],s,e))return s;return-1}}const Zn=pF(1),Ic=pF(-1);function Oc(t,e,u,r){u=L0(u,r,1);for(var i=u(e),s=0,o=P0(t);s<o;){var f=Math.floor((s+o)/2);u(t[f])<i?s=f+1:o=f}return s}function fF(t,e,u){return function(r,i,s){var o=0,f=P0(r);if(typeof s=="number")t>0?o=s>=0?s:Math.max(s+f,o):f=s>=0?Math.min(s+1,f):s+f+1;else if(u&&s&&f)return s=u(r,i),r[s]===i?s:-1;if(i!==i)return s=e(Ts.call(r,o,f),vc),s>=0?s+o:-1;for(s=t>0?o:f-1;s>=0&&s<f;s+=t)if(r[s]===i)return s;return-1}}const $c=fF(1,Zn,Oc),mF=fF(-1,Ic);function ys(t,e,u){var r=H0(t)?Zn:Bc,i=r(t,e,u);if(i!==void 0&&i!==-1)return t[i]}function vF(t,e){return ys(t,qi(e))}function dr(t,e,u){e=Ls(e,u);var r,i;if(H0(t))for(r=0,i=t.length;r<i;r++)e(t[r],r,t);else{var s=d0(t);for(r=0,i=s.length;r<i;r++)e(t[s[r]],s[r],t)}return t}function Wr(t,e,u){e=L0(e,u);for(var r=!H0(t)&&d0(t),i=(r||t).length,s=Array(i),o=0;o<i;o++){var f=r?r[o]:o;s[o]=e(t[f],f,t)}return s}function bF(t){var e=function(u,r,i,s){var o=!H0(u)&&d0(u),f=(o||u).length,n=t>0?0:f-1;for(s||(i=u[o?o[n]:n],n+=t);n>=0&&n<f;n+=t){var h=o?o[n]:n;i=r(i,u[h],h,u)}return i};return function(u,r,i,s){var o=arguments.length>=3;return e(u,Ls(r,s,4),i,o)}}const fu=bF(1),jn=bF(-1);function ni(t,e,u){var r=[];return e=L0(e,u),dr(t,function(i,s,o){e(i,s,o)&&r.push(i)}),r}function wF(t,e,u){return ni(t,Xn(L0(e)),u)}function Sn(t,e,u){e=L0(e,u);for(var r=!H0(t)&&d0(t),i=(r||t).length,s=0;s<i;s++){var o=r?r[s]:s;if(!e(t[o],o,t))return!1}return!0}function _n(t,e,u){e=L0(e,u);for(var r=!H0(t)&&d0(t),i=(r||t).length,s=0;s<i;s++){var o=r?r[s]:s;if(e(t[o],o,t))return!0}return!1}function Q0(t,e,u,r){return H0(t)||(t=Yi(t)),(typeof u!="number"||r)&&(u=0),$c(t,e,u)>=0}const yF=E0(function(t,e,u){var r,i;return v0(e)?i=e:(e=Ps(e),r=e.slice(0,-1),e=e[e.length-1]),Wr(t,function(s){var o=i;if(!o){if(r&&r.length&&(s=Dc(s,r)),s==null)return;o=s[e]}return o==null?o:o.apply(s,u)})});function eo(t,e){return Wr(t,Jn(e))}function CF(t,e){return ni(t,qi(e))}function Nc(t,e,u){var r=-1/0,i=-1/0,s,o;if(e==null||typeof e=="number"&&typeof t[0]!="object"&&t!=null){t=H0(t)?t:Yi(t);for(var f=0,n=t.length;f<n;f++)s=t[f],s!=null&&s>r&&(r=s)}else e=L0(e,u),dr(t,function(h,g,d){o=e(h,g,d),(o>i||o===-1/0&&r===-1/0)&&(r=h,i=o)});return r}function EF(t,e,u){var r=1/0,i=1/0,s,o;if(e==null||typeof e=="number"&&typeof t[0]!="object"&&t!=null){t=H0(t)?t:Yi(t);for(var f=0,n=t.length;f<n;f++)s=t[f],s!=null&&s<r&&(r=s)}else e=L0(e,u),dr(t,function(h,g,d){o=e(h,g,d),(o<i||o===1/0&&r===1/0)&&(r=h,i=o)});return r}var kv=/[^\ud800-\udfff]|[\ud800-\udbff][\udc00-\udfff]|[\ud800-\udfff]/g;function Wc(t){return t?li(t)?Ts.call(t):Gn(t)?t.match(kv):H0(t)?Wr(t,Yn):Yi(t):[]}function Hc(t,e,u){if(e==null||u)return H0(t)||(t=Yi(t)),t[kn(t.length-1)];var r=Wc(t),i=P0(r);e=Math.max(Math.min(e,i),0);for(var s=i-1,o=0;o<e;o++){var f=kn(o,s),n=r[o];r[o]=r[f],r[f]=n}return r.slice(0,e)}function AF(t){return Hc(t,1/0)}function xF(t,e,u){var r=0;return e=L0(e,u),eo(Wr(t,function(i,s,o){return{value:i,index:r++,criteria:e(i,s,o)}}).sort(function(i,s){var o=i.criteria,f=s.criteria;if(o!==f){if(o>f||o===void 0)return 1;if(o<f||f===void 0)return-1}return i.index-s.index}),"value")}function to(t,e){return function(u,r,i){var s=e?[[],[]]:{};return r=L0(r,i),dr(u,function(o,f){var n=r(o,f,u);t(s,o,n)}),s}}const kF=to(function(t,e,u){di(t,u)?t[u].push(e):t[u]=[e]}),jF=to(function(t,e,u){t[u]=e}),SF=to(function(t,e,u){di(t,u)?t[u]++:t[u]=1}),_F=to(function(t,e,u){t[u?0:1].push(e)},!0);function DF(t){return t==null?0:H0(t)?t.length:d0(t).length}function jv(t,e,u){return e in u}const Uc=E0(function(t,e){var u={},r=e[0];if(t==null)return u;v0(r)?(e.length>1&&(r=Ls(r,e[1])),e=Mu(t)):(r=jv,e=Qi(e,!1,!1),t=Object(t));for(var i=0,s=e.length;i<s;i++){var o=e[i],f=t[o];r(f,o,t)&&(u[o]=f)}return u}),MF=E0(function(t,e){var u=e[0],r;return v0(u)?(u=Xn(u),e.length>1&&(r=e[1])):(e=Wr(Qi(e,!1,!1),String),u=function(i,s){return!Q0(e,s)}),Uc(t,u,r)});function qc(t,e,u){return Ts.call(t,0,Math.max(0,t.length-(e==null||u?1:e)))}function mu(t,e,u){return t==null||t.length<1?e==null||u?void 0:[]:e==null||u?t[0]:qc(t,t.length-e)}function Wi(t,e,u){return Ts.call(t,e==null||u?1:e)}function TF(t,e,u){return t==null||t.length<1?e==null||u?void 0:[]:e==null||u?t[t.length-1]:Wi(t,Math.max(0,t.length-e))}function PF(t){return ni(t,Boolean)}function LF(t,e){return Qi(t,e,!1)}const zc=E0(function(t,e){return e=Qi(e,!0,!0),ni(t,function(u){return!Q0(e,u)})}),RF=E0(function(t,e){return zc(t,e)});function Cs(t,e,u,r){hc(e)||(r=u,u=e,e=!1),u!=null&&(u=L0(u,r));for(var i=[],s=[],o=0,f=P0(t);o<f;o++){var n=t[o],h=u?u(n,o,t):n;e&&!u?((!o||s!==h)&&i.push(n),s=h):u?Q0(s,h)||(s.push(h),i.push(n)):Q0(i,n)||i.push(n)}return i}const BF=E0(function(t){return Cs(Qi(t,!0,!0))});function IF(t){for(var e=[],u=arguments.length,r=0,i=P0(t);r<i;r++){var s=t[r];if(!Q0(e,s)){var o;for(o=1;o<u&&Q0(arguments[o],s);o++);o===u&&e.push(s)}}return e}function Es(t){for(var e=t&&Nc(t,P0).length||0,u=Array(e),r=0;r<e;r++)u[r]=eo(t,r);return u}const OF=E0(Es);function $F(t,e){for(var u={},r=0,i=P0(t);r<i;r++)e?u[t[r]]=e[r]:u[t[r][0]]=t[r][1];return u}function NF(t,e,u){e==null&&(e=t||0,t=0),u||(u=e<t?-1:1);for(var r=Math.max(Math.ceil((e-t)/u),0),i=Array(r),s=0;s<r;s++,t+=u)i[s]=t;return i}function WF(t,e){if(e==null||e<1)return[];for(var u=[],r=0,i=t.length;r<i;)u.push(Ts.call(t,r,r+=e));return u}function Vc(t,e){return t._chain?Pt(e).chain():e}function Gc(t){return dr(ws(t),function(e){var u=Pt[e]=t[e];Pt.prototype[e]=function(){var r=[this._wrapped];return iv.apply(r,arguments),Vc(this,u.apply(Pt,r))}}),Pt}dr(["pop","push","reverse","shift","sort","splice","unshift"],function(t){var e=Vn[t];Pt.prototype[t]=function(){var u=this._wrapped;return u!=null&&(e.apply(u,arguments),(t==="shift"||t==="splice")&&u.length===0&&delete u[0]),Vc(this,u)}});dr(["concat","join","slice"],function(t){var e=Vn[t];Pt.prototype[t]=function(){var u=this._wrapped;return u!=null&&(u=e.apply(u,arguments)),Vc(this,u)}});const Sv=Object.freeze(Object.defineProperty({__proto__:null,VERSION:lc,after:hF,all:Sn,allKeys:Mu,any:_n,assign:Cu,before:Rc,bind:Pc,bindAll:nF,chain:uF,chunk:WF,clone:U2,collect:Wr,compact:PF,compose:FF,constant:bc,contains:Q0,countBy:SF,create:H2,debounce:lF,default:Pt,defaults:Sc,defer:aF,delay:Lc,detect:ys,difference:zc,drop:Wi,each:dr,escape:X2,every:Sn,extend:jc,extendOwn:Cu,filter:ni,find:ys,findIndex:Zn,findKey:Bc,findLastIndex:Ic,findWhere:vF,first:mu,flatten:LF,foldl:fu,foldr:jn,forEach:dr,functions:ws,get:Mc,groupBy:kF,has:z2,head:mu,identity:Yn,include:Q0,includes:Q0,indexBy:jF,indexOf:$c,initial:qc,inject:fu,intersection:IF,invert:xc,invoke:yF,isArguments:Kn,isArray:li,isArrayBuffer:fc,isBoolean:hc,isDataView:bs,isDate:w2,isElement:b2,isEmpty:D2,isEqual:T2,isError:C2,isFinite:k2,isFunction:v0,isMap:B2,isMatch:yc,isNaN:vc,isNull:v2,isNumber:gc,isObject:ci,isRegExp:y2,isSet:O2,isString:Gn,isSymbol:pc,isTypedArray:wc,isUndefined:Fc,isWeakMap:I2,isWeakSet:$2,iteratee:Qn,keys:d0,last:TF,lastIndexOf:mF,map:Wr,mapObject:G2,matcher:qi,matches:qi,max:Nc,memoize:oF,methods:ws,min:EF,mixin:Gc,negate:Xn,noop:Tc,now:Eu,object:$F,omit:MF,once:gF,pairs:N2,partial:Ji,partition:_F,pick:Uc,pluck:eo,property:Jn,propertyOf:K2,random:kn,range:NF,reduce:fu,reduceRight:jn,reject:wF,rest:Wi,restArguments:E0,result:rF,sample:Hc,select:ni,shuffle:AF,size:DF,some:_n,sortBy:xF,sortedIndex:Oc,tail:Wi,take:mu,tap:q2,template:tF,templateSettings:eF,throttle:cF,times:Y2,toArray:Wc,toPath:_c,transpose:Es,unescape:Z2,union:BF,uniq:Cs,unique:Cs,uniqueId:iF,unzip:Es,values:Yi,where:CF,without:RF,wrap:dF,zip:OF},Symbol.toStringTag,{value:"Module"}));var xe=Gc(Sv);xe._=xe;const _v=Object.freeze(Object.defineProperty({__proto__:null,VERSION:lc,after:hF,all:Sn,allKeys:Mu,any:_n,assign:Cu,before:Rc,bind:Pc,bindAll:nF,chain:uF,chunk:WF,clone:U2,collect:Wr,compact:PF,compose:FF,constant:bc,contains:Q0,countBy:SF,create:H2,debounce:lF,default:xe,defaults:Sc,defer:aF,delay:Lc,detect:ys,difference:zc,drop:Wi,each:dr,escape:X2,every:Sn,extend:jc,extendOwn:Cu,filter:ni,find:ys,findIndex:Zn,findKey:Bc,findLastIndex:Ic,findWhere:vF,first:mu,flatten:LF,foldl:fu,foldr:jn,forEach:dr,functions:ws,get:Mc,groupBy:kF,has:z2,head:mu,identity:Yn,include:Q0,includes:Q0,indexBy:jF,indexOf:$c,initial:qc,inject:fu,intersection:IF,invert:xc,invoke:yF,isArguments:Kn,isArray:li,isArrayBuffer:fc,isBoolean:hc,isDataView:bs,isDate:w2,isElement:b2,isEmpty:D2,isEqual:T2,isError:C2,isFinite:k2,isFunction:v0,isMap:B2,isMatch:yc,isNaN:vc,isNull:v2,isNumber:gc,isObject:ci,isRegExp:y2,isSet:O2,isString:Gn,isSymbol:pc,isTypedArray:wc,isUndefined:Fc,isWeakMap:I2,isWeakSet:$2,iteratee:Qn,keys:d0,last:TF,lastIndexOf:mF,map:Wr,mapObject:G2,matcher:qi,matches:qi,max:Nc,memoize:oF,methods:ws,min:EF,mixin:Gc,negate:Xn,noop:Tc,now:Eu,object:$F,omit:MF,once:gF,pairs:N2,partial:Ji,partition:_F,pick:Uc,pluck:eo,property:Jn,propertyOf:K2,random:kn,range:NF,reduce:fu,reduceRight:jn,reject:wF,rest:Wi,restArguments:E0,result:rF,sample:Hc,select:ni,shuffle:AF,size:DF,some:_n,sortBy:xF,sortedIndex:Oc,tail:Wi,take:mu,tap:q2,template:tF,templateSettings:eF,throttle:cF,times:Y2,toArray:Wc,toPath:_c,transpose:Es,unescape:Z2,union:BF,uniq:Cs,unique:Cs,uniqueId:iF,unzip:Es,values:Yi,where:CF,without:RF,wrap:dF,zip:OF},Symbol.toStringTag,{value:"Module"}));var HF={};const Dv=tv(_v);(function(t){(function(e){var u=typeof self=="object"&&self.self===self&&self||typeof yr=="object"&&yr.global===yr&&yr;{var r=Dv,i;try{i=cc()}catch{}e(u,t,r,i)}})(function(e,u,r,i){var s=e.Backbone,o=Array.prototype.slice;u.VERSION="1.4.1",u.$=i,u.noConflict=function(){return e.Backbone=s,this},u.emulateHTTP=!1,u.emulateJSON=!1;var f=u.Events={},n=/\s+/,h,g=function(z,G,O,I,v){var E=0,L;if(O&&typeof O=="object")for(I!==void 0&&("context"in v)&&v.context===void 0&&(v.context=I),L=r.keys(O);E<L.length;E++)G=g(z,G,L[E],O[L[E]],v);else if(O&&n.test(O))for(L=O.split(n);E<L.length;E++)G=z(G,L[E],I,v);else G=z(G,O,I,v);return G};f.on=function(z,G,O){if(this._events=g(d,this._events||{},z,G,{context:O,ctx:this,listening:h}),h){var I=this._listeners||(this._listeners={});I[h.id]=h,h.interop=!1}return this},f.listenTo=function(z,G,O){if(!z)return this;var I=z._listenId||(z._listenId=r.uniqueId("l")),v=this._listeningTo||(this._listeningTo={}),E=h=v[I];E||(this._listenId||(this._listenId=r.uniqueId("l")),E=h=v[I]=new m(this,z));var L=l(z,G,O,this);if(h=void 0,L)throw L;return E.interop&&E.on(G,O),this};var d=function(z,G,O,I){if(O){var v=z[G]||(z[G]=[]),E=I.context,L=I.ctx,S=I.listening;S&&S.count++,v.push({callback:O,context:E,ctx:E||L,listening:S})}return z},l=function(z,G,O,I){try{z.on(G,O,I)}catch(v){return v}};f.off=function(z,G,O){return this._events?(this._events=g(c,this._events,z,G,{context:O,listeners:this._listeners}),this):this},f.stopListening=function(z,G,O){var I=this._listeningTo;if(!I)return this;for(var v=z?[z._listenId]:r.keys(I),E=0;E<v.length;E++){var L=I[v[E]];if(!L)break;L.obj.off(G,O,this),L.interop&&L.off(G,O)}return r.isEmpty(I)&&(this._listeningTo=void 0),this};var c=function(z,G,O,I){if(z){var v=I.context,E=I.listeners,L=0,S;if(!G&&!v&&!O){for(S=r.keys(E);L<S.length;L++)E[S[L]].cleanup();return}for(S=G?[G]:r.keys(z);L<S.length;L++){G=S[L];var P=z[G];if(!P)break;for(var W=[],K=0;K<P.length;K++){var V=P[K];if(O&&O!==V.callback&&O!==V.callback._callback||v&&v!==V.context)W.push(V);else{var ee=V.listening;ee&&ee.off(G,O)}}W.length?z[G]=W:delete z[G]}return z}};f.once=function(z,G,O){var I=g(a,{},z,G,this.off.bind(this));return typeof z=="string"&&O==null&&(G=void 0),this.on(I,G,O)},f.listenToOnce=function(z,G,O){var I=g(a,{},G,O,this.stopListening.bind(this,z));return this.listenTo(z,I)};var a=function(z,G,O,I){if(O){var v=z[G]=r.once(function(){I(G,v),O.apply(this,arguments)});v._callback=O}return z};f.trigger=function(z){if(!this._events)return this;for(var G=Math.max(0,arguments.length-1),O=Array(G),I=0;I<G;I++)O[I]=arguments[I+1];return g(F,this._events,z,void 0,O),this};var F=function(z,G,O,I){if(z){var v=z[G],E=z.all;v&&E&&(E=E.slice()),v&&p(v,I),E&&p(E,[G].concat(I))}return z},p=function(z,G){var O,I=-1,v=z.length,E=G[0],L=G[1],S=G[2];switch(G.length){case 0:for(;++I<v;)(O=z[I]).callback.call(O.ctx);return;case 1:for(;++I<v;)(O=z[I]).callback.call(O.ctx,E);return;case 2:for(;++I<v;)(O=z[I]).callback.call(O.ctx,E,L);return;case 3:for(;++I<v;)(O=z[I]).callback.call(O.ctx,E,L,S);return;default:for(;++I<v;)(O=z[I]).callback.apply(O.ctx,G);return}},m=function(z,G){this.id=z._listenId,this.listener=z,this.obj=G,this.interop=!0,this.count=0,this._events=void 0};m.prototype.on=f.on,m.prototype.off=function(z,G){var O;this.interop?(this._events=g(c,this._events,z,G,{context:void 0,listeners:void 0}),O=!this._events):(this.count--,O=this.count===0),O&&this.cleanup()},m.prototype.cleanup=function(){delete this.listener._listeningTo[this.obj._listenId],this.interop||delete this.obj._listeners[this.id]},f.bind=f.on,f.unbind=f.off,r.extend(u,f);var b=u.Model=function(z,G){var O=z||{};G||(G={}),this.preinitialize.apply(this,arguments),this.cid=r.uniqueId(this.cidPrefix),this.attributes={},G.collection&&(this.collection=G.collection),G.parse&&(O=this.parse(O,G)||{});var I=r.result(this,"defaults");O=r.defaults(r.extend({},I,O),I),this.set(O,G),this.changed={},this.initialize.apply(this,arguments)};r.extend(b.prototype,f,{changed:null,validationError:null,idAttribute:"id",cidPrefix:"c",preinitialize:function(){},initialize:function(){},toJSON:function(z){return r.clone(this.attributes)},sync:function(){return u.sync.apply(this,arguments)},get:function(z){return this.attributes[z]},escape:function(z){return r.escape(this.get(z))},has:function(z){return this.get(z)!=null},matches:function(z){return!!r.iteratee(z,this)(this.attributes)},set:function(z,G,O){if(z==null)return this;var I;if(typeof z=="object"?(I=z,O=G):(I={})[z]=G,O||(O={}),!this._validate(I,O))return!1;var v=O.unset,E=O.silent,L=[],S=this._changing;this._changing=!0,S||(this._previousAttributes=r.clone(this.attributes),this.changed={});var P=this.attributes,W=this.changed,K=this._previousAttributes;for(var V in I)G=I[V],r.isEqual(P[V],G)||L.push(V),r.isEqual(K[V],G)?delete W[V]:W[V]=G,v?delete P[V]:P[V]=G;if(this.idAttribute in I){var ee=this.id;this.id=this.get(this.idAttribute),this.trigger("changeId",this,ee,O)}if(!E){L.length&&(this._pending=O);for(var Q=0;Q<L.length;Q++)this.trigger("change:"+L[Q],this,P[L[Q]],O)}if(S)return this;if(!E)for(;this._pending;)O=this._pending,this._pending=!1,this.trigger("change",this,O);return this._pending=!1,this._changing=!1,this},unset:function(z,G){return this.set(z,void 0,r.extend({},G,{unset:!0}))},clear:function(z){var G={};for(var O in this.attributes)G[O]=void 0;return this.set(G,r.extend({},z,{unset:!0}))},hasChanged:function(z){return z==null?!r.isEmpty(this.changed):r.has(this.changed,z)},changedAttributes:function(z){if(!z)return this.hasChanged()?r.clone(this.changed):!1;var G=this._changing?this._previousAttributes:this.attributes,O={},I;for(var v in z){var E=z[v];r.isEqual(G[v],E)||(O[v]=E,I=!0)}return I?O:!1},previous:function(z){return z==null||!this._previousAttributes?null:this._previousAttributes[z]},previousAttributes:function(){return r.clone(this._previousAttributes)},fetch:function(z){z=r.extend({parse:!0},z);var G=this,O=z.success;return z.success=function(I){var v=z.parse?G.parse(I,z):I;if(!G.set(v,z))return!1;O&&O.call(z.context,G,I,z),G.trigger("sync",G,I,z)},Ie(this,z),this.sync("read",this,z)},save:function(z,G,O){var I;z==null||typeof z=="object"?(I=z,O=G):(I={})[z]=G,O=r.extend({validate:!0,parse:!0},O);var v=O.wait;if(I&&!v){if(!this.set(I,O))return!1}else if(!this._validate(I,O))return!1;var E=this,L=O.success,S=this.attributes;O.success=function(K){E.attributes=S;var V=O.parse?E.parse(K,O):K;if(v&&(V=r.extend({},I,V)),V&&!E.set(V,O))return!1;L&&L.call(O.context,E,K,O),E.trigger("sync",E,K,O)},Ie(this,O),I&&v&&(this.attributes=r.extend({},S,I));var P=this.isNew()?"create":O.patch?"patch":"update";P==="patch"&&!O.attrs&&(O.attrs=I);var W=this.sync(P,this,O);return this.attributes=S,W},destroy:function(z){z=z?r.clone(z):{};var G=this,O=z.success,I=z.wait,v=function(){G.stopListening(),G.trigger("destroy",G,G.collection,z)};z.success=function(L){I&&v(),O&&O.call(z.context,G,L,z),G.isNew()||G.trigger("sync",G,L,z)};var E=!1;return this.isNew()?r.defer(z.success):(Ie(this,z),E=this.sync("delete",this,z)),I||v(),E},url:function(){var z=r.result(this,"urlRoot")||r.result(this.collection,"url")||Pe();if(this.isNew())return z;var G=this.get(this.idAttribute);return z.replace(/[^\/]$/,"$&/")+encodeURIComponent(G)},parse:function(z,G){return z},clone:function(){return new this.constructor(this.attributes)},isNew:function(){return!this.has(this.idAttribute)},isValid:function(z){return this._validate({},r.extend({},z,{validate:!0}))},_validate:function(z,G){if(!G.validate||!this.validate)return!0;z=r.extend({},this.attributes,z);var O=this.validationError=this.validate(z,G)||null;return O?(this.trigger("invalid",this,O,r.extend(G,{validationError:O})),!1):!0}});var C=u.Collection=function(z,G){G||(G={}),this.preinitialize.apply(this,arguments),G.model&&(this.model=G.model),G.comparator!==void 0&&(this.comparator=G.comparator),this._reset(),this.initialize.apply(this,arguments),z&&this.reset(z,r.extend({silent:!0},G))},k={add:!0,remove:!0,merge:!0},T={add:!0,remove:!1},w=function(z,G,O){O=Math.min(Math.max(O,0),z.length);var I=Array(z.length-O),v=G.length,E;for(E=0;E<I.length;E++)I[E]=z[E+O];for(E=0;E<v;E++)z[E+O]=G[E];for(E=0;E<I.length;E++)z[E+v+O]=I[E]};r.extend(C.prototype,f,{model:b,preinitialize:function(){},initialize:function(){},toJSON:function(z){return this.map(function(G){return G.toJSON(z)})},sync:function(){return u.sync.apply(this,arguments)},add:function(z,G){return this.set(z,r.extend({merge:!1},G,T))},remove:function(z,G){G=r.extend({},G);var O=!r.isArray(z);z=O?[z]:z.slice();var I=this._removeModels(z,G);return!G.silent&&I.length&&(G.changes={added:[],merged:[],removed:I},this.trigger("update",this,G)),O?I[0]:I},set:function(z,G){if(z!=null){G=r.extend({},k,G),G.parse&&!this._isModel(z)&&(z=this.parse(z,G)||[]);var O=!r.isArray(z);z=O?[z]:z.slice();var I=G.at;I!=null&&(I=+I),I>this.length&&(I=this.length),I<0&&(I+=this.length+1);var v=[],E=[],L=[],S=[],P={},W=G.add,K=G.merge,V=G.remove,ee=!1,Q=this.comparator&&I==null&&G.sort!==!1,fe=r.isString(this.comparator)?this.comparator:null,oe,pe;for(pe=0;pe<z.length;pe++){oe=z[pe];var ae=this.get(oe);if(ae){if(K&&oe!==ae){var Ae=this._isModel(oe)?oe.attributes:oe;G.parse&&(Ae=ae.parse(Ae,G)),ae.set(Ae,G),L.push(ae),Q&&!ee&&(ee=ae.hasChanged(fe))}P[ae.cid]||(P[ae.cid]=!0,v.push(ae)),z[pe]=ae}else W&&(oe=z[pe]=this._prepareModel(oe,G),oe&&(E.push(oe),this._addReference(oe,G),P[oe.cid]=!0,v.push(oe)))}if(V){for(pe=0;pe<this.length;pe++)oe=this.models[pe],P[oe.cid]||S.push(oe);S.length&&this._removeModels(S,G)}var Se=!1,ze=!Q&&W&&V;if(v.length&&ze?(Se=this.length!==v.length||r.some(this.models,function(Ve,Me){return Ve!==v[Me]}),this.models.length=0,w(this.models,v,0),this.length=this.models.length):E.length&&(Q&&(ee=!0),w(this.models,E,I??this.length),this.length=this.models.length),ee&&this.sort({silent:!0}),!G.silent){for(pe=0;pe<E.length;pe++)I!=null&&(G.index=I+pe),oe=E[pe],oe.trigger("add",oe,this,G);(ee||Se)&&this.trigger("sort",this,G),(E.length||S.length||L.length)&&(G.changes={added:E,removed:S,merged:L},this.trigger("update",this,G))}return O?z[0]:z}},reset:function(z,G){G=G?r.clone(G):{};for(var O=0;O<this.models.length;O++)this._removeReference(this.models[O],G);return G.previousModels=this.models,this._reset(),z=this.add(z,r.extend({silent:!0},G)),G.silent||this.trigger("reset",this,G),z},push:function(z,G){return this.add(z,r.extend({at:this.length},G))},pop:function(z){var G=this.at(this.length-1);return this.remove(G,z)},unshift:function(z,G){return this.add(z,r.extend({at:0},G))},shift:function(z){var G=this.at(0);return this.remove(G,z)},slice:function(){return o.apply(this.models,arguments)},get:function(z){if(z!=null)return this._byId[z]||this._byId[this.modelId(this._isModel(z)?z.attributes:z,z.idAttribute)]||z.cid&&this._byId[z.cid]},has:function(z){return this.get(z)!=null},at:function(z){return z<0&&(z+=this.length),this.models[z]},where:function(z,G){return this[G?"find":"filter"](z)},findWhere:function(z){return this.where(z,!0)},sort:function(z){var G=this.comparator;if(!G)throw new Error("Cannot sort a set without a comparator");z||(z={});var O=G.length;return r.isFunction(G)&&(G=G.bind(this)),O===1||r.isString(G)?this.models=this.sortBy(G):this.models.sort(G),z.silent||this.trigger("sort",this,z),this},pluck:function(z){return this.map(z+"")},fetch:function(z){z=r.extend({parse:!0},z);var G=z.success,O=this;return z.success=function(I){var v=z.reset?"reset":"set";O[v](I,z),G&&G.call(z.context,O,I,z),O.trigger("sync",O,I,z)},Ie(this,z),this.sync("read",this,z)},create:function(z,G){G=G?r.clone(G):{};var O=G.wait;if(z=this._prepareModel(z,G),!z)return!1;O||this.add(z,G);var I=this,v=G.success;return G.success=function(E,L,S){O&&I.add(E,S),v&&v.call(S.context,E,L,S)},z.save(null,G),z},parse:function(z,G){return z},clone:function(){return new this.constructor(this.models,{model:this.model,comparator:this.comparator})},modelId:function(z,G){return z[G||this.model.prototype.idAttribute||"id"]},values:function(){return new M(this,x)},keys:function(){return new M(this,R)},entries:function(){return new M(this,N)},_reset:function(){this.length=0,this.models=[],this._byId={}},_prepareModel:function(z,G){if(this._isModel(z))return z.collection||(z.collection=this),z;G=G?r.clone(G):{},G.collection=this;var O;return this.model.prototype?O=new this.model(z,G):O=this.model(z,G),O.validationError?(this.trigger("invalid",this,O.validationError,G),!1):O},_removeModels:function(z,G){for(var O=[],I=0;I<z.length;I++){var v=this.get(z[I]);if(v){var E=this.indexOf(v);this.models.splice(E,1),this.length--,delete this._byId[v.cid];var L=this.modelId(v.attributes,v.idAttribute);L!=null&&delete this._byId[L],G.silent||(G.index=E,v.trigger("remove",v,this,G)),O.push(v),this._removeReference(v,G)}}return O},_isModel:function(z){return z instanceof b},_addReference:function(z,G){this._byId[z.cid]=z;var O=this.modelId(z.attributes,z.idAttribute);O!=null&&(this._byId[O]=z),z.on("all",this._onModelEvent,this)},_removeReference:function(z,G){delete this._byId[z.cid];var O=this.modelId(z.attributes,z.idAttribute);O!=null&&delete this._byId[O],this===z.collection&&delete z.collection,z.off("all",this._onModelEvent,this)},_onModelEvent:function(z,G,O,I){if(G){if((z==="add"||z==="remove")&&O!==this)return;if(z==="destroy"&&this.remove(G,I),z==="changeId"){var v=this.modelId(G.previousAttributes(),G.idAttribute),E=this.modelId(G.attributes,G.idAttribute);v!=null&&delete this._byId[v],E!=null&&(this._byId[E]=G)}}this.trigger.apply(this,arguments)}});var A=typeof Symbol=="function"&&Symbol.iterator;A&&(C.prototype[A]=C.prototype.values);var M=function(z,G){this._collection=z,this._kind=G,this._index=0},x=1,R=2,N=3;A&&(M.prototype[A]=function(){return this}),M.prototype.next=function(){if(this._collection){if(this._index<this._collection.length){var z=this._collection.at(this._index);this._index++;var G;if(this._kind===x)G=z;else{var O=this._collection.modelId(z.attributes,z.idAttribute);this._kind===R?G=O:G=[O,z]}return{value:G,done:!1}}this._collection=void 0}return{value:void 0,done:!0}};var j=u.View=function(z){this.cid=r.uniqueId("view"),this.preinitialize.apply(this,arguments),r.extend(this,r.pick(z,q)),this._ensureElement(),this.initialize.apply(this,arguments)},B=/^(\S+)\s*(.*)$/,q=["model","collection","el","id","attributes","className","tagName","events"];r.extend(j.prototype,f,{tagName:"div",$:function(z){return this.$el.find(z)},preinitialize:function(){},initialize:function(){},render:function(){return this},remove:function(){return this._removeElement(),this.stopListening(),this},_removeElement:function(){this.$el.remove()},setElement:function(z){return this.undelegateEvents(),this._setElement(z),this.delegateEvents(),this},_setElement:function(z){this.$el=z instanceof u.$?z:u.$(z),this.el=this.$el[0]},delegateEvents:function(z){if(z||(z=r.result(this,"events")),!z)return this;this.undelegateEvents();for(var G in z){var O=z[G];if(r.isFunction(O)||(O=this[O]),!!O){var I=G.match(B);this.delegate(I[1],I[2],O.bind(this))}}return this},delegate:function(z,G,O){return this.$el.on(z+".delegateEvents"+this.cid,G,O),this},undelegateEvents:function(){return this.$el&&this.$el.off(".delegateEvents"+this.cid),this},undelegate:function(z,G,O){return this.$el.off(z+".delegateEvents"+this.cid,G,O),this},_createElement:function(z){return document.createElement(z)},_ensureElement:function(){if(this.el)this.setElement(r.result(this,"el"));else{var z=r.extend({},r.result(this,"attributes"));this.id&&(z.id=r.result(this,"id")),this.className&&(z.class=r.result(this,"className")),this.setElement(this._createElement(r.result(this,"tagName"))),this._setAttributes(z)}},_setAttributes:function(z){this.$el.attr(z)}});var U=function(z,G,O,I){switch(G){case 1:return function(){return z[O](this[I])};case 2:return function(v){return z[O](this[I],v)};case 3:return function(v,E){return z[O](this[I],re(v,this),E)};case 4:return function(v,E,L){return z[O](this[I],re(v,this),E,L)};default:return function(){var v=o.call(arguments);return v.unshift(this[I]),z[O].apply(z,v)}}},Z=function(z,G,O,I){r.each(O,function(v,E){G[E]&&(z.prototype[E]=U(G,v,E,I))})},re=function(z,G){return r.isFunction(z)?z:r.isObject(z)&&!G._isModel(z)?le(z):r.isString(z)?function(O){return O.get(z)}:z},le=function(z){var G=r.matches(z);return function(O){return G(O.attributes)}},ce={forEach:3,each:3,map:3,collect:3,reduce:0,foldl:0,inject:0,reduceRight:0,foldr:0,find:3,detect:3,filter:3,select:3,reject:3,every:3,all:3,some:3,any:3,include:3,includes:3,contains:3,invoke:0,max:3,min:3,toArray:1,size:1,first:3,head:3,take:3,initial:3,rest:3,tail:3,drop:3,last:3,without:0,difference:0,indexOf:3,shuffle:1,lastIndexOf:3,isEmpty:1,chain:1,sample:3,partition:3,groupBy:3,countBy:3,sortBy:3,indexBy:3,findIndex:3,findLastIndex:3},de={keys:1,values:1,pairs:1,invert:1,pick:0,omit:0,chain:1,isEmpty:1};r.each([[C,ce,"models"],[b,de,"attributes"]],function(z){var G=z[0],O=z[1],I=z[2];G.mixin=function(v){var E=r.reduce(r.functions(v),function(L,S){return L[S]=0,L},{});Z(G,v,E,I)},Z(G,r,O,I)}),u.sync=function(z,G,O){var I=he[z];r.defaults(O||(O={}),{emulateHTTP:u.emulateHTTP,emulateJSON:u.emulateJSON});var v={type:I,dataType:"json"};if(O.url||(v.url=r.result(G,"url")||Pe()),O.data==null&&G&&(z==="create"||z==="update"||z==="patch")&&(v.contentType="application/json",v.data=JSON.stringify(O.attrs||G.toJSON(O))),O.emulateJSON&&(v.contentType="application/x-www-form-urlencoded",v.data=v.data?{model:v.data}:{}),O.emulateHTTP&&(I==="PUT"||I==="DELETE"||I==="PATCH")){v.type="POST",O.emulateJSON&&(v.data._method=I);var E=O.beforeSend;O.beforeSend=function(P){if(P.setRequestHeader("X-HTTP-Method-Override",I),E)return E.apply(this,arguments)}}v.type!=="GET"&&!O.emulateJSON&&(v.processData=!1);var L=O.error;O.error=function(P,W,K){O.textStatus=W,O.errorThrown=K,L&&L.call(O.context,P,W,K)};var S=O.xhr=u.ajax(r.extend(v,O));return G.trigger("request",G,S,O),S};var he={create:"POST",update:"PUT",patch:"PATCH",delete:"DELETE",read:"GET"};u.ajax=function(){return u.$.ajax.apply(u.$,arguments)};var Fe=u.Router=function(z){z||(z={}),this.preinitialize.apply(this,arguments),z.routes&&(this.routes=z.routes),this._bindRoutes(),this.initialize.apply(this,arguments)},ge=/\((.*?)\)/g,ye=/(\(\?)?:\w+/g,Y=/\*\w+/g,ue=/[\-{}\[\]+?.,\\\^$|#\s]/g;r.extend(Fe.prototype,f,{preinitialize:function(){},initialize:function(){},route:function(z,G,O){r.isRegExp(z)||(z=this._routeToRegExp(z)),r.isFunction(G)&&(O=G,G=""),O||(O=this[G]);var I=this;return u.history.route(z,function(v){var E=I._extractParameters(z,v);I.execute(O,E,G)!==!1&&(I.trigger.apply(I,["route:"+G].concat(E)),I.trigger("route",G,E),u.history.trigger("route",I,G,E))}),this},execute:function(z,G,O){z&&z.apply(this,G)},navigate:function(z,G){return u.history.navigate(z,G),this},_bindRoutes:function(){if(this.routes){this.routes=r.result(this,"routes");for(var z,G=r.keys(this.routes);(z=G.pop())!=null;)this.route(z,this.routes[z])}},_routeToRegExp:function(z){return z=z.replace(ue,"\\$&").replace(ge,"(?:$1)?").replace(ye,function(G,O){return O?G:"([^/?]+)"}).replace(Y,"([^?]*?)"),new RegExp("^"+z+"(?:\\?([\\s\\S]*))?$")},_extractParameters:function(z,G){var O=z.exec(G).slice(1);return r.map(O,function(I,v){return v===O.length-1?I||null:I?decodeURIComponent(I):null})}});var Ee=u.History=function(){this.handlers=[],this.checkUrl=this.checkUrl.bind(this),typeof window<"u"&&(this.location=window.location,this.history=window.history)},ne=/^[#\/]|\s+$/g,me=/^\/+|\/+$/g,se=/#.*$/;Ee.started=!1,r.extend(Ee.prototype,f,{interval:50,atRoot:function(){var z=this.location.pathname.replace(/[^\/]$/,"$&/");return z===this.root&&!this.getSearch()},matchRoot:function(){var z=this.decodeFragment(this.location.pathname),G=z.slice(0,this.root.length-1)+"/";return G===this.root},decodeFragment:function(z){return decodeURI(z.replace(/%25/g,"%2525"))},getSearch:function(){var z=this.location.href.replace(/#.*/,"").match(/\?.+/);return z?z[0]:""},getHash:function(z){var G=(z||this).location.href.match(/#(.*)$/);return G?G[1]:""},getPath:function(){var z=this.decodeFragment(this.location.pathname+this.getSearch()).slice(this.root.length-1);return z.charAt(0)==="/"?z.slice(1):z},getFragment:function(z){return z==null&&(this._usePushState||!this._wantsHashChange?z=this.getPath():z=this.getHash()),z.replace(ne,"")},start:function(z){if(Ee.started)throw new Error("Backbone.history has already been started");if(Ee.started=!0,this.options=r.extend({root:"/"},this.options,z),this.root=this.options.root,this._wantsHashChange=this.options.hashChange!==!1,this._hasHashChange="onhashchange"in window&&(document.documentMode===void 0||document.documentMode>7),this._useHashChange=this._wantsHashChange&&this._hasHashChange,this._wantsPushState=!!this.options.pushState,this._hasPushState=!!(this.history&&this.history.pushState),this._usePushState=this._wantsPushState&&this._hasPushState,this.fragment=this.getFragment(),this.root=("/"+this.root+"/").replace(me,"/"),this._wantsHashChange&&this._wantsPushState)if(!this._hasPushState&&!this.atRoot()){var G=this.root.slice(0,-1)||"/";return this.location.replace(G+"#"+this.getPath()),!0}else this._hasPushState&&this.atRoot()&&this.navigate(this.getHash(),{replace:!0});if(!this._hasHashChange&&this._wantsHashChange&&!this._usePushState){this.iframe=document.createElement("iframe"),this.iframe.src="javascript:0",this.iframe.style.display="none",this.iframe.tabIndex=-1;var O=document.body,I=O.insertBefore(this.iframe,O.firstChild).contentWindow;I.document.open(),I.document.close(),I.location.hash="#"+this.fragment}var v=window.addEventListener||function(E,L){return attachEvent("on"+E,L)};if(this._usePushState?v("popstate",this.checkUrl,!1):this._useHashChange&&!this.iframe?v("hashchange",this.checkUrl,!1):this._wantsHashChange&&(this._checkUrlInterval=setInterval(this.checkUrl,this.interval)),!this.options.silent)return this.loadUrl()},stop:function(){var z=window.removeEventListener||function(G,O){return detachEvent("on"+G,O)};this._usePushState?z("popstate",this.checkUrl,!1):this._useHashChange&&!this.iframe&&z("hashchange",this.checkUrl,!1),this.iframe&&(document.body.removeChild(this.iframe),this.iframe=null),this._checkUrlInterval&&clearInterval(this._checkUrlInterval),Ee.started=!1},route:function(z,G){this.handlers.unshift({route:z,callback:G})},checkUrl:function(z){var G=this.getFragment();if(G===this.fragment&&this.iframe&&(G=this.getHash(this.iframe.contentWindow)),G===this.fragment)return!1;this.iframe&&this.navigate(G),this.loadUrl()},loadUrl:function(z){return this.matchRoot()?(z=this.fragment=this.getFragment(z),r.some(this.handlers,function(G){if(G.route.test(z))return G.callback(z),!0})):!1},navigate:function(z,G){if(!Ee.started)return!1;(!G||G===!0)&&(G={trigger:!!G}),z=this.getFragment(z||"");var O=this.root;(z===""||z.charAt(0)==="?")&&(O=O.slice(0,-1)||"/");var I=O+z;z=z.replace(se,"");var v=this.decodeFragment(z);if(this.fragment!==v){if(this.fragment=v,this._usePushState)this.history[G.replace?"replaceState":"pushState"]({},document.title,I);else if(this._wantsHashChange){if(this._updateHash(this.location,z,G.replace),this.iframe&&z!==this.getHash(this.iframe.contentWindow)){var E=this.iframe.contentWindow;G.replace||(E.document.open(),E.document.close()),this._updateHash(E.location,z,G.replace)}}else return this.location.assign(I);if(G.trigger)return this.loadUrl(z)}},_updateHash:function(z,G,O){if(O){var I=z.href.replace(/(javascript:|#).*$/,"");z.replace(I+"#"+G)}else z.hash="#"+G}}),u.history=new Ee;var ve=function(z,G){var O=this,I;return z&&r.has(z,"constructor")?I=z.constructor:I=function(){return O.apply(this,arguments)},r.extend(I,O,G),I.prototype=r.create(O.prototype,z),I.prototype.constructor=I,I.__super__=O.prototype,I};b.extend=C.extend=Fe.extend=j.extend=Ee.extend=ve;var Pe=function(){throw new Error('A "url" property or function must be specified')},Ie=function(z,G){var O=G.error;G.error=function(I){O&&O.call(G.context,z,I,G),z.trigger("error",z,I,G)}};return u})})(HF);const s0=zn(HF);var UF;function Ze(){return UF.apply(null,arguments)}function Mv(t){UF=t}function Er(t){return t instanceof Array||Object.prototype.toString.call(t)==="[object Array]"}function hs(t){return t!=null&&Object.prototype.toString.call(t)==="[object Object]"}function Tv(t){if(Object.getOwnPropertyNames)return Object.getOwnPropertyNames(t).length===0;var e;for(e in t)if(t.hasOwnProperty(e))return!1;return!0}function D0(t){return t===void 0}function zi(t){return typeof t=="number"||Object.prototype.toString.call(t)==="[object Number]"}function ro(t){return t instanceof Date||Object.prototype.toString.call(t)==="[object Date]"}function qF(t,e){var u=[],r;for(r=0;r<t.length;++r)u.push(e(t[r],r));return u}function r0(t,e){return Object.prototype.hasOwnProperty.call(t,e)}function ii(t,e){for(var u in e)r0(e,u)&&(t[u]=e[u]);return r0(e,"toString")&&(t.toString=e.toString),r0(e,"valueOf")&&(t.valueOf=e.valueOf),t}function xr(t,e,u,r){return mh(t,e,u,r,!0).utc()}function Pv(){return{empty:!1,unusedTokens:[],unusedInput:[],overflow:-2,charsLeftOver:0,nullInput:!1,invalidMonth:null,invalidFormat:!1,userInvalidated:!1,iso:!1,parsedDateParts:[],meridiem:null,rfc2822:!1,weekdayMismatch:!1}}function Et(t){return t._pf==null&&(t._pf=Pv()),t._pf}var Da;Array.prototype.some?Da=Array.prototype.some:Da=function(t){for(var e=Object(this),u=e.length>>>0,r=0;r<u;r++)if(r in e&&t.call(this,e[r],r,e))return!0;return!1};function Kc(t){if(t._isValid==null){var e=Et(t),u=Da.call(e.parsedDateParts,function(i){return i!=null}),r=!isNaN(t._d.getTime())&&e.overflow<0&&!e.empty&&!e.invalidMonth&&!e.invalidWeekday&&!e.weekdayMismatch&&!e.nullInput&&!e.invalidFormat&&!e.userInvalidated&&(!e.meridiem||e.meridiem&&u);if(t._strict&&(r=r&&e.charsLeftOver===0&&e.unusedTokens.length===0&&e.bigHour===void 0),Object.isFrozen==null||!Object.isFrozen(t))t._isValid=r;else return r}return t._isValid}function io(t){var e=xr(NaN);return t!=null?ii(Et(e),t):Et(e).userInvalidated=!0,e}var ra=Ze.momentProperties=[];function Yc(t,e){var u,r,i;if(D0(e._isAMomentObject)||(t._isAMomentObject=e._isAMomentObject),D0(e._i)||(t._i=e._i),D0(e._f)||(t._f=e._f),D0(e._l)||(t._l=e._l),D0(e._strict)||(t._strict=e._strict),D0(e._tzm)||(t._tzm=e._tzm),D0(e._isUTC)||(t._isUTC=e._isUTC),D0(e._offset)||(t._offset=e._offset),D0(e._pf)||(t._pf=Et(e)),D0(e._locale)||(t._locale=e._locale),ra.length>0)for(u=0;u<ra.length;u++)r=ra[u],i=e[r],D0(i)||(t[r]=i);return t}var ia=!1;function Rs(t){Yc(this,t),this._d=new Date(t._d!=null?t._d.getTime():NaN),this.isValid()||(this._d=new Date(NaN)),ia===!1&&(ia=!0,Ze.updateOffset(this),ia=!1)}function Ar(t){return t instanceof Rs||t!=null&&t._isAMomentObject!=null}function J0(t){return t<0?Math.ceil(t)||0:Math.floor(t)}function At(t){var e=+t,u=0;return e!==0&&isFinite(e)&&(u=J0(e)),u}function zF(t,e,u){var r=Math.min(t.length,e.length),i=Math.abs(t.length-e.length),s=0,o;for(o=0;o<r;o++)(u&&t[o]!==e[o]||!u&&At(t[o])!==At(e[o]))&&s++;return s+i}function VF(t){Ze.suppressDeprecationWarnings===!1&&typeof console<"u"&&console.warn&&console.warn("Deprecation warning: "+t)}function Z0(t,e){var u=!0;return ii(function(){if(Ze.deprecationHandler!=null&&Ze.deprecationHandler(null,t),u){for(var r=[],i,s=0;s<arguments.length;s++){if(i="",typeof arguments[s]=="object"){i+=`
[`+s+"] ";for(var o in arguments[0])i+=o+": "+arguments[0][o]+", ";i=i.slice(0,-2)}else i=arguments[s];r.push(i)}VF(t+`
Arguments: `+Array.prototype.slice.call(r).join("")+`
`+new Error().stack),u=!1}return e.apply(this,arguments)},e)}var wd={};function GF(t,e){Ze.deprecationHandler!=null&&Ze.deprecationHandler(t,e),wd[t]||(VF(e),wd[t]=!0)}Ze.suppressDeprecationWarnings=!1;Ze.deprecationHandler=null;function kr(t){return t instanceof Function||Object.prototype.toString.call(t)==="[object Function]"}function Lv(t){var e,u;for(u in t)e=t[u],kr(e)?this[u]=e:this["_"+u]=e;this._config=t,this._dayOfMonthOrdinalParseLenient=new RegExp((this._dayOfMonthOrdinalParse.source||this._ordinalParse.source)+"|"+/\d{1,2}/.source)}function KF(t,e){var u=ii({},t),r;for(r in e)r0(e,r)&&(hs(t[r])&&hs(e[r])?(u[r]={},ii(u[r],t[r]),ii(u[r],e[r])):e[r]!=null?u[r]=e[r]:delete u[r]);for(r in t)r0(t,r)&&!r0(e,r)&&hs(t[r])&&(u[r]=ii({},u[r]));return u}function Jc(t){t!=null&&this.set(t)}var Ma;Object.keys?Ma=Object.keys:Ma=function(t){var e,u=[];for(e in t)r0(t,e)&&u.push(e);return u};var Rv={sameDay:"[Today at] LT",nextDay:"[Tomorrow at] LT",nextWeek:"dddd [at] LT",lastDay:"[Yesterday at] LT",lastWeek:"[Last] dddd [at] LT",sameElse:"L"};function Bv(t,e,u){var r=this._calendar[t]||this._calendar.sameElse;return kr(r)?r.call(e,u):r}var Iv={LTS:"h:mm:ss A",LT:"h:mm A",L:"MM/DD/YYYY",LL:"MMMM D, YYYY",LLL:"MMMM D, YYYY h:mm A",LLLL:"dddd, MMMM D, YYYY h:mm A"};function Ov(t){var e=this._longDateFormat[t],u=this._longDateFormat[t.toUpperCase()];return e||!u?e:(this._longDateFormat[t]=u.replace(/MMMM|MM|DD|dddd/g,function(r){return r.slice(1)}),this._longDateFormat[t])}var $v="Invalid date";function Nv(){return this._invalidDate}var Wv="%d",Hv=/\d{1,2}/;function Uv(t){return this._ordinal.replace("%d",t)}var qv={future:"in %s",past:"%s ago",s:"a few seconds",ss:"%d seconds",m:"a minute",mm:"%d minutes",h:"an hour",hh:"%d hours",d:"a day",dd:"%d days",M:"a month",MM:"%d months",y:"a year",yy:"%d years"};function zv(t,e,u,r){var i=this._relativeTime[u];return kr(i)?i(t,e,u,r):i.replace(/%d/i,t)}function Vv(t,e){var u=this._relativeTime[t>0?"future":"past"];return kr(u)?u(e):u.replace(/%s/i,e)}var gs={};function y0(t,e){var u=t.toLowerCase();gs[u]=gs[u+"s"]=gs[e]=t}function er(t){return typeof t=="string"?gs[t]||gs[t.toLowerCase()]:void 0}function Qc(t){var e={},u,r;for(r in t)r0(t,r)&&(u=er(r),u&&(e[u]=t[r]));return e}var YF={};function C0(t,e){YF[t]=e}function Gv(t){var e=[];for(var u in t)e.push({unit:u,priority:YF[u]});return e.sort(function(r,i){return r.priority-i.priority}),e}function Hr(t,e,u){var r=""+Math.abs(t),i=e-r.length,s=t>=0;return(s?u?"+":"":"-")+Math.pow(10,Math.max(0,i)).toString().substr(1)+r}var JF=/(\[[^\[]*\])|(\\)?([Hh]mm(ss)?|Mo|MM?M?M?|Do|DDDo|DD?D?D?|ddd?d?|do?|w[o|w]?|W[o|W]?|Qo?|YYYYYY|YYYYY|YYYY|YY|gg(ggg?)?|GG(GGG?)?|e|E|a|A|hh?|HH?|kk?|mm?|ss?|S{1,9}|x|X|zz?|ZZ?|.)/g,Qs=/(\[[^\[]*\])|(\\)?(LTS|LT|LL?L?L?|l{1,4})/g,ua={},vu={};function mt(t,e,u,r){var i=r;typeof r=="string"&&(i=function(){return this[r]()}),t&&(vu[t]=i),e&&(vu[e[0]]=function(){return Hr(i.apply(this,arguments),e[1],e[2])}),u&&(vu[u]=function(){return this.localeData().ordinal(i.apply(this,arguments),t)})}function Kv(t){return t.match(/\[[\s\S]/)?t.replace(/^\[|\]$/g,""):t.replace(/\\/g,"")}function Yv(t){var e=t.match(JF),u,r;for(u=0,r=e.length;u<r;u++)vu[e[u]]?e[u]=vu[e[u]]:e[u]=Kv(e[u]);return function(i){var s="",o;for(o=0;o<r;o++)s+=kr(e[o])?e[o].call(i,t):e[o];return s}}function bn(t,e){return t.isValid()?(e=QF(e,t.localeData()),ua[e]=ua[e]||Yv(e),ua[e](t)):t.localeData().invalidDate()}function QF(t,e){var u=5;function r(i){return e.longDateFormat(i)||i}for(Qs.lastIndex=0;u>=0&&Qs.test(t);)t=t.replace(Qs,r),Qs.lastIndex=0,u-=1;return t}var XF=/\d/,U0=/\d\d/,ZF=/\d{3}/,Xc=/\d{4}/,uo=/[+-]?\d{6}/,qt=/\d\d?/,eh=/\d\d\d\d?/,th=/\d\d\d\d\d\d?/,so=/\d{1,3}/,Zc=/\d{1,4}/,no=/[+-]?\d{1,6}/,Jv=/\d+/,oo=/[+-]?\d+/,Qv=/Z|[+-]\d\d:?\d\d/gi,ao=/Z|[+-]\d\d(?::?\d\d)?/gi,Xv=/[+-]?\d+(\.\d{1,3})?/,Bs=/[0-9]{0,256}['a-z\u00A0-\u05FF\u0700-\uD7FF\uF900-\uFDCF\uFDF0-\uFF07\uFF10-\uFFEF]{1,256}|[\u0600-\u06FF\/]{1,256}(\s*?[\u0600-\u06FF]{1,256}){1,2}/i,Ta={};function ct(t,e,u){Ta[t]=kr(e)?e:function(r,i){return r&&u?u:e}}function Zv(t,e){return r0(Ta,t)?Ta[t](e._strict,e._locale):new RegExp(eb(t))}function eb(t){return Hi(t.replace("\\","").replace(/\\(\[)|\\(\])|\[([^\]\[]*)\]|\\(.)/g,function(e,u,r,i,s){return u||r||i||s}))}function Hi(t){return t.replace(/[-\/\\^$*+?.()|[\]{}]/g,"\\$&")}var Pa={};function zt(t,e){var u,r=e;for(typeof t=="string"&&(t=[t]),zi(e)&&(r=function(i,s){s[e]=At(i)}),u=0;u<t.length;u++)Pa[t[u]]=r}function Is(t,e){zt(t,function(u,r,i,s){i._w=i._w||{},e(u,i._w,i,s)})}function tb(t,e,u){e!=null&&r0(Pa,t)&&Pa[t](e,u._a,u,t)}var cr=0,$r=1,br=2,l0=3,ar=4,Nr=5,Ni=6,rb=7,ib=8;mt("Y",0,0,function(){var t=this.year();return t<=9999?""+t:"+"+t});mt(0,["YY",2],0,function(){return this.year()%100});mt(0,["YYYY",4],0,"year");mt(0,["YYYYY",5],0,"year");mt(0,["YYYYYY",6,!0],0,"year");y0("year","y");C0("year",1);ct("Y",oo);ct("YY",qt,U0);ct("YYYY",Zc,Xc);ct("YYYYY",no,uo);ct("YYYYYY",no,uo);zt(["YYYYY","YYYYYY"],cr);zt("YYYY",function(t,e){e[cr]=t.length===2?Ze.parseTwoDigitYear(t):At(t)});zt("YY",function(t,e){e[cr]=Ze.parseTwoDigitYear(t)});zt("Y",function(t,e){e[cr]=parseInt(t,10)});function ps(t){return co(t)?366:365}function co(t){return t%4===0&&t%100!==0||t%400===0}Ze.parseTwoDigitYear=function(t){return At(t)+(At(t)>68?1900:2e3)};var rh=Tu("FullYear",!0);function ub(){return co(this.year())}function Tu(t,e){return function(u){return u!=null?(ih(this,t,u),Ze.updateOffset(this,e),this):Dn(this,t)}}function Dn(t,e){return t.isValid()?t._d["get"+(t._isUTC?"UTC":"")+e]():NaN}function ih(t,e,u){t.isValid()&&!isNaN(u)&&(e==="FullYear"&&co(t.year())&&t.month()===1&&t.date()===29?t._d["set"+(t._isUTC?"UTC":"")+e](u,t.month(),lo(u,t.month())):t._d["set"+(t._isUTC?"UTC":"")+e](u))}function sb(t){return t=er(t),kr(this[t])?this[t]():this}function nb(t,e){if(typeof t=="object"){t=Qc(t);for(var u=Gv(t),r=0;r<u.length;r++)this[u[r].unit](t[u[r].unit])}else if(t=er(t),kr(this[t]))return this[t](e);return this}function ob(t,e){return(t%e+e)%e}var t0;Array.prototype.indexOf?t0=Array.prototype.indexOf:t0=function(t){var e;for(e=0;e<this.length;++e)if(this[e]===t)return e;return-1};function lo(t,e){if(isNaN(t)||isNaN(e))return NaN;var u=ob(e,12);return t+=(e-u)/12,u===1?co(t)?29:28:31-u%7%2}mt("M",["MM",2],"Mo",function(){return this.month()+1});mt("MMM",0,0,function(t){return this.localeData().monthsShort(this,t)});mt("MMMM",0,0,function(t){return this.localeData().months(this,t)});y0("month","M");C0("month",8);ct("M",qt);ct("MM",qt,U0);ct("MMM",function(t,e){return e.monthsShortRegex(t)});ct("MMMM",function(t,e){return e.monthsRegex(t)});zt(["M","MM"],function(t,e){e[$r]=At(t)-1});zt(["MMM","MMMM"],function(t,e,u,r){var i=u._locale.monthsParse(t,r,u._strict);i!=null?e[$r]=i:Et(u).invalidMonth=t});var uh=/D[oD]?(\[[^\[\]]*\]|\s)+MMMM?/,ab="January_February_March_April_May_June_July_August_September_October_November_December".split("_");function cb(t,e){return t?Er(this._months)?this._months[t.month()]:this._months[(this._months.isFormat||uh).test(e)?"format":"standalone"][t.month()]:Er(this._months)?this._months:this._months.standalone}var sh="Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_");function lb(t,e){return t?Er(this._monthsShort)?this._monthsShort[t.month()]:this._monthsShort[uh.test(e)?"format":"standalone"][t.month()]:Er(this._monthsShort)?this._monthsShort:this._monthsShort.standalone}function db(t,e,u){var r,i,s,o=t.toLocaleLowerCase();if(!this._monthsParse)for(this._monthsParse=[],this._longMonthsParse=[],this._shortMonthsParse=[],r=0;r<12;++r)s=xr([2e3,r]),this._shortMonthsParse[r]=this.monthsShort(s,"").toLocaleLowerCase(),this._longMonthsParse[r]=this.months(s,"").toLocaleLowerCase();return u?e==="MMM"?(i=t0.call(this._shortMonthsParse,o),i!==-1?i:null):(i=t0.call(this._longMonthsParse,o),i!==-1?i:null):e==="MMM"?(i=t0.call(this._shortMonthsParse,o),i!==-1?i:(i=t0.call(this._longMonthsParse,o),i!==-1?i:null)):(i=t0.call(this._longMonthsParse,o),i!==-1?i:(i=t0.call(this._shortMonthsParse,o),i!==-1?i:null))}function Fb(t,e,u){var r,i,s;if(this._monthsParseExact)return db.call(this,t,e,u);for(this._monthsParse||(this._monthsParse=[],this._longMonthsParse=[],this._shortMonthsParse=[]),r=0;r<12;r++){if(i=xr([2e3,r]),u&&!this._longMonthsParse[r]&&(this._longMonthsParse[r]=new RegExp("^"+this.months(i,"").replace(".","")+"$","i"),this._shortMonthsParse[r]=new RegExp("^"+this.monthsShort(i,"").replace(".","")+"$","i")),!u&&!this._monthsParse[r]&&(s="^"+this.months(i,"")+"|^"+this.monthsShort(i,""),this._monthsParse[r]=new RegExp(s.replace(".",""),"i")),u&&e==="MMMM"&&this._longMonthsParse[r].test(t))return r;if(u&&e==="MMM"&&this._shortMonthsParse[r].test(t))return r;if(!u&&this._monthsParse[r].test(t))return r}}function nh(t,e){var u;if(!t.isValid())return t;if(typeof e=="string"){if(/^\d+$/.test(e))e=At(e);else if(e=t.localeData().monthsParse(e),!zi(e))return t}return u=Math.min(t.date(),lo(t.year(),e)),t._d["set"+(t._isUTC?"UTC":"")+"Month"](e,u),t}function oh(t){return t!=null?(nh(this,t),Ze.updateOffset(this,!0),this):Dn(this,"Month")}function hb(){return lo(this.year(),this.month())}var gb=Bs;function pb(t){return this._monthsParseExact?(r0(this,"_monthsRegex")||ah.call(this),t?this._monthsShortStrictRegex:this._monthsShortRegex):(r0(this,"_monthsShortRegex")||(this._monthsShortRegex=gb),this._monthsShortStrictRegex&&t?this._monthsShortStrictRegex:this._monthsShortRegex)}var fb=Bs;function mb(t){return this._monthsParseExact?(r0(this,"_monthsRegex")||ah.call(this),t?this._monthsStrictRegex:this._monthsRegex):(r0(this,"_monthsRegex")||(this._monthsRegex=fb),this._monthsStrictRegex&&t?this._monthsStrictRegex:this._monthsRegex)}function ah(){function t(o,f){return f.length-o.length}var e=[],u=[],r=[],i,s;for(i=0;i<12;i++)s=xr([2e3,i]),e.push(this.monthsShort(s,"")),u.push(this.months(s,"")),r.push(this.months(s,"")),r.push(this.monthsShort(s,""));for(e.sort(t),u.sort(t),r.sort(t),i=0;i<12;i++)e[i]=Hi(e[i]),u[i]=Hi(u[i]);for(i=0;i<24;i++)r[i]=Hi(r[i]);this._monthsRegex=new RegExp("^("+r.join("|")+")","i"),this._monthsShortRegex=this._monthsRegex,this._monthsStrictRegex=new RegExp("^("+u.join("|")+")","i"),this._monthsShortStrictRegex=new RegExp("^("+e.join("|")+")","i")}function vb(t,e,u,r,i,s,o){var f;return t<100&&t>=0?(f=new Date(t+400,e,u,r,i,s,o),isFinite(f.getFullYear())&&f.setFullYear(t)):f=new Date(t,e,u,r,i,s,o),f}function As(t){var e;if(t<100&&t>=0){var u=Array.prototype.slice.call(arguments);u[0]=t+400,e=new Date(Date.UTC.apply(null,u)),isFinite(e.getUTCFullYear())&&e.setUTCFullYear(t)}else e=new Date(Date.UTC.apply(null,arguments));return e}function Mn(t,e,u){var r=7+e-u,i=(7+As(t,0,r).getUTCDay()-e)%7;return-i+r-1}function ch(t,e,u,r,i){var s=(7+u-r)%7,o=Mn(t,r,i),f=1+7*(e-1)+s+o,n,h;return f<=0?(n=t-1,h=ps(n)+f):f>ps(t)?(n=t+1,h=f-ps(t)):(n=t,h=f),{year:n,dayOfYear:h}}function xs(t,e,u){var r=Mn(t.year(),e,u),i=Math.floor((t.dayOfYear()-r-1)/7)+1,s,o;return i<1?(o=t.year()-1,s=i+Ui(o,e,u)):i>Ui(t.year(),e,u)?(s=i-Ui(t.year(),e,u),o=t.year()+1):(o=t.year(),s=i),{week:s,year:o}}function Ui(t,e,u){var r=Mn(t,e,u),i=Mn(t+1,e,u);return(ps(t)-r+i)/7}mt("w",["ww",2],"wo","week");mt("W",["WW",2],"Wo","isoWeek");y0("week","w");y0("isoWeek","W");C0("week",5);C0("isoWeek",5);ct("w",qt);ct("ww",qt,U0);ct("W",qt);ct("WW",qt,U0);Is(["w","ww","W","WW"],function(t,e,u,r){e[r.substr(0,1)]=At(t)});function bb(t){return xs(t,this._week.dow,this._week.doy).week}var wb={dow:0,doy:6};function yb(){return this._week.dow}function Cb(){return this._week.doy}function Eb(t){var e=this.localeData().week(this);return t==null?e:this.add((t-e)*7,"d")}function Ab(t){var e=xs(this,1,4).week;return t==null?e:this.add((t-e)*7,"d")}mt("d",0,"do","day");mt("dd",0,0,function(t){return this.localeData().weekdaysMin(this,t)});mt("ddd",0,0,function(t){return this.localeData().weekdaysShort(this,t)});mt("dddd",0,0,function(t){return this.localeData().weekdays(this,t)});mt("e",0,0,"weekday");mt("E",0,0,"isoWeekday");y0("day","d");y0("weekday","e");y0("isoWeekday","E");C0("day",11);C0("weekday",11);C0("isoWeekday",11);ct("d",qt);ct("e",qt);ct("E",qt);ct("dd",function(t,e){return e.weekdaysMinRegex(t)});ct("ddd",function(t,e){return e.weekdaysShortRegex(t)});ct("dddd",function(t,e){return e.weekdaysRegex(t)});Is(["dd","ddd","dddd"],function(t,e,u,r){var i=u._locale.weekdaysParse(t,r,u._strict);i!=null?e.d=i:Et(u).invalidWeekday=t});Is(["d","e","E"],function(t,e,u,r){e[r]=At(t)});function xb(t,e){return typeof t!="string"?t:isNaN(t)?(t=e.weekdaysParse(t),typeof t=="number"?t:null):parseInt(t,10)}function kb(t,e){return typeof t=="string"?e.weekdaysParse(t)%7||7:isNaN(t)?null:t}function el(t,e){return t.slice(e,7).concat(t.slice(0,e))}var jb="Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_");function Sb(t,e){var u=Er(this._weekdays)?this._weekdays:this._weekdays[t&&t!==!0&&this._weekdays.isFormat.test(e)?"format":"standalone"];return t===!0?el(u,this._week.dow):t?u[t.day()]:u}var lh="Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_");function _b(t){return t===!0?el(this._weekdaysShort,this._week.dow):t?this._weekdaysShort[t.day()]:this._weekdaysShort}var Db="Su_Mo_Tu_We_Th_Fr_Sa".split("_");function Mb(t){return t===!0?el(this._weekdaysMin,this._week.dow):t?this._weekdaysMin[t.day()]:this._weekdaysMin}function Tb(t,e,u){var r,i,s,o=t.toLocaleLowerCase();if(!this._weekdaysParse)for(this._weekdaysParse=[],this._shortWeekdaysParse=[],this._minWeekdaysParse=[],r=0;r<7;++r)s=xr([2e3,1]).day(r),this._minWeekdaysParse[r]=this.weekdaysMin(s,"").toLocaleLowerCase(),this._shortWeekdaysParse[r]=this.weekdaysShort(s,"").toLocaleLowerCase(),this._weekdaysParse[r]=this.weekdays(s,"").toLocaleLowerCase();return u?e==="dddd"?(i=t0.call(this._weekdaysParse,o),i!==-1?i:null):e==="ddd"?(i=t0.call(this._shortWeekdaysParse,o),i!==-1?i:null):(i=t0.call(this._minWeekdaysParse,o),i!==-1?i:null):e==="dddd"?(i=t0.call(this._weekdaysParse,o),i!==-1||(i=t0.call(this._shortWeekdaysParse,o),i!==-1)?i:(i=t0.call(this._minWeekdaysParse,o),i!==-1?i:null)):e==="ddd"?(i=t0.call(this._shortWeekdaysParse,o),i!==-1||(i=t0.call(this._weekdaysParse,o),i!==-1)?i:(i=t0.call(this._minWeekdaysParse,o),i!==-1?i:null)):(i=t0.call(this._minWeekdaysParse,o),i!==-1||(i=t0.call(this._weekdaysParse,o),i!==-1)?i:(i=t0.call(this._shortWeekdaysParse,o),i!==-1?i:null))}function Pb(t,e,u){var r,i,s;if(this._weekdaysParseExact)return Tb.call(this,t,e,u);for(this._weekdaysParse||(this._weekdaysParse=[],this._minWeekdaysParse=[],this._shortWeekdaysParse=[],this._fullWeekdaysParse=[]),r=0;r<7;r++){if(i=xr([2e3,1]).day(r),u&&!this._fullWeekdaysParse[r]&&(this._fullWeekdaysParse[r]=new RegExp("^"+this.weekdays(i,"").replace(".","\\.?")+"$","i"),this._shortWeekdaysParse[r]=new RegExp("^"+this.weekdaysShort(i,"").replace(".","\\.?")+"$","i"),this._minWeekdaysParse[r]=new RegExp("^"+this.weekdaysMin(i,"").replace(".","\\.?")+"$","i")),this._weekdaysParse[r]||(s="^"+this.weekdays(i,"")+"|^"+this.weekdaysShort(i,"")+"|^"+this.weekdaysMin(i,""),this._weekdaysParse[r]=new RegExp(s.replace(".",""),"i")),u&&e==="dddd"&&this._fullWeekdaysParse[r].test(t))return r;if(u&&e==="ddd"&&this._shortWeekdaysParse[r].test(t))return r;if(u&&e==="dd"&&this._minWeekdaysParse[r].test(t))return r;if(!u&&this._weekdaysParse[r].test(t))return r}}function Lb(t){if(!this.isValid())return t!=null?this:NaN;var e=this._isUTC?this._d.getUTCDay():this._d.getDay();return t!=null?(t=xb(t,this.localeData()),this.add(t-e,"d")):e}function Rb(t){if(!this.isValid())return t!=null?this:NaN;var e=(this.day()+7-this.localeData()._week.dow)%7;return t==null?e:this.add(t-e,"d")}function Bb(t){if(!this.isValid())return t!=null?this:NaN;if(t!=null){var e=kb(t,this.localeData());return this.day(this.day()%7?e:e-7)}else return this.day()||7}var Ib=Bs;function Ob(t){return this._weekdaysParseExact?(r0(this,"_weekdaysRegex")||tl.call(this),t?this._weekdaysStrictRegex:this._weekdaysRegex):(r0(this,"_weekdaysRegex")||(this._weekdaysRegex=Ib),this._weekdaysStrictRegex&&t?this._weekdaysStrictRegex:this._weekdaysRegex)}var $b=Bs;function Nb(t){return this._weekdaysParseExact?(r0(this,"_weekdaysRegex")||tl.call(this),t?this._weekdaysShortStrictRegex:this._weekdaysShortRegex):(r0(this,"_weekdaysShortRegex")||(this._weekdaysShortRegex=$b),this._weekdaysShortStrictRegex&&t?this._weekdaysShortStrictRegex:this._weekdaysShortRegex)}var Wb=Bs;function Hb(t){return this._weekdaysParseExact?(r0(this,"_weekdaysRegex")||tl.call(this),t?this._weekdaysMinStrictRegex:this._weekdaysMinRegex):(r0(this,"_weekdaysMinRegex")||(this._weekdaysMinRegex=Wb),this._weekdaysMinStrictRegex&&t?this._weekdaysMinStrictRegex:this._weekdaysMinRegex)}function tl(){function t(g,d){return d.length-g.length}var e=[],u=[],r=[],i=[],s,o,f,n,h;for(s=0;s<7;s++)o=xr([2e3,1]).day(s),f=this.weekdaysMin(o,""),n=this.weekdaysShort(o,""),h=this.weekdays(o,""),e.push(f),u.push(n),r.push(h),i.push(f),i.push(n),i.push(h);for(e.sort(t),u.sort(t),r.sort(t),i.sort(t),s=0;s<7;s++)u[s]=Hi(u[s]),r[s]=Hi(r[s]),i[s]=Hi(i[s]);this._weekdaysRegex=new RegExp("^("+i.join("|")+")","i"),this._weekdaysShortRegex=this._weekdaysRegex,this._weekdaysMinRegex=this._weekdaysRegex,this._weekdaysStrictRegex=new RegExp("^("+r.join("|")+")","i"),this._weekdaysShortStrictRegex=new RegExp("^("+u.join("|")+")","i"),this._weekdaysMinStrictRegex=new RegExp("^("+e.join("|")+")","i")}function rl(){return this.hours()%12||12}function Ub(){return this.hours()||24}mt("H",["HH",2],0,"hour");mt("h",["hh",2],0,rl);mt("k",["kk",2],0,Ub);mt("hmm",0,0,function(){return""+rl.apply(this)+Hr(this.minutes(),2)});mt("hmmss",0,0,function(){return""+rl.apply(this)+Hr(this.minutes(),2)+Hr(this.seconds(),2)});mt("Hmm",0,0,function(){return""+this.hours()+Hr(this.minutes(),2)});mt("Hmmss",0,0,function(){return""+this.hours()+Hr(this.minutes(),2)+Hr(this.seconds(),2)});function dh(t,e){mt(t,0,0,function(){return this.localeData().meridiem(this.hours(),this.minutes(),e)})}dh("a",!0);dh("A",!1);y0("hour","h");C0("hour",13);function Fh(t,e){return e._meridiemParse}ct("a",Fh);ct("A",Fh);ct("H",qt);ct("h",qt);ct("k",qt);ct("HH",qt,U0);ct("hh",qt,U0);ct("kk",qt,U0);ct("hmm",eh);ct("hmmss",th);ct("Hmm",eh);ct("Hmmss",th);zt(["H","HH"],l0);zt(["k","kk"],function(t,e,u){var r=At(t);e[l0]=r===24?0:r});zt(["a","A"],function(t,e,u){u._isPm=u._locale.isPM(t),u._meridiem=t});zt(["h","hh"],function(t,e,u){e[l0]=At(t),Et(u).bigHour=!0});zt("hmm",function(t,e,u){var r=t.length-2;e[l0]=At(t.substr(0,r)),e[ar]=At(t.substr(r)),Et(u).bigHour=!0});zt("hmmss",function(t,e,u){var r=t.length-4,i=t.length-2;e[l0]=At(t.substr(0,r)),e[ar]=At(t.substr(r,2)),e[Nr]=At(t.substr(i)),Et(u).bigHour=!0});zt("Hmm",function(t,e,u){var r=t.length-2;e[l0]=At(t.substr(0,r)),e[ar]=At(t.substr(r))});zt("Hmmss",function(t,e,u){var r=t.length-4,i=t.length-2;e[l0]=At(t.substr(0,r)),e[ar]=At(t.substr(r,2)),e[Nr]=At(t.substr(i))});function qb(t){return(t+"").toLowerCase().charAt(0)==="p"}var zb=/[ap]\.?m?\.?/i;function Vb(t,e,u){return t>11?u?"pm":"PM":u?"am":"AM"}var Gb=Tu("Hours",!0),hh={calendar:Rv,longDateFormat:Iv,invalidDate:$v,ordinal:Wv,dayOfMonthOrdinalParse:Hv,relativeTime:qv,months:ab,monthsShort:sh,week:wb,weekdays:jb,weekdaysMin:Db,weekdaysShort:lh,meridiemParse:zb},c0={},Xu={},ks;function yd(t){return t&&t.toLowerCase().replace("_","-")}function Kb(t){for(var e=0,u,r,i,s;e<t.length;){for(s=yd(t[e]).split("-"),u=s.length,r=yd(t[e+1]),r=r?r.split("-"):null;u>0;){if(i=Fo(s.slice(0,u).join("-")),i)return i;if(r&&r.length>=u&&zF(s,r,!0)>=u-1)break;u--}e++}return ks}function Fo(t){var e=null;if(!c0[t]&&typeof An<"u"&&An&&An.exports)try{e=ks._abbr;var u=require;u("./locale/"+t),Pu(e)}catch{}return c0[t]}function Pu(t,e){var u;return t&&(D0(e)?u=Fi(t):u=il(t,e),u?ks=u:typeof console<"u"&&console.warn&&console.warn("Locale "+t+" not found. Did you forget to load it?")),ks._abbr}function il(t,e){if(e!==null){var u,r=hh;if(e.abbr=t,c0[t]!=null)GF("defineLocaleOverride","use moment.updateLocale(localeName, config) to change an existing locale. moment.defineLocale(localeName, config) should only be used for creating a new locale See http://momentjs.com/guides/#/warnings/define-locale/ for more info."),r=c0[t]._config;else if(e.parentLocale!=null)if(c0[e.parentLocale]!=null)r=c0[e.parentLocale]._config;else if(u=Fo(e.parentLocale),u!=null)r=u._config;else return Xu[e.parentLocale]||(Xu[e.parentLocale]=[]),Xu[e.parentLocale].push({name:t,config:e}),null;return c0[t]=new Jc(KF(r,e)),Xu[t]&&Xu[t].forEach(function(i){il(i.name,i.config)}),Pu(t),c0[t]}else return delete c0[t],null}function Yb(t,e){if(e!=null){var u,r,i=hh;r=Fo(t),r!=null&&(i=r._config),e=KF(i,e),u=new Jc(e),u.parentLocale=c0[t],c0[t]=u,Pu(t)}else c0[t]!=null&&(c0[t].parentLocale!=null?c0[t]=c0[t].parentLocale:c0[t]!=null&&delete c0[t]);return c0[t]}function Fi(t){var e;if(t&&t._locale&&t._locale._abbr&&(t=t._locale._abbr),!t)return ks;if(!Er(t)){if(e=Fo(t),e)return e;t=[t]}return Kb(t)}function Jb(){return Ma(c0)}function ul(t){var e,u=t._a;return u&&Et(t).overflow===-2&&(e=u[$r]<0||u[$r]>11?$r:u[br]<1||u[br]>lo(u[cr],u[$r])?br:u[l0]<0||u[l0]>24||u[l0]===24&&(u[ar]!==0||u[Nr]!==0||u[Ni]!==0)?l0:u[ar]<0||u[ar]>59?ar:u[Nr]<0||u[Nr]>59?Nr:u[Ni]<0||u[Ni]>999?Ni:-1,Et(t)._overflowDayOfYear&&(e<cr||e>br)&&(e=br),Et(t)._overflowWeeks&&e===-1&&(e=rb),Et(t)._overflowWeekday&&e===-1&&(e=ib),Et(t).overflow=e),t}function Fu(t,e,u){return t??e??u}function Qb(t){var e=new Date(Ze.now());return t._useUTC?[e.getUTCFullYear(),e.getUTCMonth(),e.getUTCDate()]:[e.getFullYear(),e.getMonth(),e.getDate()]}function sl(t){var e,u,r=[],i,s,o;if(!t._d){for(i=Qb(t),t._w&&t._a[br]==null&&t._a[$r]==null&&Xb(t),t._dayOfYear!=null&&(o=Fu(t._a[cr],i[cr]),(t._dayOfYear>ps(o)||t._dayOfYear===0)&&(Et(t)._overflowDayOfYear=!0),u=As(o,0,t._dayOfYear),t._a[$r]=u.getUTCMonth(),t._a[br]=u.getUTCDate()),e=0;e<3&&t._a[e]==null;++e)t._a[e]=r[e]=i[e];for(;e<7;e++)t._a[e]=r[e]=t._a[e]==null?e===2?1:0:t._a[e];t._a[l0]===24&&t._a[ar]===0&&t._a[Nr]===0&&t._a[Ni]===0&&(t._nextDay=!0,t._a[l0]=0),t._d=(t._useUTC?As:vb).apply(null,r),s=t._useUTC?t._d.getUTCDay():t._d.getDay(),t._tzm!=null&&t._d.setUTCMinutes(t._d.getUTCMinutes()-t._tzm),t._nextDay&&(t._a[l0]=24),t._w&&typeof t._w.d<"u"&&t._w.d!==s&&(Et(t).weekdayMismatch=!0)}}function Xb(t){var e,u,r,i,s,o,f,n;if(e=t._w,e.GG!=null||e.W!=null||e.E!=null)s=1,o=4,u=Fu(e.GG,t._a[cr],xs(Ut(),1,4).year),r=Fu(e.W,1),i=Fu(e.E,1),(i<1||i>7)&&(n=!0);else{s=t._locale._week.dow,o=t._locale._week.doy;var h=xs(Ut(),s,o);u=Fu(e.gg,t._a[cr],h.year),r=Fu(e.w,h.week),e.d!=null?(i=e.d,(i<0||i>6)&&(n=!0)):e.e!=null?(i=e.e+s,(e.e<0||e.e>6)&&(n=!0)):i=s}r<1||r>Ui(u,s,o)?Et(t)._overflowWeeks=!0:n!=null?Et(t)._overflowWeekday=!0:(f=ch(u,r,i,s,o),t._a[cr]=f.year,t._dayOfYear=f.dayOfYear)}var Zb=/^\s*((?:[+-]\d{6}|\d{4})-(?:\d\d-\d\d|W\d\d-\d|W\d\d|\d\d\d|\d\d))(?:(T| )(\d\d(?::\d\d(?::\d\d(?:[.,]\d+)?)?)?)([\+\-]\d\d(?::?\d\d)?|\s*Z)?)?$/,ew=/^\s*((?:[+-]\d{6}|\d{4})(?:\d\d\d\d|W\d\d\d|W\d\d|\d\d\d|\d\d))(?:(T| )(\d\d(?:\d\d(?:\d\d(?:[.,]\d+)?)?)?)([\+\-]\d\d(?::?\d\d)?|\s*Z)?)?$/,tw=/Z|[+-]\d\d(?::?\d\d)?/,Xs=[["YYYYYY-MM-DD",/[+-]\d{6}-\d\d-\d\d/],["YYYY-MM-DD",/\d{4}-\d\d-\d\d/],["GGGG-[W]WW-E",/\d{4}-W\d\d-\d/],["GGGG-[W]WW",/\d{4}-W\d\d/,!1],["YYYY-DDD",/\d{4}-\d{3}/],["YYYY-MM",/\d{4}-\d\d/,!1],["YYYYYYMMDD",/[+-]\d{10}/],["YYYYMMDD",/\d{8}/],["GGGG[W]WWE",/\d{4}W\d{3}/],["GGGG[W]WW",/\d{4}W\d{2}/,!1],["YYYYDDD",/\d{7}/]],sa=[["HH:mm:ss.SSSS",/\d\d:\d\d:\d\d\.\d+/],["HH:mm:ss,SSSS",/\d\d:\d\d:\d\d,\d+/],["HH:mm:ss",/\d\d:\d\d:\d\d/],["HH:mm",/\d\d:\d\d/],["HHmmss.SSSS",/\d\d\d\d\d\d\.\d+/],["HHmmss,SSSS",/\d\d\d\d\d\d,\d+/],["HHmmss",/\d\d\d\d\d\d/],["HHmm",/\d\d\d\d/],["HH",/\d\d/]],rw=/^\/?Date\((\-?\d+)/i;function gh(t){var e,u,r=t._i,i=Zb.exec(r)||ew.exec(r),s,o,f,n;if(i){for(Et(t).iso=!0,e=0,u=Xs.length;e<u;e++)if(Xs[e][1].exec(i[1])){o=Xs[e][0],s=Xs[e][2]!==!1;break}if(o==null){t._isValid=!1;return}if(i[3]){for(e=0,u=sa.length;e<u;e++)if(sa[e][1].exec(i[3])){f=(i[2]||" ")+sa[e][0];break}if(f==null){t._isValid=!1;return}}if(!s&&f!=null){t._isValid=!1;return}if(i[4])if(tw.exec(i[4]))n="Z";else{t._isValid=!1;return}t._f=o+(f||"")+(n||""),nl(t)}else t._isValid=!1}var iw=/^(?:(Mon|Tue|Wed|Thu|Fri|Sat|Sun),?\s)?(\d{1,2})\s(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)\s(\d{2,4})\s(\d\d):(\d\d)(?::(\d\d))?\s(?:(UT|GMT|[ECMP][SD]T)|([Zz])|([+-]\d{4}))$/;function uw(t,e,u,r,i,s){var o=[sw(t),sh.indexOf(e),parseInt(u,10),parseInt(r,10),parseInt(i,10)];return s&&o.push(parseInt(s,10)),o}function sw(t){var e=parseInt(t,10);return e<=49?2e3+e:e<=999?1900+e:e}function nw(t){return t.replace(/\([^)]*\)|[\n\t]/g," ").replace(/(\s\s+)/g," ").replace(/^\s\s*/,"").replace(/\s\s*$/,"")}function ow(t,e,u){if(t){var r=lh.indexOf(t),i=new Date(e[0],e[1],e[2]).getDay();if(r!==i)return Et(u).weekdayMismatch=!0,u._isValid=!1,!1}return!0}var aw={UT:0,GMT:0,EDT:-4*60,EST:-5*60,CDT:-5*60,CST:-6*60,MDT:-6*60,MST:-7*60,PDT:-7*60,PST:-8*60};function cw(t,e,u){if(t)return aw[t];if(e)return 0;var r=parseInt(u,10),i=r%100,s=(r-i)/100;return s*60+i}function ph(t){var e=iw.exec(nw(t._i));if(e){var u=uw(e[4],e[3],e[2],e[5],e[6],e[7]);if(!ow(e[1],u,t))return;t._a=u,t._tzm=cw(e[8],e[9],e[10]),t._d=As.apply(null,t._a),t._d.setUTCMinutes(t._d.getUTCMinutes()-t._tzm),Et(t).rfc2822=!0}else t._isValid=!1}function lw(t){var e=rw.exec(t._i);if(e!==null){t._d=new Date(+e[1]);return}if(gh(t),t._isValid===!1)delete t._isValid;else return;if(ph(t),t._isValid===!1)delete t._isValid;else return;Ze.createFromInputFallback(t)}Ze.createFromInputFallback=Z0("value provided is not in a recognized RFC2822 or ISO format. moment construction falls back to js Date(), which is not reliable across all browsers and versions. Non RFC2822/ISO date formats are discouraged and will be removed in an upcoming major release. Please refer to http://momentjs.com/guides/#/warnings/js-date/ for more info.",function(t){t._d=new Date(t._i+(t._useUTC?" UTC":""))});Ze.ISO_8601=function(){};Ze.RFC_2822=function(){};function nl(t){if(t._f===Ze.ISO_8601){gh(t);return}if(t._f===Ze.RFC_2822){ph(t);return}t._a=[],Et(t).empty=!0;var e=""+t._i,u,r,i,s,o,f=e.length,n=0;for(i=QF(t._f,t._locale).match(JF)||[],u=0;u<i.length;u++)s=i[u],r=(e.match(Zv(s,t))||[])[0],r&&(o=e.substr(0,e.indexOf(r)),o.length>0&&Et(t).unusedInput.push(o),e=e.slice(e.indexOf(r)+r.length),n+=r.length),vu[s]?(r?Et(t).empty=!1:Et(t).unusedTokens.push(s),tb(s,r,t)):t._strict&&!r&&Et(t).unusedTokens.push(s);Et(t).charsLeftOver=f-n,e.length>0&&Et(t).unusedInput.push(e),t._a[l0]<=12&&Et(t).bigHour===!0&&t._a[l0]>0&&(Et(t).bigHour=void 0),Et(t).parsedDateParts=t._a.slice(0),Et(t).meridiem=t._meridiem,t._a[l0]=dw(t._locale,t._a[l0],t._meridiem),sl(t),ul(t)}function dw(t,e,u){var r;return u==null?e:t.meridiemHour!=null?t.meridiemHour(e,u):(t.isPM!=null&&(r=t.isPM(u),r&&e<12&&(e+=12),!r&&e===12&&(e=0)),e)}function Fw(t){var e,u,r,i,s;if(t._f.length===0){Et(t).invalidFormat=!0,t._d=new Date(NaN);return}for(i=0;i<t._f.length;i++)s=0,e=Yc({},t),t._useUTC!=null&&(e._useUTC=t._useUTC),e._f=t._f[i],nl(e),Kc(e)&&(s+=Et(e).charsLeftOver,s+=Et(e).unusedTokens.length*10,Et(e).score=s,(r==null||s<r)&&(r=s,u=e));ii(t,u||e)}function hw(t){if(!t._d){var e=Qc(t._i);t._a=qF([e.year,e.month,e.day||e.date,e.hour,e.minute,e.second,e.millisecond],function(u){return u&&parseInt(u,10)}),sl(t)}}function gw(t){var e=new Rs(ul(fh(t)));return e._nextDay&&(e.add(1,"d"),e._nextDay=void 0),e}function fh(t){var e=t._i,u=t._f;return t._locale=t._locale||Fi(t._l),e===null||u===void 0&&e===""?io({nullInput:!0}):(typeof e=="string"&&(t._i=e=t._locale.preparse(e)),Ar(e)?new Rs(ul(e)):(ro(e)?t._d=e:Er(u)?Fw(t):u?nl(t):pw(t),Kc(t)||(t._d=null),t))}function pw(t){var e=t._i;D0(e)?t._d=new Date(Ze.now()):ro(e)?t._d=new Date(e.valueOf()):typeof e=="string"?lw(t):Er(e)?(t._a=qF(e.slice(0),function(u){return parseInt(u,10)}),sl(t)):hs(e)?hw(t):zi(e)?t._d=new Date(e):Ze.createFromInputFallback(t)}function mh(t,e,u,r,i){var s={};return(u===!0||u===!1)&&(r=u,u=void 0),(hs(t)&&Tv(t)||Er(t)&&t.length===0)&&(t=void 0),s._isAMomentObject=!0,s._useUTC=s._isUTC=i,s._l=u,s._i=t,s._f=e,s._strict=r,gw(s)}function Ut(t,e,u,r){return mh(t,e,u,r,!1)}var fw=Z0("moment().min is deprecated, use moment.max instead. http://momentjs.com/guides/#/warnings/min-max/",function(){var t=Ut.apply(null,arguments);return this.isValid()&&t.isValid()?t<this?this:t:io()}),mw=Z0("moment().max is deprecated, use moment.min instead. http://momentjs.com/guides/#/warnings/min-max/",function(){var t=Ut.apply(null,arguments);return this.isValid()&&t.isValid()?t>this?this:t:io()});function vh(t,e){var u,r;if(e.length===1&&Er(e[0])&&(e=e[0]),!e.length)return Ut();for(u=e[0],r=1;r<e.length;++r)(!e[r].isValid()||e[r][t](u))&&(u=e[r]);return u}function vw(){var t=[].slice.call(arguments,0);return vh("isBefore",t)}function bw(){var t=[].slice.call(arguments,0);return vh("isAfter",t)}var ww=function(){return Date.now?Date.now():+new Date},Zu=["year","quarter","month","week","day","hour","minute","second","millisecond"];function yw(t){for(var e in t)if(!(t0.call(Zu,e)!==-1&&(t[e]==null||!isNaN(t[e]))))return!1;for(var u=!1,r=0;r<Zu.length;++r)if(t[Zu[r]]){if(u)return!1;parseFloat(t[Zu[r]])!==At(t[Zu[r]])&&(u=!0)}return!0}function Cw(){return this._isValid}function Ew(){return Fr(NaN)}function ho(t){var e=Qc(t),u=e.year||0,r=e.quarter||0,i=e.month||0,s=e.week||e.isoWeek||0,o=e.day||0,f=e.hour||0,n=e.minute||0,h=e.second||0,g=e.millisecond||0;this._isValid=yw(e),this._milliseconds=+g+h*1e3+n*6e4+f*1e3*60*60,this._days=+o+s*7,this._months=+i+r*3+u*12,this._data={},this._locale=Fi(),this._bubble()}function La(t){return t instanceof ho}function Ra(t){return t<0?Math.round(-1*t)*-1:Math.round(t)}function bh(t,e){mt(t,0,0,function(){var u=this.utcOffset(),r="+";return u<0&&(u=-u,r="-"),r+Hr(~~(u/60),2)+e+Hr(~~u%60,2)})}bh("Z",":");bh("ZZ","");ct("Z",ao);ct("ZZ",ao);zt(["Z","ZZ"],function(t,e,u){u._useUTC=!0,u._tzm=ol(ao,t)});var Aw=/([\+\-]|\d\d)/gi;function ol(t,e){var u=(e||"").match(t);if(u===null)return null;var r=u[u.length-1]||[],i=(r+"").match(Aw)||["-",0,0],s=+(i[1]*60)+At(i[2]);return s===0?0:i[0]==="+"?s:-s}function al(t,e){var u,r;return e._isUTC?(u=e.clone(),r=(Ar(t)||ro(t)?t.valueOf():Ut(t).valueOf())-u.valueOf(),u._d.setTime(u._d.valueOf()+r),Ze.updateOffset(u,!1),u):Ut(t).local()}function Ba(t){return-Math.round(t._d.getTimezoneOffset()/15)*15}Ze.updateOffset=function(){};function xw(t,e,u){var r=this._offset||0,i;if(!this.isValid())return t!=null?this:NaN;if(t!=null){if(typeof t=="string"){if(t=ol(ao,t),t===null)return this}else Math.abs(t)<16&&!u&&(t=t*60);return!this._isUTC&&e&&(i=Ba(this)),this._offset=t,this._isUTC=!0,i!=null&&this.add(i,"m"),r!==t&&(!e||this._changeInProgress?Ch(this,Fr(t-r,"m"),1,!1):this._changeInProgress||(this._changeInProgress=!0,Ze.updateOffset(this,!0),this._changeInProgress=null)),this}else return this._isUTC?r:Ba(this)}function kw(t,e){return t!=null?(typeof t!="string"&&(t=-t),this.utcOffset(t,e),this):-this.utcOffset()}function jw(t){return this.utcOffset(0,t)}function Sw(t){return this._isUTC&&(this.utcOffset(0,t),this._isUTC=!1,t&&this.subtract(Ba(this),"m")),this}function _w(){if(this._tzm!=null)this.utcOffset(this._tzm,!1,!0);else if(typeof this._i=="string"){var t=ol(Qv,this._i);t!=null?this.utcOffset(t):this.utcOffset(0,!0)}return this}function Dw(t){return this.isValid()?(t=t?Ut(t).utcOffset():0,(this.utcOffset()-t)%60===0):!1}function Mw(){return this.utcOffset()>this.clone().month(0).utcOffset()||this.utcOffset()>this.clone().month(5).utcOffset()}function Tw(){if(!D0(this._isDSTShifted))return this._isDSTShifted;var t={};if(Yc(t,this),t=fh(t),t._a){var e=t._isUTC?xr(t._a):Ut(t._a);this._isDSTShifted=this.isValid()&&zF(t._a,e.toArray())>0}else this._isDSTShifted=!1;return this._isDSTShifted}function Pw(){return this.isValid()?!this._isUTC:!1}function Lw(){return this.isValid()?this._isUTC:!1}function wh(){return this.isValid()?this._isUTC&&this._offset===0:!1}var Rw=/^(\-|\+)?(?:(\d*)[. ])?(\d+)\:(\d+)(?:\:(\d+)(\.\d*)?)?$/,Bw=/^(-|\+)?P(?:([-+]?[0-9,.]*)Y)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)W)?(?:([-+]?[0-9,.]*)D)?(?:T(?:([-+]?[0-9,.]*)H)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)S)?)?$/;function Fr(t,e){var u=t,r=null,i,s,o;return La(t)?u={ms:t._milliseconds,d:t._days,M:t._months}:zi(t)?(u={},e?u[e]=t:u.milliseconds=t):(r=Rw.exec(t))?(i=r[1]==="-"?-1:1,u={y:0,d:At(r[br])*i,h:At(r[l0])*i,m:At(r[ar])*i,s:At(r[Nr])*i,ms:At(Ra(r[Ni]*1e3))*i}):(r=Bw.exec(t))?(i=r[1]==="-"?-1:1,u={y:ki(r[2],i),M:ki(r[3],i),w:ki(r[4],i),d:ki(r[5],i),h:ki(r[6],i),m:ki(r[7],i),s:ki(r[8],i)}):u==null?u={}:typeof u=="object"&&("from"in u||"to"in u)&&(o=Iw(Ut(u.from),Ut(u.to)),u={},u.ms=o.milliseconds,u.M=o.months),s=new ho(u),La(t)&&r0(t,"_locale")&&(s._locale=t._locale),s}Fr.fn=ho.prototype;Fr.invalid=Ew;function ki(t,e){var u=t&&parseFloat(t.replace(",","."));return(isNaN(u)?0:u)*e}function Cd(t,e){var u={};return u.months=e.month()-t.month()+(e.year()-t.year())*12,t.clone().add(u.months,"M").isAfter(e)&&--u.months,u.milliseconds=+e-+t.clone().add(u.months,"M"),u}function Iw(t,e){var u;return t.isValid()&&e.isValid()?(e=al(e,t),t.isBefore(e)?u=Cd(t,e):(u=Cd(e,t),u.milliseconds=-u.milliseconds,u.months=-u.months),u):{milliseconds:0,months:0}}function yh(t,e){return function(u,r){var i,s;return r!==null&&!isNaN(+r)&&(GF(e,"moment()."+e+"(period, number) is deprecated. Please use moment()."+e+"(number, period). See http://momentjs.com/guides/#/warnings/add-inverted-param/ for more info."),s=u,u=r,r=s),u=typeof u=="string"?+u:u,i=Fr(u,r),Ch(this,i,t),this}}function Ch(t,e,u,r){var i=e._milliseconds,s=Ra(e._days),o=Ra(e._months);t.isValid()&&(r=r??!0,o&&nh(t,Dn(t,"Month")+o*u),s&&ih(t,"Date",Dn(t,"Date")+s*u),i&&t._d.setTime(t._d.valueOf()+i*u),r&&Ze.updateOffset(t,s||o))}var Ow=yh(1,"add"),$w=yh(-1,"subtract");function Nw(t,e){var u=t.diff(e,"days",!0);return u<-6?"sameElse":u<-1?"lastWeek":u<0?"lastDay":u<1?"sameDay":u<2?"nextDay":u<7?"nextWeek":"sameElse"}function Ww(t,e){var u=t||Ut(),r=al(u,this).startOf("day"),i=Ze.calendarFormat(this,r)||"sameElse",s=e&&(kr(e[i])?e[i].call(this,u):e[i]);return this.format(s||this.localeData().calendar(i,this,Ut(u)))}function Hw(){return new Rs(this)}function Uw(t,e){var u=Ar(t)?t:Ut(t);return this.isValid()&&u.isValid()?(e=er(e)||"millisecond",e==="millisecond"?this.valueOf()>u.valueOf():u.valueOf()<this.clone().startOf(e).valueOf()):!1}function qw(t,e){var u=Ar(t)?t:Ut(t);return this.isValid()&&u.isValid()?(e=er(e)||"millisecond",e==="millisecond"?this.valueOf()<u.valueOf():this.clone().endOf(e).valueOf()<u.valueOf()):!1}function zw(t,e,u,r){var i=Ar(t)?t:Ut(t),s=Ar(e)?e:Ut(e);return this.isValid()&&i.isValid()&&s.isValid()?(r=r||"()",(r[0]==="("?this.isAfter(i,u):!this.isBefore(i,u))&&(r[1]===")"?this.isBefore(s,u):!this.isAfter(s,u))):!1}function Vw(t,e){var u=Ar(t)?t:Ut(t),r;return this.isValid()&&u.isValid()?(e=er(e)||"millisecond",e==="millisecond"?this.valueOf()===u.valueOf():(r=u.valueOf(),this.clone().startOf(e).valueOf()<=r&&r<=this.clone().endOf(e).valueOf())):!1}function Gw(t,e){return this.isSame(t,e)||this.isAfter(t,e)}function Kw(t,e){return this.isSame(t,e)||this.isBefore(t,e)}function Yw(t,e,u){var r,i,s;if(!this.isValid())return NaN;if(r=al(t,this),!r.isValid())return NaN;switch(i=(r.utcOffset()-this.utcOffset())*6e4,e=er(e),e){case"year":s=na(this,r)/12;break;case"month":s=na(this,r);break;case"quarter":s=na(this,r)/3;break;case"second":s=(this-r)/1e3;break;case"minute":s=(this-r)/6e4;break;case"hour":s=(this-r)/36e5;break;case"day":s=(this-r-i)/864e5;break;case"week":s=(this-r-i)/6048e5;break;default:s=this-r}return u?s:J0(s)}function na(t,e){var u=(e.year()-t.year())*12+(e.month()-t.month()),r=t.clone().add(u,"months"),i,s;return e-r<0?(i=t.clone().add(u-1,"months"),s=(e-r)/(r-i)):(i=t.clone().add(u+1,"months"),s=(e-r)/(i-r)),-(u+s)||0}Ze.defaultFormat="YYYY-MM-DDTHH:mm:ssZ";Ze.defaultFormatUtc="YYYY-MM-DDTHH:mm:ss[Z]";function Jw(){return this.clone().locale("en").format("ddd MMM DD YYYY HH:mm:ss [GMT]ZZ")}function Qw(t){if(!this.isValid())return null;var e=t!==!0,u=e?this.clone().utc():this;return u.year()<0||u.year()>9999?bn(u,e?"YYYYYY-MM-DD[T]HH:mm:ss.SSS[Z]":"YYYYYY-MM-DD[T]HH:mm:ss.SSSZ"):kr(Date.prototype.toISOString)?e?this.toDate().toISOString():new Date(this.valueOf()+this.utcOffset()*60*1e3).toISOString().replace("Z",bn(u,"Z")):bn(u,e?"YYYY-MM-DD[T]HH:mm:ss.SSS[Z]":"YYYY-MM-DD[T]HH:mm:ss.SSSZ")}function Xw(){if(!this.isValid())return"moment.invalid(/* "+this._i+" */)";var t="moment",e="";this.isLocal()||(t=this.utcOffset()===0?"moment.utc":"moment.parseZone",e="Z");var u="["+t+'("]',r=0<=this.year()&&this.year()<=9999?"YYYY":"YYYYYY",i="-MM-DD[T]HH:mm:ss.SSS",s=e+'[")]';return this.format(u+r+i+s)}function Zw(t){t||(t=this.isUtc()?Ze.defaultFormatUtc:Ze.defaultFormat);var e=bn(this,t);return this.localeData().postformat(e)}function e3(t,e){return this.isValid()&&(Ar(t)&&t.isValid()||Ut(t).isValid())?Fr({to:this,from:t}).locale(this.locale()).humanize(!e):this.localeData().invalidDate()}function t3(t){return this.from(Ut(),t)}function r3(t,e){return this.isValid()&&(Ar(t)&&t.isValid()||Ut(t).isValid())?Fr({from:this,to:t}).locale(this.locale()).humanize(!e):this.localeData().invalidDate()}function i3(t){return this.to(Ut(),t)}function Eh(t){var e;return t===void 0?this._locale._abbr:(e=Fi(t),e!=null&&(this._locale=e),this)}var Ah=Z0("moment().lang() is deprecated. Instead, use moment().localeData() to get the language configuration. Use moment().locale() to change languages.",function(t){return t===void 0?this.localeData():this.locale(t)});function xh(){return this._locale}var Tn=1e3,bu=60*Tn,Pn=60*bu,kh=(365*400+97)*24*Pn;function wu(t,e){return(t%e+e)%e}function jh(t,e,u){return t<100&&t>=0?new Date(t+400,e,u)-kh:new Date(t,e,u).valueOf()}function Sh(t,e,u){return t<100&&t>=0?Date.UTC(t+400,e,u)-kh:Date.UTC(t,e,u)}function u3(t){var e;if(t=er(t),t===void 0||t==="millisecond"||!this.isValid())return this;var u=this._isUTC?Sh:jh;switch(t){case"year":e=u(this.year(),0,1);break;case"quarter":e=u(this.year(),this.month()-this.month()%3,1);break;case"month":e=u(this.year(),this.month(),1);break;case"week":e=u(this.year(),this.month(),this.date()-this.weekday());break;case"isoWeek":e=u(this.year(),this.month(),this.date()-(this.isoWeekday()-1));break;case"day":case"date":e=u(this.year(),this.month(),this.date());break;case"hour":e=this._d.valueOf(),e-=wu(e+(this._isUTC?0:this.utcOffset()*bu),Pn);break;case"minute":e=this._d.valueOf(),e-=wu(e,bu);break;case"second":e=this._d.valueOf(),e-=wu(e,Tn);break}return this._d.setTime(e),Ze.updateOffset(this,!0),this}function s3(t){var e;if(t=er(t),t===void 0||t==="millisecond"||!this.isValid())return this;var u=this._isUTC?Sh:jh;switch(t){case"year":e=u(this.year()+1,0,1)-1;break;case"quarter":e=u(this.year(),this.month()-this.month()%3+3,1)-1;break;case"month":e=u(this.year(),this.month()+1,1)-1;break;case"week":e=u(this.year(),this.month(),this.date()-this.weekday()+7)-1;break;case"isoWeek":e=u(this.year(),this.month(),this.date()-(this.isoWeekday()-1)+7)-1;break;case"day":case"date":e=u(this.year(),this.month(),this.date()+1)-1;break;case"hour":e=this._d.valueOf(),e+=Pn-wu(e+(this._isUTC?0:this.utcOffset()*bu),Pn)-1;break;case"minute":e=this._d.valueOf(),e+=bu-wu(e,bu)-1;break;case"second":e=this._d.valueOf(),e+=Tn-wu(e,Tn)-1;break}return this._d.setTime(e),Ze.updateOffset(this,!0),this}function n3(){return this._d.valueOf()-(this._offset||0)*6e4}function o3(){return Math.floor(this.valueOf()/1e3)}function a3(){return new Date(this.valueOf())}function c3(){var t=this;return[t.year(),t.month(),t.date(),t.hour(),t.minute(),t.second(),t.millisecond()]}function l3(){var t=this;return{years:t.year(),months:t.month(),date:t.date(),hours:t.hours(),minutes:t.minutes(),seconds:t.seconds(),milliseconds:t.milliseconds()}}function d3(){return this.isValid()?this.toISOString():null}function F3(){return Kc(this)}function h3(){return ii({},Et(this))}function g3(){return Et(this).overflow}function p3(){return{input:this._i,format:this._f,locale:this._locale,isUTC:this._isUTC,strict:this._strict}}mt(0,["gg",2],0,function(){return this.weekYear()%100});mt(0,["GG",2],0,function(){return this.isoWeekYear()%100});function go(t,e){mt(0,[t,t.length],0,e)}go("gggg","weekYear");go("ggggg","weekYear");go("GGGG","isoWeekYear");go("GGGGG","isoWeekYear");y0("weekYear","gg");y0("isoWeekYear","GG");C0("weekYear",1);C0("isoWeekYear",1);ct("G",oo);ct("g",oo);ct("GG",qt,U0);ct("gg",qt,U0);ct("GGGG",Zc,Xc);ct("gggg",Zc,Xc);ct("GGGGG",no,uo);ct("ggggg",no,uo);Is(["gggg","ggggg","GGGG","GGGGG"],function(t,e,u,r){e[r.substr(0,2)]=At(t)});Is(["gg","GG"],function(t,e,u,r){e[r]=Ze.parseTwoDigitYear(t)});function f3(t){return _h.call(this,t,this.week(),this.weekday(),this.localeData()._week.dow,this.localeData()._week.doy)}function m3(t){return _h.call(this,t,this.isoWeek(),this.isoWeekday(),1,4)}function v3(){return Ui(this.year(),1,4)}function b3(){var t=this.localeData()._week;return Ui(this.year(),t.dow,t.doy)}function _h(t,e,u,r,i){var s;return t==null?xs(this,r,i).year:(s=Ui(t,r,i),e>s&&(e=s),w3.call(this,t,e,u,r,i))}function w3(t,e,u,r,i){var s=ch(t,e,u,r,i),o=As(s.year,0,s.dayOfYear);return this.year(o.getUTCFullYear()),this.month(o.getUTCMonth()),this.date(o.getUTCDate()),this}mt("Q",0,"Qo","quarter");y0("quarter","Q");C0("quarter",7);ct("Q",XF);zt("Q",function(t,e){e[$r]=(At(t)-1)*3});function y3(t){return t==null?Math.ceil((this.month()+1)/3):this.month((t-1)*3+this.month()%3)}mt("D",["DD",2],"Do","date");y0("date","D");C0("date",9);ct("D",qt);ct("DD",qt,U0);ct("Do",function(t,e){return t?e._dayOfMonthOrdinalParse||e._ordinalParse:e._dayOfMonthOrdinalParseLenient});zt(["D","DD"],br);zt("Do",function(t,e){e[br]=At(t.match(qt)[0])});var Dh=Tu("Date",!0);mt("DDD",["DDDD",3],"DDDo","dayOfYear");y0("dayOfYear","DDD");C0("dayOfYear",4);ct("DDD",so);ct("DDDD",ZF);zt(["DDD","DDDD"],function(t,e,u){u._dayOfYear=At(t)});function C3(t){var e=Math.round((this.clone().startOf("day")-this.clone().startOf("year"))/864e5)+1;return t==null?e:this.add(t-e,"d")}mt("m",["mm",2],0,"minute");y0("minute","m");C0("minute",14);ct("m",qt);ct("mm",qt,U0);zt(["m","mm"],ar);var E3=Tu("Minutes",!1);mt("s",["ss",2],0,"second");y0("second","s");C0("second",15);ct("s",qt);ct("ss",qt,U0);zt(["s","ss"],Nr);var A3=Tu("Seconds",!1);mt("S",0,0,function(){return~~(this.millisecond()/100)});mt(0,["SS",2],0,function(){return~~(this.millisecond()/10)});mt(0,["SSS",3],0,"millisecond");mt(0,["SSSS",4],0,function(){return this.millisecond()*10});mt(0,["SSSSS",5],0,function(){return this.millisecond()*100});mt(0,["SSSSSS",6],0,function(){return this.millisecond()*1e3});mt(0,["SSSSSSS",7],0,function(){return this.millisecond()*1e4});mt(0,["SSSSSSSS",8],0,function(){return this.millisecond()*1e5});mt(0,["SSSSSSSSS",9],0,function(){return this.millisecond()*1e6});y0("millisecond","ms");C0("millisecond",16);ct("S",so,XF);ct("SS",so,U0);ct("SSS",so,ZF);var ui;for(ui="SSSS";ui.length<=9;ui+="S")ct(ui,Jv);function x3(t,e){e[Ni]=At(("0."+t)*1e3)}for(ui="S";ui.length<=9;ui+="S")zt(ui,x3);var k3=Tu("Milliseconds",!1);mt("z",0,0,"zoneAbbr");mt("zz",0,0,"zoneName");function j3(){return this._isUTC?"UTC":""}function S3(){return this._isUTC?"Coordinated Universal Time":""}var Ke=Rs.prototype;Ke.add=Ow;Ke.calendar=Ww;Ke.clone=Hw;Ke.diff=Yw;Ke.endOf=s3;Ke.format=Zw;Ke.from=e3;Ke.fromNow=t3;Ke.to=r3;Ke.toNow=i3;Ke.get=sb;Ke.invalidAt=g3;Ke.isAfter=Uw;Ke.isBefore=qw;Ke.isBetween=zw;Ke.isSame=Vw;Ke.isSameOrAfter=Gw;Ke.isSameOrBefore=Kw;Ke.isValid=F3;Ke.lang=Ah;Ke.locale=Eh;Ke.localeData=xh;Ke.max=mw;Ke.min=fw;Ke.parsingFlags=h3;Ke.set=nb;Ke.startOf=u3;Ke.subtract=$w;Ke.toArray=c3;Ke.toObject=l3;Ke.toDate=a3;Ke.toISOString=Qw;Ke.inspect=Xw;Ke.toJSON=d3;Ke.toString=Jw;Ke.unix=o3;Ke.valueOf=n3;Ke.creationData=p3;Ke.year=rh;Ke.isLeapYear=ub;Ke.weekYear=f3;Ke.isoWeekYear=m3;Ke.quarter=Ke.quarters=y3;Ke.month=oh;Ke.daysInMonth=hb;Ke.week=Ke.weeks=Eb;Ke.isoWeek=Ke.isoWeeks=Ab;Ke.weeksInYear=b3;Ke.isoWeeksInYear=v3;Ke.date=Dh;Ke.day=Ke.days=Lb;Ke.weekday=Rb;Ke.isoWeekday=Bb;Ke.dayOfYear=C3;Ke.hour=Ke.hours=Gb;Ke.minute=Ke.minutes=E3;Ke.second=Ke.seconds=A3;Ke.millisecond=Ke.milliseconds=k3;Ke.utcOffset=xw;Ke.utc=jw;Ke.local=Sw;Ke.parseZone=_w;Ke.hasAlignedHourOffset=Dw;Ke.isDST=Mw;Ke.isLocal=Pw;Ke.isUtcOffset=Lw;Ke.isUtc=wh;Ke.isUTC=wh;Ke.zoneAbbr=j3;Ke.zoneName=S3;Ke.dates=Z0("dates accessor is deprecated. Use date instead.",Dh);Ke.months=Z0("months accessor is deprecated. Use month instead",oh);Ke.years=Z0("years accessor is deprecated. Use year instead",rh);Ke.zone=Z0("moment().zone is deprecated, use moment().utcOffset instead. http://momentjs.com/guides/#/warnings/zone/",kw);Ke.isDSTShifted=Z0("isDSTShifted is deprecated. See http://momentjs.com/guides/#/warnings/dst-shifted/ for more information",Tw);function _3(t){return Ut(t*1e3)}function D3(){return Ut.apply(null,arguments).parseZone()}function Mh(t){return t}var Wt=Jc.prototype;Wt.calendar=Bv;Wt.longDateFormat=Ov;Wt.invalidDate=Nv;Wt.ordinal=Uv;Wt.preparse=Mh;Wt.postformat=Mh;Wt.relativeTime=zv;Wt.pastFuture=Vv;Wt.set=Lv;Wt.months=cb;Wt.monthsShort=lb;Wt.monthsParse=Fb;Wt.monthsRegex=mb;Wt.monthsShortRegex=pb;Wt.week=bb;Wt.firstDayOfYear=Cb;Wt.firstDayOfWeek=yb;Wt.weekdays=Sb;Wt.weekdaysMin=Mb;Wt.weekdaysShort=_b;Wt.weekdaysParse=Pb;Wt.weekdaysRegex=Ob;Wt.weekdaysShortRegex=Nb;Wt.weekdaysMinRegex=Hb;Wt.isPM=qb;Wt.meridiem=Vb;function Ln(t,e,u,r){var i=Fi(),s=xr().set(r,e);return i[u](s,t)}function Th(t,e,u){if(zi(t)&&(e=t,t=void 0),t=t||"",e!=null)return Ln(t,e,u,"month");var r,i=[];for(r=0;r<12;r++)i[r]=Ln(t,r,u,"month");return i}function cl(t,e,u,r){typeof t=="boolean"?(zi(e)&&(u=e,e=void 0),e=e||""):(e=t,u=e,t=!1,zi(e)&&(u=e,e=void 0),e=e||"");var i=Fi(),s=t?i._week.dow:0;if(u!=null)return Ln(e,(u+s)%7,r,"day");var o,f=[];for(o=0;o<7;o++)f[o]=Ln(e,(o+s)%7,r,"day");return f}function M3(t,e){return Th(t,e,"months")}function T3(t,e){return Th(t,e,"monthsShort")}function P3(t,e,u){return cl(t,e,u,"weekdays")}function L3(t,e,u){return cl(t,e,u,"weekdaysShort")}function R3(t,e,u){return cl(t,e,u,"weekdaysMin")}Pu("en",{dayOfMonthOrdinalParse:/\d{1,2}(th|st|nd|rd)/,ordinal:function(t){var e=t%10,u=At(t%100/10)===1?"th":e===1?"st":e===2?"nd":e===3?"rd":"th";return t+u}});Ze.lang=Z0("moment.lang is deprecated. Use moment.locale instead.",Pu);Ze.langData=Z0("moment.langData is deprecated. Use moment.localeData instead.",Fi);var Rr=Math.abs;function B3(){var t=this._data;return this._milliseconds=Rr(this._milliseconds),this._days=Rr(this._days),this._months=Rr(this._months),t.milliseconds=Rr(t.milliseconds),t.seconds=Rr(t.seconds),t.minutes=Rr(t.minutes),t.hours=Rr(t.hours),t.months=Rr(t.months),t.years=Rr(t.years),this}function Ph(t,e,u,r){var i=Fr(e,u);return t._milliseconds+=r*i._milliseconds,t._days+=r*i._days,t._months+=r*i._months,t._bubble()}function I3(t,e){return Ph(this,t,e,1)}function O3(t,e){return Ph(this,t,e,-1)}function Ed(t){return t<0?Math.floor(t):Math.ceil(t)}function $3(){var t=this._milliseconds,e=this._days,u=this._months,r=this._data,i,s,o,f,n;return t>=0&&e>=0&&u>=0||t<=0&&e<=0&&u<=0||(t+=Ed(Ia(u)+e)*864e5,e=0,u=0),r.milliseconds=t%1e3,i=J0(t/1e3),r.seconds=i%60,s=J0(i/60),r.minutes=s%60,o=J0(s/60),r.hours=o%24,e+=J0(o/24),n=J0(Lh(e)),u+=n,e-=Ed(Ia(n)),f=J0(u/12),u%=12,r.days=e,r.months=u,r.years=f,this}function Lh(t){return t*4800/146097}function Ia(t){return t*146097/4800}function N3(t){if(!this.isValid())return NaN;var e,u,r=this._milliseconds;if(t=er(t),t==="month"||t==="quarter"||t==="year")switch(e=this._days+r/864e5,u=this._months+Lh(e),t){case"month":return u;case"quarter":return u/3;case"year":return u/12}else switch(e=this._days+Math.round(Ia(this._months)),t){case"week":return e/7+r/6048e5;case"day":return e+r/864e5;case"hour":return e*24+r/36e5;case"minute":return e*1440+r/6e4;case"second":return e*86400+r/1e3;case"millisecond":return Math.floor(e*864e5)+r;default:throw new Error("Unknown unit "+t)}}function W3(){return this.isValid()?this._milliseconds+this._days*864e5+this._months%12*2592e6+At(this._months/12)*31536e6:NaN}function Ur(t){return function(){return this.as(t)}}var H3=Ur("ms"),U3=Ur("s"),q3=Ur("m"),z3=Ur("h"),V3=Ur("d"),G3=Ur("w"),K3=Ur("M"),Y3=Ur("Q"),J3=Ur("y");function Q3(){return Fr(this)}function X3(t){return t=er(t),this.isValid()?this[t+"s"]():NaN}function Xi(t){return function(){return this.isValid()?this._data[t]:NaN}}var Z3=Xi("milliseconds"),ey=Xi("seconds"),ty=Xi("minutes"),ry=Xi("hours"),iy=Xi("days"),uy=Xi("months"),sy=Xi("years");function ny(){return J0(this.days()/7)}var ti=Math.round,mr={ss:44,s:45,m:45,h:22,d:26,M:11};function oy(t,e,u,r,i){return i.relativeTime(e||1,!!u,t,r)}function ay(t,e,u){var r=Fr(t).abs(),i=ti(r.as("s")),s=ti(r.as("m")),o=ti(r.as("h")),f=ti(r.as("d")),n=ti(r.as("M")),h=ti(r.as("y")),g=i<=mr.ss&&["s",i]||i<mr.s&&["ss",i]||s<=1&&["m"]||s<mr.m&&["mm",s]||o<=1&&["h"]||o<mr.h&&["hh",o]||f<=1&&["d"]||f<mr.d&&["dd",f]||n<=1&&["M"]||n<mr.M&&["MM",n]||h<=1&&["y"]||["yy",h];return g[2]=e,g[3]=+t>0,g[4]=u,oy.apply(null,g)}function cy(t){return t===void 0?ti:typeof t=="function"?(ti=t,!0):!1}function ly(t,e){return mr[t]===void 0?!1:e===void 0?mr[t]:(mr[t]=e,t==="s"&&(mr.ss=e-1),!0)}function dy(t){if(!this.isValid())return this.localeData().invalidDate();var e=this.localeData(),u=ay(this,!t,e);return t&&(u=e.pastFuture(+this,u)),e.postformat(u)}var oa=Math.abs;function su(t){return(t>0)-(t<0)||+t}function po(){if(!this.isValid())return this.localeData().invalidDate();var t=oa(this._milliseconds)/1e3,e=oa(this._days),u=oa(this._months),r,i,s;r=J0(t/60),i=J0(r/60),t%=60,r%=60,s=J0(u/12),u%=12;var o=s,f=u,n=e,h=i,g=r,d=t?t.toFixed(3).replace(/\.?0+$/,""):"",l=this.asSeconds();if(!l)return"P0D";var c=l<0?"-":"",a=su(this._months)!==su(l)?"-":"",F=su(this._days)!==su(l)?"-":"",p=su(this._milliseconds)!==su(l)?"-":"";return c+"P"+(o?a+o+"Y":"")+(f?a+f+"M":"")+(n?F+n+"D":"")+(h||g||d?"T":"")+(h?p+h+"H":"")+(g?p+g+"M":"")+(d?p+d+"S":"")}var _t=ho.prototype;_t.isValid=Cw;_t.abs=B3;_t.add=I3;_t.subtract=O3;_t.as=N3;_t.asMilliseconds=H3;_t.asSeconds=U3;_t.asMinutes=q3;_t.asHours=z3;_t.asDays=V3;_t.asWeeks=G3;_t.asMonths=K3;_t.asQuarters=Y3;_t.asYears=J3;_t.valueOf=W3;_t._bubble=$3;_t.clone=Q3;_t.get=X3;_t.milliseconds=Z3;_t.seconds=ey;_t.minutes=ty;_t.hours=ry;_t.days=iy;_t.weeks=ny;_t.months=uy;_t.years=sy;_t.humanize=dy;_t.toISOString=po;_t.toString=po;_t.toJSON=po;_t.locale=Eh;_t.localeData=xh;_t.toIsoString=Z0("toIsoString() is deprecated. Please use toISOString() instead (notice the capitals)",po);_t.lang=Ah;mt("X",0,0,"unix");mt("x",0,0,"valueOf");ct("x",oo);ct("X",Xv);zt("X",function(t,e,u){u._d=new Date(parseFloat(t,10)*1e3)});zt("x",function(t,e,u){u._d=new Date(At(t))});//! moment.js
//! version : 2.24.0
//! authors : Tim Wood, Iskren Chernev, Moment.js contributors
//! license : MIT
//! momentjs.com
Ze.version="2.24.0";Mv(Ut);Ze.fn=Ke;Ze.min=vw;Ze.max=bw;Ze.now=ww;Ze.utc=xr;Ze.unix=_3;Ze.months=M3;Ze.isDate=ro;Ze.locale=Pu;Ze.invalid=io;Ze.duration=Fr;Ze.isMoment=Ar;Ze.weekdays=P3;Ze.parseZone=D3;Ze.localeData=Fi;Ze.isDuration=La;Ze.monthsShort=T3;Ze.weekdaysMin=R3;Ze.defineLocale=il;Ze.updateLocale=Yb;Ze.locales=Jb;Ze.weekdaysShort=L3;Ze.normalizeUnits=er;Ze.relativeTimeRounding=cy;Ze.relativeTimeThreshold=ly;Ze.calendarFormat=Nw;Ze.prototype=Ke;Ze.HTML5_FMT={DATETIME_LOCAL:"YYYY-MM-DDTHH:mm",DATETIME_LOCAL_SECONDS:"YYYY-MM-DDTHH:mm:ss",DATETIME_LOCAL_MS:"YYYY-MM-DDTHH:mm:ss.SSS",DATE:"YYYY-MM-DD",TIME:"HH:mm",TIME_SECONDS:"HH:mm:ss",TIME_MS:"HH:mm:ss.SSS",WEEK:"GGGG-[W]WW",MONTH:"YYYY-MM"};var He=xe.clone(s0.Events);let Rh;var js={},Bh=1024*1024*64;function Zi(){return Rh}function Ih(t){Rh=t.replace(/\/$/,"")}const ut=function(t){t=t||{};const e={girderToken:ll()||window.localStorage.getItem("girderToken"),error:(r,i)=>{let s;if(r.status===401)hi(null),Lu(null),He.trigger("g:loginUi"),s={text:"You must log in to view this resource",type:"warning",timeout:4e3,icon:"info"};else if(r.status===403)s={text:"Access denied. See the console for more details.",type:"danger",timeout:5e3,icon:"attention"};else{if(r.status===0&&r.statusText==="abort")return;r.status===500&&r.responseJSON&&r.responseJSON.type==="girder"?s={text:r.responseJSON.message,type:"warning",timeout:5e3,icon:"info"}:i==="parsererror"?s={text:"A parser error occurred while communicating with the server (did you use the correct value for `dataType`?). Details have been logged in the console.",type:"danger",timeout:5e3,icon:"attention"}:s={text:"An error occurred while communicating with the server. Details have been logged in the console.",type:"danger",timeout:5e3,icon:"attention"}}He.trigger("g:alert",s),console.error(r.status+" "+r.statusText,r.responseText)}},u=xe.extend({},e,t);try{(!u.method||u.method==="GET"||u.method==="PUT")&&u.data&&!u.contentType&&JSON.stringify(u.data).length>1536&&(u.headers=u.header||{},u.headers["X-HTTP-Method-Override"]=u.method||"GET",u.method="POST")}catch{}if(!u.url)throw new Error('restRequest requires a "url" argument');return u.url=`${Zi()}${u.url.substring(0,1)==="/"?"":"/"}${u.url}`,u.girderToken&&(u.headers=u.headers||{},u.headers["Girder-Token"]=u.girderToken,delete u.girderToken),s0.$.ajax(u)};s0.ajax=ut;var Au={},aa=0;ke(document).ajaxSend(function(t,e){aa+=1,e.girderXhrNumber=aa,Au[aa]=e});ke(document).ajaxComplete(function(t,e){var u=e.girderXhrNumber;u&&Au[u]&&delete Au[u]});function Fy(t){return t?xe.filter(Au,function(e){return e.girder&&e.girder[t]}).length:xe.size(Au)}function x0(t){xe.each(Au,function(e){t&&(!e.girder||!e.girder[t])||e.abort&&e.abort()})}function Oh(){return Bh}function hy(t){Bh=t}const gy=Object.freeze(Object.defineProperty({__proto__:null,cancelRestRequests:x0,getApiRoot:Zi,getUploadChunkSize:Oh,numberOutstandingRestRequests:Fy,restRequest:ut,setApiRoot:Ih,setUploadChunkSize:hy,uploadHandlers:js},Symbol.toStringTag,{value:"Module"}));var oi=s0.Model.extend({resourceName:null,altUrl:null,idAttribute:"_id",increment:function(t,e){if(e===void 0&&(e=1),!!e)return this.set(t,this.get(t)+e)},name:function(){return this.get("name")},save:function(){if(this.altUrl===null&&this.resourceName===null)throw new Error("An altUrl or resourceName must be set on the Model.");var t,e;this.has("_id")?(t=(this.altUrl||this.resourceName)+"/"+this.get("_id"),e="PUT"):(t=this.altUrl||this.resourceName,e="POST");var u={};return xe.each(this.keys(),function(r){var i=this.get(r);xe.isObject(i)||(u[r]=i)},this),ut({url:t,method:e,data:u,error:null}).done(r=>{this.set(r),this.trigger("g:saved")}).fail(r=>{this.trigger("g:error",r)})},fetch:function(t){if(this.altUrl===null&&this.resourceName===null)throw new Error("An altUrl or resourceName must be set on the Model.");t=t||{};var e={url:`${this.altUrl||this.resourceName}/${this.id}`};return t.extraPath&&(e.url+="/"+t.extraPath),t.ignoreError&&(e.error=null),t.data&&(e.data=t.data),ut(e).done(u=>{this.set(u),t.extraPath?this.trigger("g:fetched."+t.extraPath):this.trigger("g:fetched")}).fail(u=>{this.trigger("g:error",u)})},downloadUrl:function(t){let e=`${Zi()}/${this.altUrl||this.resourceName}/${this.id}/download`;return t&&(e+="?"+ke.param(t)),e},download:function(){window.location.assign(this.downloadUrl())},destroy:function(t){if(this.altUrl===null&&this.resourceName===null)throw new Error("An altUrl or resourceName must be set on the Model.");var e={url:`${this.altUrl||this.resourceName}/${this.id}`,method:"DELETE"};return t=t||{},t.progress===!0&&(e.url+="?progress=true"),t.throwError!==!1&&(e.error=null),ut(e).done(()=>{this.collection&&this.collection.remove(this),this.trigger("g:deleted")}).fail(u=>{this.trigger("g:error",u)})},getAccessLevel:function(){return this.get("_accessLevel")}});function A0(t){const e={timeout:null,streamPath:"/notification/stream"};return this.settings=xe.extend(e,t),this._state="closed",this._eventSource=null,this._onVisibilityStateChange=xe.bind(this._onVisibilityStateChange,this),this._onMessage=xe.bind(this._onMessage,this),this._onError=xe.bind(this._onError,this),xe.extend(this,s0.Events)}A0.prototype._onVisibilityStateChange=function(){document.visibilityState==="visible"&&this._state==="stopped"?this._start():document.visibilityState==="hidden"&&this._state==="started"&&this._stop()};A0.prototype._onMessage=function(t){let e;try{e=window.JSON.parse(t.data)}catch(u){console.error("Invalid JSON from SSE stream: "+t.data+","+u),this.trigger("g:error",t);return}A0.setLastTimestamp(e._girderTime),this.trigger("g:event."+e.type,e)};A0.prototype._onError=function(){ut({url:this.settings.streamPath,method:"HEAD",error:null}).fail(t=>{t.status===503&&(this.trigger("g:eventStream.disable",t),this.close())})};A0.prototype.open=function(){if(!window.EventSource){console.error("EventSource is not supported on this platform."),this.trigger("g:eventStream.disable");return}if(this._state!=="closed"){console.warn("EventStream should be closed.");return}this._state="stopped",this._start(),document.addEventListener("visibilitychange",this._onVisibilityStateChange)};A0.prototype._start=function(){if(this._state!=="stopped"){console.warn("EventStream should be stopped");return}const t={};this.settings.timeout&&(t.timeout=this.settings.timeout);const e=A0.getLastTimestamp();xe.isNumber(e)&&(t.since=e);const u=Zi()+this.settings.streamPath+"?"+ke.param(t);this._eventSource=new window.EventSource(u),this._eventSource.onmessage=this._onMessage,this._eventSource.onerror=this._onError,this._state="started",this.trigger("g:eventStream.start")};A0.prototype._stop=function(){if(this._state!=="started"){console.warn("EventStream should be started");return}this._eventSource.close(),this._eventSource=null,this._state="stopped",this.trigger("g:eventStream.stop")};A0.prototype.close=function(){if(this._state==="closed"){console.warn("EventStream should not be closed");return}document.removeEventListener("visibilitychange",this._onVisibilityStateChange),this._state==="started"&&this._stop(),this._state="closed",this.trigger("g:eventStream.close")};A0._lastTimestamp=null;A0.setLastTimestamp=function(t){try{window.localStorage.setItem("sseTimestamp",t)}catch{}A0._lastTimestamp=t};A0.getLastTimestamp=function(){let t;try{t=parseInt(window.localStorage.getItem("sseTimestamp"),10)}catch{}return xe.isNaN(t)?A0._lastTimestamp:t};const Cr=new A0;var p0=oi.extend({resourceName:"user",current:function(){dl().done(t=>{t?this.set(t):this.clear()})},name:function(){return this.get("firstName")+" "+this.get("lastName")},addToGroup:function(t){var e=this.get("groups")||[];e.push(t),this.set("groups",e)},removeFromGroup:function(t){for(var e=this.get("groups")||[],u=e.indexOf(t);u>=0;)e.splice(u,1),u=e.indexOf(t);this.set("groups",e)},addInvitation:function(t,e){var u=this.get("groupInvites")||[];u.push({groupId:t,level:e}),this.set("groupInvites",u)},removeInvitation:function(t){var e=this.get("groupInvites")||[],u=xe.reject(e,xe.matcher({groupId:t}));this.set("groupInvites",u)},changePassword:function(t,e){return ut({url:`${this.resourceName}/password`,data:{old:t,new:e},method:"PUT",error:null}).done(()=>{this.trigger("g:passwordChanged")}).fail(u=>{this.trigger("g:error",u)})},adminChangePassword:function(t){return ut({url:`${this.resourceName}/${this.id}/password`,data:{password:t},method:"PUT",error:null}).done(()=>{this.trigger("g:passwordChanged")}).fail(e=>{this.trigger("g:error",e)})},initializeEnableOtp:function(){return ut({url:`user/${this.id}/otp`,method:"POST",error:null}).then(t=>t.totpUri)},finializeEnableOtp:function(t){return ut({url:`user/${this.id}/otp`,method:"PUT",headers:{"Girder-OTP":t},error:null}).done(()=>{this.set("otp",!0)})},disableOtp:function(){return ut({url:`user/${this.id}/otp`,method:"DELETE",error:null}).done(()=>{this.set("otp",!1)})}},{fromTemporaryToken:function(t,e){return ut({url:`user/password/temporary/${t}`,method:"GET",data:{token:e},error:null}).done(u=>{u.user.token=u.authToken.token,Cr.close(),hi(new p0(u.user)),Lu(u.authToken.token),Cr.open(),He.trigger("g:login-changed")})},sendVerificationEmail:function(t){return ut({url:"user/verification",method:"POST",data:{login:t},error:null})}}),py=!1,$h=null,Nh=window.localStorage.getItem("girderToken");function ft(){return $h}function hi(t){$h=t}function ll(){return Nh}function Lu(t){Nh=t}function dl(){return ut({method:"GET",url:"/user/me"})}function fy(t,e){const r=new TextEncoder().encode(t+":"+e);return"Basic "+btoa(String.fromCharCode(...r))}function Wh(t,e,u=null){var r=fy(t,e);const i={Authorization:r};return xe.isString(u)&&(i["Girder-OTP"]=u),ut({method:"GET",url:"/user/authentication",headers:i,error:null}).then(function(s){return s.user.token=s.authToken,hi(new p0(s.user)),Lu(s.user.token.token),window.localStorage.setItem("girderToken",s.user.token.token),He.trigger("g:login.success",s.user),He.trigger("g:login",s),s.user}).fail(function(s){He.trigger("g:login.error",s.status,s)})}function Hh(){return ut({method:"DELETE",url:"/user/authentication"}).done(function(){hi(null),Lu(null),window.localStorage.removeItem("girderToken"),He.trigger("g:login",null),He.trigger("g:logout.success")}).fail(function(t){He.trigger("g:logout.error",t.status,t)})}const my=Object.freeze(Object.defineProperty({__proto__:null,corsAuth:py,fetchCurrentUser:dl,getCurrentToken:ll,getCurrentUser:ft,login:Wh,logout:Hh,setCurrentToken:Lu,setCurrentUser:hi},Symbol.toStringTag,{value:"Module"}));var Vi=oi.extend({updateAccess:function(t){if(this.altUrl===null&&this.resourceName===null)throw new Error("An altUrl or resourceName must be set on the Model.");return ut({url:`${this.altUrl||this.resourceName}/${this.id}/access`,method:"PUT",data:xe.extend({access:JSON.stringify(this.get("access")),public:this.get("public"),publicFlags:JSON.stringify(this.get("publicFlags")||[])},t||{})}).done(()=>{this.trigger("g:accessListSaved")}).fail(e=>{this.trigger("g:error",e)})},fetchAccess:function(t){if(this.altUrl===null&&this.resourceName===null)throw new Error("An altUrl or resourceName must be set on the Model.");return!this.get("access")||t?ut({url:`${this.altUrl||this.resourceName}/${this.id}/access`,method:"GET"}).done(e=>(e.access?this.set(e):this.set("access",e),this.trigger("g:accessFetched"),e)).fail(e=>{this.trigger("g:error",e)}):(this.trigger("g:accessFetched"),ke.Deferred().resolve(this.get("access")).promise())}}),Fl=Vi.extend({resourceName:"api_key",setActive:function(t){return ut({url:`api_key/${this.id}`,method:"PUT",data:{active:t}}).done(()=>{this.set({active:t}),this.trigger("g:setActive")})},save:function(){var t=this.get("scope");this.set("scope",JSON.stringify(t),{silent:!0});var e=Vi.prototype.save.call(this,arguments);return this.set("scope",t,{silent:!0}),e}}),fs=1,Uh=-1,qh=["January","February","March","April","May","June","July","August","September","October","November","December"],nt={NONE:-1,READ:0,WRITE:1,ADMIN:2},lr={FILESYSTEM:0,S3:2},rs={DEFAULT:"default",EMPTY:"empty"};const vy=Object.freeze(Object.defineProperty({__proto__:null,AccessType:nt,AssetstoreType:lr,Layout:rs,MONTHS:qh,SORT_ASC:fs,SORT_DESC:Uh},Symbol.toStringTag,{value:"Module"}));var Zs;function zh(t){return Zs=Zs||document.createElement("textarea"),Zs.innerHTML="&"+t+";",Zs.value}var by=Object.prototype.hasOwnProperty;function wy(t,e){return t?by.call(t,e):!1}function Vh(t){var e=[].slice.call(arguments,1);return e.forEach(function(u){if(u){if(typeof u!="object")throw new TypeError(u+"must be object");Object.keys(u).forEach(function(r){t[r]=u[r]})}}),t}var yy=/\\([\\!"#$%&'()*+,.\/:;<=>?@[\]^_`{|}~-])/g;function Ss(t){return t.indexOf("\\")<0?t:t.replace(yy,"$1")}function Gh(t){return!(t>=55296&&t<=57343||t>=64976&&t<=65007||(t&65535)===65535||(t&65535)===65534||t>=0&&t<=8||t===11||t>=14&&t<=31||t>=127&&t<=159||t>1114111)}function Oa(t){if(t>65535){t-=65536;var e=55296+(t>>10),u=56320+(t&1023);return String.fromCharCode(e,u)}return String.fromCharCode(t)}var Cy=/&([a-z#][a-z0-9]{1,31});/gi,Ey=/^#((?:x[a-f0-9]{1,8}|[0-9]{1,8}))/i;function Ay(t,e){var u=0,r=zh(e);return e!==r?r:e.charCodeAt(0)===35&&Ey.test(e)&&(u=e[1].toLowerCase()==="x"?parseInt(e.slice(2),16):parseInt(e.slice(1),10),Gh(u))?Oa(u):t}function Gi(t){return t.indexOf("&")<0?t:t.replace(Cy,Ay)}var xy=/[&<>"]/,ky=/[&<>"]/g,jy={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;"};function Sy(t){return jy[t]}function T0(t){return xy.test(t)?t.replace(ky,Sy):t}var rt={};rt.blockquote_open=function(){return`<blockquote>
`};rt.blockquote_close=function(t,e){return"</blockquote>"+eu(t,e)};rt.code=function(t,e){return t[e].block?"<pre><code>"+T0(t[e].content)+"</code></pre>"+eu(t,e):"<code>"+T0(t[e].content)+"</code>"};rt.fence=function(t,e,u,r,i){var s=t[e],o="",f=u.langPrefix,n="",h,g,d;if(s.params){if(h=s.params.split(/\s+/g),g=h.join(" "),wy(i.rules.fence_custom,h[0]))return i.rules.fence_custom[h[0]](t,e,u,r,i);n=T0(Gi(Ss(g))),o=' class="'+f+n+'"'}return u.highlight?d=u.highlight.apply(u.highlight,[s.content].concat(h))||T0(s.content):d=T0(s.content),"<pre><code"+o+">"+d+"</code></pre>"+eu(t,e)};rt.fence_custom={};rt.heading_open=function(t,e){return"<h"+t[e].hLevel+">"};rt.heading_close=function(t,e){return"</h"+t[e].hLevel+`>
`};rt.hr=function(t,e,u){return(u.xhtmlOut?"<hr />":"<hr>")+eu(t,e)};rt.bullet_list_open=function(){return`<ul>
`};rt.bullet_list_close=function(t,e){return"</ul>"+eu(t,e)};rt.list_item_open=function(){return"<li>"};rt.list_item_close=function(){return`</li>
`};rt.ordered_list_open=function(t,e){var u=t[e],r=u.order>1?' start="'+u.order+'"':"";return"<ol"+r+`>
`};rt.ordered_list_close=function(t,e){return"</ol>"+eu(t,e)};rt.paragraph_open=function(t,e){return t[e].tight?"":"<p>"};rt.paragraph_close=function(t,e){var u=!(t[e].tight&&e&&t[e-1].type==="inline"&&!t[e-1].content);return(t[e].tight?"":"</p>")+(u?eu(t,e):"")};rt.link_open=function(t,e,u){var r=t[e].title?' title="'+T0(Gi(t[e].title))+'"':"",i=u.linkTarget?' target="'+u.linkTarget+'"':"";return'<a href="'+T0(t[e].href)+'"'+r+i+">"};rt.link_close=function(){return"</a>"};rt.image=function(t,e,u){var r=' src="'+T0(t[e].src)+'"',i=t[e].title?' title="'+T0(Gi(t[e].title))+'"':"",s=' alt="'+(t[e].alt?T0(Gi(Ss(t[e].alt))):"")+'"',o=u.xhtmlOut?" /":"";return"<img"+r+s+i+o+">"};rt.table_open=function(){return`<table>
`};rt.table_close=function(){return`</table>
`};rt.thead_open=function(){return`<thead>
`};rt.thead_close=function(){return`</thead>
`};rt.tbody_open=function(){return`<tbody>
`};rt.tbody_close=function(){return`</tbody>
`};rt.tr_open=function(){return"<tr>"};rt.tr_close=function(){return`</tr>
`};rt.th_open=function(t,e){var u=t[e];return"<th"+(u.align?' style="text-align:'+u.align+'"':"")+">"};rt.th_close=function(){return"</th>"};rt.td_open=function(t,e){var u=t[e];return"<td"+(u.align?' style="text-align:'+u.align+'"':"")+">"};rt.td_close=function(){return"</td>"};rt.strong_open=function(){return"<strong>"};rt.strong_close=function(){return"</strong>"};rt.em_open=function(){return"<em>"};rt.em_close=function(){return"</em>"};rt.del_open=function(){return"<del>"};rt.del_close=function(){return"</del>"};rt.ins_open=function(){return"<ins>"};rt.ins_close=function(){return"</ins>"};rt.mark_open=function(){return"<mark>"};rt.mark_close=function(){return"</mark>"};rt.sub=function(t,e){return"<sub>"+T0(t[e].content)+"</sub>"};rt.sup=function(t,e){return"<sup>"+T0(t[e].content)+"</sup>"};rt.hardbreak=function(t,e,u){return u.xhtmlOut?`<br />
`:`<br>
`};rt.softbreak=function(t,e,u){return u.breaks?u.xhtmlOut?`<br />
`:`<br>
`:`
`};rt.text=function(t,e){return T0(t[e].content)};rt.htmlblock=function(t,e){return t[e].content};rt.htmltag=function(t,e){return t[e].content};rt.abbr_open=function(t,e){return'<abbr title="'+T0(Gi(t[e].title))+'">'};rt.abbr_close=function(){return"</abbr>"};rt.footnote_ref=function(t,e){var u=Number(t[e].id+1).toString(),r="fnref"+u;return t[e].subId>0&&(r+=":"+t[e].subId),'<sup class="footnote-ref"><a href="#fn'+u+'" id="'+r+'">['+u+"]</a></sup>"};rt.footnote_block_open=function(t,e,u){var r=u.xhtmlOut?`<hr class="footnotes-sep" />
`:`<hr class="footnotes-sep">
`;return r+`<section class="footnotes">
<ol class="footnotes-list">
`};rt.footnote_block_close=function(){return`</ol>
</section>
`};rt.footnote_open=function(t,e){var u=Number(t[e].id+1).toString();return'<li id="fn'+u+'"  class="footnote-item">'};rt.footnote_close=function(){return`</li>
`};rt.footnote_anchor=function(t,e){var u=Number(t[e].id+1).toString(),r="fnref"+u;return t[e].subId>0&&(r+=":"+t[e].subId),' <a href="#'+r+'" class="footnote-backref">↩</a>'};rt.dl_open=function(){return`<dl>
`};rt.dt_open=function(){return"<dt>"};rt.dd_open=function(){return"<dd>"};rt.dl_close=function(){return`</dl>
`};rt.dt_close=function(){return`</dt>
`};rt.dd_close=function(){return`</dd>
`};function Kh(t,e){return++e>=t.length-2?e:t[e].type==="paragraph_open"&&t[e].tight&&t[e+1].type==="inline"&&t[e+1].content.length===0&&t[e+2].type==="paragraph_close"&&t[e+2].tight?Kh(t,e+2):e}var eu=rt.getBreak=function(e,u){return u=Kh(e,u),u<e.length&&e[u].type==="list_item_close"?"":`
`};function hl(){this.rules=Vh({},rt),this.getBreak=rt.getBreak}hl.prototype.renderInline=function(t,e,u){for(var r=this.rules,i=t.length,s=0,o="";i--;)o+=r[t[s].type](t,s++,e,u,this);return o};hl.prototype.render=function(t,e,u){for(var r=this.rules,i=t.length,s=-1,o="";++s<i;)t[s].type==="inline"?o+=this.renderInline(t[s].children,e,u):o+=r[t[s].type](t,s,e,u,this);return o};function q0(){this.__rules__=[],this.__cache__=null}q0.prototype.__find__=function(t){for(var e=this.__rules__.length,u=-1;e--;)if(this.__rules__[++u].name===t)return u;return-1};q0.prototype.__compile__=function(){var t=this,e=[""];t.__rules__.forEach(function(u){u.enabled&&u.alt.forEach(function(r){e.indexOf(r)<0&&e.push(r)})}),t.__cache__={},e.forEach(function(u){t.__cache__[u]=[],t.__rules__.forEach(function(r){r.enabled&&(u&&r.alt.indexOf(u)<0||t.__cache__[u].push(r.fn))})})};q0.prototype.at=function(t,e,u){var r=this.__find__(t),i=u||{};if(r===-1)throw new Error("Parser rule not found: "+t);this.__rules__[r].fn=e,this.__rules__[r].alt=i.alt||[],this.__cache__=null};q0.prototype.before=function(t,e,u,r){var i=this.__find__(t),s=r||{};if(i===-1)throw new Error("Parser rule not found: "+t);this.__rules__.splice(i,0,{name:e,enabled:!0,fn:u,alt:s.alt||[]}),this.__cache__=null};q0.prototype.after=function(t,e,u,r){var i=this.__find__(t),s=r||{};if(i===-1)throw new Error("Parser rule not found: "+t);this.__rules__.splice(i+1,0,{name:e,enabled:!0,fn:u,alt:s.alt||[]}),this.__cache__=null};q0.prototype.push=function(t,e,u){var r=u||{};this.__rules__.push({name:t,enabled:!0,fn:e,alt:r.alt||[]}),this.__cache__=null};q0.prototype.enable=function(t,e){t=Array.isArray(t)?t:[t],e&&this.__rules__.forEach(function(u){u.enabled=!1}),t.forEach(function(u){var r=this.__find__(u);if(r<0)throw new Error("Rules manager: invalid rule name "+u);this.__rules__[r].enabled=!0},this),this.__cache__=null};q0.prototype.disable=function(t){t=Array.isArray(t)?t:[t],t.forEach(function(e){var u=this.__find__(e);if(u<0)throw new Error("Rules manager: invalid rule name "+e);this.__rules__[u].enabled=!1},this),this.__cache__=null};q0.prototype.getRules=function(t){return this.__cache__===null&&this.__compile__(),this.__cache__[t]||[]};function _y(t){t.inlineMode?t.tokens.push({type:"inline",content:t.src.replace(/\n/g," ").trim(),level:0,lines:[0,1],children:[]}):t.block.parse(t.src,t.options,t.env,t.tokens)}function tu(t,e,u,r,i){this.src=t,this.env=r,this.options=u,this.parser=e,this.tokens=i,this.pos=0,this.posMax=this.src.length,this.level=0,this.pending="",this.pendingLevel=0,this.cache=[],this.isInLabel=!1,this.linkLevel=0,this.linkContent="",this.labelUnmatchedScopes=0}tu.prototype.pushPending=function(){this.tokens.push({type:"text",content:this.pending,level:this.pendingLevel}),this.pending=""};tu.prototype.push=function(t){this.pending&&this.pushPending(),this.tokens.push(t),this.pendingLevel=this.level};tu.prototype.cacheSet=function(t,e){for(var u=this.cache.length;u<=t;u++)this.cache.push(0);this.cache[t]=e};tu.prototype.cacheGet=function(t){return t<this.cache.length?this.cache[t]:0};function _s(t,e){var u,r,i,s=-1,o=t.posMax,f=t.pos,n=t.isInLabel;if(t.isInLabel)return-1;if(t.labelUnmatchedScopes)return t.labelUnmatchedScopes--,-1;for(t.pos=e+1,t.isInLabel=!0,u=1;t.pos<o;){if(i=t.src.charCodeAt(t.pos),i===91)u++;else if(i===93&&(u--,u===0)){r=!0;break}t.parser.skipToken(t)}return r?(s=t.pos,t.labelUnmatchedScopes=0):t.labelUnmatchedScopes=u-1,t.pos=f,t.isInLabel=n,s}function Dy(t,e,u,r){var i,s,o,f,n,h;if(t.charCodeAt(0)!==42||t.charCodeAt(1)!==91||t.indexOf("]:")===-1||(i=new tu(t,e,u,r,[]),s=_s(i,1),s<0||t.charCodeAt(s+1)!==58))return-1;for(f=i.posMax,o=s+2;o<f&&i.src.charCodeAt(o)!==10;o++);return n=t.slice(2,s),h=t.slice(s+2,o).trim(),h.length===0?-1:(r.abbreviations||(r.abbreviations={}),typeof r.abbreviations[":"+n]>"u"&&(r.abbreviations[":"+n]=h),o)}function My(t){var e=t.tokens,u,r,i,s;if(!t.inlineMode){for(u=1,r=e.length-1;u<r;u++)if(e[u-1].type==="paragraph_open"&&e[u].type==="inline"&&e[u+1].type==="paragraph_close"){for(i=e[u].content;i.length&&(s=Dy(i,t.inline,t.options,t.env),!(s<0));)i=i.slice(s).trim();e[u].content=i,i.length||(e[u-1].tight=!0,e[u+1].tight=!0)}}}function $a(t){var e=Gi(t);try{e=decodeURI(e)}catch{}return encodeURI(e)}function Yh(t,e){var u,r,i,s=e,o=t.posMax;if(t.src.charCodeAt(e)===60){for(e++;e<o;){if(u=t.src.charCodeAt(e),u===10)return!1;if(u===62)return i=$a(Ss(t.src.slice(s+1,e))),t.parser.validateLink(i)?(t.pos=e+1,t.linkContent=i,!0):!1;if(u===92&&e+1<o){e+=2;continue}e++}return!1}for(r=0;e<o&&(u=t.src.charCodeAt(e),!(u===32||u<32||u===127));){if(u===92&&e+1<o){e+=2;continue}if(u===40&&(r++,r>1)||u===41&&(r--,r<0))break;e++}return s===e||(i=Ss(t.src.slice(s,e)),!t.parser.validateLink(i))?!1:(t.linkContent=i,t.pos=e,!0)}function Jh(t,e){var u,r=e,i=t.posMax,s=t.src.charCodeAt(e);if(s!==34&&s!==39&&s!==40)return!1;for(e++,s===40&&(s=41);e<i;){if(u=t.src.charCodeAt(e),u===s)return t.pos=e+1,t.linkContent=Ss(t.src.slice(r+1,e)),!0;if(u===92&&e+1<i){e+=2;continue}e++}return!1}function Qh(t){return t.trim().replace(/\s+/g," ").toUpperCase()}function Ty(t,e,u,r){var i,s,o,f,n,h,g,d,l;if(t.charCodeAt(0)!==91||t.indexOf("]:")===-1||(i=new tu(t,e,u,r,[]),s=_s(i,0),s<0||t.charCodeAt(s+1)!==58))return-1;for(f=i.posMax,o=s+2;o<f&&(n=i.src.charCodeAt(o),!(n!==32&&n!==10));o++);if(!Yh(i,o))return-1;for(g=i.linkContent,o=i.pos,h=o,o=o+1;o<f&&(n=i.src.charCodeAt(o),!(n!==32&&n!==10));o++);for(o<f&&h!==o&&Jh(i,o)?(d=i.linkContent,o=i.pos):(d="",o=h);o<f&&i.src.charCodeAt(o)===32;)o++;return o<f&&i.src.charCodeAt(o)!==10?-1:(l=Qh(t.slice(1,s)),typeof r.references[l]>"u"&&(r.references[l]={title:d,href:g}),o)}function Py(t){var e=t.tokens,u,r,i,s;if(t.env.references=t.env.references||{},!t.inlineMode){for(u=1,r=e.length-1;u<r;u++)if(e[u].type==="inline"&&e[u-1].type==="paragraph_open"&&e[u+1].type==="paragraph_close"){for(i=e[u].content;i.length&&(s=Ty(i,t.inline,t.options,t.env),!(s<0));)i=i.slice(s).trim();e[u].content=i,i.length||(e[u-1].tight=!0,e[u+1].tight=!0)}}}function Ly(t){var e=t.tokens,u,r,i;for(r=0,i=e.length;r<i;r++)u=e[r],u.type==="inline"&&t.inline.parse(u.content,t.options,t.env,u.children)}function Ry(t){var e,u,r,i,s,o,f,n,h,g=0,d=!1,l={};if(t.env.footnotes&&(t.tokens=t.tokens.filter(function(c){return c.type==="footnote_reference_open"?(d=!0,n=[],h=c.label,!1):c.type==="footnote_reference_close"?(d=!1,l[":"+h]=n,!1):(d&&n.push(c),!d)}),!!t.env.footnotes.list)){for(o=t.env.footnotes.list,t.tokens.push({type:"footnote_block_open",level:g++}),e=0,u=o.length;e<u;e++){for(t.tokens.push({type:"footnote_open",id:e,level:g++}),o[e].tokens?(f=[],f.push({type:"paragraph_open",tight:!1,level:g++}),f.push({type:"inline",content:"",level:g,children:o[e].tokens}),f.push({type:"paragraph_close",tight:!1,level:--g})):o[e].label&&(f=l[":"+o[e].label]),t.tokens=t.tokens.concat(f),t.tokens[t.tokens.length-1].type==="paragraph_close"?s=t.tokens.pop():s=null,i=o[e].count>0?o[e].count:1,r=0;r<i;r++)t.tokens.push({type:"footnote_anchor",id:e,subId:r,level:g});s&&t.tokens.push(s),t.tokens.push({type:"footnote_close",level:--g})}t.tokens.push({type:"footnote_block_close",level:--g})}}var Ad=` 
()[]'".,!?-`;function ca(t){return t.replace(/([-()\[\]{}+?*.$\^|,:#<!\\])/g,"\\$1")}function By(t){var e,u,r,i,s,o,f,n,h,g,d,l,c=t.tokens;if(t.env.abbreviations){for(t.env.abbrRegExp||(l="(^|["+Ad.split("").map(ca).join("")+"])("+Object.keys(t.env.abbreviations).map(function(a){return a.substr(1)}).sort(function(a,F){return F.length-a.length}).map(ca).join("|")+")($|["+Ad.split("").map(ca).join("")+"])",t.env.abbrRegExp=new RegExp(l,"g")),g=t.env.abbrRegExp,u=0,r=c.length;u<r;u++)if(c[u].type==="inline"){for(i=c[u].children,e=i.length-1;e>=0;e--)if(s=i[e],s.type==="text"){for(n=0,o=s.content,g.lastIndex=0,h=s.level,f=[];d=g.exec(o);)g.lastIndex>n&&f.push({type:"text",content:o.slice(n,d.index+d[1].length),level:h}),f.push({type:"abbr_open",title:t.env.abbreviations[":"+d[2]],level:h++}),f.push({type:"text",content:d[2],level:h}),f.push({type:"abbr_close",level:--h}),n=g.lastIndex-d[3].length;f.length&&(n<o.length&&f.push({type:"text",content:o.slice(n),level:h}),c[u].children=i=[].concat(i.slice(0,e),f,i.slice(e+1)))}}}}var Iy=/\+-|\.\.|\?\?\?\?|!!!!|,,|--/,Oy=/\((c|tm|r|p)\)/ig,$y={c:"©",r:"®",p:"§",tm:"™"};function Ny(t){return t.indexOf("(")<0?t:t.replace(Oy,function(e,u){return $y[u.toLowerCase()]})}function Wy(t){var e,u,r,i,s;if(t.options.typographer){for(s=t.tokens.length-1;s>=0;s--)if(t.tokens[s].type==="inline")for(i=t.tokens[s].children,e=i.length-1;e>=0;e--)u=i[e],u.type==="text"&&(r=u.content,r=Ny(r),Iy.test(r)&&(r=r.replace(/\+-/g,"±").replace(/\.{2,}/g,"…").replace(/([?!])…/g,"$1..").replace(/([?!]){4,}/g,"$1$1$1").replace(/,{2,}/g,",").replace(/(^|[^-])---([^-]|$)/mg,"$1—$2").replace(/(^|\s)--(\s|$)/mg,"$1–$2").replace(/(^|[^-\s])--([^-\s]|$)/mg,"$1–$2")),u.content=r)}}var Hy=/['"]/,xd=/['"]/g,Uy=/[-\s()\[\]]/,kd="’";function jd(t,e){return e<0||e>=t.length?!1:!Uy.test(t[e])}function nu(t,e,u){return t.substr(0,e)+u+t.substr(e+1)}function qy(t){var e,u,r,i,s,o,f,n,h,g,d,l,c,a,F,p,m;if(t.options.typographer){for(m=[],F=t.tokens.length-1;F>=0;F--)if(t.tokens[F].type==="inline"){for(p=t.tokens[F].children,m.length=0,e=0;e<p.length;e++)if(u=p[e],!(u.type!=="text"||Hy.test(u.text))){for(f=p[e].level,c=m.length-1;c>=0&&!(m[c].level<=f);c--);m.length=c+1,r=u.content,s=0,o=r.length;e:for(;s<o&&(xd.lastIndex=s,i=xd.exec(r),!!i);){if(n=!jd(r,i.index-1),s=i.index+1,a=i[0]==="'",h=!jd(r,s),!h&&!n){a&&(u.content=nu(u.content,i.index,kd));continue}if(d=!h,l=!n,l){for(c=m.length-1;c>=0&&(g=m[c],!(m[c].level<f));c--)if(g.single===a&&m[c].level===f){g=m[c],a?(p[g.token].content=nu(p[g.token].content,g.pos,t.options.quotes[2]),u.content=nu(u.content,i.index,t.options.quotes[3])):(p[g.token].content=nu(p[g.token].content,g.pos,t.options.quotes[0]),u.content=nu(u.content,i.index,t.options.quotes[1])),m.length=c;continue e}}d?m.push({token:e,pos:i.index,single:a,level:f}):l&&a&&(u.content=nu(u.content,i.index,kd))}}}}}var la=[["block",_y],["abbr",My],["references",Py],["inline",Ly],["footnote_tail",Ry],["abbr2",By],["replacements",Wy],["smartquotes",qy]];function Xh(){this.options={},this.ruler=new q0;for(var t=0;t<la.length;t++)this.ruler.push(la[t][0],la[t][1])}Xh.prototype.process=function(t){var e,u,r;for(r=this.ruler.getRules(""),e=0,u=r.length;e<u;e++)r[e](t)};function ru(t,e,u,r,i){var s,o,f,n,h,g,d;for(this.src=t,this.parser=e,this.options=u,this.env=r,this.tokens=i,this.bMarks=[],this.eMarks=[],this.tShift=[],this.blkIndent=0,this.line=0,this.lineMax=0,this.tight=!1,this.parentType="root",this.ddIndent=-1,this.level=0,this.result="",o=this.src,g=0,d=!1,f=n=g=0,h=o.length;n<h;n++){if(s=o.charCodeAt(n),!d)if(s===32){g++;continue}else d=!0;(s===10||n===h-1)&&(s!==10&&n++,this.bMarks.push(f),this.eMarks.push(n),this.tShift.push(g),d=!1,g=0,f=n+1)}this.bMarks.push(o.length),this.eMarks.push(o.length),this.tShift.push(0),this.lineMax=this.bMarks.length-1}ru.prototype.isEmpty=function(e){return this.bMarks[e]+this.tShift[e]>=this.eMarks[e]};ru.prototype.skipEmptyLines=function(e){for(var u=this.lineMax;e<u&&!(this.bMarks[e]+this.tShift[e]<this.eMarks[e]);e++);return e};ru.prototype.skipSpaces=function(e){for(var u=this.src.length;e<u&&this.src.charCodeAt(e)===32;e++);return e};ru.prototype.skipChars=function(e,u){for(var r=this.src.length;e<r&&this.src.charCodeAt(e)===u;e++);return e};ru.prototype.skipCharsBack=function(e,u,r){if(e<=r)return e;for(;e>r;)if(u!==this.src.charCodeAt(--e))return e+1;return e};ru.prototype.getLines=function(e,u,r,i){var s,o,f,n,h,g=e;if(e>=u)return"";if(g+1===u)return o=this.bMarks[g]+Math.min(this.tShift[g],r),f=i?this.eMarks[g]+1:this.eMarks[g],this.src.slice(o,f);for(n=new Array(u-e),s=0;g<u;g++,s++)h=this.tShift[g],h>r&&(h=r),h<0&&(h=0),o=this.bMarks[g]+h,g+1<u||i?f=this.eMarks[g]+1:f=this.eMarks[g],n[s]=this.src.slice(o,f);return n.join("")};function zy(t,e,u){var r,i;if(t.tShift[e]-t.blkIndent<4)return!1;for(i=r=e+1;r<u;){if(t.isEmpty(r)){r++;continue}if(t.tShift[r]-t.blkIndent>=4){r++,i=r;continue}break}return t.line=r,t.tokens.push({type:"code",content:t.getLines(e,i,4+t.blkIndent,!0),block:!0,lines:[e,t.line],level:t.level}),!0}function Vy(t,e,u,r){var i,s,o,f,n,h=!1,g=t.bMarks[e]+t.tShift[e],d=t.eMarks[e];if(g+3>d||(i=t.src.charCodeAt(g),i!==126&&i!==96)||(n=g,g=t.skipChars(g,i),s=g-n,s<3)||(o=t.src.slice(g,d).trim(),o.indexOf("`")>=0))return!1;if(r)return!0;for(f=e;f++,!(f>=u||(g=n=t.bMarks[f]+t.tShift[f],d=t.eMarks[f],g<d&&t.tShift[f]<t.blkIndent));)if(t.src.charCodeAt(g)===i&&!(t.tShift[f]-t.blkIndent>=4)&&(g=t.skipChars(g,i),!(g-n<s)&&(g=t.skipSpaces(g),!(g<d)))){h=!0;break}return s=t.tShift[e],t.line=f+(h?1:0),t.tokens.push({type:"fence",params:o,content:t.getLines(e+1,f,s,!0),lines:[e,t.line],level:t.level}),!0}function Gy(t,e,u,r){var i,s,o,f,n,h,g,d,l,c,a,F=t.bMarks[e]+t.tShift[e],p=t.eMarks[e];if(F>p||t.src.charCodeAt(F++)!==62||t.level>=t.options.maxNesting)return!1;if(r)return!0;for(t.src.charCodeAt(F)===32&&F++,n=t.blkIndent,t.blkIndent=0,f=[t.bMarks[e]],t.bMarks[e]=F,F=F<p?t.skipSpaces(F):F,s=F>=p,o=[t.tShift[e]],t.tShift[e]=F-t.bMarks[e],d=t.parser.ruler.getRules("blockquote"),i=e+1;i<u&&(F=t.bMarks[i]+t.tShift[i],p=t.eMarks[i],!(F>=p));i++){if(t.src.charCodeAt(F++)===62){t.src.charCodeAt(F)===32&&F++,f.push(t.bMarks[i]),t.bMarks[i]=F,F=F<p?t.skipSpaces(F):F,s=F>=p,o.push(t.tShift[i]),t.tShift[i]=F-t.bMarks[i];continue}if(s)break;for(a=!1,l=0,c=d.length;l<c;l++)if(d[l](t,i,u,!0)){a=!0;break}if(a)break;f.push(t.bMarks[i]),o.push(t.tShift[i]),t.tShift[i]=-1337}for(h=t.parentType,t.parentType="blockquote",t.tokens.push({type:"blockquote_open",lines:g=[e,0],level:t.level++}),t.parser.tokenize(t,e,i),t.tokens.push({type:"blockquote_close",level:--t.level}),t.parentType=h,g[1]=t.line,l=0;l<o.length;l++)t.bMarks[l+e]=f[l],t.tShift[l+e]=o[l];return t.blkIndent=n,!0}function Ky(t,e,u,r){var i,s,o,f=t.bMarks[e],n=t.eMarks[e];if(f+=t.tShift[e],f>n||(i=t.src.charCodeAt(f++),i!==42&&i!==45&&i!==95))return!1;for(s=1;f<n;){if(o=t.src.charCodeAt(f++),o!==i&&o!==32)return!1;o===i&&s++}return s<3?!1:(r||(t.line=e+1,t.tokens.push({type:"hr",lines:[e,t.line],level:t.level})),!0)}function Sd(t,e){var u,r,i;return r=t.bMarks[e]+t.tShift[e],i=t.eMarks[e],r>=i||(u=t.src.charCodeAt(r++),u!==42&&u!==45&&u!==43)||r<i&&t.src.charCodeAt(r)!==32?-1:r}function _d(t,e){var u,r=t.bMarks[e]+t.tShift[e],i=t.eMarks[e];if(r+1>=i||(u=t.src.charCodeAt(r++),u<48||u>57))return-1;for(;;){if(r>=i)return-1;if(u=t.src.charCodeAt(r++),!(u>=48&&u<=57)){if(u===41||u===46)break;return-1}}return r<i&&t.src.charCodeAt(r)!==32?-1:r}function Yy(t,e){var u,r,i=t.level+2;for(u=e+2,r=t.tokens.length-2;u<r;u++)t.tokens[u].level===i&&t.tokens[u].type==="paragraph_open"&&(t.tokens[u+2].tight=!0,t.tokens[u].tight=!0,u+=2)}function Jy(t,e,u,r){var i,s,o,f,n,h,g,d,l,c,a,F,p,m,b,C,k,T,w=!0,A,M,x,R;if((d=_d(t,e))>=0)p=!0;else if((d=Sd(t,e))>=0)p=!1;else return!1;if(t.level>=t.options.maxNesting)return!1;if(F=t.src.charCodeAt(d-1),r)return!0;for(b=t.tokens.length,p?(g=t.bMarks[e]+t.tShift[e],a=Number(t.src.substr(g,d-g-1)),t.tokens.push({type:"ordered_list_open",order:a,lines:k=[e,0],level:t.level++})):t.tokens.push({type:"bullet_list_open",lines:k=[e,0],level:t.level++}),i=e,C=!1,A=t.parser.ruler.getRules("list");i<u&&(m=t.skipSpaces(d),l=t.eMarks[i],m>=l?c=1:c=m-d,c>4&&(c=1),c<1&&(c=1),s=d-t.bMarks[i]+c,t.tokens.push({type:"list_item_open",lines:T=[e,0],level:t.level++}),f=t.blkIndent,n=t.tight,o=t.tShift[e],h=t.parentType,t.tShift[e]=m-t.bMarks[e],t.blkIndent=s,t.tight=!0,t.parentType="list",t.parser.tokenize(t,e,u,!0),(!t.tight||C)&&(w=!1),C=t.line-e>1&&t.isEmpty(t.line-1),t.blkIndent=f,t.tShift[e]=o,t.tight=n,t.parentType=h,t.tokens.push({type:"list_item_close",level:--t.level}),i=e=t.line,T[1]=i,m=t.bMarks[e],!(i>=u||t.isEmpty(i)||t.tShift[i]<t.blkIndent));){for(R=!1,M=0,x=A.length;M<x;M++)if(A[M](t,i,u,!0)){R=!0;break}if(R)break;if(p){if(d=_d(t,i),d<0)break}else if(d=Sd(t,i),d<0)break;if(F!==t.src.charCodeAt(d-1))break}return t.tokens.push({type:p?"ordered_list_close":"bullet_list_close",level:--t.level}),k[1]=i,t.line=i,w&&Yy(t,b),!0}function Qy(t,e,u,r){var i,s,o,f,n,h=t.bMarks[e]+t.tShift[e],g=t.eMarks[e];if(h+4>g||t.src.charCodeAt(h)!==91||t.src.charCodeAt(h+1)!==94||t.level>=t.options.maxNesting)return!1;for(f=h+2;f<g;f++){if(t.src.charCodeAt(f)===32)return!1;if(t.src.charCodeAt(f)===93)break}return f===h+2||f+1>=g||t.src.charCodeAt(++f)!==58?!1:(r||(f++,t.env.footnotes||(t.env.footnotes={}),t.env.footnotes.refs||(t.env.footnotes.refs={}),n=t.src.slice(h+2,f-2),t.env.footnotes.refs[":"+n]=-1,t.tokens.push({type:"footnote_reference_open",label:n,level:t.level++}),i=t.bMarks[e],s=t.tShift[e],o=t.parentType,t.tShift[e]=t.skipSpaces(f)-f,t.bMarks[e]=f,t.blkIndent+=4,t.parentType="footnote",t.tShift[e]<t.blkIndent&&(t.tShift[e]+=t.blkIndent,t.bMarks[e]-=t.blkIndent),t.parser.tokenize(t,e,u,!0),t.parentType=o,t.blkIndent-=4,t.tShift[e]=s,t.bMarks[e]=i,t.tokens.push({type:"footnote_reference_close",level:--t.level})),!0)}function Xy(t,e,u,r){var i,s,o,f=t.bMarks[e]+t.tShift[e],n=t.eMarks[e];if(f>=n||(i=t.src.charCodeAt(f),i!==35||f>=n))return!1;for(s=1,i=t.src.charCodeAt(++f);i===35&&f<n&&s<=6;)s++,i=t.src.charCodeAt(++f);return s>6||f<n&&i!==32?!1:(r||(n=t.skipCharsBack(n,32,f),o=t.skipCharsBack(n,35,f),o>f&&t.src.charCodeAt(o-1)===32&&(n=o),t.line=e+1,t.tokens.push({type:"heading_open",hLevel:s,lines:[e,t.line],level:t.level}),f<n&&t.tokens.push({type:"inline",content:t.src.slice(f,n).trim(),level:t.level+1,lines:[e,t.line],children:[]}),t.tokens.push({type:"heading_close",hLevel:s,level:t.level})),!0)}function Zy(t,e,u){var r,i,s,o=e+1;return o>=u||t.tShift[o]<t.blkIndent||t.tShift[o]-t.blkIndent>3||(i=t.bMarks[o]+t.tShift[o],s=t.eMarks[o],i>=s)||(r=t.src.charCodeAt(i),r!==45&&r!==61)||(i=t.skipChars(i,r),i=t.skipSpaces(i),i<s)?!1:(i=t.bMarks[e]+t.tShift[e],t.line=o+1,t.tokens.push({type:"heading_open",hLevel:r===61?1:2,lines:[e,t.line],level:t.level}),t.tokens.push({type:"inline",content:t.src.slice(i,t.eMarks[e]).trim(),level:t.level+1,lines:[e,t.line-1],children:[]}),t.tokens.push({type:"heading_close",hLevel:r===61?1:2,level:t.level}),!0)}var Zh={};["article","aside","button","blockquote","body","canvas","caption","col","colgroup","dd","div","dl","dt","embed","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","hr","iframe","li","map","object","ol","output","p","pre","progress","script","section","style","table","tbody","td","textarea","tfoot","th","tr","thead","ul","video"].forEach(function(t){Zh[t]=!0});var eC=/^<([a-zA-Z]{1,15})[\s\/>]/,tC=/^<\/([a-zA-Z]{1,15})[\s>]/;function rC(t){var e=t|32;return e>=97&&e<=122}function iC(t,e,u,r){var i,s,o,f=t.bMarks[e],n=t.eMarks[e],h=t.tShift[e];if(f+=h,!t.options.html||h>3||f+2>=n||t.src.charCodeAt(f)!==60)return!1;if(i=t.src.charCodeAt(f+1),i===33||i===63){if(r)return!0}else if(i===47||rC(i)){if(i===47){if(s=t.src.slice(f,n).match(tC),!s)return!1}else if(s=t.src.slice(f,n).match(eC),!s)return!1;if(Zh[s[1].toLowerCase()]!==!0)return!1;if(r)return!0}else return!1;for(o=e+1;o<t.lineMax&&!t.isEmpty(o);)o++;return t.line=o,t.tokens.push({type:"htmlblock",level:t.level,lines:[e,t.line],content:t.getLines(e,o,0,!0)}),!0}function da(t,e){var u=t.bMarks[e]+t.blkIndent,r=t.eMarks[e];return t.src.substr(u,r-u)}function uC(t,e,u,r){var i,s,o,f,n,h,g,d,l,c,a;if(e+2>u||(n=e+1,t.tShift[n]<t.blkIndent)||(o=t.bMarks[n]+t.tShift[n],o>=t.eMarks[n])||(i=t.src.charCodeAt(o),i!==124&&i!==45&&i!==58)||(s=da(t,e+1),!/^[-:| ]+$/.test(s))||(h=s.split("|"),h<=2))return!1;for(d=[],f=0;f<h.length;f++){if(l=h[f].trim(),!l){if(f===0||f===h.length-1)continue;return!1}if(!/^:?-+:?$/.test(l))return!1;l.charCodeAt(l.length-1)===58?d.push(l.charCodeAt(0)===58?"center":"right"):l.charCodeAt(0)===58?d.push("left"):d.push("")}if(s=da(t,e).trim(),s.indexOf("|")===-1||(h=s.replace(/^\||\|$/g,"").split("|"),d.length!==h.length))return!1;if(r)return!0;for(t.tokens.push({type:"table_open",lines:c=[e,0],level:t.level++}),t.tokens.push({type:"thead_open",lines:[e,e+1],level:t.level++}),t.tokens.push({type:"tr_open",lines:[e,e+1],level:t.level++}),f=0;f<h.length;f++)t.tokens.push({type:"th_open",align:d[f],lines:[e,e+1],level:t.level++}),t.tokens.push({type:"inline",content:h[f].trim(),lines:[e,e+1],level:t.level,children:[]}),t.tokens.push({type:"th_close",level:--t.level});for(t.tokens.push({type:"tr_close",level:--t.level}),t.tokens.push({type:"thead_close",level:--t.level}),t.tokens.push({type:"tbody_open",lines:a=[e+2,0],level:t.level++}),n=e+2;n<u&&!(t.tShift[n]<t.blkIndent||(s=da(t,n).trim(),s.indexOf("|")===-1));n++){for(h=s.replace(/^\||\|$/g,"").split("|"),t.tokens.push({type:"tr_open",level:t.level++}),f=0;f<h.length;f++)t.tokens.push({type:"td_open",align:d[f],level:t.level++}),g=h[f].substring(h[f].charCodeAt(0)===124?1:0,h[f].charCodeAt(h[f].length-1)===124?h[f].length-1:h[f].length).trim(),t.tokens.push({type:"inline",content:g,level:t.level,children:[]}),t.tokens.push({type:"td_close",level:--t.level});t.tokens.push({type:"tr_close",level:--t.level})}return t.tokens.push({type:"tbody_close",level:--t.level}),t.tokens.push({type:"table_close",level:--t.level}),c[1]=a[1]=n,t.line=n,!0}function en(t,e){var u,r,i=t.bMarks[e]+t.tShift[e],s=t.eMarks[e];return i>=s||(r=t.src.charCodeAt(i++),r!==126&&r!==58)||(u=t.skipSpaces(i),i===u)||u>=s?-1:u}function sC(t,e){var u,r,i=t.level+2;for(u=e+2,r=t.tokens.length-2;u<r;u++)t.tokens[u].level===i&&t.tokens[u].type==="paragraph_open"&&(t.tokens[u+2].tight=!0,t.tokens[u].tight=!0,u+=2)}function nC(t,e,u,r){var i,s,o,f,n,h,g,d,l,c,a,F,p,m;if(r)return t.ddIndent<0?!1:en(t,e)>=0;if(g=e+1,t.isEmpty(g)&&++g>u||t.tShift[g]<t.blkIndent||(i=en(t,g),i<0)||t.level>=t.options.maxNesting)return!1;h=t.tokens.length,t.tokens.push({type:"dl_open",lines:n=[e,0],level:t.level++}),o=e,s=g;e:for(;;){for(m=!0,p=!1,t.tokens.push({type:"dt_open",lines:[o,o],level:t.level++}),t.tokens.push({type:"inline",content:t.getLines(o,o+1,t.blkIndent,!1).trim(),level:t.level+1,lines:[o,o],children:[]}),t.tokens.push({type:"dt_close",level:--t.level});;){if(t.tokens.push({type:"dd_open",lines:f=[g,0],level:t.level++}),F=t.tight,l=t.ddIndent,d=t.blkIndent,a=t.tShift[s],c=t.parentType,t.blkIndent=t.ddIndent=t.tShift[s]+2,t.tShift[s]=i-t.bMarks[s],t.tight=!0,t.parentType="deflist",t.parser.tokenize(t,s,u,!0),(!t.tight||p)&&(m=!1),p=t.line-s>1&&t.isEmpty(t.line-1),t.tShift[s]=a,t.tight=F,t.parentType=c,t.blkIndent=d,t.ddIndent=l,t.tokens.push({type:"dd_close",level:--t.level}),f[1]=g=t.line,g>=u||t.tShift[g]<t.blkIndent)break e;if(i=en(t,g),i<0)break;s=g}if(g>=u||(o=g,t.isEmpty(o))||t.tShift[o]<t.blkIndent||(s=o+1,s>=u)||(t.isEmpty(s)&&s++,s>=u)||t.tShift[s]<t.blkIndent||(i=en(t,s),i<0))break}return t.tokens.push({type:"dl_close",level:--t.level}),n[1]=g,t.line=g,m&&sC(t,h),!0}function oC(t,e){var u,r,i,s,o,f=e+1,n;if(u=t.lineMax,f<u&&!t.isEmpty(f)){for(n=t.parser.ruler.getRules("paragraph");f<u&&!t.isEmpty(f);f++)if(!(t.tShift[f]-t.blkIndent>3)){for(i=!1,s=0,o=n.length;s<o;s++)if(n[s](t,f,u,!0)){i=!0;break}if(i)break}}return r=t.getLines(e,f,t.blkIndent,!1).trim(),t.line=f,r.length&&(t.tokens.push({type:"paragraph_open",tight:!1,lines:[e,t.line],level:t.level}),t.tokens.push({type:"inline",content:r,level:t.level+1,lines:[e,t.line],children:[]}),t.tokens.push({type:"paragraph_close",tight:!1,level:t.level})),!0}var tn=[["code",zy],["fences",Vy,["paragraph","blockquote","list"]],["blockquote",Gy,["paragraph","blockquote","list"]],["hr",Ky,["paragraph","blockquote","list"]],["list",Jy,["paragraph","blockquote"]],["footnote",Qy,["paragraph"]],["heading",Xy,["paragraph","blockquote"]],["lheading",Zy],["htmlblock",iC,["paragraph","blockquote"]],["table",uC,["paragraph"]],["deflist",nC,["paragraph"]],["paragraph",oC]];function gl(){this.ruler=new q0;for(var t=0;t<tn.length;t++)this.ruler.push(tn[t][0],tn[t][1],{alt:(tn[t][2]||[]).slice()})}gl.prototype.tokenize=function(t,e,u){for(var r=this.ruler.getRules(""),i=r.length,s=e,o=!1,f,n;s<u&&(t.line=s=t.skipEmptyLines(s),!(s>=u||t.tShift[s]<t.blkIndent));){for(n=0;n<i&&(f=r[n](t,s,u,!1),!f);n++);if(t.tight=!o,t.isEmpty(t.line-1)&&(o=!0),s=t.line,s<u&&t.isEmpty(s)){if(o=!0,s++,s<u&&t.parentType==="list"&&t.isEmpty(s))break;t.line=s}}};var aC=/[\n\t]/g,cC=/\r[\n\u0085]|[\u2424\u2028\u0085]/g,lC=/\u00a0/g;gl.prototype.parse=function(t,e,u,r){var i,s=0,o=0;if(!t)return[];t=t.replace(lC," "),t=t.replace(cC,`
`),t.indexOf("	")>=0&&(t=t.replace(aC,function(f,n){var h;return t.charCodeAt(n)===10?(s=n+1,o=0,f):(h="    ".slice((n-s-o)%4),o=n-s+1,h)})),i=new ru(t,this,e,u,r),this.tokenize(i,i.line,i.lineMax)};function dC(t){switch(t){case 10:case 92:case 96:case 42:case 95:case 94:case 91:case 93:case 33:case 38:case 60:case 62:case 123:case 125:case 36:case 37:case 64:case 126:case 43:case 61:case 58:return!0;default:return!1}}function FC(t,e){for(var u=t.pos;u<t.posMax&&!dC(t.src.charCodeAt(u));)u++;return u===t.pos?!1:(e||(t.pending+=t.src.slice(t.pos,u)),t.pos=u,!0)}function hC(t,e){var u,r,i=t.pos;if(t.src.charCodeAt(i)!==10)return!1;if(u=t.pending.length-1,r=t.posMax,!e)if(u>=0&&t.pending.charCodeAt(u)===32)if(u>=1&&t.pending.charCodeAt(u-1)===32){for(var s=u-2;s>=0;s--)if(t.pending.charCodeAt(s)!==32){t.pending=t.pending.substring(0,s+1);break}t.push({type:"hardbreak",level:t.level})}else t.pending=t.pending.slice(0,-1),t.push({type:"softbreak",level:t.level});else t.push({type:"softbreak",level:t.level});for(i++;i<r&&t.src.charCodeAt(i)===32;)i++;return t.pos=i,!0}var pl=[];for(var Dd=0;Dd<256;Dd++)pl.push(0);"\\!\"#$%&'()*+,./:;<=>?@[]^_`{|}~-".split("").forEach(function(t){pl[t.charCodeAt(0)]=1});function gC(t,e){var u,r=t.pos,i=t.posMax;if(t.src.charCodeAt(r)!==92)return!1;if(r++,r<i){if(u=t.src.charCodeAt(r),u<256&&pl[u]!==0)return e||(t.pending+=t.src[r]),t.pos+=2,!0;if(u===10){for(e||t.push({type:"hardbreak",level:t.level}),r++;r<i&&t.src.charCodeAt(r)===32;)r++;return t.pos=r,!0}}return e||(t.pending+="\\"),t.pos++,!0}function pC(t,e){var u,r,i,s,o,f=t.pos,n=t.src.charCodeAt(f);if(n!==96)return!1;for(u=f,f++,r=t.posMax;f<r&&t.src.charCodeAt(f)===96;)f++;for(i=t.src.slice(u,f),s=o=f;(s=t.src.indexOf("`",o))!==-1;){for(o=s+1;o<r&&t.src.charCodeAt(o)===96;)o++;if(o-s===i.length)return e||t.push({type:"code",content:t.src.slice(f,s).replace(/[ \n]+/g," ").trim(),block:!1,level:t.level}),t.pos=o,!0}return e||(t.pending+=i),t.pos+=i.length,!0}function fC(t,e){var u,r,i,s=t.posMax,o=t.pos,f,n;if(t.src.charCodeAt(o)!==126||e||o+4>=s||t.src.charCodeAt(o+1)!==126||t.level>=t.options.maxNesting||(f=o>0?t.src.charCodeAt(o-1):-1,n=t.src.charCodeAt(o+2),f===126)||n===126||n===32||n===10)return!1;for(r=o+2;r<s&&t.src.charCodeAt(r)===126;)r++;if(r>o+3)return t.pos+=r-o,e||(t.pending+=t.src.slice(o,r)),!0;for(t.pos=o+2,i=1;t.pos+1<s;){if(t.src.charCodeAt(t.pos)===126&&t.src.charCodeAt(t.pos+1)===126&&(f=t.src.charCodeAt(t.pos-1),n=t.pos+2<s?t.src.charCodeAt(t.pos+2):-1,n!==126&&f!==126&&(f!==32&&f!==10?i--:n!==32&&n!==10&&i++,i<=0))){u=!0;break}t.parser.skipToken(t)}return u?(t.posMax=t.pos,t.pos=o+2,e||(t.push({type:"del_open",level:t.level++}),t.parser.tokenize(t),t.push({type:"del_close",level:--t.level})),t.pos=t.posMax+2,t.posMax=s,!0):(t.pos=o,!1)}function mC(t,e){var u,r,i,s=t.posMax,o=t.pos,f,n;if(t.src.charCodeAt(o)!==43||e||o+4>=s||t.src.charCodeAt(o+1)!==43||t.level>=t.options.maxNesting||(f=o>0?t.src.charCodeAt(o-1):-1,n=t.src.charCodeAt(o+2),f===43)||n===43||n===32||n===10)return!1;for(r=o+2;r<s&&t.src.charCodeAt(r)===43;)r++;if(r!==o+2)return t.pos+=r-o,e||(t.pending+=t.src.slice(o,r)),!0;for(t.pos=o+2,i=1;t.pos+1<s;){if(t.src.charCodeAt(t.pos)===43&&t.src.charCodeAt(t.pos+1)===43&&(f=t.src.charCodeAt(t.pos-1),n=t.pos+2<s?t.src.charCodeAt(t.pos+2):-1,n!==43&&f!==43&&(f!==32&&f!==10?i--:n!==32&&n!==10&&i++,i<=0))){u=!0;break}t.parser.skipToken(t)}return u?(t.posMax=t.pos,t.pos=o+2,e||(t.push({type:"ins_open",level:t.level++}),t.parser.tokenize(t),t.push({type:"ins_close",level:--t.level})),t.pos=t.posMax+2,t.posMax=s,!0):(t.pos=o,!1)}function vC(t,e){var u,r,i,s=t.posMax,o=t.pos,f,n;if(t.src.charCodeAt(o)!==61||e||o+4>=s||t.src.charCodeAt(o+1)!==61||t.level>=t.options.maxNesting||(f=o>0?t.src.charCodeAt(o-1):-1,n=t.src.charCodeAt(o+2),f===61)||n===61||n===32||n===10)return!1;for(r=o+2;r<s&&t.src.charCodeAt(r)===61;)r++;if(r!==o+2)return t.pos+=r-o,e||(t.pending+=t.src.slice(o,r)),!0;for(t.pos=o+2,i=1;t.pos+1<s;){if(t.src.charCodeAt(t.pos)===61&&t.src.charCodeAt(t.pos+1)===61&&(f=t.src.charCodeAt(t.pos-1),n=t.pos+2<s?t.src.charCodeAt(t.pos+2):-1,n!==61&&f!==61&&(f!==32&&f!==10?i--:n!==32&&n!==10&&i++,i<=0))){u=!0;break}t.parser.skipToken(t)}return u?(t.posMax=t.pos,t.pos=o+2,e||(t.push({type:"mark_open",level:t.level++}),t.parser.tokenize(t),t.push({type:"mark_close",level:--t.level})),t.pos=t.posMax+2,t.posMax=s,!0):(t.pos=o,!1)}function Md(t){return t>=48&&t<=57||t>=65&&t<=90||t>=97&&t<=122}function Td(t,e){var u=e,r,i,s,o=!0,f=!0,n=t.posMax,h=t.src.charCodeAt(e);for(r=e>0?t.src.charCodeAt(e-1):-1;u<n&&t.src.charCodeAt(u)===h;)u++;return u>=n&&(o=!1),s=u-e,s>=4?o=f=!1:(i=u<n?t.src.charCodeAt(u):-1,(i===32||i===10)&&(o=!1),(r===32||r===10)&&(f=!1),h===95&&(Md(r)&&(o=!1),Md(i)&&(f=!1))),{can_open:o,can_close:f,delims:s}}function bC(t,e){var u,r,i,s,o,f,n,h=t.posMax,g=t.pos,d=t.src.charCodeAt(g);if(d!==95&&d!==42||e)return!1;if(n=Td(t,g),u=n.delims,!n.can_open)return t.pos+=u,e||(t.pending+=t.src.slice(g,t.pos)),!0;if(t.level>=t.options.maxNesting)return!1;for(t.pos=g+u,f=[u];t.pos<h;){if(t.src.charCodeAt(t.pos)===d){if(n=Td(t,t.pos),r=n.delims,n.can_close){for(s=f.pop(),o=r;s!==o;){if(o<s){f.push(s-o);break}if(o-=s,f.length===0)break;t.pos+=s,s=f.pop()}if(f.length===0){u=s,i=!0;break}t.pos+=r;continue}n.can_open&&f.push(r),t.pos+=r;continue}t.parser.skipToken(t)}return i?(t.posMax=t.pos,t.pos=g+u,e||((u===2||u===3)&&t.push({type:"strong_open",level:t.level++}),(u===1||u===3)&&t.push({type:"em_open",level:t.level++}),t.parser.tokenize(t),(u===1||u===3)&&t.push({type:"em_close",level:--t.level}),(u===2||u===3)&&t.push({type:"strong_close",level:--t.level})),t.pos=t.posMax+u,t.posMax=h,!0):(t.pos=g,!1)}var wC=/\\([ \\!"#$%&'()*+,.\/:;<=>?@[\]^_`{|}~-])/g;function yC(t,e){var u,r,i=t.posMax,s=t.pos;if(t.src.charCodeAt(s)!==126||e||s+2>=i||t.level>=t.options.maxNesting)return!1;for(t.pos=s+1;t.pos<i;){if(t.src.charCodeAt(t.pos)===126){u=!0;break}t.parser.skipToken(t)}return!u||s+1===t.pos||(r=t.src.slice(s+1,t.pos),r.match(/(^|[^\\])(\\\\)*\s/))?(t.pos=s,!1):(t.posMax=t.pos,t.pos=s+1,e||t.push({type:"sub",level:t.level,content:r.replace(wC,"$1")}),t.pos=t.posMax+1,t.posMax=i,!0)}var CC=/\\([ \\!"#$%&'()*+,.\/:;<=>?@[\]^_`{|}~-])/g;function EC(t,e){var u,r,i=t.posMax,s=t.pos;if(t.src.charCodeAt(s)!==94||e||s+2>=i||t.level>=t.options.maxNesting)return!1;for(t.pos=s+1;t.pos<i;){if(t.src.charCodeAt(t.pos)===94){u=!0;break}t.parser.skipToken(t)}return!u||s+1===t.pos||(r=t.src.slice(s+1,t.pos),r.match(/(^|[^\\])(\\\\)*\s/))?(t.pos=s,!1):(t.posMax=t.pos,t.pos=s+1,e||t.push({type:"sup",level:t.level,content:r.replace(CC,"$1")}),t.pos=t.posMax+1,t.posMax=i,!0)}function AC(t,e){var u,r,i,s,o,f,n,h,g=!1,d=t.pos,l=t.posMax,c=t.pos,a=t.src.charCodeAt(c);if(a===33&&(g=!0,a=t.src.charCodeAt(++c)),a!==91||t.level>=t.options.maxNesting||(u=c+1,r=_s(t,c),r<0))return!1;if(f=r+1,f<l&&t.src.charCodeAt(f)===40){for(f++;f<l&&(h=t.src.charCodeAt(f),!(h!==32&&h!==10));f++);if(f>=l)return!1;for(c=f,Yh(t,f)?(s=t.linkContent,f=t.pos):s="",c=f;f<l&&(h=t.src.charCodeAt(f),!(h!==32&&h!==10));f++);if(f<l&&c!==f&&Jh(t,f))for(o=t.linkContent,f=t.pos;f<l&&(h=t.src.charCodeAt(f),!(h!==32&&h!==10));f++);else o="";if(f>=l||t.src.charCodeAt(f)!==41)return t.pos=d,!1;f++}else{if(t.linkLevel>0)return!1;for(;f<l&&(h=t.src.charCodeAt(f),!(h!==32&&h!==10));f++);if(f<l&&t.src.charCodeAt(f)===91&&(c=f+1,f=_s(t,f),f>=0?i=t.src.slice(c,f++):f=c-1),i||(typeof i>"u"&&(f=r+1),i=t.src.slice(u,r)),n=t.env.references[Qh(i)],!n)return t.pos=d,!1;s=n.href,o=n.title}return e||(t.pos=u,t.posMax=r,g?t.push({type:"image",src:s,title:o,alt:t.src.substr(u,r-u),level:t.level}):(t.push({type:"link_open",href:s,title:o,level:t.level++}),t.linkLevel++,t.parser.tokenize(t),t.linkLevel--,t.push({type:"link_close",level:--t.level}))),t.pos=f,t.posMax=l,!0}function xC(t,e){var u,r,i,s,o=t.posMax,f=t.pos;return f+2>=o||t.src.charCodeAt(f)!==94||t.src.charCodeAt(f+1)!==91||t.level>=t.options.maxNesting||(u=f+2,r=_s(t,f+1),r<0)?!1:(e||(t.env.footnotes||(t.env.footnotes={}),t.env.footnotes.list||(t.env.footnotes.list=[]),i=t.env.footnotes.list.length,t.pos=u,t.posMax=r,t.push({type:"footnote_ref",id:i,level:t.level}),t.linkLevel++,s=t.tokens.length,t.parser.tokenize(t),t.env.footnotes.list[i]={tokens:t.tokens.splice(s)},t.linkLevel--),t.pos=r+1,t.posMax=o,!0)}function kC(t,e){var u,r,i,s,o=t.posMax,f=t.pos;if(f+3>o||!t.env.footnotes||!t.env.footnotes.refs||t.src.charCodeAt(f)!==91||t.src.charCodeAt(f+1)!==94||t.level>=t.options.maxNesting)return!1;for(r=f+2;r<o;r++){if(t.src.charCodeAt(r)===32||t.src.charCodeAt(r)===10)return!1;if(t.src.charCodeAt(r)===93)break}return r===f+2||r>=o||(r++,u=t.src.slice(f+2,r-1),typeof t.env.footnotes.refs[":"+u]>"u")?!1:(e||(t.env.footnotes.list||(t.env.footnotes.list=[]),t.env.footnotes.refs[":"+u]<0?(i=t.env.footnotes.list.length,t.env.footnotes.list[i]={label:u,count:0},t.env.footnotes.refs[":"+u]=i):i=t.env.footnotes.refs[":"+u],s=t.env.footnotes.list[i].count,t.env.footnotes.list[i].count++,t.push({type:"footnote_ref",id:i,subId:s,level:t.level})),t.pos=r,t.posMax=o,!0)}var jC=["coap","doi","javascript","aaa","aaas","about","acap","cap","cid","crid","data","dav","dict","dns","file","ftp","geo","go","gopher","h323","http","https","iax","icap","im","imap","info","ipp","iris","iris.beep","iris.xpc","iris.xpcs","iris.lwz","ldap","mailto","mid","msrp","msrps","mtqp","mupdate","news","nfs","ni","nih","nntp","opaquelocktoken","pop","pres","rtsp","service","session","shttp","sieve","sip","sips","sms","snmp","soap.beep","soap.beeps","tag","tel","telnet","tftp","thismessage","tn3270","tip","tv","urn","vemmi","ws","wss","xcon","xcon-userid","xmlrpc.beep","xmlrpc.beeps","xmpp","z39.50r","z39.50s","adiumxtra","afp","afs","aim","apt","attachment","aw","beshare","bitcoin","bolo","callto","chrome","chrome-extension","com-eventbrite-attendee","content","cvs","dlna-playsingle","dlna-playcontainer","dtn","dvb","ed2k","facetime","feed","finger","fish","gg","git","gizmoproject","gtalk","hcp","icon","ipn","irc","irc6","ircs","itms","jar","jms","keyparc","lastfm","ldaps","magnet","maps","market","message","mms","ms-help","msnim","mumble","mvn","notes","oid","palm","paparazzi","platform","proxy","psyc","query","res","resource","rmi","rsync","rtmp","secondlife","sftp","sgn","skype","smb","soldat","spotify","ssh","steam","svn","teamspeak","things","udp","unreal","ut2004","ventrilo","view-source","webcal","wtai","wyciwyg","xfire","xri","ymsgr"],SC=/^<([a-zA-Z0-9.!#$%&'*+\/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*)>/,_C=/^<([a-zA-Z.\-]{1,25}):([^<>\x00-\x20]*)>/;function DC(t,e){var u,r,i,s,o,f=t.pos;return t.src.charCodeAt(f)!==60||(u=t.src.slice(f),u.indexOf(">")<0)?!1:(r=u.match(_C),r?jC.indexOf(r[1].toLowerCase())<0||(s=r[0].slice(1,-1),o=$a(s),!t.parser.validateLink(s))?!1:(e||(t.push({type:"link_open",href:o,level:t.level}),t.push({type:"text",content:s,level:t.level+1}),t.push({type:"link_close",level:t.level})),t.pos+=r[0].length,!0):(i=u.match(SC),i?(s=i[0].slice(1,-1),o=$a("mailto:"+s),t.parser.validateLink(o)?(e||(t.push({type:"link_open",href:o,level:t.level}),t.push({type:"text",content:s,level:t.level+1}),t.push({type:"link_close",level:t.level})),t.pos+=i[0].length,!0):!1):!1))}function fo(t,e){return t=t.source,e=e||"",function u(r,i){return r?(i=i.source||i,t=t.replace(r,i),u):new RegExp(t,e)}}var MC=/[a-zA-Z_:][a-zA-Z0-9:._-]*/,TC=/[^"'=<>`\x00-\x20]+/,PC=/'[^']*'/,LC=/"[^"]*"/,RC=fo(/(?:unquoted|single_quoted|double_quoted)/)("unquoted",TC)("single_quoted",PC)("double_quoted",LC)(),BC=fo(/(?:\s+attr_name(?:\s*=\s*attr_value)?)/)("attr_name",MC)("attr_value",RC)(),IC=fo(/<[A-Za-z][A-Za-z0-9]*attribute*\s*\/?>/)("attribute",BC)(),OC=/<\/[A-Za-z][A-Za-z0-9]*\s*>/,$C=/<!---->|<!--(?:-?[^>-])(?:-?[^-])*-->/,NC=/<[?].*?[?]>/,WC=/<![A-Z]+\s+[^>]*>/,HC=/<!\[CDATA\[[\s\S]*?\]\]>/,UC=fo(/^(?:open_tag|close_tag|comment|processing|declaration|cdata)/)("open_tag",IC)("close_tag",OC)("comment",$C)("processing",NC)("declaration",WC)("cdata",HC)();function qC(t){var e=t|32;return e>=97&&e<=122}function zC(t,e){var u,r,i,s=t.pos;return!t.options.html||(i=t.posMax,t.src.charCodeAt(s)!==60||s+2>=i)||(u=t.src.charCodeAt(s+1),u!==33&&u!==63&&u!==47&&!qC(u))||(r=t.src.slice(s).match(UC),!r)?!1:(e||t.push({type:"htmltag",content:t.src.slice(s,s+r[0].length),level:t.level}),t.pos+=r[0].length,!0)}var VC=/^&#((?:x[a-f0-9]{1,8}|[0-9]{1,8}));/i,GC=/^&([a-z][a-z0-9]{1,31});/i;function KC(t,e){var u,r,i,s=t.pos,o=t.posMax;if(t.src.charCodeAt(s)!==38)return!1;if(s+1<o){if(u=t.src.charCodeAt(s+1),u===35){if(i=t.src.slice(s).match(VC),i)return e||(r=i[1][0].toLowerCase()==="x"?parseInt(i[1].slice(1),16):parseInt(i[1],10),t.pending+=Gh(r)?Oa(r):Oa(65533)),t.pos+=i[0].length,!0}else if(i=t.src.slice(s).match(GC),i){var f=zh(i[1]);if(i[1]!==f)return e||(t.pending+=f),t.pos+=i[0].length,!0}}return e||(t.pending+="&"),t.pos++,!0}var Fa=[["text",FC],["newline",hC],["escape",gC],["backticks",pC],["del",fC],["ins",mC],["mark",vC],["emphasis",bC],["sub",yC],["sup",EC],["links",AC],["footnote_inline",xC],["footnote_ref",kC],["autolink",DC],["htmltag",zC],["entity",KC]];function mo(){this.ruler=new q0;for(var t=0;t<Fa.length;t++)this.ruler.push(Fa[t][0],Fa[t][1]);this.validateLink=YC}mo.prototype.skipToken=function(t){var e=this.ruler.getRules(""),u=e.length,r=t.pos,i,s;if((s=t.cacheGet(r))>0){t.pos=s;return}for(i=0;i<u;i++)if(e[i](t,!0)){t.cacheSet(r,t.pos);return}t.pos++,t.cacheSet(r,t.pos)};mo.prototype.tokenize=function(t){for(var e=this.ruler.getRules(""),u=e.length,r=t.posMax,i,s;t.pos<r;){for(s=0;s<u&&(i=e[s](t,!1),!i);s++);if(i){if(t.pos>=r)break;continue}t.pending+=t.src[t.pos++]}t.pending&&t.pushPending()};mo.prototype.parse=function(t,e,u,r){var i=new tu(t,this,e,u,r);this.tokenize(i)};function YC(t){var e=["vbscript","javascript","file","data"],u=t.trim().toLowerCase();return u=Gi(u),!(u.indexOf(":")!==-1&&e.indexOf(u.split(":")[0])!==-1)}var JC={options:{html:!1,xhtmlOut:!1,breaks:!1,langPrefix:"language-",linkTarget:"",typographer:!1,quotes:"“”‘’",highlight:null,maxNesting:20},components:{core:{rules:["block","inline","references","replacements","smartquotes","references","abbr2","footnote_tail"]},block:{rules:["blockquote","code","fences","footnote","heading","hr","htmlblock","lheading","list","paragraph","table"]},inline:{rules:["autolink","backticks","del","emphasis","entity","escape","footnote_ref","htmltag","links","newline","text"]}}},QC={options:{html:!1,xhtmlOut:!1,breaks:!1,langPrefix:"language-",linkTarget:"",typographer:!1,quotes:"“”‘’",highlight:null,maxNesting:20},components:{core:{},block:{},inline:{}}},XC={options:{html:!0,xhtmlOut:!0,breaks:!1,langPrefix:"language-",linkTarget:"",typographer:!1,quotes:"“”‘’",highlight:null,maxNesting:20},components:{core:{rules:["block","inline","references","abbr2"]},block:{rules:["blockquote","code","fences","heading","hr","htmlblock","lheading","list","paragraph"]},inline:{rules:["autolink","backticks","emphasis","entity","escape","htmltag","links","newline","text"]}}},ZC={default:JC,full:QC,commonmark:XC};function eg(t,e,u){this.src=e,this.env=u,this.options=t.options,this.tokens=[],this.inlineMode=!1,this.inline=t.inline,this.block=t.block,this.renderer=t.renderer,this.typographer=t.typographer}function gi(t,e){typeof t!="string"&&(e=t,t="default"),e&&e.linkify!=null&&console.warn(`linkify option is removed. Use linkify plugin instead:

import Remarkable from 'remarkable';
import linkify from 'remarkable/linkify';
new Remarkable().use(linkify)
`),this.inline=new mo,this.block=new gl,this.core=new Xh,this.renderer=new hl,this.ruler=new q0,this.options={},this.configure(ZC[t]),this.set(e||{})}gi.prototype.set=function(t){Vh(this.options,t)};gi.prototype.configure=function(t){var e=this;if(!t)throw new Error("Wrong `remarkable` preset, check name/content");t.options&&e.set(t.options),t.components&&Object.keys(t.components).forEach(function(u){t.components[u].rules&&e[u].ruler.enable(t.components[u].rules,!0)})};gi.prototype.use=function(t,e){return t(this,e),this};gi.prototype.parse=function(t,e){var u=new eg(this,t,e);return this.core.process(u),u.tokens};gi.prototype.render=function(t,e){return e=e||{},this.renderer.render(this.parse(t,e),this.options,e)};gi.prototype.parseInline=function(t,e){var u=new eg(this,t,e);return u.inlineMode=!0,this.core.process(u),u.tokens};gi.prototype.renderInline=function(t,e){return e=e||{},this.renderer.render(this.parseInline(t,e),this.options,e)};var eE="3.16.2";function tE(t,e){for(var u in e)e.hasOwnProperty(u)&&t[u]===void 0&&(t[u]=e[u]);return t}function rE(t,e,u){var r;return t.length>e&&(u==null?(u="&hellip;",r=3):r=u.length,t=t.substring(0,e-r)+u),t}function Pd(t,e){if(Array.prototype.indexOf)return t.indexOf(e);for(var u=0,r=t.length;u<r;u++)if(t[u]===e)return u;return-1}function ji(t,e){for(var u=t.length-1;u>=0;u--)e(t[u])===!0&&t.splice(u,1)}function iE(t,e){if(!e.global)throw new Error("`splitRegex` must have the 'g' flag set");for(var u=[],r=0,i;i=e.exec(t);)u.push(t.substring(r,i.index)),u.push(i[0]),r=i.index+i[0].length;return u.push(t.substring(r)),u}function fl(t){throw new Error("Unhandled case for value: '".concat(t,"'"))}var Na=function(){function t(e){e===void 0&&(e={}),this.tagName="",this.attrs={},this.innerHTML="",this.whitespaceRegex=/\s+/,this.tagName=e.tagName||"",this.attrs=e.attrs||{},this.innerHTML=e.innerHtml||e.innerHTML||""}return t.prototype.setTagName=function(e){return this.tagName=e,this},t.prototype.getTagName=function(){return this.tagName||""},t.prototype.setAttr=function(e,u){var r=this.getAttrs();return r[e]=u,this},t.prototype.getAttr=function(e){return this.getAttrs()[e]},t.prototype.setAttrs=function(e){return Object.assign(this.getAttrs(),e),this},t.prototype.getAttrs=function(){return this.attrs||(this.attrs={})},t.prototype.setClass=function(e){return this.setAttr("class",e)},t.prototype.addClass=function(e){for(var u=this.getClass(),r=this.whitespaceRegex,i=u?u.split(r):[],s=e.split(r),o;o=s.shift();)Pd(i,o)===-1&&i.push(o);return this.getAttrs().class=i.join(" "),this},t.prototype.removeClass=function(e){for(var u=this.getClass(),r=this.whitespaceRegex,i=u?u.split(r):[],s=e.split(r),o;i.length&&(o=s.shift());){var f=Pd(i,o);f!==-1&&i.splice(f,1)}return this.getAttrs().class=i.join(" "),this},t.prototype.getClass=function(){return this.getAttrs().class||""},t.prototype.hasClass=function(e){return(" "+this.getClass()+" ").indexOf(" "+e+" ")!==-1},t.prototype.setInnerHTML=function(e){return this.innerHTML=e,this},t.prototype.setInnerHtml=function(e){return this.setInnerHTML(e)},t.prototype.getInnerHTML=function(){return this.innerHTML||""},t.prototype.getInnerHtml=function(){return this.getInnerHTML()},t.prototype.toAnchorString=function(){var e=this.getTagName(),u=this.buildAttrsStr();return u=u?" "+u:"",["<",e,u,">",this.getInnerHtml(),"</",e,">"].join("")},t.prototype.buildAttrsStr=function(){if(!this.attrs)return"";var e=this.getAttrs(),u=[];for(var r in e)e.hasOwnProperty(r)&&u.push(r+'="'+e[r]+'"');return u.join(" ")},t}();function uE(t,e,u){var r,i;u==null?(u="&hellip;",i=3,r=8):(i=u.length,r=u.length);var s=function(b){var C={},k=b,T=k.match(/^([a-z]+):\/\//i);return T&&(C.scheme=T[1],k=k.substr(T[0].length)),T=k.match(/^(.*?)(?=(\?|#|\/|$))/i),T&&(C.host=T[1],k=k.substr(T[0].length)),T=k.match(/^\/(.*?)(?=(\?|#|$))/i),T&&(C.path=T[1],k=k.substr(T[0].length)),T=k.match(/^\?(.*?)(?=(#|$))/i),T&&(C.query=T[1],k=k.substr(T[0].length)),T=k.match(/^#(.*?)$/i),T&&(C.fragment=T[1]),C},o=function(b){var C="";return b.scheme&&b.host&&(C+=b.scheme+"://"),b.host&&(C+=b.host),b.path&&(C+="/"+b.path),b.query&&(C+="?"+b.query),b.fragment&&(C+="#"+b.fragment),C},f=function(b,C){var k=C/2,T=Math.ceil(k),w=-1*Math.floor(k),A="";return w<0&&(A=b.substr(w)),b.substr(0,T)+u+A};if(t.length<=e)return t;var n=e-i,h=s(t);if(h.query){var g=h.query.match(/^(.*?)(?=(\?|\#))(.*?)$/i);g&&(h.query=h.query.substr(0,g[1].length),t=o(h))}if(t.length<=e||(h.host&&(h.host=h.host.replace(/^www\./,""),t=o(h)),t.length<=e))return t;var d="";if(h.host&&(d+=h.host),d.length>=n)return h.host.length==e?(h.host.substr(0,e-i)+u).substr(0,n+r):f(d,n).substr(0,n+r);var l="";if(h.path&&(l+="/"+h.path),h.query&&(l+="?"+h.query),l)if((d+l).length>=n){if((d+l).length==e)return(d+l).substr(0,e);var c=n-d.length;return(d+f(l,c)).substr(0,n+r)}else d+=l;if(h.fragment){var a="#"+h.fragment;if((d+a).length>=n){if((d+a).length==e)return(d+a).substr(0,e);var F=n-d.length;return(d+f(a,F)).substr(0,n+r)}else d+=a}if(h.scheme&&h.host){var p=h.scheme+"://";if((d+p).length<n)return(p+d).substr(0,e)}if(d.length<=e)return d;var m="";return n>0&&(m=d.substr(-1*Math.floor(n/2))),(d.substr(0,Math.ceil(n/2))+u+m).substr(0,n+r)}function sE(t,e,u){if(t.length<=e)return t;var r,i;u==null?(u="&hellip;",r=8,i=3):(r=u.length,i=u.length);var s=e-i,o="";return s>0&&(o=t.substr(-1*Math.floor(s/2))),(t.substr(0,Math.ceil(s/2))+u+o).substr(0,s+r)}function nE(t,e,u){return rE(t,e,u)}var Ld=function(){function t(e){e===void 0&&(e={}),this.newWindow=!1,this.truncate={},this.className="",this.newWindow=e.newWindow||!1,this.truncate=e.truncate||{},this.className=e.className||""}return t.prototype.build=function(e){return new Na({tagName:"a",attrs:this.createAttrs(e),innerHtml:this.processAnchorText(e.getAnchorText())})},t.prototype.createAttrs=function(e){var u={href:e.getAnchorHref()},r=this.createCssClass(e);return r&&(u.class=r),this.newWindow&&(u.target="_blank",u.rel="noopener noreferrer"),this.truncate&&this.truncate.length&&this.truncate.length<e.getAnchorText().length&&(u.title=e.getAnchorHref()),u},t.prototype.createCssClass=function(e){var u=this.className;if(u){for(var r=[u],i=e.getCssClassSuffixes(),s=0,o=i.length;s<o;s++)r.push(u+"-"+i[s]);return r.join(" ")}else return""},t.prototype.processAnchorText=function(e){return e=this.doTruncate(e),e},t.prototype.doTruncate=function(e){var u=this.truncate;if(!u||!u.length)return e;var r=u.length,i=u.location;return i==="smart"?uE(e,r):i==="middle"?sE(e,r):nE(e,r)},t}(),Ru=function(){function t(e){this.__jsduckDummyDocProp=null,this.matchedText="",this.offset=0,this.tagBuilder=e.tagBuilder,this.matchedText=e.matchedText,this.offset=e.offset}return t.prototype.getMatchedText=function(){return this.matchedText},t.prototype.setOffset=function(e){this.offset=e},t.prototype.getOffset=function(){return this.offset},t.prototype.getCssClassSuffixes=function(){return[this.getType()]},t.prototype.buildTag=function(){return this.tagBuilder.build(this)},t}(),Wa=function(t,e){return Wa=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(u,r){u.__proto__=r}||function(u,r){for(var i in r)Object.prototype.hasOwnProperty.call(r,i)&&(u[i]=r[i])},Wa(t,e)};function jr(t,e){if(typeof e!="function"&&e!==null)throw new TypeError("Class extends value "+String(e)+" is not a constructor or null");Wa(t,e);function u(){this.constructor=t}t.prototype=e===null?Object.create(e):(u.prototype=e.prototype,new u)}var Qt=function(){return Qt=Object.assign||function(e){for(var u,r=1,i=arguments.length;r<i;r++){u=arguments[r];for(var s in u)Object.prototype.hasOwnProperty.call(u,s)&&(e[s]=u[s])}return e},Qt.apply(this,arguments)},tg=function(t){jr(e,t);function e(u){var r=t.call(this,u)||this;return r.email="",r.email=u.email,r}return e.prototype.getType=function(){return"email"},e.prototype.getEmail=function(){return this.email},e.prototype.getAnchorHref=function(){return"mailto:"+this.email},e.prototype.getAnchorText=function(){return this.email},e}(Ru),rg=function(t){jr(e,t);function e(u){var r=t.call(this,u)||this;return r.serviceName="",r.hashtag="",r.serviceName=u.serviceName,r.hashtag=u.hashtag,r}return e.prototype.getType=function(){return"hashtag"},e.prototype.getServiceName=function(){return this.serviceName},e.prototype.getHashtag=function(){return this.hashtag},e.prototype.getAnchorHref=function(){var u=this.serviceName,r=this.hashtag;switch(u){case"twitter":return"https://twitter.com/hashtag/"+r;case"facebook":return"https://www.facebook.com/hashtag/"+r;case"instagram":return"https://instagram.com/explore/tags/"+r;case"tiktok":return"https://www.tiktok.com/tag/"+r;default:throw new Error("Unknown service name to point hashtag to: "+u)}},e.prototype.getAnchorText=function(){return"#"+this.hashtag},e}(Ru),ig=function(t){jr(e,t);function e(u){var r=t.call(this,u)||this;return r.serviceName="twitter",r.mention="",r.mention=u.mention,r.serviceName=u.serviceName,r}return e.prototype.getType=function(){return"mention"},e.prototype.getMention=function(){return this.mention},e.prototype.getServiceName=function(){return this.serviceName},e.prototype.getAnchorHref=function(){switch(this.serviceName){case"twitter":return"https://twitter.com/"+this.mention;case"instagram":return"https://instagram.com/"+this.mention;case"soundcloud":return"https://soundcloud.com/"+this.mention;case"tiktok":return"https://www.tiktok.com/@"+this.mention;default:throw new Error("Unknown service name to point mention to: "+this.serviceName)}},e.prototype.getAnchorText=function(){return"@"+this.mention},e.prototype.getCssClassSuffixes=function(){var u=t.prototype.getCssClassSuffixes.call(this),r=this.getServiceName();return r&&u.push(r),u},e}(Ru),ug=function(t){jr(e,t);function e(u){var r=t.call(this,u)||this;return r.number="",r.plusSign=!1,r.number=u.number,r.plusSign=u.plusSign,r}return e.prototype.getType=function(){return"phone"},e.prototype.getPhoneNumber=function(){return this.number},e.prototype.getNumber=function(){return this.getPhoneNumber()},e.prototype.getAnchorHref=function(){return"tel:"+(this.plusSign?"+":"")+this.number},e.prototype.getAnchorText=function(){return this.matchedText},e}(Ru),sg=function(t){jr(e,t);function e(u){var r=t.call(this,u)||this;return r.url="",r.urlMatchType="scheme",r.protocolUrlMatch=!1,r.protocolRelativeMatch=!1,r.stripPrefix={scheme:!0,www:!0},r.stripTrailingSlash=!0,r.decodePercentEncoding=!0,r.schemePrefixRegex=/^(https?:\/\/)?/i,r.wwwPrefixRegex=/^(https?:\/\/)?(www\.)?/i,r.protocolRelativeRegex=/^\/\//,r.protocolPrepended=!1,r.urlMatchType=u.urlMatchType,r.url=u.url,r.protocolUrlMatch=u.protocolUrlMatch,r.protocolRelativeMatch=u.protocolRelativeMatch,r.stripPrefix=u.stripPrefix,r.stripTrailingSlash=u.stripTrailingSlash,r.decodePercentEncoding=u.decodePercentEncoding,r}return e.prototype.getType=function(){return"url"},e.prototype.getUrlMatchType=function(){return this.urlMatchType},e.prototype.getUrl=function(){var u=this.url;return!this.protocolRelativeMatch&&!this.protocolUrlMatch&&!this.protocolPrepended&&(u=this.url="http://"+u,this.protocolPrepended=!0),u},e.prototype.getAnchorHref=function(){var u=this.getUrl();return u.replace(/&amp;/g,"&")},e.prototype.getAnchorText=function(){var u=this.getMatchedText();return this.protocolRelativeMatch&&(u=this.stripProtocolRelativePrefix(u)),this.stripPrefix.scheme&&(u=this.stripSchemePrefix(u)),this.stripPrefix.www&&(u=this.stripWwwPrefix(u)),this.stripTrailingSlash&&(u=this.removeTrailingSlash(u)),this.decodePercentEncoding&&(u=this.removePercentEncoding(u)),u},e.prototype.stripSchemePrefix=function(u){return u.replace(this.schemePrefixRegex,"")},e.prototype.stripWwwPrefix=function(u){return u.replace(this.wwwPrefixRegex,"$1")},e.prototype.stripProtocolRelativePrefix=function(u){return u.replace(this.protocolRelativeRegex,"")},e.prototype.removeTrailingSlash=function(u){return u.charAt(u.length-1)==="/"&&(u=u.slice(0,-1)),u},e.prototype.removePercentEncoding=function(u){var r=u.replace(/%22/gi,"&quot;").replace(/%26/gi,"&amp;").replace(/%27/gi,"&#39;").replace(/%3C/gi,"&lt;").replace(/%3E/gi,"&gt;");try{return decodeURIComponent(r)}catch{return r}},e}(Ru),Bu=function(){function t(e){this.__jsduckDummyDocProp=null,this.tagBuilder=e.tagBuilder}return t}(),ha=/[A-Za-z]/,oE=/[\d]/,aE=/[\D]/,Si=/\s/,ga=/['"]/,cE=/[\x00-\x1F\x7F]/,ng=/A-Za-z\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16F1-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FD5\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA7AE\uA7B0-\uA7B7\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC/.source,lE=/\u2700-\u27bf\udde6-\uddff\ud800-\udbff\udc00-\udfff\ufe0e\ufe0f\u0300-\u036f\ufe20-\ufe23\u20d0-\u20f0\ud83c\udffb-\udfff\u200d\u3299\u3297\u303d\u3030\u24c2\ud83c\udd70-\udd71\udd7e-\udd7f\udd8e\udd91-\udd9a\udde6-\uddff\ude01-\ude02\ude1a\ude2f\ude32-\ude3a\ude50-\ude51\u203c\u2049\u25aa-\u25ab\u25b6\u25c0\u25fb-\u25fe\u00a9\u00ae\u2122\u2139\udc04\u2600-\u26FF\u2b05\u2b06\u2b07\u2b1b\u2b1c\u2b50\u2b55\u231a\u231b\u2328\u23cf\u23e9-\u23f3\u23f8-\u23fa\udccf\u2935\u2934\u2190-\u21ff/.source,dE=/\u0300-\u036F\u0483-\u0489\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u0610-\u061A\u064B-\u065F\u0670\u06D6-\u06DC\u06DF-\u06E4\u06E7\u06E8\u06EA-\u06ED\u0711\u0730-\u074A\u07A6-\u07B0\u07EB-\u07F3\u0816-\u0819\u081B-\u0823\u0825-\u0827\u0829-\u082D\u0859-\u085B\u08D4-\u08E1\u08E3-\u0903\u093A-\u093C\u093E-\u094F\u0951-\u0957\u0962\u0963\u0981-\u0983\u09BC\u09BE-\u09C4\u09C7\u09C8\u09CB-\u09CD\u09D7\u09E2\u09E3\u0A01-\u0A03\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A70\u0A71\u0A75\u0A81-\u0A83\u0ABC\u0ABE-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AE2\u0AE3\u0B01-\u0B03\u0B3C\u0B3E-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B62\u0B63\u0B82\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD7\u0C00-\u0C03\u0C3E-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C62\u0C63\u0C81-\u0C83\u0CBC\u0CBE-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CE2\u0CE3\u0D01-\u0D03\u0D3E-\u0D44\u0D46-\u0D48\u0D4A-\u0D4D\u0D57\u0D62\u0D63\u0D82\u0D83\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DF2\u0DF3\u0E31\u0E34-\u0E3A\u0E47-\u0E4E\u0EB1\u0EB4-\u0EB9\u0EBB\u0EBC\u0EC8-\u0ECD\u0F18\u0F19\u0F35\u0F37\u0F39\u0F3E\u0F3F\u0F71-\u0F84\u0F86\u0F87\u0F8D-\u0F97\u0F99-\u0FBC\u0FC6\u102B-\u103E\u1056-\u1059\u105E-\u1060\u1062-\u1064\u1067-\u106D\u1071-\u1074\u1082-\u108D\u108F\u109A-\u109D\u135D-\u135F\u1712-\u1714\u1732-\u1734\u1752\u1753\u1772\u1773\u17B4-\u17D3\u17DD\u180B-\u180D\u1885\u1886\u18A9\u1920-\u192B\u1930-\u193B\u1A17-\u1A1B\u1A55-\u1A5E\u1A60-\u1A7C\u1A7F\u1AB0-\u1ABE\u1B00-\u1B04\u1B34-\u1B44\u1B6B-\u1B73\u1B80-\u1B82\u1BA1-\u1BAD\u1BE6-\u1BF3\u1C24-\u1C37\u1CD0-\u1CD2\u1CD4-\u1CE8\u1CED\u1CF2-\u1CF4\u1CF8\u1CF9\u1DC0-\u1DF5\u1DFB-\u1DFF\u20D0-\u20F0\u2CEF-\u2CF1\u2D7F\u2DE0-\u2DFF\u302A-\u302F\u3099\u309A\uA66F-\uA672\uA674-\uA67D\uA69E\uA69F\uA6F0\uA6F1\uA802\uA806\uA80B\uA823-\uA827\uA880\uA881\uA8B4-\uA8C5\uA8E0-\uA8F1\uA926-\uA92D\uA947-\uA953\uA980-\uA983\uA9B3-\uA9C0\uA9E5\uAA29-\uAA36\uAA43\uAA4C\uAA4D\uAA7B-\uAA7D\uAAB0\uAAB2-\uAAB4\uAAB7\uAAB8\uAABE\uAABF\uAAC1\uAAEB-\uAAEF\uAAF5\uAAF6\uABE3-\uABEA\uABEC\uABED\uFB1E\uFE00-\uFE0F\uFE20-\uFE2F/.source,og=ng+lE+dE,Rn=/0-9\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0BE6-\u0BEF\u0C66-\u0C6F\u0CE6-\u0CEF\u0D66-\u0D6F\u0DE6-\u0DEF\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F29\u1040-\u1049\u1090-\u1099\u17E0-\u17E9\u1810-\u1819\u1946-\u194F\u19D0-\u19D9\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\uA620-\uA629\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uA9F0-\uA9F9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19/.source,FE=og+Rn,e0=og+Rn,is=new RegExp("[".concat(e0,"]")),hE="(?:["+Rn+"]{1,3}\\.){3}["+Rn+"]{1,3}",gE="["+e0+"](?:["+e0+"\\-_]{0,61}["+e0+"])?",Rd=function(t){return"(?=("+gE+"))\\"+t},pa=function(t){return"(?:"+Rd(t)+"(?:\\."+Rd(t+1)+"){0,126}|"+hE+")"},rn=is,ag=/(?:xn--vermgensberatung-pwb|xn--vermgensberater-ctb|xn--clchc0ea0b2g2a9gcd|xn--w4r85el8fhu5dnra|northwesternmutual|travelersinsurance|vermögensberatung|xn--5su34j936bgsg|xn--bck1b9a5dre4c|xn--mgbah1a3hjkrd|xn--mgbai9azgqp6j|xn--mgberp4a5d4ar|xn--xkc2dl3a5ee0h|vermögensberater|xn--fzys8d69uvgm|xn--mgba7c0bbn0a|xn--mgbcpq6gpa1a|xn--xkc2al3hye2a|americanexpress|kerryproperties|sandvikcoromant|xn--i1b6b1a6a2e|xn--kcrx77d1x4a|xn--lgbbat1ad8j|xn--mgba3a4f16a|xn--mgbaakc7dvf|xn--mgbc0a9azcg|xn--nqv7fs00ema|americanfamily|bananarepublic|cancerresearch|cookingchannel|kerrylogistics|weatherchannel|xn--54b7fta0cc|xn--6qq986b3xl|xn--80aqecdr1a|xn--b4w605ferd|xn--fiq228c5hs|xn--h2breg3eve|xn--jlq480n2rg|xn--jlq61u9w7b|xn--mgba3a3ejt|xn--mgbaam7a8h|xn--mgbayh7gpa|xn--mgbbh1a71e|xn--mgbca7dzdo|xn--mgbi4ecexp|xn--mgbx4cd0ab|xn--rvc1e0am3e|international|lifeinsurance|travelchannel|wolterskluwer|xn--cckwcxetd|xn--eckvdtc9d|xn--fpcrj9c3d|xn--fzc2c9e2c|xn--h2brj9c8c|xn--tiq49xqyj|xn--yfro4i67o|xn--ygbi2ammx|construction|lplfinancial|scholarships|versicherung|xn--3e0b707e|xn--45br5cyl|xn--4dbrk0ce|xn--80adxhks|xn--80asehdb|xn--8y0a063a|xn--gckr3f0f|xn--mgb9awbf|xn--mgbab2bd|xn--mgbgu82a|xn--mgbpl2fh|xn--mgbt3dhd|xn--mk1bu44c|xn--ngbc5azd|xn--ngbe9e0a|xn--ogbpf8fl|xn--qcka1pmc|accountants|barclaycard|blackfriday|blockbuster|bridgestone|calvinklein|contractors|creditunion|engineering|enterprises|foodnetwork|investments|kerryhotels|lamborghini|motorcycles|olayangroup|photography|playstation|productions|progressive|redumbrella|williamhill|xn--11b4c3d|xn--1ck2e1b|xn--1qqw23a|xn--2scrj9c|xn--3bst00m|xn--3ds443g|xn--3hcrj9c|xn--42c2d9a|xn--45brj9c|xn--55qw42g|xn--6frz82g|xn--80ao21a|xn--9krt00a|xn--cck2b3b|xn--czr694b|xn--d1acj3b|xn--efvy88h|xn--fct429k|xn--fjq720a|xn--flw351e|xn--g2xx48c|xn--gecrj9c|xn--gk3at1e|xn--h2brj9c|xn--hxt814e|xn--imr513n|xn--j6w193g|xn--jvr189m|xn--kprw13d|xn--kpry57d|xn--mgbbh1a|xn--mgbtx2b|xn--mix891f|xn--nyqy26a|xn--otu796d|xn--pgbs0dh|xn--q9jyb4c|xn--rhqv96g|xn--rovu88b|xn--s9brj9c|xn--ses554g|xn--t60b56a|xn--vuq861b|xn--w4rs40l|xn--xhq521b|xn--zfr164b|சிங்கப்பூர்|accountant|apartments|associates|basketball|bnpparibas|boehringer|capitalone|consulting|creditcard|cuisinella|eurovision|extraspace|foundation|healthcare|immobilien|industries|management|mitsubishi|nextdirect|properties|protection|prudential|realestate|republican|restaurant|schaeffler|tatamotors|technology|university|vlaanderen|volkswagen|xn--30rr7y|xn--3pxu8k|xn--45q11c|xn--4gbrim|xn--55qx5d|xn--5tzm5g|xn--80aswg|xn--90a3ac|xn--9dbq2a|xn--9et52u|xn--c2br7g|xn--cg4bki|xn--czrs0t|xn--czru2d|xn--fiq64b|xn--fiqs8s|xn--fiqz9s|xn--io0a7i|xn--kput3i|xn--mxtq1m|xn--o3cw4h|xn--pssy2u|xn--q7ce6a|xn--unup4y|xn--wgbh1c|xn--wgbl6a|xn--y9a3aq|accenture|alfaromeo|allfinanz|amsterdam|analytics|aquarelle|barcelona|bloomberg|christmas|community|directory|education|equipment|fairwinds|financial|firestone|fresenius|frontdoor|furniture|goldpoint|hisamitsu|homedepot|homegoods|homesense|institute|insurance|kuokgroup|lancaster|landrover|lifestyle|marketing|marshalls|melbourne|microsoft|panasonic|passagens|pramerica|richardli|shangrila|solutions|statebank|statefarm|stockholm|travelers|vacations|xn--90ais|xn--c1avg|xn--d1alf|xn--e1a4c|xn--fhbei|xn--j1aef|xn--j1amh|xn--l1acc|xn--ngbrx|xn--nqv7f|xn--p1acf|xn--qxa6a|xn--tckwe|xn--vhquv|yodobashi|موريتانيا|abudhabi|airforce|allstate|attorney|barclays|barefoot|bargains|baseball|boutique|bradesco|broadway|brussels|builders|business|capetown|catering|catholic|cipriani|cityeats|cleaning|clinique|clothing|commbank|computer|delivery|deloitte|democrat|diamonds|discount|discover|download|engineer|ericsson|etisalat|exchange|feedback|fidelity|firmdale|football|frontier|goodyear|grainger|graphics|guardian|hdfcbank|helsinki|holdings|hospital|infiniti|ipiranga|istanbul|jpmorgan|lighting|lundbeck|marriott|maserati|mckinsey|memorial|merckmsd|mortgage|observer|partners|pharmacy|pictures|plumbing|property|redstone|reliance|saarland|samsclub|security|services|shopping|showtime|softbank|software|stcgroup|supplies|training|vanguard|ventures|verisign|woodside|xn--90ae|xn--node|xn--p1ai|xn--qxam|yokohama|السعودية|abogado|academy|agakhan|alibaba|android|athleta|auction|audible|auspost|avianca|banamex|bauhaus|bentley|bestbuy|booking|brother|bugatti|capital|caravan|careers|channel|charity|chintai|citadel|clubmed|college|cologne|comcast|company|compare|contact|cooking|corsica|country|coupons|courses|cricket|cruises|dentist|digital|domains|exposed|express|farmers|fashion|ferrari|ferrero|finance|fishing|fitness|flights|florist|flowers|forsale|frogans|fujitsu|gallery|genting|godaddy|grocery|guitars|hamburg|hangout|hitachi|holiday|hosting|hoteles|hotmail|hyundai|ismaili|jewelry|juniper|kitchen|komatsu|lacaixa|lanxess|lasalle|latrobe|leclerc|limited|lincoln|markets|monster|netbank|netflix|network|neustar|okinawa|oldnavy|organic|origins|philips|pioneer|politie|realtor|recipes|rentals|reviews|rexroth|samsung|sandvik|schmidt|schwarz|science|shiksha|singles|staples|storage|support|surgery|systems|temasek|theater|theatre|tickets|tiffany|toshiba|trading|walmart|wanggou|watches|weather|website|wedding|whoswho|windows|winners|xfinity|yamaxun|youtube|zuerich|католик|اتصالات|البحرين|الجزائر|العليان|پاکستان|كاثوليك|இந்தியா|abarth|abbott|abbvie|africa|agency|airbus|airtel|alipay|alsace|alstom|amazon|anquan|aramco|author|bayern|beauty|berlin|bharti|bostik|boston|broker|camera|career|casino|center|chanel|chrome|church|circle|claims|clinic|coffee|comsec|condos|coupon|credit|cruise|dating|datsun|dealer|degree|dental|design|direct|doctor|dunlop|dupont|durban|emerck|energy|estate|events|expert|family|flickr|futbol|gallup|garden|george|giving|global|google|gratis|health|hermes|hiphop|hockey|hotels|hughes|imamat|insure|intuit|jaguar|joburg|juegos|kaufen|kinder|kindle|kosher|lancia|latino|lawyer|lefrak|living|locker|london|luxury|madrid|maison|makeup|market|mattel|mobile|monash|mormon|moscow|museum|mutual|nagoya|natura|nissan|nissay|norton|nowruz|office|olayan|online|oracle|orange|otsuka|pfizer|photos|physio|pictet|quebec|racing|realty|reisen|repair|report|review|rocher|rogers|ryukyu|safety|sakura|sanofi|school|schule|search|secure|select|shouji|soccer|social|stream|studio|supply|suzuki|swatch|sydney|taipei|taobao|target|tattoo|tennis|tienda|tjmaxx|tkmaxx|toyota|travel|unicom|viajes|viking|villas|virgin|vision|voting|voyage|vuelos|walter|webcam|xihuan|yachts|yandex|zappos|москва|онлайн|ابوظبي|ارامكو|الاردن|المغرب|امارات|فلسطين|مليسيا|भारतम्|இலங்கை|ファッション|actor|adult|aetna|amfam|amica|apple|archi|audio|autos|azure|baidu|beats|bible|bingo|black|boats|bosch|build|canon|cards|chase|cheap|cisco|citic|click|cloud|coach|codes|crown|cymru|dabur|dance|deals|delta|drive|dubai|earth|edeka|email|epson|faith|fedex|final|forex|forum|gallo|games|gifts|gives|glass|globo|gmail|green|gripe|group|gucci|guide|homes|honda|horse|house|hyatt|ikano|irish|jetzt|koeln|kyoto|lamer|lease|legal|lexus|lilly|linde|lipsy|loans|locus|lotte|lotto|macys|mango|media|miami|money|movie|music|nexus|nikon|ninja|nokia|nowtv|omega|osaka|paris|parts|party|phone|photo|pizza|place|poker|praxi|press|prime|promo|quest|radio|rehab|reise|ricoh|rocks|rodeo|rugby|salon|sener|seven|sharp|shell|shoes|skype|sling|smart|smile|solar|space|sport|stada|store|study|style|sucks|swiss|tatar|tires|tirol|tmall|today|tokyo|tools|toray|total|tours|trade|trust|tunes|tushu|ubank|vegas|video|vodka|volvo|wales|watch|weber|weibo|works|world|xerox|yahoo|ישראל|ایران|بازار|بھارت|سودان|سورية|همراه|भारोत|संगठन|বাংলা|భారత్|ഭാരതം|嘉里大酒店|aarp|able|adac|aero|akdn|ally|amex|arab|army|arpa|arte|asda|asia|audi|auto|baby|band|bank|bbva|beer|best|bike|bing|blog|blue|bofa|bond|book|buzz|cafe|call|camp|care|cars|casa|case|cash|cbre|cern|chat|citi|city|club|cool|coop|cyou|data|date|dclk|deal|dell|desi|diet|dish|docs|dvag|erni|fage|fail|fans|farm|fast|fiat|fido|film|fire|fish|flir|food|ford|free|fund|game|gbiz|gent|ggee|gift|gmbh|gold|golf|goog|guge|guru|hair|haus|hdfc|help|here|hgtv|host|hsbc|icbc|ieee|imdb|immo|info|itau|java|jeep|jobs|jprs|kddi|kids|kiwi|kpmg|kred|land|lego|lgbt|lidl|life|like|limo|link|live|loan|loft|love|ltda|luxe|maif|meet|meme|menu|mini|mint|mobi|moda|moto|name|navy|news|next|nico|nike|ollo|open|page|pars|pccw|pics|ping|pink|play|plus|pohl|porn|post|prod|prof|qpon|read|reit|rent|rest|rich|room|rsvp|ruhr|safe|sale|sarl|save|saxo|scot|seat|seek|sexy|shaw|shia|shop|show|silk|sina|site|skin|sncf|sohu|song|sony|spot|star|surf|talk|taxi|team|tech|teva|tiaa|tips|town|toys|tube|vana|visa|viva|vivo|vote|voto|wang|weir|wien|wiki|wine|work|xbox|yoga|zara|zero|zone|дети|сайт|بارت|بيتك|ڀارت|تونس|شبكة|عراق|عمان|موقع|भारत|ভারত|ভাৰত|ਭਾਰਤ|ભારત|ଭାରତ|ಭಾರತ|ලංකා|アマゾン|グーグル|クラウド|ポイント|组织机构|電訊盈科|香格里拉|aaa|abb|abc|aco|ads|aeg|afl|aig|anz|aol|app|art|aws|axa|bar|bbc|bbt|bcg|bcn|bet|bid|bio|biz|bms|bmw|bom|boo|bot|box|buy|bzh|cab|cal|cam|car|cat|cba|cbn|cbs|ceo|cfa|cfd|com|cpa|crs|dad|day|dds|dev|dhl|diy|dnp|dog|dot|dtv|dvr|eat|eco|edu|esq|eus|fan|fit|fly|foo|fox|frl|ftr|fun|fyi|gal|gap|gay|gdn|gea|gle|gmo|gmx|goo|gop|got|gov|hbo|hiv|hkt|hot|how|ibm|ice|icu|ifm|inc|ing|ink|int|ist|itv|jcb|jio|jll|jmp|jnj|jot|joy|kfh|kia|kim|kpn|krd|lat|law|lds|llc|llp|lol|lpl|ltd|man|map|mba|med|men|mil|mit|mlb|mls|mma|moe|moi|mom|mov|msd|mtn|mtr|nab|nba|nec|net|new|nfl|ngo|nhk|now|nra|nrw|ntt|nyc|obi|one|ong|onl|ooo|org|ott|ovh|pay|pet|phd|pid|pin|pnc|pro|pru|pub|pwc|red|ren|ril|rio|rip|run|rwe|sap|sas|sbi|sbs|sca|scb|ses|sew|sex|sfr|ski|sky|soy|spa|srl|stc|tab|tax|tci|tdk|tel|thd|tjx|top|trv|tui|tvs|ubs|uno|uol|ups|vet|vig|vin|vip|wed|win|wme|wow|wtc|wtf|xin|xxx|xyz|you|yun|zip|бел|ком|қаз|мкд|мон|орг|рус|срб|укр|հայ|קום|عرب|قطر|كوم|مصر|कॉम|नेट|คอม|ไทย|ລາວ|ストア|セール|みんな|中文网|亚马逊|天主教|我爱你|新加坡|淡马锡|诺基亚|飞利浦|ac|ad|ae|af|ag|ai|al|am|ao|aq|ar|as|at|au|aw|ax|az|ba|bb|bd|be|bf|bg|bh|bi|bj|bm|bn|bo|br|bs|bt|bv|bw|by|bz|ca|cc|cd|cf|cg|ch|ci|ck|cl|cm|cn|co|cr|cu|cv|cw|cx|cy|cz|de|dj|dk|dm|do|dz|ec|ee|eg|er|es|et|eu|fi|fj|fk|fm|fo|fr|ga|gb|gd|ge|gf|gg|gh|gi|gl|gm|gn|gp|gq|gr|gs|gt|gu|gw|gy|hk|hm|hn|hr|ht|hu|id|ie|il|im|in|io|iq|ir|is|it|je|jm|jo|jp|ke|kg|kh|ki|km|kn|kp|kr|kw|ky|kz|la|lb|lc|li|lk|lr|ls|lt|lu|lv|ly|ma|mc|md|me|mg|mh|mk|ml|mm|mn|mo|mp|mq|mr|ms|mt|mu|mv|mw|mx|my|mz|na|nc|ne|nf|ng|ni|nl|no|np|nr|nu|nz|om|pa|pe|pf|pg|ph|pk|pl|pm|pn|pr|ps|pt|pw|py|qa|re|ro|rs|ru|rw|sa|sb|sc|sd|se|sg|sh|si|sj|sk|sl|sm|sn|so|sr|ss|st|su|sv|sx|sy|sz|tc|td|tf|tg|th|tj|tk|tl|tm|tn|to|tr|tt|tv|tw|tz|ua|ug|uk|us|uy|uz|va|vc|ve|vg|vi|vn|vu|wf|ws|ye|yt|za|zm|zw|ελ|ευ|бг|ею|рф|გე|닷넷|닷컴|삼성|한국|コム|世界|中信|中国|中國|企业|佛山|信息|健康|八卦|公司|公益|台湾|台灣|商城|商店|商标|嘉里|在线|大拿|娱乐|家電|广东|微博|慈善|手机|招聘|政务|政府|新闻|时尚|書籍|机构|游戏|澳門|点看|移动|网址|网店|网站|网络|联通|谷歌|购物|通販|集团|食品|餐厅|香港)/,pE=new RegExp("[".concat(e0,"!#$%&'*+/=?^_`{|}~-]")),fE=new RegExp("^".concat(ag.source,"$")),Bd=function(t){jr(e,t);function e(){var u=t!==null&&t.apply(this,arguments)||this;return u.localPartCharRegex=pE,u.strictTldRegex=fE,u}return e.prototype.parseMatches=function(u){for(var r=this.tagBuilder,i=this.localPartCharRegex,s=this.strictTldRegex,o=[],f=u.length,n=new un,h={m:"a",a:"i",i:"l",l:"t",t:"o",o:":"},g=0,d=0,l=n;g<f;){var c=u.charAt(g);switch(d){case 0:a(c);break;case 1:F(u.charAt(g-1),c);break;case 2:p(c);break;case 3:m(c);break;case 4:b(c);break;case 5:C(c);break;case 6:k(c);break;case 7:T(c);break;default:fl(d)}g++}return M(),o;function a(x){x==="m"?w(1):i.test(x)&&w()}function F(x,R){x===":"?i.test(R)?(d=2,l=new un(Qt(Qt({},l),{hasMailtoPrefix:!0}))):A():h[x]===R||(i.test(R)?d=2:R==="."?d=3:R==="@"?d=4:A())}function p(x){x==="."?d=3:x==="@"?d=4:i.test(x)||A()}function m(x){x==="."||x==="@"?A():i.test(x)?d=2:A()}function b(x){rn.test(x)?d=5:A()}function C(x){x==="."?d=7:x==="-"?d=6:rn.test(x)||M()}function k(x){x==="-"||x==="."?M():rn.test(x)?d=5:M()}function T(x){x==="."||x==="-"?M():rn.test(x)?(d=5,l=new un(Qt(Qt({},l),{hasDomainDot:!0}))):M()}function w(x){x===void 0&&(x=2),d=x,l=new un({idx:g})}function A(){d=0,l=n}function M(){if(l.hasDomainDot){var x=u.slice(l.idx,g);/[-.]$/.test(x)&&(x=x.slice(0,-1));var R=l.hasMailtoPrefix?x.slice(7):x;N(R)&&o.push(new tg({tagBuilder:r,matchedText:x,offset:l.idx,email:R}))}A();function N(j){var B=j.split(".").pop()||"",q=B.toLowerCase(),U=s.test(q);return U}}},e}(Bu),un=function(){function t(e){e===void 0&&(e={}),this.idx=e.idx!==void 0?e.idx:-1,this.hasMailtoPrefix=!!e.hasMailtoPrefix,this.hasDomainDot=!!e.hasDomainDot}return t}(),mE=function(){function t(){}return t.isValid=function(e,u){return!(u&&!this.isValidUriScheme(u)||this.urlMatchDoesNotHaveProtocolOrDot(e,u)||this.urlMatchDoesNotHaveAtLeastOneWordChar(e,u)&&!this.isValidIpAddress(e)||this.containsMultipleDots(e))},t.isValidIpAddress=function(e){var u=new RegExp(this.hasFullProtocolRegex.source+this.ipRegex.source),r=e.match(u);return r!==null},t.containsMultipleDots=function(e){var u=e;return this.hasFullProtocolRegex.test(e)&&(u=e.split("://")[1]),u.split("/")[0].indexOf("..")>-1},t.isValidUriScheme=function(e){var u=e.match(this.uriSchemeRegex),r=u&&u[0].toLowerCase();return r!=="javascript:"&&r!=="vbscript:"},t.urlMatchDoesNotHaveProtocolOrDot=function(e,u){return!!e&&(!u||!this.hasFullProtocolRegex.test(u))&&e.indexOf(".")===-1},t.urlMatchDoesNotHaveAtLeastOneWordChar=function(e,u){return e&&u?!this.hasFullProtocolRegex.test(u)&&!this.hasWordCharAfterProtocolRegex.test(e):!1},t.hasFullProtocolRegex=/^[A-Za-z][-.+A-Za-z0-9]*:\/\//,t.uriSchemeRegex=/^[A-Za-z][-.+A-Za-z0-9]*:/,t.hasWordCharAfterProtocolRegex=new RegExp(":[^\\s]*?["+ng+"]"),t.ipRegex=/[0-9][0-9]?[0-9]?\.[0-9][0-9]?[0-9]?\.[0-9][0-9]?[0-9]?\.[0-9][0-9]?[0-9]?(:[0-9]*)?\/?$/,t}(),vE=function(){var t=/(?:[A-Za-z][-.+A-Za-z0-9]{0,63}:(?![A-Za-z][-.+A-Za-z0-9]{0,63}:\/\/)(?!\d+\/?)(?:\/\/)?)/,e=/(?:www\.)/,u=new RegExp("[/?#](?:["+e0+"\\-+&@#/%=~_()|'$*\\[\\]{}?!:,.;^✓]*["+e0+"\\-+&@#/%=~_()|'$*\\[\\]{}✓])?");return new RegExp(["(?:","(",t.source,pa(2),")","|","(","(//)?",e.source,pa(6),")","|","(","(//)?",pa(10)+"\\.",ag.source,"(?![-"+FE+"])",")",")","(?::[0-9]+)?","(?:"+u.source+")?"].join(""),"gi")}(),bE=new RegExp("["+e0+"]"),Id=function(t){jr(e,t);function e(u){var r=t.call(this,u)||this;return r.stripPrefix={scheme:!0,www:!0},r.stripTrailingSlash=!0,r.decodePercentEncoding=!0,r.matcherRegex=vE,r.wordCharRegExp=bE,r.stripPrefix=u.stripPrefix,r.stripTrailingSlash=u.stripTrailingSlash,r.decodePercentEncoding=u.decodePercentEncoding,r}return e.prototype.parseMatches=function(u){for(var r=this.matcherRegex,i=this.stripPrefix,s=this.stripTrailingSlash,o=this.decodePercentEncoding,f=this.tagBuilder,n=[],h,g=function(){var l=h[0],c=h[1],a=h[4],F=h[5],p=h[9],m=h.index,b=F||p,C=u.charAt(m-1);if(!mE.isValid(l,c)||m>0&&C==="@"||m>0&&b&&d.wordCharRegExp.test(C))return"continue";if(/\?$/.test(l)&&(l=l.substr(0,l.length-1)),d.matchHasUnbalancedClosingParen(l))l=l.substr(0,l.length-1);else{var k=d.matchHasInvalidCharAfterTld(l,c);k>-1&&(l=l.substr(0,k))}var T=["http://","https://"].find(function(x){return!!c&&c.indexOf(x)!==-1});if(T){var w=l.indexOf(T);l=l.substr(w),c=c.substr(w),m=m+w}var A=c?"scheme":a?"www":"tld",M=!!c;n.push(new sg({tagBuilder:f,matchedText:l,offset:m,urlMatchType:A,url:l,protocolUrlMatch:M,protocolRelativeMatch:!!b,stripPrefix:i,stripTrailingSlash:s,decodePercentEncoding:o}))},d=this;(h=r.exec(u))!==null;)g();return n},e.prototype.matchHasUnbalancedClosingParen=function(u){var r=u.charAt(u.length-1),i;if(r===")")i="(";else if(r==="]")i="[";else if(r==="}")i="{";else return!1;for(var s=0,o=0,f=u.length-1;o<f;o++){var n=u.charAt(o);n===i?s++:n===r&&(s=Math.max(s-1,0))}return s===0},e.prototype.matchHasInvalidCharAfterTld=function(u,r){if(!u)return-1;var i=0;r&&(i=u.indexOf(":"),u=u.slice(i));var s=new RegExp("^((.?//)?[-."+e0+"]*[-"+e0+"]\\.[-"+e0+"]+)"),o=s.exec(u);return o===null?-1:(i+=o[1].length,u=u.slice(o[1].length),/^[^-.A-Za-z0-9:\/?#]/.test(u)?i:-1)},e}(Bu),Od=new RegExp("[_".concat(e0,"]")),$d=function(t){jr(e,t);function e(u){var r=t.call(this,u)||this;return r.serviceName="twitter",r.serviceName=u.serviceName,r}return e.prototype.parseMatches=function(u){for(var r=this.tagBuilder,i=this.serviceName,s=[],o=u.length,f=0,n=-1,h=0;f<o;){var g=u.charAt(f);switch(h){case 0:d(g);break;case 1:l(g);break;case 2:c(g);break;case 3:a(g);break;default:fl(h)}f++}return F(),s;function d(p){p==="#"?(h=2,n=f):is.test(p)&&(h=1)}function l(p){is.test(p)||(h=0)}function c(p){Od.test(p)?h=3:is.test(p)?h=1:h=0}function a(p){Od.test(p)||(F(),n=-1,is.test(p)?h=1:h=0)}function F(){if(n>-1&&f-n<=140){var p=u.slice(n,f),m=new rg({tagBuilder:r,matchedText:p,offset:n,serviceName:i,hashtag:p.slice(1)});s.push(m)}}},e}(Bu),wE=["twitter","facebook","instagram","tiktok"],yE=/(?:(?:(?:(\+)?\d{1,3}[-\040.]?)?\(?\d{3}\)?[-\040.]?\d{3}[-\040.]?\d{4})|(?:(\+)(?:9[976]\d|8[987530]\d|6[987]\d|5[90]\d|42\d|3[875]\d|2[98654321]\d|9[8543210]|8[6421]|6[6543210]|5[87654321]|4[987654310]|3[9643210]|2[70]|7|1)[-\040.]?(?:\d[-\040.]?){6,12}\d+))([,;]+[0-9]+#?)*/,CE=/(0([1-9]{1}-?[1-9]\d{3}|[1-9]{2}-?\d{3}|[1-9]{2}\d{1}-?\d{2}|[1-9]{2}\d{2}-?\d{1})-?\d{4}|0[789]0-?\d{4}-?\d{4}|050-?\d{4}-?\d{4})/,EE=new RegExp("".concat(yE.source,"|").concat(CE.source),"g"),Nd=function(t){jr(e,t);function e(){var u=t!==null&&t.apply(this,arguments)||this;return u.matcherRegex=EE,u}return e.prototype.parseMatches=function(u){for(var r=this.matcherRegex,i=this.tagBuilder,s=[],o;(o=r.exec(u))!==null;){var f=o[0],n=f.replace(/[^0-9,;#]/g,""),h=!!(o[1]||o[2]),g=o.index==0?"":u.substr(o.index-1,1),d=u.substr(o.index+f.length,1),l=!g.match(/\d/)&&!d.match(/\d/);this.testMatch(o[3])&&this.testMatch(f)&&l&&s.push(new ug({tagBuilder:i,matchedText:f,offset:o.index,number:n,plusSign:h}))}return s},e.prototype.testMatch=function(u){return aE.test(u)},e}(Bu),AE=new RegExp("@[_".concat(e0,"]{1,50}(?![_").concat(e0,"])"),"g"),xE=new RegExp("@[_.".concat(e0,"]{1,30}(?![_").concat(e0,"])"),"g"),kE=new RegExp("@[-_.".concat(e0,"]{1,50}(?![-_").concat(e0,"])"),"g"),jE=new RegExp("@[_.".concat(e0,"]{1,23}[_").concat(e0,"](?![_").concat(e0,"])"),"g"),SE=new RegExp("[^"+e0+"]"),Wd=function(t){jr(e,t);function e(u){var r=t.call(this,u)||this;return r.serviceName="twitter",r.matcherRegexes={twitter:AE,instagram:xE,soundcloud:kE,tiktok:jE},r.nonWordCharRegex=SE,r.serviceName=u.serviceName,r}return e.prototype.parseMatches=function(u){var r=this.serviceName,i=this.matcherRegexes[this.serviceName],s=this.nonWordCharRegex,o=this.tagBuilder,f=[],n;if(!i)return f;for(;(n=i.exec(u))!==null;){var h=n.index,g=u.charAt(h-1);if(h===0||s.test(g)){var d=n[0].replace(/\.+$/g,""),l=d.slice(1);f.push(new ig({tagBuilder:o,matchedText:d,offset:h,serviceName:r,mention:l}))}}return f},e}(Bu);function _E(t,e){for(var u=e.onOpenTag,r=e.onCloseTag,i=e.onText,s=e.onComment,o=e.onDoctype,f=new hr,n=0,h=t.length,g=0,d=0,l=f;n<h;){var c=t.charAt(n);switch(g){case 0:a(c);break;case 1:F(c);break;case 2:m(c);break;case 3:p(c);break;case 4:b(c);break;case 5:C(c);break;case 6:k(c);break;case 7:T(c);break;case 8:w(c);break;case 9:A(c);break;case 10:M(c);break;case 11:x(c);break;case 12:R(c);break;case 13:N();break;case 14:j(c);break;case 15:B(c);break;case 16:q(c);break;case 17:U(c);break;case 18:Z(c);break;case 19:re(c);break;case 20:le(c);break;default:fl(g)}n++}d<n&&Fe();function a(Y){Y==="<"&&de()}function F(Y){Y==="!"?g=13:Y==="/"?(g=2,l=new hr(Qt(Qt({},l),{isClosing:!0}))):Y==="<"?de():ha.test(Y)?(g=3,l=new hr(Qt(Qt({},l),{isOpening:!0}))):(g=0,l=f)}function p(Y){Si.test(Y)?(l=new hr(Qt(Qt({},l),{name:ge()})),g=4):Y==="<"?de():Y==="/"?(l=new hr(Qt(Qt({},l),{name:ge()})),g=12):Y===">"?(l=new hr(Qt(Qt({},l),{name:ge()})),he()):!ha.test(Y)&&!oE.test(Y)&&Y!==":"&&ce()}function m(Y){Y===">"?ce():ha.test(Y)?g=3:ce()}function b(Y){Si.test(Y)||(Y==="/"?g=12:Y===">"?he():Y==="<"?de():Y==="="||ga.test(Y)||cE.test(Y)?ce():g=5)}function C(Y){Si.test(Y)?g=6:Y==="/"?g=12:Y==="="?g=7:Y===">"?he():Y==="<"?de():ga.test(Y)&&ce()}function k(Y){Si.test(Y)||(Y==="/"?g=12:Y==="="?g=7:Y===">"?he():Y==="<"?de():ga.test(Y)?ce():g=5)}function T(Y){Si.test(Y)||(Y==='"'?g=8:Y==="'"?g=9:/[>=`]/.test(Y)?ce():Y==="<"?de():g=10)}function w(Y){Y==='"'&&(g=11)}function A(Y){Y==="'"&&(g=11)}function M(Y){Si.test(Y)?g=4:Y===">"?he():Y==="<"&&de()}function x(Y){Si.test(Y)?g=4:Y==="/"?g=12:Y===">"?he():Y==="<"?de():(g=4,ye())}function R(Y){Y===">"?(l=new hr(Qt(Qt({},l),{isClosing:!0})),he()):g=4}function N(Y){t.substr(n,2)==="--"?(n+=2,l=new hr(Qt(Qt({},l),{type:"comment"})),g=14):t.substr(n,7).toUpperCase()==="DOCTYPE"?(n+=7,l=new hr(Qt(Qt({},l),{type:"doctype"})),g=20):ce()}function j(Y){Y==="-"?g=15:Y===">"?ce():g=16}function B(Y){Y==="-"?g=18:Y===">"?ce():g=16}function q(Y){Y==="-"&&(g=17)}function U(Y){Y==="-"?g=18:g=16}function Z(Y){Y===">"?he():Y==="!"?g=19:Y==="-"||(g=16)}function re(Y){Y==="-"?g=17:Y===">"?he():g=16}function le(Y){Y===">"?he():Y==="<"&&de()}function ce(){g=0,l=f}function de(){g=1,l=new hr({idx:n})}function he(){var Y=t.slice(d,l.idx);Y&&i(Y,d),l.type==="comment"?s(l.idx):l.type==="doctype"?o(l.idx):(l.isOpening&&u(l.name,l.idx),l.isClosing&&r(l.name,l.idx)),ce(),d=n+1}function Fe(){var Y=t.slice(d,n);i(Y,d),d=n+1}function ge(){var Y=l.idx+(l.isClosing?2:1);return t.slice(Y,n).toLowerCase()}function ye(){n--}}var hr=function(){function t(e){e===void 0&&(e={}),this.idx=e.idx!==void 0?e.idx:-1,this.type=e.type||"tag",this.name=e.name||"",this.isOpening=!!e.isOpening,this.isClosing=!!e.isClosing}return t}(),DE=function(){function t(e){e===void 0&&(e={}),this.version=t.version,this.urls={},this.email=!0,this.phone=!0,this.hashtag=!1,this.mention=!1,this.newWindow=!0,this.stripPrefix={scheme:!0,www:!0},this.stripTrailingSlash=!0,this.decodePercentEncoding=!0,this.truncate={length:0,location:"end"},this.className="",this.replaceFn=null,this.context=void 0,this.sanitizeHtml=!1,this.matchers=null,this.tagBuilder=null,this.urls=this.normalizeUrlsCfg(e.urls),this.email=typeof e.email=="boolean"?e.email:this.email,this.phone=typeof e.phone=="boolean"?e.phone:this.phone,this.hashtag=e.hashtag||this.hashtag,this.mention=e.mention||this.mention,this.newWindow=typeof e.newWindow=="boolean"?e.newWindow:this.newWindow,this.stripPrefix=this.normalizeStripPrefixCfg(e.stripPrefix),this.stripTrailingSlash=typeof e.stripTrailingSlash=="boolean"?e.stripTrailingSlash:this.stripTrailingSlash,this.decodePercentEncoding=typeof e.decodePercentEncoding=="boolean"?e.decodePercentEncoding:this.decodePercentEncoding,this.sanitizeHtml=e.sanitizeHtml||!1;var u=this.mention;if(u!==!1&&["twitter","instagram","soundcloud","tiktok"].indexOf(u)===-1)throw new Error("invalid `mention` cfg '".concat(u,"' - see docs"));var r=this.hashtag;if(r!==!1&&wE.indexOf(r)===-1)throw new Error("invalid `hashtag` cfg '".concat(r,"' - see docs"));this.truncate=this.normalizeTruncateCfg(e.truncate),this.className=e.className||this.className,this.replaceFn=e.replaceFn||this.replaceFn,this.context=e.context||this}return t.link=function(e,u){var r=new t(u);return r.link(e)},t.parse=function(e,u){var r=new t(u);return r.parse(e)},t.prototype.normalizeUrlsCfg=function(e){return e==null&&(e=!0),typeof e=="boolean"?{schemeMatches:e,wwwMatches:e,tldMatches:e}:{schemeMatches:typeof e.schemeMatches=="boolean"?e.schemeMatches:!0,wwwMatches:typeof e.wwwMatches=="boolean"?e.wwwMatches:!0,tldMatches:typeof e.tldMatches=="boolean"?e.tldMatches:!0}},t.prototype.normalizeStripPrefixCfg=function(e){return e==null&&(e=!0),typeof e=="boolean"?{scheme:e,www:e}:{scheme:typeof e.scheme=="boolean"?e.scheme:!0,www:typeof e.www=="boolean"?e.www:!0}},t.prototype.normalizeTruncateCfg=function(e){return typeof e=="number"?{length:e,location:"end"}:tE(e||{},{length:Number.POSITIVE_INFINITY,location:"end"})},t.prototype.parse=function(e){var u=this,r=["a","style","script"],i=0,s=[];return _E(e,{onOpenTag:function(o){r.indexOf(o)>=0&&i++},onText:function(o,f){if(i===0){var n=/(&nbsp;|&#160;|&lt;|&#60;|&gt;|&#62;|&quot;|&#34;|&#39;)/gi,h=iE(o,n),g=f;h.forEach(function(d,l){if(l%2===0){var c=u.parseText(d,g);s.push.apply(s,c)}g+=d.length})}},onCloseTag:function(o){r.indexOf(o)>=0&&(i=Math.max(i-1,0))},onComment:function(o){},onDoctype:function(o){}}),s=this.compactMatches(s),s=this.removeUnwantedMatches(s),s},t.prototype.compactMatches=function(e){e.sort(function(n,h){return n.getOffset()-h.getOffset()});for(var u=0;u<e.length-1;){var r=e[u],i=r.getOffset(),s=r.getMatchedText().length,o=i+s;if(u+1<e.length){if(e[u+1].getOffset()===i){var f=e[u+1].getMatchedText().length>s?u:u+1;e.splice(f,1);continue}if(e[u+1].getOffset()<o){e.splice(u+1,1);continue}}u++}return e},t.prototype.removeUnwantedMatches=function(e){return this.hashtag||ji(e,function(u){return u.getType()==="hashtag"}),this.email||ji(e,function(u){return u.getType()==="email"}),this.phone||ji(e,function(u){return u.getType()==="phone"}),this.mention||ji(e,function(u){return u.getType()==="mention"}),this.urls.schemeMatches||ji(e,function(u){return u.getType()==="url"&&u.getUrlMatchType()==="scheme"}),this.urls.wwwMatches||ji(e,function(u){return u.getType()==="url"&&u.getUrlMatchType()==="www"}),this.urls.tldMatches||ji(e,function(u){return u.getType()==="url"&&u.getUrlMatchType()==="tld"}),e},t.prototype.parseText=function(e,u){u===void 0&&(u=0),u=u||0;for(var r=this.getMatchers(),i=[],s=0,o=r.length;s<o;s++){for(var f=r[s].parseMatches(e),n=0,h=f.length;n<h;n++)f[n].setOffset(u+f[n].getOffset());i.push.apply(i,f)}return i},t.prototype.link=function(e){if(!e)return"";this.sanitizeHtml&&(e=e.replace(/</g,"&lt;").replace(/>/g,"&gt;"));for(var u=this.parse(e),r=[],i=0,s=0,o=u.length;s<o;s++){var f=u[s];r.push(e.substring(i,f.getOffset())),r.push(this.createMatchReturnVal(f)),i=f.getOffset()+f.getMatchedText().length}return r.push(e.substring(i)),r.join("")},t.prototype.createMatchReturnVal=function(e){var u;if(this.replaceFn&&(u=this.replaceFn.call(this.context,e)),typeof u=="string")return u;if(u===!1)return e.getMatchedText();if(u instanceof Na)return u.toAnchorString();var r=e.buildTag();return r.toAnchorString()},t.prototype.getMatchers=function(){if(this.matchers)return this.matchers;var e=this.getTagBuilder(),u=[new $d({tagBuilder:e,serviceName:this.hashtag}),new Bd({tagBuilder:e}),new Nd({tagBuilder:e}),new Wd({tagBuilder:e,serviceName:this.mention}),new Id({tagBuilder:e,stripPrefix:this.stripPrefix,stripTrailingSlash:this.stripTrailingSlash,decodePercentEncoding:this.decodePercentEncoding})];return this.matchers=u},t.prototype.getTagBuilder=function(){var e=this.tagBuilder;return e||(e=this.tagBuilder=new Ld({newWindow:this.newWindow,truncate:this.truncate,className:this.className})),e},t.version=eE,t.AnchorTagBuilder=Ld,t.HtmlTag=Na,t.matcher={Email:Bd,Hashtag:$d,Matcher:Bu,Mention:Wd,Phone:Nd,Url:Id},t.match={Email:tg,Hashtag:rg,Match:Ru,Mention:ig,Phone:ug,Url:sg},t}(),ME=/www|@|\:\/\//;function TE(t){return/^<a[>\s]/i.test(t)}function PE(t){return/^<\/a\s*>/i.test(t)}function LE(){var t=[],e=new DE({stripPrefix:!1,url:!0,email:!0,replaceFn:function(u){switch(u.getType()){case"url":t.push({text:u.matchedText,url:u.getUrl()});break;case"email":t.push({text:u.matchedText,url:"mailto:"+u.getEmail().replace(/^mailto:/i,"")});break}return!1}});return{links:t,autolinker:e}}function RE(t){var e,u,r,i,s,o,f,n,h,g,d,l=t.tokens,c=null,a,F;for(u=0,r=l.length;u<r;u++)if(l[u].type==="inline")for(i=l[u].children,d=0,e=i.length-1;e>=0;e--){if(s=i[e],s.type==="link_close"){for(e--;i[e].level!==s.level&&i[e].type!=="link_open";)e--;continue}if(s.type==="htmltag"&&(TE(s.content)&&d>0&&d--,PE(s.content)&&d++),!(d>0)&&s.type==="text"&&ME.test(s.content)){if(c||(c=LE(),a=c.links,F=c.autolinker),o=s.content,a.length=0,F.link(o),!a.length)continue;for(f=[],g=s.level,n=0;n<a.length;n++)t.inline.validateLink(a[n].url)&&(h=o.indexOf(a[n].text),h&&f.push({type:"text",content:o.slice(0,h),level:g}),f.push({type:"link_open",href:a[n].url,title:"",level:g++}),f.push({type:"text",content:a[n].text,level:g}),f.push({type:"link_close",level:--g}),o=o.slice(h+a[n].text.length));o.length&&f.push({type:"text",content:o,level:g}),l[u].children=i=[].concat(i.slice(0,e),f,i.slice(e+1))}}}function BE(t){t.core.ruler.push("linkify",RE)}var cg=0,vo=1,ml=2,Iu=3;function pi(t,e){t=t.replace(" ","T");var u=new Date(t),r=qh[u.getMonth()];return e=e||cg,e>=vo&&(r+=" "+u.getDate()+","),r+=" "+u.getFullYear(),e>=ml&&(r+=" at "+u.getHours()+":"+("0"+u.getMinutes()).slice(-2)),e>=Iu&&(r+=":"+("0"+u.getSeconds()).slice(-2)),r}function Zt(t){if(t<1024)return t+" B";var e,u=t,r=1;for(e=0;u>=1024;e+=1)u/=1024;return u<10?r=3:u<100&&(r=2),u.toFixed(r)+" "+["B","kB","MB","GB","TB"][Math.min(e,4)]}function Ha(t,e){t=t||0,e=e||{};for(var u=0,r=e.base||1e3,i=e.sep||"",s=e.maxLen||3,o=s-1;t>r;u+=1)t/=r;return u?t>100?o-=2:t>10&&(o-=1):o=0,t.toFixed(Math.max(0,o))+i+["","k","M","G","T"][Math.min(u,4)]}function lg(t,e){var u=t.get(this.sortField),r=e.get(this.sortField);if(u!==void 0&&u.localeCompare){var i=u.localeCompare(r)*this.sortDir;return i||!this.secondarySortField?i:(u=t.get(this.secondarySortField),r=e.get(this.secondarySortField),u.localeCompare(r)*this.sortDir)}return u>r?this.sortDir:u<r?-this.sortDir:0}function dg(t,e){return t!==void 0&&t.localeCompare?t.localeCompare(e):t>e?1:t<e?-1:0}function Fg(t){var e=t.charAt(0).toUpperCase();return e+t.substr(1)+"Model"}function bo(t){var e={};return t&&xe.each(t.replace(/\+/g," ").split(/&/g),function(u){var r=u.split("="),i;r.length>1&&(i=decodeURIComponent(u.substr(r[0].length+1))),e[decodeURIComponent(r[0])]=i}),e}function IE(t,e){var u=0,r={};return e&&(r[e]=1),xe.each(t,function(i){r[i]=1<<u,e&&(r[e]|=r[i]),u+=1}),r}var fi=function(){var t=new gi().use(BE);return function(e,u){if(u)ke(u).html(t.render(e));else return t.render(e)}}();function hg(t){return t.charAt(0).toUpperCase()+t.substring(1)}function wo(t){if(!t)return{base:"",name:""};var e=t.indexOf("?"),u=t.lastIndexOf("?"),r,i;return e===-1?i=t:i=t.slice(0,e),u===-1?r="":r=t.slice(u+1),{name:r,base:i}}function OE(t){return ke.when(...t).then((...e)=>e)}const $E=Object.freeze(Object.defineProperty({__proto__:null,DATE_DAY:vo,DATE_MINUTE:ml,DATE_MONTH:cg,DATE_SECOND:Iu,_whenAll:OE,capitalize:hg,defineFlags:IE,formatCount:Ha,formatDate:pi,formatSize:Zt,getModelClassByName:Fg,localeComparator:lg,localeSort:dg,parseQueryString:bo,renderMarkdown:fi,splitRoute:wo},Symbol.toStringTag,{value:"Module"}));var qr=s0.Collection.extend({model:oi,resourceName:null,sortField:"name",sortDir:fs,comparator:lg,pageLimit:25,offset:0,altUrl:null,append:!1,filterFunc:null,pageOffsetStack:null,_totalCount:0,hasPreviousPage:function(){return this.filterFunc?this.append?!1:(this.pageOffsetStack=this.pageOffsetStack||[],this.pageOffsetStack.length>1):this.offset-this.length>0},hasNextPage:function(){return this._hasMorePages},getTotalCount:function(){return this._totalCount||0},fetchPreviousPage:function(t){return this.filterFunc?this.append?this.offset=0:(this.pageOffsetStack=this.pageOffsetStack||[],this.pageOffsetStack.length&&this.pageOffsetStack.pop(),this.offset=this.pageOffsetStack.length?this.pageOffsetStack.pop():0):this.offset=Math.max(0,this.offset-this.length-this.pageLimit),this.fetch(xe.extend({},this.params,t||{}))},fetchNextPage:function(t){return this.fetch(xe.extend({},this.params,t||{}))},pageNum:function(){return this.filterFunc?this.append?0:(this.pageOffsetStack=this.pageOffsetStack||[],this.pageOffsetStack.length-1):Math.ceil((this.offset-this.length)/this.pageLimit)},fetchPage:function(t,e){if(!this.append&&t*this.pageLimit<this._totalCount&&t>=0)return this.offset=t*this.pageLimit,this.fetch(xe.extend({},this.params,e||{}))},fetch:function(t,e){if(this.altUrl===null&&this.resourceName===null)throw new Error("An altUrl or resourceName must be set on the Collection.");this.filterFunc&&!this.append&&(this.pageOffsetStack=this.pageOffsetStack||[]),e?(this.filterFunc&&!this.append&&(this.pageOffsetStack=[]),this.offset=0):this.params=t||{},this.filterFunc&&!this.append&&this.pageOffsetStack.push(this.offset);var u=this.pageLimit>0?this.pageLimit+1:0,r=[];function i(){var s=ut({url:this.altUrl||this.resourceName,data:xe.extend({limit:u,offset:this.offset,sort:this.sortField,sortdir:this.sortDir},this.params)}),o=s.then(f=>{this.pageLimit>0&&f.length>this.pageLimit?(f.pop(),this._totalCount=s.getResponseHeader("girder-total-count"),this._hasMorePages=!0):this._hasMorePages=!1;var n=f.length;if(this.filterFunc){var h=this.filterFunc;f=f.map(function(c,a){return[a,c]}).filter(function(c){return h(c[1])})}var g=f.length,d=this.pageLimit===0||r.length+g<this.pageLimit;if(!d&&this.pageLimit>0){var l=this.pageLimit-r.length;g>l&&(this._hasMorePages=!0,g=l),this.filterFunc?n=f[g-1][0]+1:n=g}if(f=f.slice(0,g),this.filterFunc&&(f=f.map(function(c){return c[1]})),r=r.concat(f),this.offset+=n,d&&this._hasMorePages)return i.apply(this);(r.length>0||e)&&(this.append&&!e?this.add(r):this.reset(r)),this.trigger("g:changed")});return s.girder={fetch:!0},o}return i.apply(this)}}),gg=qr.extend({resourceName:"api_key",model:Fl}),yo=oi.extend({resourceName:"assetstore",capacityKnown:function(){var t=this.get("capacity");return t&&t.free!==null&&t.total!==null},capacityString:function(){var t=this.get("capacity");return Zt(t.free)+" free of "+Zt(t.total)+" total"},import:function(t){return ut({url:`assetstore/${this.id}/import`,method:"POST",data:t,error:null}).done(e=>{this.trigger("g:imported",e)}).fail(e=>{this.trigger("g:error",e)})},save:function(){return xe.isNumber(this.get("perms"))&&this.set("perms",this.get("perms").toString(8)),oi.prototype.save.call(this,arguments)}}),pg=qr.extend({resourceName:"assetstore",model:yo}),Co={_sendMetadata:function(t,e,u,r){r=r||{},ut({url:r.path||(this.altUrl||this.resourceName)+`/${this.id}/metadata?allowNull=true`,contentType:"application/json",data:JSON.stringify(t),method:"PUT",error:null}).done(i=>{this.set(r.field||"meta",i.meta),xe.isFunction(e)&&e()}).fail(i=>{i.message=i.responseJSON.message,xe.isFunction(u)&&u(i)})},addMetadata:function(t,e,u,r,i){i=i||{};var s={};s[t]=e;var o=this.get(i.field||"meta");o&&xe.has(o,t)?xe.isFunction(r)&&r({message:t+" is already a metadata key"}):this._sendMetadata(s,u,r,i)},removeMetadata:function(t,e,u,r){xe.isArray(t)||(t=[t]),ut({url:r.path||(this.altUrl||this.resourceName)+`/${this.id}/metadata`,contentType:"application/json",data:JSON.stringify(t),method:"DELETE",error:null}).done(i=>{this.set(r.field||"meta",i.meta),xe.isFunction(e)&&e()}).fail(i=>{i.message=i.responseJSON.message,xe.isFunction(u)&&u(i)})},editMetadata:function(t,e,u,r,i,s){if(s=s||{},t===e){var o={};o[t]=u,this._sendMetadata(o,r,i,s)}else if(xe.has(this.get(s.field||"meta"),t))xe.isFunction(i)&&i({message:t+" is already a metadata key"});else{var f={};f[e]=null,f[t]=u,this._sendMetadata(f,r,i,s)}}},ai=Vi.extend({resourceName:"collection"});xe.extend(ai.prototype,Co);var vl=qr.extend({resourceName:"collection",model:ai}),Sr=Vi.extend({resourceName:"folder",getRootPath:function(){return ut({url:`${this.resourceName}/${this.id}/rootpath`})},removeContents:function(){return ut({url:`${this.resourceName}/${this.id}/contents`,method:"DELETE"}).done(()=>{this.trigger("g:success")}).fail(t=>{this.trigger("g:error",t)})}});xe.extend(Sr.prototype,Co);var iu=oi.extend({resourceName:"item",getAccessLevel:function(t){if(t=t||ke.noop,this.has("_accessLevel"))return t(this.get("_accessLevel")),this.get("_accessLevel");if(this.parent&&this.parent.getAccessLevel())return this.set("_accessLevel",this.parent.getAccessLevel()),t(this.get("_accessLevel")),this.get("_accessLevel");var e=new Sr;e.set({_id:this.get("folderId")}).once("g:fetched",function(){this.parent=e,this.set("_accessLevel",this.parent.getAccessLevel()),t(this.get("_accessLevel"))},this).fetch()},getRootPath:function(t){return ut({url:`${this.resourceName}/${this.id}/rootpath`}).done(e=>{t(e)}).fail(e=>{this.trigger("g:error",e)})},getFiles:function(){return ut({url:`${this.resourceName}/${this.id}/files`}).then(t=>{const e=new bl(t);return this.trigger("g:files",e),e}).fail(t=>{this.trigger("g:error",t)})}});xe.extend(iu.prototype,Co);js.s3=function(t){return this.params=t,this.startByte=0,xe.extend(this,s0.Events)};var Ou=js.s3.prototype;Ou._xhrProgress=function(t){if(t.lengthComputable){var e=this.payloadLength+t.loaded-t.total;e>=0&&this.trigger("g:upload.progress",{startByte:this.startByte,loaded:e,total:this.params.file.size,file:this.params.file})}};Ou.execute=function(){var t=this.params.upload.s3,e=new XMLHttpRequest;e.open(t.request.method,t.request.url),xe.each(t.request.headers,(u,r)=>{e.setRequestHeader(r,u)}),t.chunked?this._multiChunkUpload(e):(this.payloadLength=this.params.file.size,e.onload=()=>{e.status===200?(this.trigger("g:upload.chunkSent",{bytes:this.payloadLength}),ut({url:"file/completion",method:"POST",data:{uploadId:this.params.upload._id},error:null}).done(u=>{this.trigger("g:upload.complete",u)}).fail(u=>{var r;u.status===0?r="Could not connect to the server.":r="An error occurred when resuming upload, check console.",this.trigger("g:upload.error",{message:r})})):this.trigger("g:upload.error",{message:"Error occurred uploading to S3 ("+e.status+")."})},e.upload.addEventListener("progress",u=>{this._xhrProgress(u)}),e.addEventListener("error",u=>{this.trigger("g:upload.error",{message:"Error occurred uploading to S3.",event:u})}),e.send(this.params.file))};Ou.resume=function(){if(this.params.upload.s3.chunked)return this._sendNextChunk();ut({url:"file/offset",method:"GET",data:{uploadId:this.params.upload._id},error:null}).done(t=>{this.params.upload.s3.request=t,this.execute()}).fail(t=>{var e;t.status===0?e="Could not connect to the Girder server.":e="An error occurred when resuming upload, check console.",this.trigger("g:upload.error",{message:e})})};Ou._multiChunkUpload=function(t){this.eTagList={},this.startByte=0,this.chunkN=1,t.onload=()=>{t.status===200?(this.s3UploadId=t.responseText.match(/<UploadId>(.*)<\/UploadId>/).pop(),this._sendNextChunk()):this.trigger("g:upload.error",{message:"Error while initializing multichunk S3 upload.",event})},t.addEventListener("error",e=>{this.trigger("g:upload.error",{message:"Error occurred uploading to S3.",event:e})}),t.send()};Ou._sendNextChunk=function(){var t=this.params.file.webkitSlice?"webkitSlice":"slice",e=this.params.file[t](this.startByte,this.startByte+this.params.upload.s3.chunkLength);this.payloadLength=e.size,ut({url:"file/chunk",method:"POST",data:{offset:0,chunk:JSON.stringify({s3UploadId:this.s3UploadId,partNumber:this.chunkN,contentLength:this.payloadLength}),uploadId:this.params.upload._id},error:null}).done(u=>{var r=new XMLHttpRequest;r.open(u.s3.request.method,u.s3.request.url),r.onload=()=>{r.status===200?(this.trigger("g:upload.chunkSent",{bytes:this.payloadLength}),this.eTagList[this.chunkN]=r.getResponseHeader("ETag"),this.startByte+=this.payloadLength,this.chunkN+=1,this.startByte<this.params.file.size?this._sendNextChunk():this._finalizeMultiChunkUpload()):this.trigger("g:upload.error",{message:"Error occurred uploading to S3 ("+r.status+")."})},r.upload.addEventListener("progress",i=>{this._xhrProgress(i)}),r.addEventListener("error",i=>{this.trigger("g:upload.error",{message:"Error occurred uploading to S3.",event:i})}),r.send(e)}).fail(()=>{this.trigger("g:upload.error",{message:"Error getting signed chunk request from Girder."})})};Ou._finalizeMultiChunkUpload=function(){ut({url:"file/completion",method:"POST",data:{uploadId:this.params.upload._id},error:null}).done(t=>{var e=document.implementation.createDocument(null,null,null),u=e.createElement("CompleteMultipartUpload");xe.each(this.eTagList,(s,o)=>{var f=e.createElement("Part"),n=e.createElement("PartNumber"),h=e.createElement("ETag");n.appendChild(e.createTextNode(o)),h.appendChild(e.createTextNode(s)),f.appendChild(n),f.appendChild(h),u.appendChild(f)});var r=t.s3FinalizeRequest,i=new XMLHttpRequest;i.open(r.method,r.url),xe.each(r.headers,(s,o)=>{i.setRequestHeader(o,s)}),i.onload=()=>{i.status===200?(delete t.s3FinalizeRequest,this.trigger("g:upload.complete",t)):this.trigger("g:upload.error",{message:"Error occurred uploading to S3 ("+i.status+")."})},i.send(new window.XMLSerializer().serializeToString(u))}).fail(t=>{var e;t.status===0?e="Could not connect to the server.":e="Upload error during finalize, check console.",this.trigger("g:upload.error",{message:e})})};const NE=Object.freeze(Object.defineProperty({__proto__:null},Symbol.toStringTag,{value:"Module"}));var Eo=oi.extend({resourceName:"file",resumeInfo:null,_wrapData:function(t,e){var u=t;return t instanceof Blob||(xe.isArray(t)||(u=[t]),u=new Blob(u,{type:e})),u},updateContents:function(t){t=this._wrapData(t),this.upload(null,t,{url:`file/${this.id}/contents`,method:"PUT",data:{size:t.size}})},_uploadToContainer:function(t,e,u,r,i){xe.isString(e)&&(e=new t({_id:e})),u=this._wrapData(u,i),u.name=r,this.upload(e,u)},uploadToFolder:function(t,e,u,r){this._uploadToContainer(Sr,t,e,u,r)},uploadToItem:function(t,e,u,r){this._uploadToContainer(iu,t,e,u,r)},upload:function(t,e,u,r){this.startByte=0,this.resumeInfo=null,this.uploadHandler=null,u=u||{url:"file",method:"POST",data:xe.extend({parentType:t.resourceName,parentId:t.get("_id"),name:e.name,size:e.size,mimeType:e.type},r)},ut(u).done(i=>{var s=i.behavior;if(s&&js[s])return this.uploadHandler=new js[s]({upload:i,parentModel:t,file:e}),this.uploadHandler.on({"g:upload.complete":function(o){this.set(o),this.trigger("g:upload.complete",o),this.uploadHandler=null},"g:upload.chunkSent":function(o){this.trigger("g:upload.chunkSent",o)},"g:upload.error":function(o){this.trigger("g:upload.error",o)},"g:upload.errorStarting":function(o){this.trigger("g:upload.errorStarting",o)},"g:upload.progress":function(o){this.trigger("g:upload.progress",{startByte:o.startByte,loaded:o.loaded,total:o.file.size,file:o.file})}},this),this.uploadHandler.execute();e.size>0?this._uploadChunk(e,i._id):(this.set(i),this.trigger("g:upload.complete"))}).fail(i=>{var s="Error: ",o;i.status===0?s+="Connection to the server interrupted.":(s+=i.responseJSON.message,o=i.responseJSON.identifier),this.trigger("g:upload.errorStarting",{message:s,identifier:o,response:i})})},resumeUpload:function(){if(this.uploadHandler!==null&&this.uploadHandler.resume)return this.uploadHandler.resume();ut({url:"file/offset",method:"GET",data:{uploadId:this.resumeInfo.uploadId},error:null}).done(t=>{this.startByte=t.offset,this._uploadChunk(this.resumeInfo.file,this.resumeInfo.uploadId)}).fail(t=>{var e;t.status===0?e="Could not connect to the server.":e="An error occurred when resuming upload, check console.",this.trigger("g:upload.error",{message:e,response:t})})},abortUpload:function(){!this.resumeInfo||!this.resumeInfo.uploadId||ut({url:"system/uploads",method:"DELETE",data:{uploadId:this.resumeInfo.uploadId},error:null,done:null})},_uploadChunk:function(t,e){var u=Math.min(this.startByte+Oh(),t.size);this.chunkLength=u-this.startByte;var r=t.webkitSlice?"webkitSlice":"slice",i=t[r](this.startByte,u);ut({url:`file/chunk?offset=${this.startByte}&uploadId=${e}`,method:"POST",data:i,contentType:!1,processData:!1,success:s=>{this.trigger("g:upload.chunkSent",{bytes:u-this.startByte}),u===t.size?(this.startByte=0,this.resumeInfo=null,this.set(s),this.trigger("g:upload.complete")):(this.startByte=u,this._uploadChunk(t,e))},error:s=>{var o="Error: ",f;s.status===0?o+="Connection to the server interrupted.":(o+=s.responseJSON.message,f=s.responseJSON.identifier),this.resumeInfo={uploadId:e,file:t},this.trigger("g:upload.error",{message:o,identifier:f,response:s})},xhr:()=>{var s=new window.XMLHttpRequest;return s.upload.addEventListener("progress",o=>{this._uploadProgress(t,o)}),s}})},_uploadProgress:function(t,e){if(e.lengthComputable){var u=this.chunkLength+e.loaded-e.total;u>=0&&this.trigger("g:upload.progress",{startByte:this.startByte,loaded:u,total:t.size,file:t})}}}),WE=qr.extend({resourceName:"file",model:Eo,pageLimit:100});const bl=WE;var fg=qr.extend({resourceName:"folder",model:Sr,pageLimit:100}),Ki=Vi.extend({resourceName:"group",sendInvitation:function(t,e,u,r){return r=r||{},ut({url:`${this.resourceName}/${this.id}/invitation`,data:xe.extend({userId:t,level:e},r),method:"POST",error:null}).done(i=>{this.set(i),!u&&t===ft().get("_id")&&(r.force?ft().addToGroup(this.get("_id")):ft().addInvitation(this.get("_id"),e)),this.trigger("g:invited")}).fail(i=>{this.trigger("g:error",i)})},joinGroup:function(){return ut({url:`${this.resourceName}/${this.id}/member`,method:"POST"}).done(t=>{ft().addToGroup(this.get("_id")),ft().removeInvitation(this.get("_id")),this.set(t),this.trigger("g:joined")}).fail(t=>{this.trigger("g:error",t)})},requestInvitation:function(){return ut({url:`${this.resourceName}/${this.id}/member`,method:"POST"}).done(t=>{this.set(t),this.trigger("g:inviteRequested")}).fail(t=>{this.trigger("g:error",t)})},promoteUser:function(t,e){var u;return e===nt.WRITE?u="moderator":e===nt.ADMIN&&(u="admin"),ut({url:`${this.resourceName}/${this.id}/${u}`,data:{userId:t.get("_id")},method:"POST"}).done(r=>{this.set(r),this.trigger("g:promoted")}).fail(r=>{this.trigger("g:error",r)})},demoteUser:function(t,e){var u;return e===nt.WRITE?u="moderator":e===nt.ADMIN&&(u="admin"),ut({url:`${this.resourceName}/${this.id}/${u}?userId=${t}`,method:"DELETE"}).done(r=>{this.set(r),this.trigger("g:demoted")}).fail(r=>{this.trigger("g:error",r)})},removeMember:function(t){return ut({url:`${this.resourceName}/${this.id}/member?userId=${t}`,method:"DELETE"}).done(e=>{t===ft().get("_id")&&ft().removeFromGroup(this.get("_id")),this.set(e),this.trigger("g:removed")}).fail(e=>{this.trigger("g:error",e)})},mayAddMembers:function(){if(ft().get("admin"))return!0;var t,e=this.get("_addToGroupPolicy");if(e==="nomod"||e==="yesmod")t="mod";else if(e==="noadmin"||e==="yesadmin")t="admin";else return!1;var u=this.get("addAllowed")||"";return u==="no"||e.substr(0,3)!=="yes"&&u.substr(0,3)!=="yes"?!1:(u==="yesadmin"&&(t="admin"),t==="admin"&&this.get("_accessLevel")>=nt.ADMIN||t==="mod"&&this.get("_accessLevel")>=nt.WRITE)}}),mg=qr.extend({resourceName:"group",model:Ki}),vg=qr.extend({resourceName:"item",model:iu,pageLimit:100}),xu=qr.extend({resourceName:"user",model:p0,sortField:"lastName",secondarySortField:"firstName"},{getTotalCount:function(){return ut({url:"user/details",method:"GET"}).then(t=>t.nUsers)}});const HE=Object.freeze(Object.defineProperty({__proto__:null,ApiKeyCollection:gg,AssetstoreCollection:pg,Collection:qr,CollectionCollection:vl,FileCollection:bl,FolderCollection:fg,GroupCollection:mg,ItemCollection:vg,UserCollection:xu},Symbol.toStringTag,{value:"Module"}));+function(t){var e=function(i,s){this.options=s,this.$body=t(document.body),this.$element=t(i),this.$dialog=this.$element.find(".modal-dialog"),this.$backdrop=null,this.isShown=null,this.originalBodyPad=null,this.scrollbarWidth=0,this.ignoreBackdropClick=!1,this.fixedContent=".navbar-fixed-top, .navbar-fixed-bottom",this.options.remote&&this.$element.find(".modal-content").load(this.options.remote,t.proxy(function(){this.$element.trigger("loaded.bs.modal")},this))};e.VERSION="3.4.1",e.TRANSITION_DURATION=300,e.BACKDROP_TRANSITION_DURATION=150,e.DEFAULTS={backdrop:!0,keyboard:!0,show:!0},e.prototype.toggle=function(i){return this.isShown?this.hide():this.show(i)},e.prototype.show=function(i){var s=this,o=t.Event("show.bs.modal",{relatedTarget:i});this.$element.trigger(o),!(this.isShown||o.isDefaultPrevented())&&(this.isShown=!0,this.checkScrollbar(),this.setScrollbar(),this.$body.addClass("modal-open"),this.escape(),this.resize(),this.$element.on("click.dismiss.bs.modal",'[data-dismiss="modal"]',t.proxy(this.hide,this)),this.$dialog.on("mousedown.dismiss.bs.modal",function(){s.$element.one("mouseup.dismiss.bs.modal",function(f){t(f.target).is(s.$element)&&(s.ignoreBackdropClick=!0)})}),this.backdrop(function(){var f=t.support.transition&&s.$element.hasClass("fade");s.$element.parent().length||s.$element.appendTo(s.$body),s.$element.show().scrollTop(0),s.adjustDialog(),f&&s.$element[0].offsetWidth,s.$element.addClass("in"),s.enforceFocus();var n=t.Event("shown.bs.modal",{relatedTarget:i});f?s.$dialog.one("bsTransitionEnd",function(){s.$element.trigger("focus").trigger(n)}).emulateTransitionEnd(e.TRANSITION_DURATION):s.$element.trigger("focus").trigger(n)}))},e.prototype.hide=function(i){i&&i.preventDefault(),i=t.Event("hide.bs.modal"),this.$element.trigger(i),!(!this.isShown||i.isDefaultPrevented())&&(this.isShown=!1,this.escape(),this.resize(),t(document).off("focusin.bs.modal"),this.$element.removeClass("in").off("click.dismiss.bs.modal").off("mouseup.dismiss.bs.modal"),this.$dialog.off("mousedown.dismiss.bs.modal"),t.support.transition&&this.$element.hasClass("fade")?this.$element.one("bsTransitionEnd",t.proxy(this.hideModal,this)).emulateTransitionEnd(e.TRANSITION_DURATION):this.hideModal())},e.prototype.enforceFocus=function(){t(document).off("focusin.bs.modal").on("focusin.bs.modal",t.proxy(function(i){document!==i.target&&this.$element[0]!==i.target&&!this.$element.has(i.target).length&&this.$element.trigger("focus")},this))},e.prototype.escape=function(){this.isShown&&this.options.keyboard?this.$element.on("keydown.dismiss.bs.modal",t.proxy(function(i){i.which==27&&this.hide()},this)):this.isShown||this.$element.off("keydown.dismiss.bs.modal")},e.prototype.resize=function(){this.isShown?t(window).on("resize.bs.modal",t.proxy(this.handleUpdate,this)):t(window).off("resize.bs.modal")},e.prototype.hideModal=function(){var i=this;this.$element.hide(),this.backdrop(function(){i.$body.removeClass("modal-open"),i.resetAdjustments(),i.resetScrollbar(),i.$element.trigger("hidden.bs.modal")})},e.prototype.removeBackdrop=function(){this.$backdrop&&this.$backdrop.remove(),this.$backdrop=null},e.prototype.backdrop=function(i){var s=this,o=this.$element.hasClass("fade")?"fade":"";if(this.isShown&&this.options.backdrop){var f=t.support.transition&&o;if(this.$backdrop=t(document.createElement("div")).addClass("modal-backdrop "+o).appendTo(this.$body),this.$element.on("click.dismiss.bs.modal",t.proxy(function(h){if(this.ignoreBackdropClick){this.ignoreBackdropClick=!1;return}h.target===h.currentTarget&&(this.options.backdrop=="static"?this.$element[0].focus():this.hide())},this)),f&&this.$backdrop[0].offsetWidth,this.$backdrop.addClass("in"),!i)return;f?this.$backdrop.one("bsTransitionEnd",i).emulateTransitionEnd(e.BACKDROP_TRANSITION_DURATION):i()}else if(!this.isShown&&this.$backdrop){this.$backdrop.removeClass("in");var n=function(){s.removeBackdrop(),i&&i()};t.support.transition&&this.$element.hasClass("fade")?this.$backdrop.one("bsTransitionEnd",n).emulateTransitionEnd(e.BACKDROP_TRANSITION_DURATION):n()}else i&&i()},e.prototype.handleUpdate=function(){this.adjustDialog()},e.prototype.adjustDialog=function(){var i=this.$element[0].scrollHeight>document.documentElement.clientHeight;this.$element.css({paddingLeft:!this.bodyIsOverflowing&&i?this.scrollbarWidth:"",paddingRight:this.bodyIsOverflowing&&!i?this.scrollbarWidth:""})},e.prototype.resetAdjustments=function(){this.$element.css({paddingLeft:"",paddingRight:""})},e.prototype.checkScrollbar=function(){var i=window.innerWidth;if(!i){var s=document.documentElement.getBoundingClientRect();i=s.right-Math.abs(s.left)}this.bodyIsOverflowing=document.body.clientWidth<i,this.scrollbarWidth=this.measureScrollbar()},e.prototype.setScrollbar=function(){var i=parseInt(this.$body.css("padding-right")||0,10);this.originalBodyPad=document.body.style.paddingRight||"";var s=this.scrollbarWidth;this.bodyIsOverflowing&&(this.$body.css("padding-right",i+s),t(this.fixedContent).each(function(o,f){var n=f.style.paddingRight,h=t(f).css("padding-right");t(f).data("padding-right",n).css("padding-right",parseFloat(h)+s+"px")}))},e.prototype.resetScrollbar=function(){this.$body.css("padding-right",this.originalBodyPad),t(this.fixedContent).each(function(i,s){var o=t(s).data("padding-right");t(s).removeData("padding-right"),s.style.paddingRight=o||""})},e.prototype.measureScrollbar=function(){var i=document.createElement("div");i.className="modal-scrollbar-measure",this.$body.append(i);var s=i.offsetWidth-i.clientWidth;return this.$body[0].removeChild(i),s};function u(i,s){return this.each(function(){var o=t(this),f=o.data("bs.modal"),n=t.extend({},e.DEFAULTS,o.data(),typeof i=="object"&&i);f||o.data("bs.modal",f=new e(this,n)),typeof i=="string"?f[i](s):n.show&&f.show(s)})}var r=t.fn.modal;t.fn.modal=u,t.fn.modal.Constructor=e,t.fn.modal.noConflict=function(){return t.fn.modal=r,this},t(document).on("click.bs.modal.data-api",'[data-toggle="modal"]',function(i){var s=t(this),o=s.attr("href"),f=s.attr("data-target")||o&&o.replace(/.*(?=#[^\s]+$)/,""),n=t(document).find(f),h=n.data("bs.modal")?"toggle":t.extend({remote:!/#/.test(o)&&o},n.data(),s.data());s.is("a")&&i.preventDefault(),n.one("show.bs.modal",function(g){g.isDefaultPrevented()||n.one("hidden.bs.modal",function(){s.is(":visible")&&s.trigger("focus")})}),u.call(n,h,this)})}(ke);ke.fn.girderModal=function(t){if(ke(this).is(".modal")&&ke(this).data("bs.modal")&&ke(this).data("bs.modal").isShown){var e=ke(ke(this).data("bs.modal").$element),u=e.hasClass("fade");e.removeClass("fade"),ke(this).modal("hide"),e.toggleClass("fade",u)}return t!=="close"&&(this.off(),setTimeout(()=>{this.modal().find('[data-dismiss="modal"]').off("click").on("click",()=>{this.modal("hide")})},0),t!==!1&&t.delegateEvents()),this};var UE=s0.Router.extend({initialize:function(){this._enabled=!0},execute:function(t,e){e.push(bo(e.pop()));var u=e[e.length-1];t&&t.apply(this,e),u.dialog==="login"?He.trigger("g:loginUi"):u.dialog==="register"?He.trigger("g:registerUi"):u.dialog==="resetpassword"&&He.trigger("g:resetPasswordUi")},enabled:function(){return arguments.length&&(this._enabled=!!arguments[0]),this._enabled},navigate:function(){this._enabled&&s0.Router.prototype.navigate.apply(this,arguments)}}),tt=new UE;tt.on("route",function(t,e){e.slice(-1)[0].dialog||ke(".modal").girderModal("close")});function qE(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Ii(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function bg(t,e){return Array.isArray(t)?zE(t,e):t&&typeof t=="object"?VE(t):t||""}function zE(t,e){for(var u,r="",i="",s=Array.isArray(e),o=0;o<t.length;o++)(u=bg(t[o]))&&(s&&e[o]&&(u=Ii(u)),r=r+i+u,i=" ");return r}function VE(t){var e="",u="";for(var r in t)r&&t[r]&&GE.call(t,r)&&(e=e+u+r,u=" ");return e}function Ii(t){var e=""+t,u=KE.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var GE=Object.prototype.hasOwnProperty,KE=/["&<>]/;function wg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void wg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function YE(t){var e="",u,r,i;try{var s=t||{};(function(o){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+'<div class="modal-dialog">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+'<div class="modal-content">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+'<div class="modal-body">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+"<p></p>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",o.msgConfirmation&&(i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+'<p class="g-additional-text"></p>',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+'<p class="g-additional-instruction">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+"You need to enter '",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+Ii((u=o.yesText.toUpperCase())==null?"":u),i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+" ",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+Ii((u=o.name)==null?"":u),i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+"'",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+`
`,i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+'and then click on the "',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+Ii((u=o.yesText)==null?"":u),i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+'" button</p>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+'<input class="input-sm form-control" id="g-confirm-text" type="text" name="confirmMsg"/>',i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+'<spam class="g-msg-error"></spam>'),e=e+"</div>",i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+'<div class="modal-footer">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+Ii((u=o.noText)==null?"":u)+"</a>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+"<a"+(qE("class",bg(["btn","btn-small",o.yesClass],[!1,!1,!0]),!1,!1)+' id="g-confirm-button"')+">",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/confirmDialog.pug",e=e+Ii((u=o.yesText)==null?"":u)+"</a></div></div></div>"}).call(this,"params"in s?s.params:typeof params<"u"?params:void 0)}catch(o){wg(o,r,i)}return e}function F0(t,e,u){if(tt.enabled()){var r=s0.history.fragment,i=wo(r),s=bo(i.name),o=s.dialog,f=s.dialogid;delete s.dialog,delete s.dialogid;var n=ke.param(s);n.length>0&&(n="?"+n),o===t&&f===u&&tt.navigate(i.base+n,e)}}function b0(t,e,u){if(tt.enabled()){var r=s0.history.fragment,i=wo(r),s=bo(i.name),o=s.dialog,f=s.dialogid;if(o!==t||u!==f){s.dialog=t,u&&(s.dialogid=u);var n=ke.param(s);n.length>0&&(n="?"+n),tt.navigate(i.base+n,e)}}}function n0(t){t=xe.extend({text:"Are you sure?",yesText:"Yes",yesClass:"btn-danger",noText:"Cancel",escapedHtml:!1,msgConfirmation:!1,additionalText:"",name:""},t),ke("#g-dialog-container").html(YE({params:t})).girderModal(!1).one("hidden.bs.modal",function(){ke("#g-confirm-button").off("click")});const e=ke("#g-dialog-container").find(".modal-body>p:first-child");t.escapedHtml?e.html(t.text):e.text(t.text),t.msgConfirmation&&(t.escapedHtml?ke(".g-additional-text").html(t.additionalText):ke(".g-additional-text").text(t.additionalText)),ke("#g-confirm-button").off("click").on("click",function(){if(t.msgConfirmation){const u=`${t.yesText.toUpperCase()} ${t.name}`,r=ke("#g-confirm-text").val();r.toUpperCase()===u.toUpperCase()?(ke("#g-dialog-container").modal("hide"),t.confirmCallback()):r.toUpperCase()===""?(ke(".g-msg-error").html(`Error: You need to enter <b>'${u}'</b>.`),ke(".g-msg-error").css("color","red")):(ke(".g-msg-error").html(`Error: <b>'${r}'</b> isn't <b>'${u}'</b>`),ke(".g-msg-error").css("color","red"))}else ke("#g-dialog-container").modal("hide"),t.confirmCallback()})}const JE=Object.freeze(Object.defineProperty({__proto__:null,confirm:n0,handleClose:F0,handleOpen:b0},Symbol.toStringTag,{value:"Module"})),yg=Object.freeze(Object.defineProperty({__proto__:null,AccessControlledModel:Vi,ApiKeyModel:Fl,AssetstoreModel:yo,CollectionModel:ai,FileModel:Eo,FolderModel:Sr,GroupModel:Ki,ItemModel:iu,MetadataMixin:Co,Model:oi,UserModel:p0},Symbol.toStringTag,{value:"Module"}));var QE=function(t,e){window.girder.plugins[t]=e};const XE=Object.freeze(Object.defineProperty({__proto__:null,registerPluginNamespace:QE},Symbol.toStringTag,{value:"Module"}));function ZE(t,e,u){t.prototype[e]=xe.wrap(t.prototype[e],u)}var Cg={};function e1(t,e){Cg[t]=e}function Eg(t){return Cg[t]}const t1=Object.freeze(Object.defineProperty({__proto__:null,exposePluginConfig:e1,getPluginConfigRoute:Eg,wrap:ZE},Symbol.toStringTag,{value:"Module"})),r1=Object.freeze(Object.defineProperty({__proto__:null,PluginUtils:t1,S3UploadHandler:NE,eventStream:Cr},Symbol.toStringTag,{value:"Module"}));+function(t){var e='[data-dismiss="alert"]',u=function(s){t(s).on("click",e,this.close)};u.VERSION="3.4.1",u.TRANSITION_DURATION=150,u.prototype.close=function(s){var o=t(this),f=o.attr("data-target");f||(f=o.attr("href"),f=f&&f.replace(/.*(?=#[^\s]*$)/,"")),f=f==="#"?[]:f;var n=t(document).find(f);if(s&&s.preventDefault(),n.length||(n=o.closest(".alert")),n.trigger(s=t.Event("close.bs.alert")),s.isDefaultPrevented())return;n.removeClass("in");function h(){n.detach().trigger("closed.bs.alert").remove()}t.support.transition&&n.hasClass("fade")?n.one("bsTransitionEnd",h).emulateTransitionEnd(u.TRANSITION_DURATION):h()};function r(s){return this.each(function(){var o=t(this),f=o.data("bs.alert");f||o.data("bs.alert",f=new u(this)),typeof s=="string"&&f[s].call(o)})}var i=t.fn.alert;t.fn.alert=r,t.fn.alert.Constructor=u,t.fn.alert.noConflict=function(){return t.fn.alert=i,this},t(document).on("click.bs.alert.data-api",e,u.prototype.close)}(ke);var Xe=s0.View.extend({constructor:function(t){t&&xe.has(t,"parentView")?t.parentView&&(t.parentView.registerChildView(this),this.parentView=t.parentView):console.error("View created with no parentView property set. This view may not be garbage collected."),s0.View.prototype.constructor.apply(this,arguments)},destroy:function(){if(xe.each(this._childViews,function(e){e.destroy()}),this._childViews=null,this.undelegateEvents(),this.stopListening(),this.off(),He.off(null,null,this),Cr.off(null,null,this),this.parentView&&this.parentView.unregisterChildView(this),this.$el.is(".modal")){var t=this.$el;t.data("bs.modal")&&t.data("bs.modal").isShown?(t.on("hidden.bs.modal",function(){t.empty().off().removeData()}).modal("hide"),t.modal("removeBackdrop")):(t.modal("hideModal"),t.modal("removeBackdrop"),t.empty().off().removeData())}else this.$el.empty().off().removeData()},registerChildView:function(t){this._childViews=this._childViews||[],this._childViews.push(t)},unregisterChildView:function(t){this._childViews=xe.without(this._childViews,t)}});function fa(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=i1(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function i1(t){var e=""+t,u=u1.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var u1=/["&<>]/;function Ag(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Ag(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function s1(t){var e="",u,r;try{var i=t||{};(function(s,o,f){r=1,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",e=e+'<div class="g-footer-links">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",e=e+'<a id="g-about-link" href="http://girder.readthedocs.org/en/latest/user-guide.html">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",e=e+"About</a>",r=3,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",o&&(r=4,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",e=e+"<a"+(' id="g-contact-link"'+fa("href",o,!0,!1))+">",r=4,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",e=e+"Contact</a>"),r=5,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",e=e+"<a"+fa("href",s,!0,!1)+">",r=5,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",e=e+"Web API</a>",r=6,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",e=e+'<a id="g-bug-link" href="https://github.com/girder/girder/issues/new">',r=6,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",e=e+"Report a bug</a>",r=7,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",f&&(r=8,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",e=e+"<a"+(' id="g-privacy-notice-link"'+fa("href",f,!0,!1))+">",r=8,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",e=e+"Privacy Notice</a>"),e=e+"</div>",r=10,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",e=e+'<div class="g-footer-info">',r=11,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutFooter.pug",e=e+"&copy; Kitware, Inc.</div>"}).call(this,"apiRoot"in i?i.apiRoot:typeof apiRoot<"u"?apiRoot:void 0,"contactHref"in i?i.contactHref:typeof contactHref<"u"?contactHref:void 0,"privacyNoticeLink"in i?i.privacyNoticeLink:typeof privacyNoticeLink<"u"?privacyNoticeLink:void 0)}catch(s){Ag(s,u,r)}return e}var xg=Xe.extend({initialize:function(t){const e=t.contactEmail||null;this.contactHref=e!==null?`mailto:${e}`:null,this.privacyNoticeHref=t.privacyNoticeHref||null},render:function(){return this.$el.html(s1({apiRoot:Zi(),contactHref:this.contactHref,privacyNoticeLink:this.privacyNoticeHref})),this}});function Kr(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Bn(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Ua(t,e){return Array.isArray(t)?n1(t,e):t&&typeof t=="object"?o1(t):t||""}function n1(t,e){for(var u,r="",i="",s=Array.isArray(e),o=0;o<t.length;o++)(u=Ua(t[o]))&&(s&&e[o]&&(u=Bn(u)),r=r+i+u,i=" ");return r}function o1(t){var e="",u="";for(var r in t)r&&t[r]&&a1.call(t,r)&&(e=e+u+r,u=" ");return e}function Bn(t){var e=""+t,u=c1.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var a1=Object.prototype.hasOwnProperty,c1=/["&<>]/;function kg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void kg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function l1(t){var e="",u,r,i;try{var s=t||{};(function(o){i=1,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutGlobalNav.pug",e=e+'<div class="g-global-nav-main">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutGlobalNav.pug",e=e+'<ul class="g-global-nav">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutGlobalNav.pug",function(){var f=o;if(typeof f.length=="number")for(var n=0,h=f.length;n<h;n++){var g=f[n];i=4,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutGlobalNav.pug",e=e+'<li class="g-global-nav-li">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutGlobalNav.pug",e=e+"<a"+(' class="g-nav-link"'+Kr("g-target",g.target,!0,!1)+Kr("g-name",g.name,!0,!1)+Kr("href",`#${g.target}`,!0,!1))+">",i=6,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutGlobalNav.pug",e=e+"<i"+Kr("class",Ua([g.icon],[!0]),!1,!1)+"></i>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutGlobalNav.pug",e=e+"<span>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutGlobalNav.pug",e=e+Bn((u=g.name)==null?"":u)+"</span></a></li>"}else{var h=0;for(var n in f){h++;var g=f[n];i=4,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutGlobalNav.pug",e=e+'<li class="g-global-nav-li">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutGlobalNav.pug",e=e+"<a"+(' class="g-nav-link"'+Kr("g-target",g.target,!0,!1)+Kr("g-name",g.name,!0,!1)+Kr("href",`#${g.target}`,!0,!1))+">",i=6,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutGlobalNav.pug",e=e+"<i"+Kr("class",Ua([g.icon],[!0]),!1,!1)+"></i>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutGlobalNav.pug",e=e+"<span>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutGlobalNav.pug",e=e+Bn((u=g.name)==null?"":u)+"</span></a></li>"}}}.call(this),e=e+"</ul></div>"}).call(this,"navItems"in s?s.navItems:typeof navItems<"u"?navItems:void 0)}catch(o){kg(o,r,i)}return e}var jg=Xe.extend({events:{"click .g-nav-link":function(t){t.preventDefault();var e=ke(t.currentTarget);tt.navigate(e.attr("g-target"),{trigger:!0}),e.parent().addClass("g-active")}},initialize:function(t){He.on("g:highlightItem",this.selectForView,this),He.on("g:login",this.render,this),He.on("g:logout",this.render,this),He.on("g:login-changed",this.render,this),t=t||{},t.navItems?this.navItems=t.navItems:this.defaultNavItems=[{name:"Collections",icon:"icon-sitemap",target:"collections"},{name:"Groups",icon:"icon-users",target:"groups"}]},render:function(){var t;return this.navItems?t=this.navItems:(t=this.defaultNavItems,ft()&&(t=t.slice(),t.push({name:"Users",icon:"icon-user",target:"users"}),ft().get("admin")&&t.push({name:"Admin console",icon:"icon-wrench",target:"admin"}))),this.$el.html(l1({navItems:t})),s0.history.fragment&&this.$('[g-target="'+s0.history.fragment+'"]').parent().addClass("g-active"),this},selectForView:function(t){this.deactivateAll(),this.$('[g-name="'+t.slice(0,-4)+'"]').parent().addClass("g-active")},deactivateAll:function(){this.$(".g-global-nav-li").removeClass("g-active")}});function Hd(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Sg(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Sg(t){var e=""+t,u=d1.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var d1=/["&<>]/;function _g(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void _g(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function F1(t){var e="",u,r,i;try{var s=t||{};(function(o,f){i=1,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<div class="g-user-text">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",f?(i=3,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<a class="g-user-dropdown-link" data-toggle="dropdown" data-target="#g-user-action-menu">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+"",i=4,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<i class="icon-user"></i>',i=4,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+" ",i=4,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+Sg((u=f.get("login"))==null?"":u),i=5,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<i class="icon-down-open"></i></a>',i=6,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<div class="dropdown" id="g-user-action-menu">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<ul class="dropdown-menu" role="menu">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<li role="presentation">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+"<a"+(' class="g-my-folders"'+Hd("href",`#user/${f.id}`,!0,!1))+">",i=10,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<i class="icon-folder"></i>',i=11,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+"My folders</a></li>",i=12,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<li role="presentation">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+"<a"+(' class="g-my-settings"'+Hd("href",`#useraccount/${f.id}/info`,!0,!1))+">",i=14,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<i class="icon-cog"></i>',i=15,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+"My account</a></li>",i=16,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<li class="divider" role="presentation"></li>',i=17,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<li role="presentation">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<a class="g-logout">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<i class="icon-logout"></i>',i=20,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+"Log out</a></li></ul></div>"):(i=22,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",o!=="closed"&&(i=23,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<a class="g-register">',i=23,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+"Register</a>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<div class="g-or-text">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+"or</div>"),i=25,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<a class="g-login">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+"Log In",i=26,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeaderUser.pug",e=e+'<i class="icon-login"></i></a>'),e=e+"</div>"}).call(this,"registrationPolicy"in s?s.registrationPolicy:typeof registrationPolicy<"u"?registrationPolicy:void 0,"user"in s?s.user:typeof user<"u"?user:void 0)}catch(o){_g(o,r,i)}return e}+function(t){var e=".dropdown-backdrop",u='[data-toggle="dropdown"]',r=function(n){t(n).on("click.bs.dropdown",this.toggle)};r.VERSION="3.4.1";function i(n){var h=n.attr("data-target");h||(h=n.attr("href"),h=h&&/#[A-Za-z]/.test(h)&&h.replace(/.*(?=#[^\s]*$)/,""));var g=h!=="#"?t(document).find(h):null;return g&&g.length?g:n.parent()}function s(n){n&&n.which===3||(t(e).remove(),t(u).each(function(){var h=t(this),g=i(h),d={relatedTarget:this};g.hasClass("open")&&(n&&n.type=="click"&&/input|textarea/i.test(n.target.tagName)&&t.contains(g[0],n.target)||(g.trigger(n=t.Event("hide.bs.dropdown",d)),!n.isDefaultPrevented()&&(h.attr("aria-expanded","false"),g.removeClass("open").trigger(t.Event("hidden.bs.dropdown",d)))))}))}r.prototype.toggle=function(n){var h=t(this);if(!h.is(".disabled, :disabled")){var g=i(h),d=g.hasClass("open");if(s(),!d){"ontouchstart"in document.documentElement&&!g.closest(".navbar-nav").length&&t(document.createElement("div")).addClass("dropdown-backdrop").insertAfter(t(this)).on("click",s);var l={relatedTarget:this};if(g.trigger(n=t.Event("show.bs.dropdown",l)),n.isDefaultPrevented())return;h.trigger("focus").attr("aria-expanded","true"),g.toggleClass("open").trigger(t.Event("shown.bs.dropdown",l))}return!1}},r.prototype.keydown=function(n){if(!(!/(38|40|27|32)/.test(n.which)||/input|textarea/i.test(n.target.tagName))){var h=t(this);if(n.preventDefault(),n.stopPropagation(),!h.is(".disabled, :disabled")){var g=i(h),d=g.hasClass("open");if(!d&&n.which!=27||d&&n.which==27)return n.which==27&&g.find(u).trigger("focus"),h.trigger("click");var l=" li:not(.disabled):visible a",c=g.find(".dropdown-menu"+l);if(c.length){var a=c.index(n.target);n.which==38&&a>0&&a--,n.which==40&&a<c.length-1&&a++,~a||(a=0),c.eq(a).trigger("focus")}}}};function o(n){return this.each(function(){var h=t(this),g=h.data("bs.dropdown");g||h.data("bs.dropdown",g=new r(this)),typeof n=="string"&&g[n].call(h)})}var f=t.fn.dropdown;t.fn.dropdown=o,t.fn.dropdown.Constructor=r,t.fn.dropdown.noConflict=function(){return t.fn.dropdown=f,this},t(document).on("click.bs.dropdown.data-api",s).on("click.bs.dropdown.data-api",".dropdown form",function(n){n.stopPropagation()}).on("click.bs.dropdown.data-api",u,r.prototype.toggle).on("keydown.bs.dropdown.data-api",u,r.prototype.keydown).on("keydown.bs.dropdown.data-api",".dropdown-menu",r.prototype.keydown)}(ke);var Dg=Xe.extend({events:{"click a.g-login":function(){He.trigger("g:loginUi")},"click a.g-register":function(){He.trigger("g:registerUi")},"click a.g-logout":Hh},initialize:function(t){this.registrationPolicy=t.registrationPolicy,He.on("g:login",this.render,this),He.on("g:login-changed",this.render,this),He.on("g:logout",this.render,this)},render:function(){return this.$el.html(F1({user:ft(),registrationPolicy:this.registrationPolicy})),this}});+function(t){var e=["sanitize","whiteList","sanitizeFn"],u=["background","cite","href","itemtype","longdesc","poster","src","xlink:href"],r=/^aria-[\w-]*$/i,i={"*":["class","dir","id","lang","role",r],a:["target","href","title","rel"],area:[],b:[],br:[],col:[],code:[],div:[],em:[],hr:[],h1:[],h2:[],h3:[],h4:[],h5:[],h6:[],i:[],img:["src","alt","title","width","height"],li:[],ol:[],p:[],pre:[],s:[],small:[],span:[],sub:[],sup:[],strong:[],u:[],ul:[]},s=/^(?:(?:https?|mailto|ftp|tel|file):|[^&:/?#]*(?:[/?#]|$))/gi,o=/^data:(?:image\/(?:bmp|gif|jpeg|jpg|png|tiff|webp)|video\/(?:mpeg|mp4|ogg|webm)|audio\/(?:mp3|oga|ogg|opus));base64,[a-z0-9+/]+=*$/i;function f(l,c){var a=l.nodeName.toLowerCase();if(t.inArray(a,c)!==-1)return t.inArray(a,u)!==-1?!!(l.nodeValue.match(s)||l.nodeValue.match(o)):!0;for(var F=t(c).filter(function(b,C){return C instanceof RegExp}),p=0,m=F.length;p<m;p++)if(a.match(F[p]))return!0;return!1}function n(l,c,a){if(l.length===0)return l;if(a&&typeof a=="function")return a(l);if(!document.implementation||!document.implementation.createHTMLDocument)return l;var F=document.implementation.createHTMLDocument("sanitization");F.body.innerHTML=l;for(var p=t.map(c,function(R,N){return N}),m=t(F.body).find("*"),b=0,C=m.length;b<C;b++){var k=m[b],T=k.nodeName.toLowerCase();if(t.inArray(T,p)===-1){k.parentNode.removeChild(k);continue}for(var w=t.map(k.attributes,function(R){return R}),A=[].concat(c["*"]||[],c[T]||[]),M=0,x=w.length;M<x;M++)f(w[M],A)||k.removeAttribute(w[M].nodeName)}return F.body.innerHTML}var h=function(l,c){this.type=null,this.options=null,this.enabled=null,this.timeout=null,this.hoverState=null,this.$element=null,this.inState=null,this.init("tooltip",l,c)};h.VERSION="3.4.1",h.TRANSITION_DURATION=150,h.DEFAULTS={animation:!0,placement:"top",selector:!1,template:'<div class="tooltip" role="tooltip"><div class="tooltip-arrow"></div><div class="tooltip-inner"></div></div>',trigger:"hover focus",title:"",delay:0,html:!1,container:!1,viewport:{selector:"body",padding:0},sanitize:!0,sanitizeFn:null,whiteList:i},h.prototype.init=function(l,c,a){if(this.enabled=!0,this.type=l,this.$element=t(c),this.options=this.getOptions(a),this.$viewport=this.options.viewport&&t(document).find(t.isFunction(this.options.viewport)?this.options.viewport.call(this,this.$element):this.options.viewport.selector||this.options.viewport),this.inState={click:!1,hover:!1,focus:!1},this.$element[0]instanceof document.constructor&&!this.options.selector)throw new Error("`selector` option must be specified when initializing "+this.type+" on the window.document object!");for(var F=this.options.trigger.split(" "),p=F.length;p--;){var m=F[p];if(m=="click")this.$element.on("click."+this.type,this.options.selector,t.proxy(this.toggle,this));else if(m!="manual"){var b=m=="hover"?"mouseenter":"focusin",C=m=="hover"?"mouseleave":"focusout";this.$element.on(b+"."+this.type,this.options.selector,t.proxy(this.enter,this)),this.$element.on(C+"."+this.type,this.options.selector,t.proxy(this.leave,this))}}this.options.selector?this._options=t.extend({},this.options,{trigger:"manual",selector:""}):this.fixTitle()},h.prototype.getDefaults=function(){return h.DEFAULTS},h.prototype.getOptions=function(l){var c=this.$element.data();for(var a in c)c.hasOwnProperty(a)&&t.inArray(a,e)!==-1&&delete c[a];return l=t.extend({},this.getDefaults(),c,l),l.delay&&typeof l.delay=="number"&&(l.delay={show:l.delay,hide:l.delay}),l.sanitize&&(l.template=n(l.template,l.whiteList,l.sanitizeFn)),l},h.prototype.getDelegateOptions=function(){var l={},c=this.getDefaults();return this._options&&t.each(this._options,function(a,F){c[a]!=F&&(l[a]=F)}),l},h.prototype.enter=function(l){var c=l instanceof this.constructor?l:t(l.currentTarget).data("bs."+this.type);if(c||(c=new this.constructor(l.currentTarget,this.getDelegateOptions()),t(l.currentTarget).data("bs."+this.type,c)),l instanceof t.Event&&(c.inState[l.type=="focusin"?"focus":"hover"]=!0),c.tip().hasClass("in")||c.hoverState=="in"){c.hoverState="in";return}if(clearTimeout(c.timeout),c.hoverState="in",!c.options.delay||!c.options.delay.show)return c.show();c.timeout=setTimeout(function(){c.hoverState=="in"&&c.show()},c.options.delay.show)},h.prototype.isInStateTrue=function(){for(var l in this.inState)if(this.inState[l])return!0;return!1},h.prototype.leave=function(l){var c=l instanceof this.constructor?l:t(l.currentTarget).data("bs."+this.type);if(c||(c=new this.constructor(l.currentTarget,this.getDelegateOptions()),t(l.currentTarget).data("bs."+this.type,c)),l instanceof t.Event&&(c.inState[l.type=="focusout"?"focus":"hover"]=!1),!c.isInStateTrue()){if(clearTimeout(c.timeout),c.hoverState="out",!c.options.delay||!c.options.delay.hide)return c.hide();c.timeout=setTimeout(function(){c.hoverState=="out"&&c.hide()},c.options.delay.hide)}},h.prototype.show=function(){var l=t.Event("show.bs."+this.type);if(this.hasContent()&&this.enabled){this.$element.trigger(l);var c=t.contains(this.$element[0].ownerDocument.documentElement,this.$element[0]);if(l.isDefaultPrevented()||!c)return;var a=this,F=this.tip(),p=this.getUID(this.type);this.setContent(),F.attr("id",p),this.$element.attr("aria-describedby",p),this.options.animation&&F.addClass("fade");var m=typeof this.options.placement=="function"?this.options.placement.call(this,F[0],this.$element[0]):this.options.placement,b=/\s?auto?\s?/i,C=b.test(m);C&&(m=m.replace(b,"")||"top"),F.detach().css({top:0,left:0,display:"block"}).addClass(m).data("bs."+this.type,this),this.options.container?F.appendTo(t(document).find(this.options.container)):F.insertAfter(this.$element),this.$element.trigger("inserted.bs."+this.type);var k=this.getPosition(),T=F[0].offsetWidth,w=F[0].offsetHeight;if(C){var A=m,M=this.getPosition(this.$viewport);m=m=="bottom"&&k.bottom+w>M.bottom?"top":m=="top"&&k.top-w<M.top?"bottom":m=="right"&&k.right+T>M.width?"left":m=="left"&&k.left-T<M.left?"right":m,F.removeClass(A).addClass(m)}var x=this.getCalculatedOffset(m,k,T,w);this.applyPlacement(x,m);var R=function(){var N=a.hoverState;a.$element.trigger("shown.bs."+a.type),a.hoverState=null,N=="out"&&a.leave(a)};t.support.transition&&this.$tip.hasClass("fade")?F.one("bsTransitionEnd",R).emulateTransitionEnd(h.TRANSITION_DURATION):R()}},h.prototype.applyPlacement=function(l,c){var a=this.tip(),F=a[0].offsetWidth,p=a[0].offsetHeight,m=parseInt(a.css("margin-top"),10),b=parseInt(a.css("margin-left"),10);isNaN(m)&&(m=0),isNaN(b)&&(b=0),l.top+=m,l.left+=b,t.offset.setOffset(a[0],t.extend({using:function(x){a.css({top:Math.round(x.top),left:Math.round(x.left)})}},l),0),a.addClass("in");var C=a[0].offsetWidth,k=a[0].offsetHeight;c=="top"&&k!=p&&(l.top=l.top+p-k);var T=this.getViewportAdjustedDelta(c,l,C,k);T.left?l.left+=T.left:l.top+=T.top;var w=/top|bottom/.test(c),A=w?T.left*2-F+C:T.top*2-p+k,M=w?"offsetWidth":"offsetHeight";a.offset(l),this.replaceArrow(A,a[0][M],w)},h.prototype.replaceArrow=function(l,c,a){this.arrow().css(a?"left":"top",50*(1-l/c)+"%").css(a?"top":"left","")},h.prototype.setContent=function(){var l=this.tip(),c=this.getTitle();this.options.html?(this.options.sanitize&&(c=n(c,this.options.whiteList,this.options.sanitizeFn)),l.find(".tooltip-inner").html(c)):l.find(".tooltip-inner").text(c),l.removeClass("fade in top bottom left right")},h.prototype.hide=function(l){var c=this,a=t(this.$tip),F=t.Event("hide.bs."+this.type);function p(){c.hoverState!="in"&&a.detach(),c.$element&&c.$element.removeAttr("aria-describedby").trigger("hidden.bs."+c.type),l&&l()}if(this.$element.trigger(F),!F.isDefaultPrevented())return a.removeClass("in"),t.support.transition&&a.hasClass("fade")?a.one("bsTransitionEnd",p).emulateTransitionEnd(h.TRANSITION_DURATION):p(),this.hoverState=null,this},h.prototype.fixTitle=function(){var l=this.$element;(l.attr("title")||typeof l.attr("data-original-title")!="string")&&l.attr("data-original-title",l.attr("title")||"").attr("title","")},h.prototype.hasContent=function(){return this.getTitle()},h.prototype.getPosition=function(l){l=l||this.$element;var c=l[0],a=c.tagName=="BODY",F=c.getBoundingClientRect();F.width==null&&(F=t.extend({},F,{width:F.right-F.left,height:F.bottom-F.top}));var p=window.SVGElement&&c instanceof window.SVGElement,m=a?{top:0,left:0}:p?null:l.offset(),b={scroll:a?document.documentElement.scrollTop||document.body.scrollTop:l.scrollTop()},C=a?{width:t(window).width(),height:t(window).height()}:null;return t.extend({},F,b,C,m)},h.prototype.getCalculatedOffset=function(l,c,a,F){return l=="bottom"?{top:c.top+c.height,left:c.left+c.width/2-a/2}:l=="top"?{top:c.top-F,left:c.left+c.width/2-a/2}:l=="left"?{top:c.top+c.height/2-F/2,left:c.left-a}:{top:c.top+c.height/2-F/2,left:c.left+c.width}},h.prototype.getViewportAdjustedDelta=function(l,c,a,F){var p={top:0,left:0};if(!this.$viewport)return p;var m=this.options.viewport&&this.options.viewport.padding||0,b=this.getPosition(this.$viewport);if(/right|left/.test(l)){var C=c.top-m-b.scroll,k=c.top+m-b.scroll+F;C<b.top?p.top=b.top-C:k>b.top+b.height&&(p.top=b.top+b.height-k)}else{var T=c.left-m,w=c.left+m+a;T<b.left?p.left=b.left-T:w>b.right&&(p.left=b.left+b.width-w)}return p},h.prototype.getTitle=function(){var l,c=this.$element,a=this.options;return l=c.attr("data-original-title")||(typeof a.title=="function"?a.title.call(c[0]):a.title),l},h.prototype.getUID=function(l){do l+=~~(Math.random()*1e6);while(document.getElementById(l));return l},h.prototype.tip=function(){if(!this.$tip&&(this.$tip=t(this.options.template),this.$tip.length!=1))throw new Error(this.type+" `template` option must consist of exactly 1 top-level element!");return this.$tip},h.prototype.arrow=function(){return this.$arrow=this.$arrow||this.tip().find(".tooltip-arrow")},h.prototype.enable=function(){this.enabled=!0},h.prototype.disable=function(){this.enabled=!1},h.prototype.toggleEnabled=function(){this.enabled=!this.enabled},h.prototype.toggle=function(l){var c=this;l&&(c=t(l.currentTarget).data("bs."+this.type),c||(c=new this.constructor(l.currentTarget,this.getDelegateOptions()),t(l.currentTarget).data("bs."+this.type,c))),l?(c.inState.click=!c.inState.click,c.isInStateTrue()?c.enter(c):c.leave(c)):c.tip().hasClass("in")?c.leave(c):c.enter(c)},h.prototype.destroy=function(){var l=this;clearTimeout(this.timeout),this.hide(function(){l.$element.off("."+l.type).removeData("bs."+l.type),l.$tip&&l.$tip.detach(),l.$tip=null,l.$arrow=null,l.$viewport=null,l.$element=null})},h.prototype.sanitizeHtml=function(l){return n(l,this.options.whiteList,this.options.sanitizeFn)};function g(l){return this.each(function(){var c=t(this),a=c.data("bs.tooltip"),F=typeof l=="object"&&l;!a&&/destroy|hide/.test(l)||(a||c.data("bs.tooltip",a=new h(this,F)),typeof l=="string"&&a[l]())})}var d=t.fn.tooltip;t.fn.tooltip=g,t.fn.tooltip.Constructor=h,t.fn.tooltip.noConflict=function(){return t.fn.tooltip=d,this}}(ke);+function(t){var e=function(i,s){this.init("popover",i,s)};if(!t.fn.tooltip)throw new Error("Popover requires tooltip.js");e.VERSION="3.4.1",e.DEFAULTS=t.extend({},t.fn.tooltip.Constructor.DEFAULTS,{placement:"right",trigger:"click",content:"",template:'<div class="popover" role="tooltip"><div class="arrow"></div><h3 class="popover-title"></h3><div class="popover-content"></div></div>'}),e.prototype=t.extend({},t.fn.tooltip.Constructor.prototype),e.prototype.constructor=e,e.prototype.getDefaults=function(){return e.DEFAULTS},e.prototype.setContent=function(){var i=this.tip(),s=this.getTitle(),o=this.getContent();if(this.options.html){var f=typeof o;this.options.sanitize&&(s=this.sanitizeHtml(s),f==="string"&&(o=this.sanitizeHtml(o))),i.find(".popover-title").html(s),i.find(".popover-content").children().detach().end()[f==="string"?"html":"append"](o)}else i.find(".popover-title").text(s),i.find(".popover-content").children().detach().end().text(o);i.removeClass("fade top bottom left right in"),i.find(".popover-title").html()||i.find(".popover-title").hide()},e.prototype.hasContent=function(){return this.getTitle()||this.getContent()},e.prototype.getContent=function(){var i=this.$element,s=this.options;return i.attr("data-content")||(typeof s.content=="function"?s.content.call(i[0]):s.content)},e.prototype.arrow=function(){return this.$arrow=this.$arrow||this.tip().find(".arrow")};function u(i){return this.each(function(){var s=t(this),o=s.data("bs.popover"),f=typeof i=="object"&&i;!o&&/destroy|hide/.test(i)||(o||s.data("bs.popover",o=new e(this,f)),typeof i=="string"&&o[i]())})}var r=t.fn.popover;t.fn.popover=u,t.fn.popover.Constructor=e,t.fn.popover.noConflict=function(){return t.fn.popover=r,this}}(ke);function Ud(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=h1(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function h1(t){var e=""+t,u=g1.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var g1=/["&<>]/;function Mg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Mg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function p1(t){var e="",u,r;try{var i=t||{};(function(s,o){r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/searchField.pug",e=e+'<div class="g-search-wrapper">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/widgets/searchField.pug",e=e+'<a class="g-search-options-button btn btn-sm" title="Show search help">',r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/searchField.pug",e=e+'<i class="g-search-state icon-search"></i></a>',r=4,u="/home/circleci/project/girder/girder/web/src/templates/widgets/searchField.pug",e=e+"<input"+(' class="g-search-field form-control input-sm" type="text"'+Ud("placeholder",o,!0,!1)+Ud("mode-select",s.length>1?"on":"off",!0,!1))+"/>",r=6,u="/home/circleci/project/girder/girder/web/src/templates/widgets/searchField.pug",e=e+'<div class="g-search-results dropdown">',r=7,u="/home/circleci/project/girder/girder/web/src/templates/widgets/searchField.pug",e=e+'<ul class="dropdown-menu" role="menu"></ul></div>',r=8,u="/home/circleci/project/girder/girder/web/src/templates/widgets/searchField.pug",s.length>1&&(r=9,u="/home/circleci/project/girder/girder/web/src/templates/widgets/searchField.pug",e=e+'<a class="g-search-mode-choose btn btn-sm" title="Search mode">',r=10,u="/home/circleci/project/girder/girder/web/src/templates/widgets/searchField.pug",e=e+'<i class="icon-down-dir"></i></a>'),e=e+"</div>"}).call(this,"modes"in i?i.modes:typeof modes<"u"?modes:void 0,"placeholder"in i?i.placeholder:typeof placeholder<"u"?placeholder:void 0)}catch(s){Mg(s,u,r)}return e}function f1(t){var e=""+t,u=m1.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var m1=/["&<>]/;function Tg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Tg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function v1(t){var e="",u,r,i;try{var s=t||{};(function(o,f){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+'<p class="g-search-help-text">',i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+f1((u=f)==null?"":u)+"</p>",i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",o==="text"&&(i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+'<ul class="g-search-examples-list">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+"<li>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+"<code>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+"cat dog</code>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+' returns documents containing either "cat" or "dog".</li>',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+"<li>",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+"<code>",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+'"cat" "dog"</code>',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+' returns documents containing both "cat" and "dog".</li>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+"<li>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+"<code>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+'"cat dog"</code>',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchHelp.pug",e=e+' returns documents containing the phrase "cat dog".</li></ul>')}).call(this,"mode"in s?s.mode:typeof mode<"u"?mode:void 0,"modeHelp"in s?s.modeHelp:typeof modeHelp<"u"?modeHelp:void 0)}catch(o){Tg(o,r,i)}return e}function sn(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=qa(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function qa(t){var e=""+t,u=b1.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var b1=/["&<>]/;function Pg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Pg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function w1(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchModeSelect.pug",e=e+"<p>",i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchModeSelect.pug",e=e+"Choose search mode:</p>",i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchModeSelect.pug",function(){var h=n;if(typeof h.length=="number")for(var g=0,d=h.length;g<d;g++){var l=h[g];i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchModeSelect.pug",e=e+'<div class="radio">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchModeSelect.pug",e=e+"<label>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchModeSelect.pug",e=e+"<input"+(' class="g-search-mode-radio" type="radio" name="search-mode"'+sn("value",l,!0,!1)+sn("checked",l===o?"checked":void 0,!0,!1))+"/>",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchModeSelect.pug",e=e+qa((u=f(l))==null?"":u)+"</label></div>"}else{var d=0;for(var g in h){d++;var l=h[g];i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchModeSelect.pug",e=e+'<div class="radio">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchModeSelect.pug",e=e+"<label>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchModeSelect.pug",e=e+"<input"+(' class="g-search-mode-radio" type="radio" name="search-mode"'+sn("value",l,!0,!1)+sn("checked",l===o?"checked":void 0,!0,!1))+"/>",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchModeSelect.pug",e=e+qa((u=f(l))==null?"":u)+"</label></div>"}}}.call(this)}).call(this,"currentMode"in s?s.currentMode:typeof currentMode<"u"?currentMode:void 0,"getModeDescription"in s?s.getModeDescription:typeof getModeDescription<"u"?getModeDescription:void 0,"modes"in s?s.modes:typeof modes<"u"?modes:void 0)}catch(o){Pg(o,r,i)}return e}function Yr(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=In(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function za(t,e){return Array.isArray(t)?y1(t,e):t&&typeof t=="object"?C1(t):t||""}function y1(t,e){for(var u,r="",i="",s=Array.isArray(e),o=0;o<t.length;o++)(u=za(t[o]))&&(s&&e[o]&&(u=In(u)),r=r+i+u,i=" ");return r}function C1(t){var e="",u="";for(var r in t)r&&t[r]&&E1.call(t,r)&&(e=e+u+r,u=" ");return e}function In(t){var e=""+t,u=A1.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var E1=Object.prototype.hasOwnProperty,A1=/["&<>]/;function Lg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Lg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function x1(t){var e="",u,r,i;try{var s=t||{};(function(o){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",function(){var f=o;if(typeof f.length=="number")for(var n=0,h=f.length;n<h;n++){var g=f[n];i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+'<li class="g-search-result">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+"<a"+(' class="g-search-result-element"'+Yr("data-resource-id",g.id,!0,!1)+Yr("data-resource-type",g.type,!0,!1)+Yr("data-resource-icon",g.icon,!0,!1)+' tabindex="-1"')+">",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+"<i"+Yr("class",za([`icon-${g.icon}`],[!0]),!1,!1)+"></i>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+In((u=g.text)==null?"":u)+"</a></li>"}else{var h=0;for(var n in f){h++;var g=f[n];i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+'<li class="g-search-result">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+"<a"+(' class="g-search-result-element"'+Yr("data-resource-id",g.id,!0,!1)+Yr("data-resource-type",g.type,!0,!1)+Yr("data-resource-icon",g.icon,!0,!1)+' tabindex="-1"')+">",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+"<i"+Yr("class",za([`icon-${g.icon}`],[!0]),!1,!1)+"></i>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+In((u=g.text)==null?"":u)+"</a></li>"}}}.call(this),i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",o.length===0?(i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+'<li class="g-no-search-results disabled">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+'<a tabindex="-1">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+'<i class="icon-block">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+"No results found</i></a></li>"):(i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+'<li class="g-search-result">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+'<a class="g-search-result-page-link" data-resource-type="resultPage">',i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/searchResults.pug",e=e+"...</a></li>")}).call(this,"results"in s?s.results:typeof results<"u"?results:void 0)}catch(o){Lg(o,r,i)}return e}var Xt=Xe.extend({events:{"input .g-search-field":"search","click .g-search-mode-radio":function(t){this.currentMode=ke(t.target).val(),this.hideResults().search(),window.setTimeout(()=>{this.$(".g-search-mode-choose").popover("hide")},250)},"click .g-search-result>a":function(t){this._resultClicked(ke(t.currentTarget))},"keydown .g-search-field":function(t){var e=t.keyCode||t.which,u,r;if(e===13&&this.noResourceSelected)t.preventDefault(),this.$(".g-search-field").val()!==""&&!this.noResultsPage&&this._goToResultPage(this.$(".g-search-field").val(),this.currentMode);else if(e===40||e===38)this.noResourceSelected=!1,e===40?(u=this.$(".g-search-result"),r=u.index(u.filter(".g-search-selected"))+1,u.removeClass("g-search-selected"),r<u.length&&u.eq(r).addClass("g-search-selected"),r===u.length&&(this.noResourceSelected=!0)):e===38&&(u=this.$(".g-search-result"),r=u.index(u.filter(".g-search-selected"))-1,u.removeClass("g-search-selected"),r===-1&&(this.noResourceSelected=!0),r===-2&&(r=u.length-1),r>=0&&u.eq(r).addClass("g-search-selected"));else if(e===13){t.preventDefault(),this.noResourceSelected=!0;var i=this.$(".g-search-result.g-search-selected>a");i.length&&this._resultClicked(i)}}},initialize:function(t){this.ajaxLock=!1,this.pending=null,this.noResourceSelected=!0,this.placeholder=t.placeholder||"Search...",this.noResultsPage=t.noResultsPage||!1,this.getInfoCallback=t.getInfoCallback||null,this.types=t.types||[],this.modes=t.modes||Xt.getModes(),xe.isArray(this.modes)||(this.modes=[this.modes]),this.currentMode=this.modes[0],this._animatePending=xe.debounce(this._animatePending,100)},search:function(){var t=this.$(".g-search-field").val();return t?(this.ajaxLock?this.pending=t:this._doSearch(t),this):(this.hideResults(),this)},_goToResultPage:function(t,e){this.resetState(),tt.navigate(`#search/results?query=${t}&mode=${e}`,{trigger:!0})},_resultClicked:function(t){t.data("resourceType")==="resultPage"?this._goToResultPage(this.$(".g-search-field").val(),this.currentMode):this.trigger("g:resultClicked",{type:t.data("resourceType"),id:t.data("resourceId"),text:t.text().trim(),icon:t.data("resourceIcon")})},render:function(){return this.$el.html(p1({placeholder:this.placeholder,modes:this.modes,currentMode:this.currentMode})),this.$(".g-search-options-button").popover({trigger:"manual",viewport:{selector:"body",padding:10},content:()=>v1({mode:this.currentMode,modeHelp:Xt.getModeHelp(this.currentMode)}),html:!0,sanitize:!1}).on("click",function(){ke(this).popover("toggle")}),this.$(".g-search-mode-choose").popover({trigger:"manual",viewport:{selector:"body",padding:10},content:()=>w1({modes:this.modes,currentMode:this.currentMode,getModeDescription:Xt.getModeDescription}),html:!0,sanitize:!1}).on("click",function(){ke(this).popover("toggle")}),this},hideResults:function(){return this.$(".dropdown").removeClass("open"),this},clearText:function(){return this.$(".g-search-field").val(""),this},resetState:function(){return this.hideResults().clearText()},_animatePending:function(){const t=this.ajaxLock;this.$(".g-search-state").toggleClass("icon-search",!t).toggleClass("icon-spin4 animate-spin",t)},_doSearch:function(t){this.ajaxLock=!0,this.pending=null,this._animatePending(),ut({url:"resource/search",data:{q:t,mode:this.currentMode,types:JSON.stringify(xe.intersection(this.types,Xt.getModeTypes(this.currentMode)))}}).done(e=>{if(this.ajaxLock=!1,this._animatePending(),this.pending)this._doSearch(this.pending);else{if(!this.$(".g-search-field").val())return;var u=[];xe.each(this.types,function(r){xe.each(e[r]||[],function(i){var s,o;if(r==="user")s=i.firstName+" "+i.lastName+" ("+i.login+")",o="user";else if(r==="group")s=i.name,o="users";else if(r==="collection")s=i.name,o="sitemap";else if(r==="folder")s=i.name,o="folder";else if(r==="item")s=i.name,o="doc-text-inv";else{if(this.getInfoCallback){var f=this.getInfoCallback(r,i);f&&(s=f.text,o=f.icon)}(!s||!o)&&(s="[unknown type]",o="attention")}u.push({type:r,id:i._id,text:s,icon:o})},this)},this),this.$(".g-search-results>ul").html(x1({results:u.slice(0,6)})),this.$(".dropdown").addClass("open")}})}},{_allowedSearchMode:{},addMode:function(t,e,u,r){if(xe.has(Xt._allowedSearchMode,t))throw new Error(`The mode "${t}" exist already. You can't change it`);Xt._allowedSearchMode[t]={types:e,description:u,help:r}},getModes:function(){return xe.keys(Xt._allowedSearchMode)},getModeTypes:function(t){return Xt._allowedSearchMode[t].types},getModeDescription:function(t){return Xt._allowedSearchMode[t].description},getModeHelp:function(t){return Xt._allowedSearchMode[t].help},removeMode:function(t){delete Xt._allowedSearchMode[t]}});Xt.addMode("text",["item","folder","group","collection","user"],"Full text search",`By default, search results will be returned if they contain
     any of the terms of the search. If you wish to search for documents
     containing all of the terms, place them in quotes.
     Examples:`);Xt.addMode("prefix",["item","folder","group","collection","user"],"Search by prefix",`You are searching by prefix.
     Start typing the first letters of whatever you are searching for.`);function k1(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Rg(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Rg(t){var e=""+t,u=S1.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var j1=Object.prototype.hasOwnProperty,S1=/["&<>]/;function Bg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Bg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function _1(t){if(!t)return"";if(typeof t=="object"){var e="";for(var u in t)j1.call(t,u)&&(e=e+u+":"+t[u]+";");return e}return t+""}function D1(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeader.pug",e=e+"<div"+(' class="g-header-wrapper"'+k1("style",_1(`background-color: ${o}; color: ${n}`),!0,!1))+">",i=2,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeader.pug",e=e+'<div class="g-app-title">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeader.pug",e=e+Rg((u=f)==null?"":u)+"</div>",i=4,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeader.pug",e=e+'<form class="g-quick-search-form" role="form">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeader.pug",e=e+'<div class="form-group g-quick-search-container"></div></form>',i=7,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeader.pug",e=e+'<div class="g-current-user-wrapper"></div>',i=8,r="/home/circleci/project/girder/girder/web/src/templates/layout/layoutHeader.pug",e=e+'<div class="g-clear-both"></div></div>'}).call(this,"bannerColor"in s?s.bannerColor:typeof bannerColor<"u"?bannerColor:void 0,"brandName"in s?s.brandName:typeof brandName<"u"?brandName:void 0,"textColor"in s?s.textColor:typeof textColor<"u"?textColor:void 0)}catch(o){Bg(o,r,i)}return e}var Ig=Xe.extend({events:{"click .g-app-title":function(){tt.navigate("",{trigger:!0})}},initialize:function(t){this.brandName=t.brandName||"Girder",this.bannerColor=t.bannerColor||"#3F3B3B",this.userView=new Dg({parentView:this,registrationPolicy:t.registrationPolicy}),this.searchWidget=new Xt({placeholder:"Quick search...",types:["collection","folder","item","group","user"],parentView:this}).on("g:resultClicked",function(e){this.searchWidget.resetState(),tt.navigate(e.type+"/"+e.id,{trigger:!0})},this)},render:function(){var t=this._getTextColor(this.bannerColor);return this.$el.html(D1({brandName:this.brandName,bannerColor:this.bannerColor,textColor:t})),this.userView.setElement(this.$(".g-current-user-wrapper")).render(),t!=="#ffffff"&&this.userView.$(".g-user-text a").css("color",t),this.searchWidget.setElement(this.$(".g-quick-search-container")).render(),this},_getTextColor:function(t){const e=t.substr(1,2),u=t.substr(3,2),r=t.substr(5,2),i=xe.map([e,u,r],f=>parseInt(f,16)/255),s=xe.map(i,f=>f<=.03928?f/12.92:Math.pow((f+.055)/1.055,2.4)),o=.2126*s[0]+.7152*s[1]+.0722*s[2];return(o+.05)/(0+.05)>(1+.05)/(o+.05)?"#000000":"#ffffff"}});function Og(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Og(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function M1(t){var e="",u,r;try{var i=t||{};(function(s,o){r=1,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<div class="modal-dialog">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<div class="modal-content">',r=3,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<form class="modal-form" id="g-login-form" role="form">',r=4,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<div class="modal-header">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+"&times;</button>",r=6,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<h4 class="modal-title">',r=6,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+"Log in</h4></div>",r=7,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<div class="modal-body">',r=8,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",s&&(r=9,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<div class="form-group">',r=10,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<label class="control-label" for="g-login">',r=10,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+"Login or email</label>",r=11,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<input class="input-sm form-control" id="g-login" type="text" placeholder="Enter login"/></div>',r=12,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<div class="form-group">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<label class="control-label" for="g-password">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+"Password</label>",r=14,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<input class="input-sm form-control" id="g-password" type="password" placeholder="Enter password"/></div>',r=15,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<div class="form-group hidden" id="g-login-otp-group">',r=16,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<label class="control-label" for="g-login-otp">',r=16,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+"Two-factor code</label>",r=17,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<input class="input-sm form-control" id="g-login-otp" type="text" minlength="6" maxlength="6" placeholder="Your 6-digit two-factor authentication code, if enabled"/></div>',r=19,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<div class="g-validation-failed-message"></div>',r=20,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<div class="g-bottom-message">',r=21,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",o!=="closed"&&(r=22,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+"Don't have an account yet?",r=23,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<a class="g-register-link">',r=23,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+" Register here.</a>",r=24,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+" |"),r=25,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<a class="g-forgot-password">',r=25,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+" Forgot your password?</a></div>"),e=e+"</div>",r=26,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<div class="modal-footer">',r=27,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<a class="btn btn-default" data-dismiss="modal">',r=27,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+"Close</a>",r=28,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<button class="btn btn-primary" id="g-login-button" type="submit">',r=29,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+'<i class="icon-login"></i>',r=30,u="/home/circleci/project/girder/girder/web/src/templates/layout/loginDialog.pug",e=e+" Login</button></div></form></div></div>"}).call(this,"enablePasswordLogin"in i?i.enablePasswordLogin:typeof enablePasswordLogin<"u"?enablePasswordLogin:void 0,"registrationPolicy"in i?i.registrationPolicy:typeof registrationPolicy<"u"?registrationPolicy:void 0)}catch(s){Og(s,u,r)}return e}ke.fn.girderEnable=function(t){var e=ke(this);return e.is(":input")&&e.prop("disabled",!t),t?e.removeClass("disabled"):e.addClass("disabled"),this};var $g=Xe.extend({events:{"submit #g-login-form":function(t){t.preventDefault(),this.$("#g-login-button").girderEnable(!1),this.$(".g-validation-failed-message").text("");const e=this.$("#g-login").val(),u=this.$("#g-password").val(),r=this.$("#g-login-otp-group").hasClass("hidden")?null:this.$("#g-login-otp").val();Wh(e,u,r).done(()=>{this.$el.modal("hide")}).fail(i=>{if(i.responseJSON.message.indexOf("Girder-OTP")!==-1&&this.$("#g-login-otp-group").hasClass("hidden")){this.$("#g-login-otp-group").removeClass("hidden"),this.$("#g-login-otp").trigger("focus");return}if(this.$(".g-validation-failed-message").text(i.responseJSON.message),i.responseJSON.extra==="emailVerification"){var s=i.responseJSON.message+' <a class="g-send-verification-email">Click here to send verification email.</a>';ke(".g-validation-failed-message").html(s)}}).always(()=>{this.$("#g-login-button").girderEnable(!0)})},"click .g-send-verification-email":function(){this.$(".g-validation-failed-message").html("");const t=this.$("#g-login").val();p0.sendVerificationEmail(t).done(e=>{this.$(".g-validation-failed-message").html(e.message)}).fail(e=>{this.$(".g-validation-failed-message").html(e.responseJSON.message)})},"click a.g-register-link":function(){He.trigger("g:registerUi")},"click a.g-forgot-password":function(){He.trigger("g:resetPasswordUi")}},initialize:function(t){this.registrationPolicy=t.registrationPolicy,this.enablePasswordLogin=xe.has(t,"enablePasswordLogin")?t.enablePasswordLogin:!0},render:function(){return this.$el.html(M1({registrationPolicy:this.registrationPolicy,enablePasswordLogin:this.enablePasswordLogin,showOtp:!0})).girderModal(this).on("shown.bs.modal",()=>{this.$("#g-login").trigger("focus")}).on("hidden.bs.modal",()=>{F0("login",{replace:!0})}),b0("login",{replace:!0}),this.$("#g-login").trigger("focus"),this}}),Va={};(function(t){(function(e){var u={not_string:/[^s]/,number:/[diefg]/,json:/[j]/,not_json:/[^j]/,text:/^[^\x25]+/,modulo:/^\x25{2}/,placeholder:/^\x25(?:([1-9]\d*)\$|\(([^\)]+)\))?(\+)?(0|'[^$])?(-)?(\d+)?(?:\.(\d+))?([b-gijosuxX])/,key:/^([a-z_][a-z_\d]*)/i,key_access:/^\.([a-z_][a-z_\d]*)/i,index_access:/^\[(\d+)\]/,sign:/^[\+\-]/};function r(){var f=arguments[0],n=r.cache;return n[f]&&n.hasOwnProperty(f)||(n[f]=r.parse(f)),r.format.call(null,n[f],arguments)}r.format=function(f,n){var h=1,g=f.length,d="",l,c=[],a,F,p,m,b,C,k=!0,T="";for(a=0;a<g;a++)if(d=s(f[a]),d==="string")c[c.length]=f[a];else if(d==="array"){if(p=f[a],p[2])for(l=n[h],F=0;F<p[2].length;F++){if(!l.hasOwnProperty(p[2][F]))throw new Error(r("[sprintf] property '%s' does not exist",p[2][F]));l=l[p[2][F]]}else p[1]?l=n[p[1]]:l=n[h++];if(s(l)=="function"&&(l=l()),u.not_string.test(p[8])&&u.not_json.test(p[8])&&s(l)!="number"&&isNaN(l))throw new TypeError(r("[sprintf] expecting number but found %s",s(l)));switch(u.number.test(p[8])&&(k=l>=0),p[8]){case"b":l=l.toString(2);break;case"c":l=String.fromCharCode(l);break;case"d":case"i":l=parseInt(l,10);break;case"j":l=JSON.stringify(l,null,p[6]?parseInt(p[6]):0);break;case"e":l=p[7]?l.toExponential(p[7]):l.toExponential();break;case"f":l=p[7]?parseFloat(l).toFixed(p[7]):parseFloat(l);break;case"g":l=p[7]?parseFloat(l).toPrecision(p[7]):parseFloat(l);break;case"o":l=l.toString(8);break;case"s":l=(l=String(l))&&p[7]?l.substring(0,p[7]):l;break;case"u":l=l>>>0;break;case"x":l=l.toString(16);break;case"X":l=l.toString(16).toUpperCase();break}u.json.test(p[8])?c[c.length]=l:(u.number.test(p[8])&&(!k||p[3])?(T=k?"+":"-",l=l.toString().replace(u.sign,"")):T="",b=p[4]?p[4]==="0"?"0":p[4].charAt(1):" ",C=p[6]-(T+l).length,m=p[6]&&C>0?o(b,C):"",c[c.length]=p[5]?T+l+m:b==="0"?T+m+l:m+T+l)}return c.join("")},r.cache={},r.parse=function(f){for(var n=f,h=[],g=[],d=0;n;){if((h=u.text.exec(n))!==null)g[g.length]=h[0];else if((h=u.modulo.exec(n))!==null)g[g.length]="%";else if((h=u.placeholder.exec(n))!==null){if(h[2]){d|=1;var l=[],c=h[2],a=[];if((a=u.key.exec(c))!==null)for(l[l.length]=a[1];(c=c.substring(a[0].length))!=="";)if((a=u.key_access.exec(c))!==null)l[l.length]=a[1];else if((a=u.index_access.exec(c))!==null)l[l.length]=a[1];else throw new SyntaxError("[sprintf] failed to parse named argument key");else throw new SyntaxError("[sprintf] failed to parse named argument key");h[2]=l}else d|=2;if(d===3)throw new Error("[sprintf] mixing positional and named placeholders is not (yet) supported");g[g.length]=h}else throw new SyntaxError("[sprintf] unexpected placeholder");n=n.substring(h[0].length)}return g};var i=function(f,n,h){return h=(n||[]).slice(0),h.splice(0,0,f),r.apply(null,h)};function s(f){return Object.prototype.toString.call(f).slice(8,-1).toLowerCase()}function o(f,n){return Array(n+1).join(f)}t.sprintf=r,t.vsprintf=i})()})(Va);function ou(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Oi(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Ga(t,e){return Array.isArray(t)?T1(t,e):t&&typeof t=="object"?P1(t):t||""}function T1(t,e){for(var u,r="",i="",s=Array.isArray(e),o=0;o<t.length;o++)(u=Ga(t[o]))&&(s&&e[o]&&(u=Oi(u)),r=r+i+u,i=" ");return r}function P1(t){var e="",u="";for(var r in t)r&&t[r]&&Ng.call(t,r)&&(e=e+u+r,u=" ");return e}function Oi(t){var e=""+t,u=L1.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Ng=Object.prototype.hasOwnProperty,L1=/["&<>]/;function Wg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Wg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function R1(t){if(!t)return"";if(typeof t=="object"){var e="";for(var u in t)Ng.call(t,u)&&(e=e+u+":"+t[u]+";");return e}return t+""}function B1(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h,g,d){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+'<div class="g-task-progress-top">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+"<div"+ou("class",Ga(["g-task-progress-bar","progress",h],[!1,!1,!0]),!1,!1)+">",i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+"<div"+(ou("class",Ga(["progress-bar",o],[!1,!0]),!1,!1)+ou("style",R1(`width: ${d};`),!0,!1))+">",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+'<div class="progress-status">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+'<div class="progress-percent">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+Oi((u=f)==null?"":u)+"</div>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+'<div class="progress-left">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+Oi((u=g)==null?"":u)+"</div></div></div></div>",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+"<div"+(' class="g-task-progress-title"'+ou("title",n.data.title,!0,!1))+">",i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",n.data.resource&&n.data.resource._id&&n.data.resourceName?(i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+"<a"+(ou("title",n.data.title,!0,!1)+ou("href","#"+n.data.resourceName+"/"+n.data.resource._id,!0,!1))+">",i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+Oi((u=n.data.title)==null?"":u)+"</a>"):(i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+Oi((u=n.data.title)==null?"":u)),e=e+"</div></div>",i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+'<div class="g-task-progress-bottom">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+'<div class="g-task-progress-message">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/taskProgress.pug",e=e+Oi((u=n.data.message)==null?"":u)+"</div></div>"}).call(this,"barClass"in s?s.barClass:typeof barClass<"u"?barClass:void 0,"percentText"in s?s.percentText:typeof percentText<"u"?percentText:void 0,"progress"in s?s.progress:typeof progress<"u"?progress:void 0,"progressClass"in s?s.progressClass:typeof progressClass<"u"?progressClass:void 0,"timeLeftText"in s?s.timeLeftText:typeof timeLeftText<"u"?timeLeftText:void 0,"width"in s?s.width:typeof width<"u"?width:void 0)}catch(o){Wg(o,r,i)}return e}var Hg=Xe.extend({initialize:function(t){this.progress=t.progress},render:function(){var t="0",e=[],u=[],r="",i="";if(this.progress.data.state==="active")if(this.progress.data.total<=0)t="100%",e.push("progress-bar-warning"),u.push("progress-striped","active");else if(this.progress.data.current<=0)t="0",r="0%";else if(this.progress.data.current>=this.progress.data.total)r=t="100%";else{var s=100*this.progress.data.current/this.progress.data.total;t=Math.round(s)+"%",r=s.toFixed(1)+"%";var o=parseInt(this.progress.estimatedTotalTime-(this.progress.updatedTime-this.progress.startTime),10);o>=3600?i=Va.sprintf("%d:%02d:%02d left",o/3600,o/60%60,o%60):o>0&&(i=Va.sprintf("%d:%02d left",o/60,o%60))}else this.progress.data.state==="success"?(t="100%",e.push("progress-bar-success"),this._scheduleHide(5e3)):this.progress.data.state==="error"&&(t="100%",e.push("progress-bar-danger"),this._scheduleHide(1e4));return this.$el.html(B1({progress:this.progress,width:t,barClass:e.join(" "),progressClass:u.join(" "),percentText:r,timeLeftText:i})),this},update:function(t){this.progress=t,this.render()},_scheduleHide:function(t){window.setTimeout(()=>{this.$el.fadeOut(500,()=>{this.remove(),this.trigger("g:hide",this.progress)})},t)}});function Ug(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Ug(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function I1(t){var e="",u,r;try{r=1,u="/home/circleci/project/girder/girder/web/src/templates/layout/layoutProgressArea.pug",e=e+'<div class="g-progress-list-container"></div>'}catch(i){Ug(i,u,r)}return e}var qg=Xe.extend({initialize:function(t){this.eventStream=t.eventStream,this.listenTo(this.eventStream,"g:event.progress",this._handleProgress,this),this.listenTo(this.eventStream,"g:eventStream.stop",this._clearProgress,this),this._map={}},render:function(){return this.$el.html(I1()),this._onUpdate(),this},_handleProgress:function(t){xe.has(this._map,t._id)?this._map[t._id].update(t):(this._map[t._id]=new Hg({className:"g-progress-widget-container",progress:t,parentView:null}).on("g:hide",function(e){this._map[e._id].destroy(),delete this._map[e._id],this._onUpdate()},this).render(),this._map[t._id].$el.appendTo(this.$(".g-progress-list-container"))),this._onUpdate()},_clearProgress:function(){const t=!xe.isEmpty(this._map);xe.each(this._map,(e,u)=>{e.destroy(),e.remove(),delete this._map[u]}),t&&this._onUpdate()},_onUpdate:function(){this.$el.toggle(!xe.isEmpty(this._map))}});function O1(t){var e=""+t,u=$1.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var $1=/["&<>]/;function zg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void zg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function N1(t){var e="",u,r,i;try{var s=t||{};(function(o,f){i=1,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<div class="modal-dialog">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<div class="modal-content">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<form class="modal-form" id="g-register-form" role="form">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<div class="modal-header">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+"&times;</button>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<h4 class="modal-title">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+O1((u=f)==null?"":u)+"</h4></div>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<div class="modal-body">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<div class="form-group" id="g-group-login">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<label class="control-label" for="g-login">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+"Choose a login name</label>",i=10,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<input class="input-sm form-control" id="g-login" type="text" placeholder="Login"/></div>',i=11,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<div class="form-group" id="g-group-email">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<label class="control-label" for="g-email">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+"Enter email address</label>",i=13,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<input class="input-sm form-control" id="g-email" type="text" placeholder="Email"/></div>',i=14,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<div class="form-group" id="g-group-firstName">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<label class="control-label" for="g-firstName">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+"Enter first name</label>",i=16,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<input class="input-sm form-control" id="g-firstName" type="text" placeholder="First name"/></div>',i=17,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<div class="form-group" id="g-group-lastName">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<label class="control-label" for="g-lastName">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+"Enter last name</label>",i=19,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<input class="input-sm form-control" id="g-lastName" type="text" placeholder="Last name"/></div>',i=20,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<div class="form-group" id="g-group-password">',i=21,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<label class="control-label" for="g-password">',i=21,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+"Choose a password</label>",i=22,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<input class="input-sm form-control" id="g-password" type="password" placeholder="Password"/></div>',i=23,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<div class="form-group" id="g-group-password2">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<label class="control-label" for="g-password2">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+"Retype password</label>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<input class="input-sm form-control" id="g-password2" type="password" placeholder="Password"/></div>',i=26,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<div class="g-validation-failed-message"></div>',i=27,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",o||(i=28,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<div class="g-bottom-message">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+"Already have an account?",i=30,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<a class="g-login-link">',i=30,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+" Log in here.</a></div>"),e=e+"</div>",i=31,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<div class="modal-footer">',i=32,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<a class="btn btn-default" data-dismiss="modal">',i=32,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+"Close</a>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<button class="btn btn-primary" id="g-register-button" type="submit">',i=34,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+'<i class="icon-plus-circled"></i>',i=35,r="/home/circleci/project/girder/girder/web/src/templates/layout/registerDialog.pug",e=e+" Register</button></div></form></div></div>"}).call(this,"currentUser"in s?s.currentUser:typeof currentUser<"u"?currentUser:void 0,"title"in s?s.title:typeof title<"u"?title:void 0)}catch(o){zg(o,r,i)}return e}var wl=Xe.extend({events:{"submit #g-register-form":function(t){if(t.preventDefault(),this.$(".form-group").removeClass("has-error"),this.$("#g-password").val()!==this.$("#g-password2").val()){this.$("#g-group-password,#g-group-password2").addClass("has-error"),this.$("#g-password").trigger("focus"),this.$(".g-validation-failed-message").text("Passwords must match.");return}var e=new p0({login:this.$("#g-login").val(),password:this.$("#g-password").val(),email:this.$("#g-email").val(),firstName:this.$("#g-firstName").val(),lastName:this.$("#g-lastName").val()});e.on("g:saved",function(){if(ft())this.trigger("g:userCreated",{user:e});else{var u=e.get("authToken")||{};u.token?(hi(e),Lu(u.token),window.localStorage.setItem("girderToken",ll()),He.trigger("g:login")):He.trigger("g:alert",{icon:"ok",text:"Check your email to verify registration.",type:"success",timeout:4e3}),F0("register",{replace:!0})}this.$el.modal("hide")},this).on("g:error",function(u){var r=u.responseJSON;this.$(".g-validation-failed-message").text(r.message),r.field&&(this.$("#g-group-"+r.field).addClass("has-error"),this.$("#g-"+r.field).trigger("focus")),this.$("#g-register-button").girderEnable(!0)},this).save(),this.$("#g-register-button").girderEnable(!1),this.$(".g-validation-failed-message").text("")},"click a.g-login-link":function(){He.trigger("g:loginUi")}},render:function(){return this.$el.html(N1({currentUser:ft(),title:ft()?"Create new user":"Sign up"})).girderModal(this).on("shown.bs.modal",()=>{this.$("#g-login").trigger("focus")}).on("hidden.bs.modal",()=>{F0("register",{replace:!0})}),this.$("#g-login").trigger("focus"),b0("register",{replace:!0}),this}});function Vg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Vg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function W1(t){var e="",u,r;try{var i=t||{};(function(s){r=1,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<div class="modal-dialog">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<div class="modal-content">',r=3,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<form class="modal-form" id="g-reset-password-form" role="form">',r=4,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<div class="modal-header">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+"&times;</button>",r=6,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<h4 class="modal-title">',r=6,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+"Forgotten password</h4></div>",r=7,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<div class="modal-body">',r=8,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<div class="g-password-reset-explanation">',r=9,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+"If you have forgotten your password, enter your email address here.",r=10,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+`
`,r=10,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+"You will be sent an email with a temporary access link, from",r=11,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+`
`,r=11,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+"which you can reset your password.</div>",r=12,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<div class="form-group">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<label class="control-label" for="g-email">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+"Email</label>",r=14,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<input class="input-sm form-control" id="g-email" type="text" placeholder="Enter your email"/></div>',r=15,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<div class="g-validation-failed-message"></div>',r=16,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<div class="g-bottom-message">',r=17,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",s!=="closed"&&(r=18,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<a class="g-register-link">',r=18,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+" Register</a>",r=19,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+" |"),r=20,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<a class="g-login-link">',r=20,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+" Login</a></div></div>",r=21,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<div class="modal-footer">',r=22,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<a class="btn btn-default" data-dismiss="modal">',r=22,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+"Close</a>",r=23,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<button class="btn btn-primary" id="g-reset-password-button" type="submit">',r=24,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+'<i class="icon-mail"></i>',r=25,u="/home/circleci/project/girder/girder/web/src/templates/layout/resetPasswordDialog.pug",e=e+" Submit</button></div></form></div></div>"}).call(this,"registrationPolicy"in i?i.registrationPolicy:typeof registrationPolicy<"u"?registrationPolicy:void 0)}catch(s){Vg(s,u,r)}return e}var Gg=Xe.extend({events:{"submit #g-reset-password-form":function(t){t.preventDefault(),ut({url:"user/password/temporary",data:{email:this.$("#g-email").val().trim()},method:"PUT",error:null}).done(()=>{this.$el.modal("hide"),He.trigger("g:alert",{icon:"mail-alt",text:"Password reset email sent.",type:"success"})}).fail(e=>{this.$(".g-validation-failed-message").text(e.responseJSON.message),this.$("#g-reset-password-button").girderEnable(!0)}),this.$("#g-reset-password-button").girderEnable(!1),this.$(".g-validation-failed-message").text("")},"click a.g-register-link":function(){He.trigger("g:registerUi")},"click a.g-login-link":function(){He.trigger("g:loginUi")}},initialize:function(t){this.registrationPolicy=t.registrationPolicy},render:function(){return this.$el.html(W1({registrationPolicy:this.registrationPolicy})).girderModal(this).on("shown.bs.modal",()=>{this.$("#g-email").trigger("focus")}).on("hidden.bs.modal",()=>{F0("resetpassword",{replace:!0})}),this.$("#g-email").trigger("focus"),b0("resetpassword",{replace:!0}),this}});function qd(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=yl(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Ka(t,e){return Array.isArray(t)?H1(t,e):t&&typeof t=="object"?U1(t):t||""}function H1(t,e){for(var u,r="",i="",s=Array.isArray(e),o=0;o<t.length;o++)(u=Ka(t[o]))&&(s&&e[o]&&(u=yl(u)),r=r+i+u,i=" ");return r}function U1(t){var e="",u="";for(var r in t)r&&t[r]&&q1.call(t,r)&&(e=e+u+r,u=" ");return e}function yl(t){var e=""+t,u=z1.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var q1=Object.prototype.hasOwnProperty,z1=/["&<>]/;function Kg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Kg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function V1(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/layout/alert.pug",e=e+"<div"+qd("class",Ka(["alert","alert-dismissable",`alert-${n}`],[!1,!1,!0]),!1,!1)+">",i=2,r="/home/circleci/project/girder/girder/web/src/templates/layout/alert.pug",e=e+'<button class="close" type="button" data-dismiss="alert" aria-hidden="true">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/layout/alert.pug",e=e+"&times;</button>",i=3,r="/home/circleci/project/girder/girder/web/src/templates/layout/alert.pug",o&&(i=4,r="/home/circleci/project/girder/girder/web/src/templates/layout/alert.pug",e=e+"<i"+qd("class",Ka([`icon-${o}`],[!0]),!1,!1)+"></i>"),i=5,r="/home/circleci/project/girder/girder/web/src/templates/layout/alert.pug",e=e+" ",i=5,r="/home/circleci/project/girder/girder/web/src/templates/layout/alert.pug",e=e+yl((u=f)==null?"":u)+"</div>"}).call(this,"icon"in s?s.icon:typeof icon<"u"?icon:void 0,"text"in s?s.text:typeof text<"u"?text:void 0,"type"in s?s.type:typeof type<"u"?type:void 0)}catch(o){Kg(o,r,i)}return e}function Yg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Yg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function G1(t){var e="",u,r;try{r=1,u="/home/circleci/project/girder/girder/web/src/templates/layout/layout.pug",e=e+'<div id="g-app-header-container"></div>',r=2,u="/home/circleci/project/girder/girder/web/src/templates/layout/layout.pug",e=e+'<div id="g-global-nav-container"></div>',r=3,u="/home/circleci/project/girder/girder/web/src/templates/layout/layout.pug",e=e+'<div class="g-default-layout" id="g-app-body-container"></div>',r=4,u="/home/circleci/project/girder/girder/web/src/templates/layout/layout.pug",e=e+'<div id="g-app-footer-container"></div>',r=6,u="/home/circleci/project/girder/girder/web/src/templates/layout/layout.pug",e=e+'<div id="g-app-progress-container"></div>',r=11,u="/home/circleci/project/girder/girder/web/src/templates/layout/layout.pug",e=e+'<div class="modal fade" id="g-dialog-container" tabindex="-1"></div>',r=12,u="/home/circleci/project/girder/girder/web/src/templates/layout/layout.pug",e=e+'<div id="g-alerts-container"></div>'}catch(i){Yg(i,u,r)}return e}function Jg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Jg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function K1(t){var e="",u,r;try{r=1,u="/home/circleci/project/girder/girder/web/src/templates/body/adminConsole.pug",e=e+'<ul class="g-admin-options">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/body/adminConsole.pug",e=e+"<li>",r=3,u="/home/circleci/project/girder/girder/web/src/templates/body/adminConsole.pug",e=e+'<a class="g-server-config" href="#settings">',r=4,u="/home/circleci/project/girder/girder/web/src/templates/body/adminConsole.pug",e=e+'<i class="icon-cog-alt"></i>',r=5,u="/home/circleci/project/girder/girder/web/src/templates/body/adminConsole.pug",e=e+" Server configuration</a></li>",r=6,u="/home/circleci/project/girder/girder/web/src/templates/body/adminConsole.pug",e=e+"<li>",r=7,u="/home/circleci/project/girder/girder/web/src/templates/body/adminConsole.pug",e=e+'<a class="g-plugins-config" href="#plugins">',r=8,u="/home/circleci/project/girder/girder/web/src/templates/body/adminConsole.pug",e=e+'<i class="icon-puzzle"></i>',r=9,u="/home/circleci/project/girder/girder/web/src/templates/body/adminConsole.pug",e=e+" Plugins</a></li>",r=10,u="/home/circleci/project/girder/girder/web/src/templates/body/adminConsole.pug",e=e+"<li>",r=11,u="/home/circleci/project/girder/girder/web/src/templates/body/adminConsole.pug",e=e+'<a class="g-assetstore-config" href="#assetstores">',r=12,u="/home/circleci/project/girder/girder/web/src/templates/body/adminConsole.pug",e=e+'<i class="icon-box-1"></i>',r=13,u="/home/circleci/project/girder/girder/web/src/templates/body/adminConsole.pug",e=e+" Assetstores</a></li></ul>"}catch(i){Jg(i,u,r)}return e}var Qg=Xe.extend({initialize:function(){x0("fetch"),this.render()},render:function(){if(!ft()||!ft().get("admin")){this.$el.text("Must be logged in as admin to view this page.");return}return this.$el.html(K1()),this}});function Xg(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Xg(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Y1(t){var e="",u,r;try{var i=t||{};(function(s,o){r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="modal-dialog">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="modal-content">',r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<form class="modal-form" id="g-assetstore-edit-form" role="form">',r=4,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="modal-header">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"&times;</button>",r=6,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<h4 class="modal-title">',r=7,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Edit assetstore</h4></div>",r=8,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="modal-body">',r=9,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="g-assetstore-form-fields">',r=10,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="form-group">',r=11,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<label class="control-label" for="g-edit-name">',r=11,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Assetstore Name</label>",r=12,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<input class="input-sm form-control" id="g-edit-name" type="text" placeholder="Name"/></div>',r=13,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",s.get("type")===o.FILESYSTEM&&(r=14,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="form-group">',r=15,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<label class="control-label" for="g-edit-fs-root">',r=15,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Root directory</label>",r=16,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<input class="input-sm form-control" id="g-edit-fs-root" type="text" placeholder="Root directory"/></div>',r=17,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="form-group">',r=18,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<label class="control-label" for="g-edit-fs-perms">',r=18,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"File creation permissions (octal)</label>",r=19,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<input class="input-sm form-control" id="g-edit-fs-perms" type="text" placeholder="600"/></div>'),r=20,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",s.get("type")===o.S3&&(r=21,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="form-group">',r=22,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<label class="control-label" for="g-edit-s3-bucket">',r=22,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"S3 bucket name</label>",r=23,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<input class="input-sm form-control" id="g-edit-s3-bucket" type="text" placeholder="Bucket"/></div>',r=24,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="form-group">',r=25,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<label class="control-label" for="g-edit-s3-prefix">',r=25,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Path prefix (optional)</label>",r=26,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<input class="input-sm form-control" id="g-edit-s3-prefix" type="text" placeholder="Prefix"/></div>',r=27,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="form-group">',r=28,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<label class="control-label" for="g-edit-s3-access-key-id">',r=28,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Access key ID</label>",r=29,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<input class="input-sm form-control" id="g-edit-s3-access-key-id" type="text" placeholder="Access key ID"/></div>',r=30,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="form-group">',r=31,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<label class="control-label" for="g-edit-s3-secret">',r=31,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Secret access key</label>",r=32,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<input class="input-sm form-control" id="g-edit-s3-secret" type="text" placeholder="Secret access key"/></div>',r=33,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="form-group">',r=34,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<label class="control-label" for="g-edit-s3-service">',r=34,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Service</label>",r=35,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<input class="input-sm form-control" id="g-edit-s3-service" type="text" placeholder="Service" title="The service if different from s3.amazonaws.com, such as storage.googleapis.com."/></div>',r=36,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="form-group">',r=37,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<label class="control-label" for="g-edit-s3-region">',r=37,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Region</label>",r=38,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<input class="input-sm form-control" id="g-edit-s3-region" type="text" placeholder="Region"/></div>',r=39,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="checkbox">',r=40,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"<label>",r=41,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<input id="g-edit-s3-infercredentials" type="checkbox"/>',r=42,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Infer Credentials</label></div>",r=43,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="checkbox">',r=44,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"<label>",r=45,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<input id="g-edit-s3-readonly" type="checkbox"/>',r=46,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Read only</label></div>",r=47,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="checkbox">',r=48,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"<label>",r=49,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<input id="g-edit-s3-sse" type="checkbox"/>',r=50,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Server side encryption</label></div>"),e=e+"</div>",r=51,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",s.get("hasFiles")&&(r=52,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"<div>",r=53,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<i class="icon-attention"></i>',r=54,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"",r=54,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"<b>",r=54,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Warning:</b>",r=54,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+" This assetstore contains files.  If you edit where the assetstore is located or how it is reached, those files may become unreachable.</div>"),r=55,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="g-validation-failed-message"></div></div>',r=56,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<div class="modal-footer">',r=57,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',r=57,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Cancel</a>",r=58,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",s.get("hasFiles")?(r=63,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<button class="g-save-assetstore btn btn-small btn-primary btn-danger" type="submit">',r=64,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<i class="icon-edit"></i>',r=65,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Save",r=66,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<i class="icon-attention"></i></button>'):(r=59,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<button class="g-save-assetstore btn btn-small btn-primary" type="submit">',r=60,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+'<i class="icon-edit"></i>',r=61,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editAssetstoreWidget.pug",e=e+"Save</button>"),e=e+"</div></form></div></div>"}).call(this,"assetstore"in i?i.assetstore:typeof assetstore<"u"?assetstore:void 0,"types"in i?i.types:typeof types<"u"?types:void 0)}catch(s){Xg(s,u,r)}return e}var Cl=Xe.extend({events:{"submit #g-assetstore-edit-form":function(t){t.preventDefault();var e=this.fieldsMap[this.model.get("type")].get.call(this);e.name=this.$("#g-edit-name").val(),this.updateAssetstore(e),this.$("button.g-save-assetstore").girderEnable(!1),this.$(".g-validation-failed-message").text("")}},initialize:function(t){this.model=t.model||null},fieldsMap:{},render:function(){var t=this.$el.html(Y1({assetstore:this.model,types:lr})).girderModal(this).on("shown.bs.modal",()=>{this.$("#g-edit-name").trigger("focus"),b0("assetstoreedit",void 0,this.model.get("id")),this.$("#g-edit-name").val(this.model.get("name")),this.fieldsMap[this.model.get("type")].set.call(this)}).on("hidden.bs.modal",()=>{F0("assetstoreedit",void 0,this.model.get("id"))});return t.trigger(ke.Event("ready.girder.modal",{relatedTarget:t})),this},updateAssetstore:function(t){var e={},u=this.model;xe.each(t,function(r,i){e[i]=u.get(i)}),this.model.set(t),this.model.on("g:saved",function(){this.$el.modal("hide"),this.trigger("g:saved",this.model)},this).on("g:error",function(r){this.$(".g-validation-failed-message").text(r.responseJSON.message),this.$("button.g-save-assetstore").girderEnable(!0),this.$("#g-"+r.responseJSON.field).trigger("focus"),this.model.set(e)},this).save()}}),Zg=Cl.prototype.fieldsMap;Zg[lr.FILESYSTEM]={get:function(){return{root:this.$("#g-edit-fs-root").val(),perms:this.$("#g-edit-fs-perms").val()}},set:function(){var t=this.model.get("perms")?this.model.get("perms").toString(8):"600";this.$("#g-edit-fs-perms").val(t),this.$("#g-edit-fs-root").val(this.model.get("root"))}};Zg[lr.S3]={get:function(){return{bucket:this.$("#g-edit-s3-bucket").val(),prefix:this.$("#g-edit-s3-prefix").val(),accessKeyId:this.$("#g-edit-s3-access-key-id").val(),secret:this.$("#g-edit-s3-secret").val(),service:this.$("#g-edit-s3-service").val(),region:this.$("#g-edit-s3-region").val(),readOnly:this.$("#g-edit-s3-readonly").is(":checked"),inferCredentials:this.$("#g-edit-s3-infercredentials").is(":checked"),serverSideEncryption:this.$("#g-edit-s3-sse").is(":checked")}},set:function(){this.$("#g-edit-s3-bucket").val(this.model.get("bucket")),this.$("#g-edit-s3-prefix").val(this.model.get("prefix")),this.$("#g-edit-s3-access-key-id").val(this.model.get("accessKeyId")),this.$("#g-edit-s3-secret").val(this.model.get("secret")),this.$("#g-edit-s3-service").val(this.model.get("service")),this.$("#g-edit-s3-region").val(this.model.get("region")),this.$("#g-edit-s3-readonly").attr("checked",this.model.get("readOnly")?"checked":void 0),this.$("#g-edit-s3-infercredentials").attr("checked",this.model.get("inferCredentials")?"checked":void 0),this.$("#g-edit-s3-sse").attr("checked",this.model.get("serverSideEncryption")?"checked":void 0)}};function ep(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void ep(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function J1(t){var e="",u,r;try{r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="panel-group" id="g-assetstore-accordion">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="panel panel-default">',r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="panel-heading" data-toggle="collapse" data-parent="#g-assetstore-accordion" data-target="#g-create-fs-tab">',r=6,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="panel-title">',r=7,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"<a>",r=8,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<i class="icon-hdd"></i>',r=9,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"<span>",r=9,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Create new ",r=9,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"<b>",r=9,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Filesystem</b>",r=9,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+" assetstore</span></a></div></div>",r=10,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="panel-collapse collapse" id="g-create-fs-tab">',r=11,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="panel-body">',r=12,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"<p>",r=13,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"This type of assetstore will store files in a directory on the",r=14,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+`
`,r=14,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"local filesystem, using content-addressed storage to ensure that",r=15,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+`
`,r=15,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"data is never duplicated on disk. Just specify the root directory",r=16,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+`
`,r=16,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"that files will be stored under.</p>",r=17,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"<p>",r=18,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"If the specified root directory does not already exist, the server",r=19,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+`
`,r=19,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"will attempt to create it.</p>",r=20,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<form id="g-new-fs-form" role="form">',r=21,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="form-group">',r=22,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<label class="control-label" for="g-new-fs-name">',r=22,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Assetstore name</label>",r=23,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input class="input-sm form-control" id="g-new-fs-name" type="text" placeholder="Name"/></div>',r=24,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="form-group">',r=25,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<label class="control-label" for="g-new-fs-root">',r=25,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Root directory</label>",r=26,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input class="input-sm form-control" id="g-new-fs-root" type="text" placeholder="Root directory"/></div>',r=28,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<p class="g-validation-failed-message" id="g-new-fs-error"></p>',r=29,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input class="g-new-assetstore-submit btn btn-sm btn-primary" type="submit" value="Create"/></form></div></div></div>',r=31,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="panel panel-default">',r=32,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="panel-heading" data-toggle="collapse" data-parent="#g-assetstore-accordion" data-target="#g-create-s3-tab">',r=35,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="panel-title">',r=36,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"<a>",r=37,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<i class="icon-upload-cloud"></i>',r=38,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"<span>",r=38,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Create new ",r=38,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"<b>",r=38,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Amazon S3</b>",r=38,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+" assetstore</span></a></div></div>",r=39,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="panel-collapse collapse" id="g-create-s3-tab">',r=40,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="panel-body">',r=41,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"<p>",r=42,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"This type of assetstore keeps files in",r=43,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+`
`,r=43,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"an ",r=43,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<a target="_blank" href="http://aws.amazon.com/s3/">',r=43,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Amazon S3</a>",r=43,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"",r=44,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+`
`,r=44,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"bucket. The service defaults to s3.amazonaws.com. You can specify an",r=45,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+`
`,r=45,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"alternate service, including an optional protocol and port using the",r=46,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+`
`,r=46,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"form [http[s]://](service domain)[:(port)].</p>",r=47,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<form id="g-new-s3-form" role="form">',r=48,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="form-group">',r=49,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<label class="control-label" for="g-new-s3-name">',r=49,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Assetstore name</label>",r=50,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input class="input-sm form-control" id="g-new-s3-name" type="text" placeholder="Name"/></div>',r=51,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="form-group">',r=52,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<label class="control-label" for="g-new-s3-bucket">',r=52,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"S3 bucket name</label>",r=53,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input class="input-sm form-control" id="g-new-s3-bucket" type="text" placeholder="Bucket"/></div>',r=54,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="form-group">',r=55,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<label class="control-label" for="g-new-s3-prefix">',r=55,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Path prefix (optional)</label>",r=56,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input class="input-sm form-control" id="g-new-s3-prefix" type="text" placeholder="Prefix"/></div>',r=57,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="form-group">',r=58,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<label class="control-label" for="g-new-s3-access-key-id">',r=58,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Access key ID</label>",r=59,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input class="input-sm form-control" id="g-new-s3-access-key-id" type="text" placeholder="Access key ID"/></div>',r=60,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="form-group">',r=61,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<label class="control-label" for="g-new-s3-secret">',r=61,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Secret access key</label>",r=62,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input class="input-sm form-control" id="g-new-s3-secret" type="text" placeholder="Secret access key"/></div>',r=63,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="form-group">',r=64,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<label class="control-label" for="g-new-s3-service">',r=64,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Service</label>",r=65,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input class="input-sm form-control" id="g-new-s3-service" type="text" placeholder="Service" title="The service if different from s3.amazonaws.com, such as storage.googleapis.com."/></div>',r=66,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="form-group">',r=67,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<label class="control-label" for="g-new-s3-region">',r=67,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Region</label>",r=68,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input class="input-sm form-control" id="g-new-s3-region" type="text" placeholder="Region"/></div>',r=69,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="checkbox">',r=70,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"<label>",r=71,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input id="g-new-s3-readonly" type="checkbox"/>',r=72,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Read only</label></div>",r=73,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="checkbox">',r=74,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"<label>",r=75,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input id="g-new-s3-infercredentials" type="checkbox"/>',r=76,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Infer Credentials</label></div>",r=77,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<div class="checkbox">',r=78,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"<label>",r=79,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input id="g-new-s3-sse" type="checkbox"/>',r=80,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+"Server side encryption</label></div>",r=82,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<p class="g-validation-failed-message" id="g-new-s3-error"></p>',r=83,u="/home/circleci/project/girder/girder/web/src/templates/widgets/newAssetstore.pug",e=e+'<input class="g-new-assetstore-submit btn btn-sm btn-primary" type="submit" value="Create"/></form></div></div></div></div>'}catch(i){ep(i,u,r)}return e}+function(t){var e=function(s,o){this.$element=t(s),this.options=t.extend({},e.DEFAULTS,o),this.$trigger=t('[data-toggle="collapse"][href="#'+s.id+'"],[data-toggle="collapse"][data-target="#'+s.id+'"]'),this.transitioning=null,this.options.parent?this.$parent=this.getParent():this.addAriaAndCollapsedClass(this.$element,this.$trigger),this.options.toggle&&this.toggle()};e.VERSION="3.4.1",e.TRANSITION_DURATION=350,e.DEFAULTS={toggle:!0},e.prototype.dimension=function(){var s=this.$element.hasClass("width");return s?"width":"height"},e.prototype.show=function(){if(!(this.transitioning||this.$element.hasClass("in"))){var s,o=this.$parent&&this.$parent.children(".panel").children(".in, .collapsing");if(!(o&&o.length&&(s=o.data("bs.collapse"),s&&s.transitioning))){var f=t.Event("show.bs.collapse");if(this.$element.trigger(f),!f.isDefaultPrevented()){o&&o.length&&(r.call(o,"hide"),s||o.data("bs.collapse",null));var n=this.dimension();this.$element.removeClass("collapse").addClass("collapsing")[n](0).attr("aria-expanded",!0),this.$trigger.removeClass("collapsed").attr("aria-expanded",!0),this.transitioning=1;var h=function(){this.$element.removeClass("collapsing").addClass("collapse in")[n](""),this.transitioning=0,this.$element.trigger("shown.bs.collapse")};if(!t.support.transition)return h.call(this);var g=t.camelCase(["scroll",n].join("-"));this.$element.one("bsTransitionEnd",t.proxy(h,this)).emulateTransitionEnd(e.TRANSITION_DURATION)[n](this.$element[0][g])}}}},e.prototype.hide=function(){if(!(this.transitioning||!this.$element.hasClass("in"))){var s=t.Event("hide.bs.collapse");if(this.$element.trigger(s),!s.isDefaultPrevented()){var o=this.dimension();this.$element[o](this.$element[o]())[0].offsetHeight,this.$element.addClass("collapsing").removeClass("collapse in").attr("aria-expanded",!1),this.$trigger.addClass("collapsed").attr("aria-expanded",!1),this.transitioning=1;var f=function(){this.transitioning=0,this.$element.removeClass("collapsing").addClass("collapse").trigger("hidden.bs.collapse")};if(!t.support.transition)return f.call(this);this.$element[o](0).one("bsTransitionEnd",t.proxy(f,this)).emulateTransitionEnd(e.TRANSITION_DURATION)}}},e.prototype.toggle=function(){this[this.$element.hasClass("in")?"hide":"show"]()},e.prototype.getParent=function(){return t(document).find(this.options.parent).find('[data-toggle="collapse"][data-parent="'+this.options.parent+'"]').each(t.proxy(function(s,o){var f=t(o);this.addAriaAndCollapsedClass(u(f),f)},this)).end()},e.prototype.addAriaAndCollapsedClass=function(s,o){var f=s.hasClass("in");s.attr("aria-expanded",f),o.toggleClass("collapsed",!f).attr("aria-expanded",f)};function u(s){var o,f=s.attr("data-target")||(o=s.attr("href"))&&o.replace(/.*(?=#[^\s]+$)/,"");return t(document).find(f)}function r(s){return this.each(function(){var o=t(this),f=o.data("bs.collapse"),n=t.extend({},e.DEFAULTS,o.data(),typeof s=="object"&&s);!f&&n.toggle&&/show|hide/.test(s)&&(n.toggle=!1),f||o.data("bs.collapse",f=new e(this,n)),typeof s=="string"&&f[s]()})}var i=t.fn.collapse;t.fn.collapse=r,t.fn.collapse.Constructor=e,t.fn.collapse.noConflict=function(){return t.fn.collapse=i,this},t(document).on("click.bs.collapse.data-api",'[data-toggle="collapse"]',function(s){var o=t(this);o.attr("data-target")||s.preventDefault();var f=u(o),n=f.data("bs.collapse"),h=n?"toggle":o.data();r.call(f,h)})}(ke);+function(t){function e(){var u=document.createElement("bootstrap"),r={WebkitTransition:"webkitTransitionEnd",MozTransition:"transitionend",OTransition:"oTransitionEnd otransitionend",transition:"transitionend"};for(var i in r)if(u.style[i]!==void 0)return{end:r[i]};return!1}t.fn.emulateTransitionEnd=function(u){var r=!1,i=this;t(this).one("bsTransitionEnd",function(){r=!0});var s=function(){r||t(i).trigger(t.support.transition.end)};return setTimeout(s,u),this},t(function(){t.support.transition=e(),t.support.transition&&(t.event.special.bsTransitionEnd={bindType:t.support.transition.end,delegateType:t.support.transition.end,handle:function(u){if(t(u.target).is(this))return u.handleObj.handler.apply(this,arguments)}})})}(ke);var tp=Xe.extend({events:{"submit #g-new-fs-form":function(t){this.createAssetstore(t,this.$("#g-new-fs-error"),{type:lr.FILESYSTEM,name:this.$("#g-new-fs-name").val(),root:this.$("#g-new-fs-root").val()})},"submit #g-new-s3-form":function(t){this.createAssetstore(t,this.$("#g-new-s3-error"),{type:lr.S3,name:this.$("#g-new-s3-name").val(),bucket:this.$("#g-new-s3-bucket").val(),prefix:this.$("#g-new-s3-prefix").val(),accessKeyId:this.$("#g-new-s3-access-key-id").val(),secret:this.$("#g-new-s3-secret").val(),service:this.$("#g-new-s3-service").val(),region:this.$("#g-new-s3-region").val(),readOnly:this.$("#g-new-s3-readonly").is(":checked"),inferCredentials:this.$("#g-new-s3-infercredentials").is(":checked"),serverSideEncryption:this.$("#g-new-s3-sse").is(":checked")})}},render:function(){return this.$el.html(J1()),this},createAssetstore:function(t,e,u){t.preventDefault(),this.$(".g-new-assetstore-submit").girderEnable(!1),e.empty();var r=new yo;r.set(u),r.on("g:saved",function(){this.$(".g-new-assetstore-submit").girderEnable(!0),this.trigger("g:created",r)},this).on("g:error",function(i){this.$(".g-new-assetstore-submit").girderEnable(!0),e.text(i.responseJSON.message)},this).save()}});function u0(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Kt(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Ya(t,e){return Array.isArray(t)?Q1(t,e):t&&typeof t=="object"?X1(t):t||""}function Q1(t,e){for(var u,r="",i="",s=Array.isArray(e),o=0;o<t.length;o++)(u=Ya(t[o]))&&(s&&e[o]&&(u=Kt(u)),r=r+i+u,i=" ");return r}function X1(t){var e="",u="";for(var r in t)r&&t[r]&&Z1.call(t,r)&&(e=e+u+r,u=" ");return e}function Kt(t){var e=""+t,u=eA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Z1=Object.prototype.hasOwnProperty,eA=/["&<>]/;function rp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void rp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function tA(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<div class="g-current-assetstores-container">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<div class="g-body-title">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Assetstores</div>",i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",o.length?(i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<div class="g-bottom-message">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Below is a list of all of the assetstores available to the server. The",i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+`
`,i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'one set as "current" is the one that uploaded files will be written to.</div>'):(i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<div class="g-bottom-message">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"You must create an assetstore before you can upload files to the server.",i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+`
`,i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Select from the options below to create one.</div>"),i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",function(){var h=o;if(typeof h.length=="number")for(var g=0,d=h.length;g<d;g++){var l=h[g];i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div"+u0("class",Ya(["g-assetstore-container","panel","panel-default",l.get("current")?"g-assetstore-current":void 0],[!1,!1,!1,!0]),!1,!1)+">",i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<div class="panel-body">',i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div"+(' class="g-assetstore-info-section"'+u0("assetstore-type",l.get("type"),!0,!1)+u0("cid",l.cid,!0,!1))+">",i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Name:</b>",i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-name">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("name"))==null?"":u)+"</span>",i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",l.get("current")&&(i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-current-text">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" (Current assetstore)</span>"),e=e+"</div>",i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Unique ID:</b>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-id">',i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.id)==null?"":u)+"</span></div>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",l.get("type")===n.FILESYSTEM?(i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Type:</b>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-type">',i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" Filesystem</span></div>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Root path:</b>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-root">',i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("root"))==null?"":u)+"</span></div>",i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"File creation permissions (octal):</b>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-perms">',i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=(l.get("perms")||384).toString(8))==null?"":u)+"</span></div>"):l.get("type")===n.S3&&(i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Type:</b>",i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-type">',i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" S3</span></div>",i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Bucket:</b>",i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-bucket">',i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("bucket"))==null?"":u)+"</span></div>",i=41,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",l.get("prefix")&&(i=42,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=43,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=43,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Path prefix:</b>",i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-prefix">',i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("prefix"))==null?"":u)+"</span></div>"),i=45,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=46,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=46,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Access key ID:</b>",i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-access-key-id">',i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("accessKeyId"))==null?"":u)+"</span></div>",i=48,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=49,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=49,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Secret access key:</b>",i=50,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-secret-key">',i=50,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=50,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("secret")&&"[hidden]")==null?"":u)+"</span></div>",i=51,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=52,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=52,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Service:</b>",i=53,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-service-key">',i=53,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=53,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("service"))==null?"":u)+"</span></div>",i=54,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=55,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=55,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Region:</b>",i=56,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-region-key">',i=56,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=56,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("region"))==null?"":u)+"</span></div>"),e=e+"</div>",i=58,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",l.capacityKnown()&&(i=59,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=60,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=60,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Capacity:</b>",i=61,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-capacity">',i=61,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=61,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.capacityString())==null?"":u)+"</span>",i=62,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div"+(' class="g-assetstore-capacity-chart"'+u0("cid",l.cid,!0,!1))+"></div></div>"),i=63,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<div class="g-assetstore-buttons">',i=64,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<button"+(' class="g-edit-assetstore btn btn-sm btn-default"'+u0("cid",l.cid,!0,!1))+">",i=65,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Edit</button>",i=66,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",l.get("hasFiles")?(i=70,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<div class="g-assetstore-button-container" title="You must delete all files from the assetstore before you can delete the assetstore.">',i=71,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<button"+(' class="g-delete-assetstore btn btn-sm btn-danger disabled"'+u0("cid",l.cid,!0,!1)+u0("disabled",!0,!0,!1))+">",i=72,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Delete</button></div>"):(i=67,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<button"+(' class="g-delete-assetstore btn btn-sm btn-danger"'+u0("cid",l.cid,!0,!1))+">",i=68,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Delete</button>"),i=73,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",!l.get("current")&&!l.get("readOnly")&&(i=74,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<button"+(' class="g-set-current btn btn-sm btn-primary"'+u0("cid",l.cid,!0,!1))+">",i=75,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Set as current</button>"),i=77,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",f.indexOf(l.get("type"))!==-1&&(i=78,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<div class="g-assetstore-import-button-container">',i=79,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<a"+(' class="g-import-button btn btn-sm btn-success"'+u0("href",`#assetstore/${l.id}/import`,!0,!1))+">",i=80,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<i class="icon-link-ext"></i>',i=81,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" Import data</a></div>"),e=e+"</div></div></div>"}else{var d=0;for(var g in h){d++;var l=h[g];i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div"+u0("class",Ya(["g-assetstore-container","panel","panel-default",l.get("current")?"g-assetstore-current":void 0],[!1,!1,!1,!0]),!1,!1)+">",i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<div class="panel-body">',i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div"+(' class="g-assetstore-info-section"'+u0("assetstore-type",l.get("type"),!0,!1)+u0("cid",l.cid,!0,!1))+">",i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Name:</b>",i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-name">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("name"))==null?"":u)+"</span>",i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",l.get("current")&&(i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-current-text">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" (Current assetstore)</span>"),e=e+"</div>",i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Unique ID:</b>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-id">',i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.id)==null?"":u)+"</span></div>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",l.get("type")===n.FILESYSTEM?(i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Type:</b>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-type">',i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" Filesystem</span></div>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Root path:</b>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-root">',i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("root"))==null?"":u)+"</span></div>",i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"File creation permissions (octal):</b>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-perms">',i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=(l.get("perms")||384).toString(8))==null?"":u)+"</span></div>"):l.get("type")===n.S3&&(i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Type:</b>",i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-type">',i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" S3</span></div>",i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Bucket:</b>",i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-bucket">',i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("bucket"))==null?"":u)+"</span></div>",i=41,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",l.get("prefix")&&(i=42,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=43,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=43,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Path prefix:</b>",i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-prefix">',i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("prefix"))==null?"":u)+"</span></div>"),i=45,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=46,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=46,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Access key ID:</b>",i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-access-key-id">',i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("accessKeyId"))==null?"":u)+"</span></div>",i=48,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=49,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=49,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Secret access key:</b>",i=50,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-secret-key">',i=50,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=50,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("secret")&&"[hidden]")==null?"":u)+"</span></div>",i=51,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=52,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=52,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Service:</b>",i=53,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-service-key">',i=53,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=53,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("service"))==null?"":u)+"</span></div>",i=54,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=55,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=55,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Region:</b>",i=56,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-region-key">',i=56,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=56,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.get("region"))==null?"":u)+"</span></div>"),e=e+"</div>",i=58,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",l.capacityKnown()&&(i=59,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div>",i=60,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<b>",i=60,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Capacity:</b>",i=61,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<span class="g-assetstore-capacity">',i=61,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" ",i=61,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+Kt((u=l.capacityString())==null?"":u)+"</span>",i=62,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<div"+(' class="g-assetstore-capacity-chart"'+u0("cid",l.cid,!0,!1))+"></div></div>"),i=63,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<div class="g-assetstore-buttons">',i=64,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<button"+(' class="g-edit-assetstore btn btn-sm btn-default"'+u0("cid",l.cid,!0,!1))+">",i=65,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Edit</button>",i=66,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",l.get("hasFiles")?(i=70,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<div class="g-assetstore-button-container" title="You must delete all files from the assetstore before you can delete the assetstore.">',i=71,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<button"+(' class="g-delete-assetstore btn btn-sm btn-danger disabled"'+u0("cid",l.cid,!0,!1)+u0("disabled",!0,!0,!1))+">",i=72,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Delete</button></div>"):(i=67,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<button"+(' class="g-delete-assetstore btn btn-sm btn-danger"'+u0("cid",l.cid,!0,!1))+">",i=68,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Delete</button>"),i=73,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",!l.get("current")&&!l.get("readOnly")&&(i=74,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<button"+(' class="g-set-current btn btn-sm btn-primary"'+u0("cid",l.cid,!0,!1))+">",i=75,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"Set as current</button>"),i=77,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",f.indexOf(l.get("type"))!==-1&&(i=78,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<div class="g-assetstore-import-button-container">',i=79,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+"<a"+(' class="g-import-button btn btn-sm btn-success"'+u0("href",`#assetstore/${l.id}/import`,!0,!1))+">",i=80,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<i class="icon-link-ext"></i>',i=81,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+" Import data</a></div>"),e=e+"</div></div></div>"}}}.call(this),e=e+"</div>",i=83,r="/home/circleci/project/girder/girder/web/src/templates/body/assetstores.pug",e=e+'<div id="g-new-assetstore-container"></div>'}).call(this,"assetstores"in s?s.assetstores:typeof assetstores<"u"?assetstores:void 0,"importableTypes"in s?s.importableTypes:typeof importableTypes<"u"?importableTypes:void 0,"types"in s?s.types:typeof types<"u"?types:void 0)}catch(o){rp(o,r,i)}return e}(function(t){var e;t.fn.emptyForce=function(){for(var v=0,E;(E=t(this)[v])!=null;v++){if(E.nodeType===1&&t.cleanData(E.getElementsByTagName("*")),t.jqplot.use_excanvas)E.outerHTML="";else for(;E.firstChild;)E.removeChild(E.firstChild);E=null}return t(this)},t.fn.removeChildForce=function(v){for(;v.firstChild;)this.removeChildForce(v.firstChild),v.removeChild(v.firstChild)},t.fn.jqplot=function(){for(var v=[],E=[],L=0,S=arguments.length;L<S;L++)t.isArray(arguments[L])?v.push(arguments[L]):t.isPlainObject(arguments[L])&&E.push(arguments[L]);return this.each(function(P){var W,K,V=t(this),ee=v.length,Q=E.length,fe,oe;P<ee?fe=v[P]:fe=ee?v[ee-1]:null,P<Q?oe=E[P]:oe=Q?E[Q-1]:null,W=V.attr("id"),W===e&&(W="jqplot_target_"+t.jqplot.targetCounter++,V.attr("id",W)),K=t.jqplot(W,fe,oe),V.data("jqplot",K)})},t.jqplot=function(v,E,L){var S=null,P=null;arguments.length===3?(S=E,P=L):arguments.length===2&&(t.isArray(E)?S=E:t.isPlainObject(E)&&(P=E)),S===null&&P!==null&&P.data&&(S=P.data);var W=new n;if(t("#"+v).removeClass("jqplot-error"),t.jqplot.config.catchErrors)try{return W.init(v,S,P),W.draw(),W.themeEngine.init.call(W),W}catch(V){var K=t.jqplot.config.errorMessage||V.message;t("#"+v).append('<div class="jqplot-error-message">'+K+"</div>"),t("#"+v).addClass("jqplot-error"),document.getElementById(v).style.background=t.jqplot.config.errorBackground,document.getElementById(v).style.border=t.jqplot.config.errorBorder,document.getElementById(v).style.fontFamily=t.jqplot.config.errorFontFamily,document.getElementById(v).style.fontSize=t.jqplot.config.errorFontSize,document.getElementById(v).style.fontStyle=t.jqplot.config.errorFontStyle,document.getElementById(v).style.fontWeight=t.jqplot.config.errorFontWeight}else return W.init(v,S,P),W.draw(),W.themeEngine.init.call(W),W},t.jqplot.version="1.0.8",t.jqplot.revision="1250",t.jqplot.targetCounter=1,t.jqplot.CanvasManager=function(){typeof t.jqplot.CanvasManager.canvases>"u"&&(t.jqplot.CanvasManager.canvases=[],t.jqplot.CanvasManager.free=[]);var v=[];this.getCanvas=function(){var E,L=!0;if(!t.jqplot.use_excanvas){for(var S=0,P=t.jqplot.CanvasManager.canvases.length;S<P;S++)if(t.jqplot.CanvasManager.free[S]===!0){L=!1,E=t.jqplot.CanvasManager.canvases[S],t.jqplot.CanvasManager.free[S]=!1,v.push(S);break}}return L&&(E=document.createElement("canvas"),v.push(t.jqplot.CanvasManager.canvases.length),t.jqplot.CanvasManager.canvases.push(E),t.jqplot.CanvasManager.free.push(!1)),E},this.initCanvas=function(E){return t.jqplot.use_excanvas?window.G_vmlCanvasManager.initElement(E):E},this.freeAllCanvases=function(){for(var E=0,L=v.length;E<L;E++)this.freeCanvas(v[E]);v=[]},this.freeCanvas=function(E){if(t.jqplot.use_excanvas&&window.G_vmlCanvasManager.uninitElement!==e)window.G_vmlCanvasManager.uninitElement(t.jqplot.CanvasManager.canvases[E]),t.jqplot.CanvasManager.canvases[E]=null;else{var L=t.jqplot.CanvasManager.canvases[E];L.getContext("2d").clearRect(0,0,L.width,L.height),t(L).unbind().removeAttr("class").removeAttr("style"),t(L).css({left:"",top:"",position:""}),L.width=0,L.height=0,t.jqplot.CanvasManager.free[E]=!0}}},t.jqplot.log=function(){window.console&&window.console.log.apply(window.console,arguments)},t.jqplot.config={addDomReference:!1,enablePlugins:!1,defaultHeight:300,defaultWidth:400,UTCAdjust:!1,timezoneOffset:new Date(new Date().getTimezoneOffset()*6e4),errorMessage:"",errorBackground:"",errorBorder:"",errorFontFamily:"",errorFontSize:"",errorFontStyle:"",errorFontWeight:"",catchErrors:!1,defaultTickFormatString:"%.1f",defaultColors:["#4bb2c5","#EAA228","#c5b47f","#579575","#839557","#958c12","#953579","#4b5de4","#d8b83f","#ff5800","#0085cc","#c747a3","#cddf54","#FBD178","#26B4E3","#bd70c7"],defaultNegativeColors:["#498991","#C08840","#9F9274","#546D61","#646C4A","#6F6621","#6E3F5F","#4F64B0","#A89050","#C45923","#187399","#945381","#959E5C","#C7AF7B","#478396","#907294"],dashLength:4,gapLength:4,dotGapLength:2.5,srcLocation:"jqplot/src/",pluginLocation:"jqplot/src/plugins/"},t.jqplot.arrayMax=function(v){return Math.max.apply(Math,v)},t.jqplot.arrayMin=function(v){return Math.min.apply(Math,v)},t.jqplot.enablePlugins=t.jqplot.config.enablePlugins,t.jqplot.support_canvas=function(){return typeof t.jqplot.support_canvas.result>"u"&&(t.jqplot.support_canvas.result=!!document.createElement("canvas").getContext),t.jqplot.support_canvas.result},t.jqplot.support_canvas_text=function(){return typeof t.jqplot.support_canvas_text.result>"u"&&(window.G_vmlCanvasManager!==e&&window.G_vmlCanvasManager._version>887?t.jqplot.support_canvas_text.result=!0:t.jqplot.support_canvas_text.result=!!(document.createElement("canvas").getContext&&typeof document.createElement("canvas").getContext("2d").fillText=="function")),t.jqplot.support_canvas_text.result},t.jqplot.use_excanvas=(!t.support.boxModel||!t.support.objectAll||!$support.leadingWhitespace)&&!t.jqplot.support_canvas(),t.jqplot.preInitHooks=[],t.jqplot.postInitHooks=[],t.jqplot.preParseOptionsHooks=[],t.jqplot.postParseOptionsHooks=[],t.jqplot.preDrawHooks=[],t.jqplot.postDrawHooks=[],t.jqplot.preDrawSeriesHooks=[],t.jqplot.postDrawSeriesHooks=[],t.jqplot.preDrawLegendHooks=[],t.jqplot.addLegendRowHooks=[],t.jqplot.preSeriesInitHooks=[],t.jqplot.postSeriesInitHooks=[],t.jqplot.preParseSeriesOptionsHooks=[],t.jqplot.postParseSeriesOptionsHooks=[],t.jqplot.eventListenerHooks=[],t.jqplot.preDrawSeriesShadowHooks=[],t.jqplot.postDrawSeriesShadowHooks=[],t.jqplot.ElemContainer=function(){this._elem,this._plotWidth,this._plotHeight,this._plotDimensions={height:null,width:null}},t.jqplot.ElemContainer.prototype.createElement=function(v,E,L,S,P){this._offsets=E;var W=L||"jqplot",K=document.createElement(v);return this._elem=t(K),this._elem.addClass(W),this._elem.css(S),this._elem.attr(P),K=null,this._elem},t.jqplot.ElemContainer.prototype.getWidth=function(){return this._elem?this._elem.outerWidth(!0):null},t.jqplot.ElemContainer.prototype.getHeight=function(){return this._elem?this._elem.outerHeight(!0):null},t.jqplot.ElemContainer.prototype.getPosition=function(){return this._elem?this._elem.position():{top:null,left:null,bottom:null,right:null}},t.jqplot.ElemContainer.prototype.getTop=function(){return this.getPosition().top},t.jqplot.ElemContainer.prototype.getLeft=function(){return this.getPosition().left},t.jqplot.ElemContainer.prototype.getBottom=function(){return this._elem.css("bottom")},t.jqplot.ElemContainer.prototype.getRight=function(){return this._elem.css("right")};function u(v){t.jqplot.ElemContainer.call(this),this.name=v,this._series=[],this.show=!1,this.tickRenderer=t.jqplot.AxisTickRenderer,this.tickOptions={},this.labelRenderer=t.jqplot.AxisLabelRenderer,this.labelOptions={},this.label=null,this.showLabel=!0,this.min=null,this.max=null,this.autoscale=!1,this.pad=1.2,this.padMax=null,this.padMin=null,this.ticks=[],this.numberTicks,this.tickInterval,this.renderer=t.jqplot.LinearAxisRenderer,this.rendererOptions={},this.showTicks=!0,this.showTickMarks=!0,this.showMinorTicks=!0,this.drawMajorGridlines=!0,this.drawMinorGridlines=!1,this.drawMajorTickMarks=!0,this.drawMinorTickMarks=!0,this.useSeriesColor=!1,this.borderWidth=null,this.borderColor=null,this.scaleToHiddenSeries=!1,this._dataBounds={min:null,max:null},this._intervalStats=[],this._offsets={min:null,max:null},this._ticks=[],this._label=null,this.syncTicks=null,this.tickSpacing=75,this._min=null,this._max=null,this._tickInterval=null,this._numberTicks=null,this.__ticks=null,this._options={}}u.prototype=new t.jqplot.ElemContainer,u.prototype.constructor=u,u.prototype.init=function(){t.isFunction(this.renderer)&&(this.renderer=new this.renderer),this.tickOptions.axis=this.name,this.tickOptions.showMark==null&&(this.tickOptions.showMark=this.showTicks),this.tickOptions.showMark==null&&(this.tickOptions.showMark=this.showTickMarks),this.tickOptions.showLabel==null&&(this.tickOptions.showLabel=this.showTicks),this.label==null||this.label==""?this.showLabel=!1:this.labelOptions.label=this.label,this.showLabel==!1&&(this.labelOptions.show=!1),this.pad==0&&(this.pad=1),this.padMax==0&&(this.padMax=1),this.padMin==0&&(this.padMin=1),this.padMax==null&&(this.padMax=(this.pad-1)/2+1),this.padMin==null&&(this.padMin=(this.pad-1)/2+1),this.pad=this.padMax+this.padMin-1,(this.min!=null||this.max!=null)&&(this.autoscale=!1),this.syncTicks==null&&this.name.indexOf("y")>-1?this.syncTicks=!0:this.syncTicks==null&&(this.syncTicks=!1),this.renderer.init.call(this,this.rendererOptions)},u.prototype.draw=function(v,E){return this.__ticks&&(this.__ticks=null),this.renderer.draw.call(this,v,E)},u.prototype.set=function(){this.renderer.set.call(this)},u.prototype.pack=function(v,E){this.show&&this.renderer.pack.call(this,v,E),this._min==null&&(this._min=this.min,this._max=this.max,this._tickInterval=this.tickInterval,this._numberTicks=this.numberTicks,this.__ticks=this._ticks)},u.prototype.reset=function(){this.renderer.reset.call(this)},u.prototype.resetScale=function(v){t.extend(!0,this,{min:null,max:null,numberTicks:null,tickInterval:null,_ticks:[],ticks:[]},v),this.resetDataBounds()},u.prototype.resetDataBounds=function(){var v=this._dataBounds;v.min=null,v.max=null;for(var E,L,S,P=!!this.show,W=0;W<this._series.length;W++)if(L=this._series[W],L.show||this.scaleToHiddenSeries){S=L._plotData,L._type==="line"&&L.renderer.bands.show&&this.name.charAt(0)!=="x"&&(S=[[0,L.renderer.bands._min],[1,L.renderer.bands._max]]);var K=1,V=1;L._type!=null&&L._type=="ohlc"&&(K=3,V=2);for(var ee=0,E=S.length;ee<E;ee++)this.name=="xaxis"||this.name=="x2axis"?((S[ee][0]!=null&&S[ee][0]<v.min||v.min==null)&&(v.min=S[ee][0]),(S[ee][0]!=null&&S[ee][0]>v.max||v.max==null)&&(v.max=S[ee][0])):((S[ee][K]!=null&&S[ee][K]<v.min||v.min==null)&&(v.min=S[ee][K]),(S[ee][V]!=null&&S[ee][V]>v.max||v.max==null)&&(v.max=S[ee][V]));P&&L.renderer.constructor!==t.jqplot.BarRenderer||P&&this._options.hasOwnProperty("forceTickAt0")&&this._options.forceTickAt0==!1?P=!1:P&&L.renderer.constructor===t.jqplot.BarRenderer&&(L.barDirection=="vertical"&&this.name!="xaxis"&&this.name!="x2axis"?(this._options.pad!=null||this._options.padMin!=null)&&(P=!1):L.barDirection=="horizontal"&&(this.name=="xaxis"||this.name=="x2axis")&&(this._options.pad!=null||this._options.padMin!=null)&&(P=!1))}P&&this.renderer.constructor===t.jqplot.LinearAxisRenderer&&v.min>=0&&(this.padMin=1,this.forceTickAt0=!0)};function r(v){t.jqplot.ElemContainer.call(this),this.show=!1,this.location="ne",this.labels=[],this.showLabels=!0,this.showSwatches=!0,this.placement="insideGrid",this.xoffset=0,this.yoffset=0,this.border,this.background,this.textColor,this.fontFamily,this.fontSize,this.rowSpacing="0.5em",this.renderer=t.jqplot.TableLegendRenderer,this.rendererOptions={},this.preDraw=!1,this.marginTop=null,this.marginRight=null,this.marginBottom=null,this.marginLeft=null,this.escapeHtml=!1,this._series=[],t.extend(!0,this,v)}r.prototype=new t.jqplot.ElemContainer,r.prototype.constructor=r,r.prototype.setOptions=function(v){if(t.extend(!0,this,v),this.placement=="inside"&&(this.placement="insideGrid"),this.xoffset>0){if(this.placement=="insideGrid")switch(this.location){case"nw":case"w":case"sw":this.marginLeft==null&&(this.marginLeft=this.xoffset+"px"),this.marginRight="0px";break;case"ne":case"e":case"se":default:this.marginRight==null&&(this.marginRight=this.xoffset+"px"),this.marginLeft="0px";break}else if(this.placement=="outside")switch(this.location){case"nw":case"w":case"sw":this.marginRight==null&&(this.marginRight=this.xoffset+"px"),this.marginLeft="0px";break;case"ne":case"e":case"se":default:this.marginLeft==null&&(this.marginLeft=this.xoffset+"px"),this.marginRight="0px";break}this.xoffset=0}if(this.yoffset>0){if(this.placement=="outside")switch(this.location){case"sw":case"s":case"se":this.marginTop==null&&(this.marginTop=this.yoffset+"px"),this.marginBottom="0px";break;case"ne":case"n":case"nw":default:this.marginBottom==null&&(this.marginBottom=this.yoffset+"px"),this.marginTop="0px";break}else if(this.placement=="insideGrid")switch(this.location){case"sw":case"s":case"se":this.marginBottom==null&&(this.marginBottom=this.yoffset+"px"),this.marginTop="0px";break;case"ne":case"n":case"nw":default:this.marginTop==null&&(this.marginTop=this.yoffset+"px"),this.marginBottom="0px";break}this.yoffset=0}},r.prototype.init=function(){t.isFunction(this.renderer)&&(this.renderer=new this.renderer),this.renderer.init.call(this,this.rendererOptions)},r.prototype.draw=function(v,E){for(var L=0;L<t.jqplot.preDrawLegendHooks.length;L++)t.jqplot.preDrawLegendHooks[L].call(this,v);return this.renderer.draw.call(this,v,E)},r.prototype.pack=function(v){this.renderer.pack.call(this,v)};function i(v){t.jqplot.ElemContainer.call(this),this.text=v,this.show=!0,this.fontFamily,this.fontSize,this.textAlign,this.textColor,this.renderer=t.jqplot.DivTitleRenderer,this.rendererOptions={},this.escapeHtml=!1}i.prototype=new t.jqplot.ElemContainer,i.prototype.constructor=i,i.prototype.init=function(){t.isFunction(this.renderer)&&(this.renderer=new this.renderer),this.renderer.init.call(this,this.rendererOptions)},i.prototype.draw=function(v){return this.renderer.draw.call(this,v)},i.prototype.pack=function(){this.renderer.pack.call(this)};function s(v){t.jqplot.ElemContainer.call(this),this.show=!0,this.xaxis="xaxis",this._xaxis,this.yaxis="yaxis",this._yaxis,this.gridBorderWidth=2,this.renderer=t.jqplot.LineRenderer,this.rendererOptions={},this.data=[],this.gridData=[],this.label="",this.showLabel=!0,this.color,this.negativeColor,this.lineWidth=2.5,this.lineJoin="round",this.lineCap="round",this.linePattern="solid",this.shadow=!0,this.shadowAngle=45,this.shadowOffset=1.25,this.shadowDepth=3,this.shadowAlpha="0.1",this.breakOnNull=!1,this.markerRenderer=t.jqplot.MarkerRenderer,this.markerOptions={},this.showLine=!0,this.showMarker=!0,this.index,this.fill=!1,this.fillColor,this.fillAlpha,this.fillAndStroke=!1,this.disableStack=!1,this._stack=!1,this.neighborThreshold=4,this.fillToZero=!1,this.fillToValue=0,this.fillAxis="y",this.useNegativeColors=!0,this._stackData=[],this._plotData=[],this._plotValues={x:[],y:[]},this._intervals={x:{},y:{}},this._prevPlotData=[],this._prevGridData=[],this._stackAxis="y",this._primaryAxis="_xaxis",this.canvas=new t.jqplot.GenericCanvas,this.shadowCanvas=new t.jqplot.GenericCanvas,this.plugins={},this._sumy=0,this._sumx=0,this._type=""}s.prototype=new t.jqplot.ElemContainer,s.prototype.constructor=s,s.prototype.init=function(v,E,L){this.index=v,this.gridBorderWidth=E;var S=this.data,P=[],W,K;for(W=0,K=S.length;W<K;W++)if(this.breakOnNull)P.push(S[W]);else{if(S[W]==null||S[W][0]==null||S[W][1]==null)continue;P.push(S[W])}if(this.data=P,this.color||(this.color=L.colorGenerator.get(this.index)),this.negativeColor||(this.negativeColor=L.negativeColorGenerator.get(this.index)),this.fillColor||(this.fillColor=this.color),this.fillAlpha){var V=t.jqplot.normalize2rgb(this.fillColor),V=t.jqplot.getColorComponents(V);this.fillColor="rgba("+V[0]+","+V[1]+","+V[2]+","+this.fillAlpha+")"}t.isFunction(this.renderer)&&(this.renderer=new this.renderer),this.renderer.init.call(this,this.rendererOptions,L),this.markerRenderer=new this.markerRenderer,this.markerOptions.color||(this.markerOptions.color=this.color),this.markerOptions.show==null&&(this.markerOptions.show=this.showMarker),this.showMarker=this.markerOptions.show,this.markerRenderer.init(this.markerOptions)},s.prototype.draw=function(v,E,L){var S=E==e?{}:E;v=v==e?this.canvas._ctx:v;var P,W,K;for(P=0;P<t.jqplot.preDrawSeriesHooks.length;P++)t.jqplot.preDrawSeriesHooks[P].call(this,v,S);for(this.show&&(this.renderer.setGridData.call(this,L),S.preventJqPlotSeriesDrawTrigger||t(v.canvas).trigger("jqplotSeriesDraw",[this.data,this.gridData]),W=[],S.data?W=S.data:this._stack?W=this._plotData:W=this.data,K=S.gridData||this.renderer.makeGridData.call(this,W,L),this._type==="line"&&this.renderer.smooth&&this.renderer._smoothedData.length&&(K=this.renderer._smoothedData),this.renderer.draw.call(this,v,K,S,L)),P=0;P<t.jqplot.postDrawSeriesHooks.length;P++)t.jqplot.postDrawSeriesHooks[P].call(this,v,S,L);v=E=L=P=W=K=null},s.prototype.drawShadow=function(v,E,L){var S=E==e?{}:E;v=v==e?this.shadowCanvas._ctx:v;var P,W,K;for(P=0;P<t.jqplot.preDrawSeriesShadowHooks.length;P++)t.jqplot.preDrawSeriesShadowHooks[P].call(this,v,S);for(this.shadow&&(this.renderer.setGridData.call(this,L),W=[],S.data?W=S.data:this._stack?W=this._plotData:W=this.data,K=S.gridData||this.renderer.makeGridData.call(this,W,L),this.renderer.drawShadow.call(this,v,K,S,L)),P=0;P<t.jqplot.postDrawSeriesShadowHooks.length;P++)t.jqplot.postDrawSeriesShadowHooks[P].call(this,v,S);v=E=L=P=W=K=null},s.prototype.toggleDisplay=function(v,E){var L,S;v.data.series?L=v.data.series:L=this,v.data.speed&&(S=v.data.speed),S?L.canvas._elem.is(":hidden")||!L.show?(L.show=!0,L.canvas._elem.removeClass("jqplot-series-hidden"),L.shadowCanvas._elem&&L.shadowCanvas._elem.fadeIn(S),L.canvas._elem.fadeIn(S,E),L.canvas._elem.nextAll(".jqplot-point-label.jqplot-series-"+L.index).fadeIn(S)):(L.show=!1,L.canvas._elem.addClass("jqplot-series-hidden"),L.shadowCanvas._elem&&L.shadowCanvas._elem.fadeOut(S),L.canvas._elem.fadeOut(S,E),L.canvas._elem.nextAll(".jqplot-point-label.jqplot-series-"+L.index).fadeOut(S)):L.canvas._elem.is(":hidden")||!L.show?(L.show=!0,L.canvas._elem.removeClass("jqplot-series-hidden"),L.shadowCanvas._elem&&L.shadowCanvas._elem.show(),L.canvas._elem.show(0,E),L.canvas._elem.nextAll(".jqplot-point-label.jqplot-series-"+L.index).show()):(L.show=!1,L.canvas._elem.addClass("jqplot-series-hidden"),L.shadowCanvas._elem&&L.shadowCanvas._elem.hide(),L.canvas._elem.hide(0,E),L.canvas._elem.nextAll(".jqplot-point-label.jqplot-series-"+L.index).hide())};function o(){t.jqplot.ElemContainer.call(this),this.drawGridlines=!0,this.gridLineColor="#cccccc",this.gridLineWidth=1,this.background="#fffdf6",this.borderColor="#999999",this.borderWidth=2,this.drawBorder=!0,this.shadow=!0,this.shadowAngle=45,this.shadowOffset=1.5,this.shadowWidth=3,this.shadowDepth=3,this.shadowColor=null,this.shadowAlpha="0.07",this._left,this._top,this._right,this._bottom,this._width,this._height,this._axes=[],this.renderer=t.jqplot.CanvasGridRenderer,this.rendererOptions={},this._offsets={top:null,bottom:null,left:null,right:null}}o.prototype=new t.jqplot.ElemContainer,o.prototype.constructor=o,o.prototype.init=function(){t.isFunction(this.renderer)&&(this.renderer=new this.renderer),this.renderer.init.call(this,this.rendererOptions)},o.prototype.createElement=function(v,E){return this._offsets=v,this.renderer.createElement.call(this,E)},o.prototype.draw=function(){this.renderer.draw.call(this)},t.jqplot.GenericCanvas=function(){t.jqplot.ElemContainer.call(this),this._ctx},t.jqplot.GenericCanvas.prototype=new t.jqplot.ElemContainer,t.jqplot.GenericCanvas.prototype.constructor=t.jqplot.GenericCanvas,t.jqplot.GenericCanvas.prototype.createElement=function(v,E,L,S){this._offsets=v;var P="jqplot";E!=e&&(P=E);var W;return W=S.canvasManager.getCanvas(),L!=null&&(this._plotDimensions=L),W.width=this._plotDimensions.width-this._offsets.left-this._offsets.right,W.height=this._plotDimensions.height-this._offsets.top-this._offsets.bottom,this._elem=t(W),this._elem.css({position:"absolute",left:this._offsets.left,top:this._offsets.top}),this._elem.addClass(P),W=S.canvasManager.initCanvas(W),W=null,this._elem},t.jqplot.GenericCanvas.prototype.setContext=function(){return this._ctx=this._elem.get(0).getContext("2d"),this._ctx},t.jqplot.GenericCanvas.prototype.resetCanvas=function(){this._elem&&(t.jqplot.use_excanvas&&window.G_vmlCanvasManager.uninitElement!==e&&window.G_vmlCanvasManager.uninitElement(this._elem.get(0)),this._elem.emptyForce()),this._ctx=null},t.jqplot.HooksManager=function(){this.hooks=[],this.args=[]},t.jqplot.HooksManager.prototype.addOnce=function(v,E){E=E||[];for(var L=!1,S=0,P=this.hooks.length;S<P;S++)this.hooks[S]==v&&(L=!0);L||(this.hooks.push(v),this.args.push(E))},t.jqplot.HooksManager.prototype.add=function(v,E){E=E||[],this.hooks.push(v),this.args.push(E)},t.jqplot.EventListenerManager=function(){this.hooks=[]},t.jqplot.EventListenerManager.prototype.addOnce=function(v,E){for(var L=!1,S,P,P=0,W=this.hooks.length;P<W;P++)S=this.hooks[P],S[0]==v&&S[1]==E&&(L=!0);L||this.hooks.push([v,E])},t.jqplot.EventListenerManager.prototype.add=function(v,E){this.hooks.push([v,E])};var f=["yMidAxis","xaxis","yaxis","x2axis","y2axis","y3axis","y4axis","y5axis","y6axis","y7axis","y8axis","y9axis"];function n(){this.animate=!1,this.animateReplot=!1,this.axes={xaxis:new u("xaxis"),yaxis:new u("yaxis"),x2axis:new u("x2axis"),y2axis:new u("y2axis"),y3axis:new u("y3axis"),y4axis:new u("y4axis"),y5axis:new u("y5axis"),y6axis:new u("y6axis"),y7axis:new u("y7axis"),y8axis:new u("y8axis"),y9axis:new u("y9axis"),yMidAxis:new u("yMidAxis")},this.baseCanvas=new t.jqplot.GenericCanvas,this.captureRightClick=!1,this.data=[],this.dataRenderer,this.dataRendererOptions,this.defaults={axesDefaults:{},axes:{xaxis:{},yaxis:{},x2axis:{},y2axis:{},y3axis:{},y4axis:{},y5axis:{},y6axis:{},y7axis:{},y8axis:{},y9axis:{},yMidAxis:{}},seriesDefaults:{},series:[]},this.defaultAxisStart=1,this.drawIfHidden=!1,this.eventCanvas=new t.jqplot.GenericCanvas,this.fillBetween={series1:null,series2:null,color:null,baseSeries:0,fill:!0},this.fontFamily,this.fontSize,this.grid=new o,this.legend=new r,this.noDataIndicator={show:!1,indicator:"Loading Data...",axes:{xaxis:{min:0,max:10,tickInterval:2,show:!0},yaxis:{min:0,max:12,tickInterval:3,show:!0}}},this.negativeSeriesColors=t.jqplot.config.defaultNegativeColors,this.options={},this.previousSeriesStack=[],this.plugins={},this.series=[],this.seriesStack=[],this.seriesColors=t.jqplot.config.defaultColors,this.sortData=!0,this.stackSeries=!1,this.syncXTicks=!0,this.syncYTicks=!0,this.target=null,this.targetId=null,this.textColor,this.title=new i,this._drawCount=0,this._sumy=0,this._sumx=0,this._stackData=[],this._plotData=[],this._width=null,this._height=null,this._plotDimensions={height:null,width:null},this._gridPadding={top:null,right:null,bottom:null,left:null},this._defaultGridPadding={top:10,right:10,bottom:23,left:10},this._addDomReference=t.jqplot.config.addDomReference,this.preInitHooks=new t.jqplot.HooksManager,this.postInitHooks=new t.jqplot.HooksManager,this.preParseOptionsHooks=new t.jqplot.HooksManager,this.postParseOptionsHooks=new t.jqplot.HooksManager,this.preDrawHooks=new t.jqplot.HooksManager,this.postDrawHooks=new t.jqplot.HooksManager,this.preDrawSeriesHooks=new t.jqplot.HooksManager,this.postDrawSeriesHooks=new t.jqplot.HooksManager,this.preDrawLegendHooks=new t.jqplot.HooksManager,this.addLegendRowHooks=new t.jqplot.HooksManager,this.preSeriesInitHooks=new t.jqplot.HooksManager,this.postSeriesInitHooks=new t.jqplot.HooksManager,this.preParseSeriesOptionsHooks=new t.jqplot.HooksManager,this.postParseSeriesOptionsHooks=new t.jqplot.HooksManager,this.eventListenerHooks=new t.jqplot.EventListenerManager,this.preDrawSeriesShadowHooks=new t.jqplot.HooksManager,this.postDrawSeriesShadowHooks=new t.jqplot.HooksManager,this.colorGenerator=new t.jqplot.ColorGenerator,this.negativeColorGenerator=new t.jqplot.ColorGenerator,this.canvasManager=new t.jqplot.CanvasManager,this.themeEngine=new t.jqplot.ThemeEngine,this.init=function(S,P,W){W=W||{};for(var K=0;K<t.jqplot.preInitHooks.length;K++)t.jqplot.preInitHooks[K].call(this,S,P,W);for(var K=0;K<this.preInitHooks.hooks.length;K++)this.preInitHooks.hooks[K].call(this,S,P,W);if(this.targetId="#"+S,this.target=t("#"+S),this._addDomReference&&this.target.data("jqplot",this),this.target.removeClass("jqplot-error"),!this.target.get(0))throw new Error("No plot target specified");if(this.target.css("position")=="static"&&this.target.css("position","relative"),this.target.hasClass("jqplot-target")||this.target.addClass("jqplot-target"),this.target.height())this._height=V=this.target.height();else{var V;W&&W.height?V=parseInt(W.height,10):this.target.attr("data-height")?V=parseInt(this.target.attr("data-height"),10):V=parseInt(t.jqplot.config.defaultHeight,10),this._height=V,this.target.css("height",V+"px")}if(this.target.width())this._width=ee=this.target.width();else{var ee;W&&W.width?ee=parseInt(W.width,10):this.target.attr("data-width")?ee=parseInt(this.target.attr("data-width"),10):ee=parseInt(t.jqplot.config.defaultWidth,10),this._width=ee,this.target.css("width",ee+"px")}for(var K=0,Q=f.length;K<Q;K++)this.axes[f[K]]=new u(f[K]);if(this._plotDimensions.height=this._height,this._plotDimensions.width=this._width,this.grid._plotDimensions=this._plotDimensions,this.title._plotDimensions=this._plotDimensions,this.baseCanvas._plotDimensions=this._plotDimensions,this.eventCanvas._plotDimensions=this._plotDimensions,this.legend._plotDimensions=this._plotDimensions,this._height<=0||this._width<=0||!this._height||!this._width)throw new Error("Canvas dimension not set");if(W.dataRenderer&&t.isFunction(W.dataRenderer)&&(W.dataRendererOptions&&(this.dataRendererOptions=W.dataRendererOptions),this.dataRenderer=W.dataRenderer,P=this.dataRenderer(P,this,this.dataRendererOptions)),W.noDataIndicator&&t.isPlainObject(W.noDataIndicator)&&t.extend(!0,this.noDataIndicator,W.noDataIndicator),P==null||t.isArray(P)==!1||P.length==0||t.isArray(P[0])==!1||P[0].length==0){if(this.noDataIndicator.show==!1)throw new Error("No data specified");for(var fe in this.noDataIndicator.axes)for(var oe in this.noDataIndicator.axes[fe])this.axes[fe][oe]=this.noDataIndicator.axes[fe][oe];this.postDrawHooks.add(function(){var Se=this.eventCanvas.getHeight(),ze=this.eventCanvas.getWidth(),Ve=t('<div class="jqplot-noData-container" style="position:absolute;"></div>');this.target.append(Ve),Ve.height(Se),Ve.width(ze),Ve.css("top",this.eventCanvas._offsets.top),Ve.css("left",this.eventCanvas._offsets.left);var Me=t('<div class="jqplot-noData-contents" style="text-align:center; position:relative; margin-left:auto; margin-right:auto;"></div>');Ve.append(Me),Me.html(this.noDataIndicator.indicator);var Le=Me.height(),Be=Me.width();Me.height(Le),Me.width(Be),Me.css("top",(Se-Le)/2+"px")})}this.data=t.extend(!0,[],P),this.parseOptions(W),this.textColor&&this.target.css("color",this.textColor),this.fontFamily&&this.target.css("font-family",this.fontFamily),this.fontSize&&this.target.css("font-size",this.fontSize),this.title.init(),this.legend.init(),this._sumy=0,this._sumx=0,this.computePlotData();for(var K=0;K<this.series.length;K++){this.seriesStack.push(K),this.previousSeriesStack.push(K),this.series[K].shadowCanvas._plotDimensions=this._plotDimensions,this.series[K].canvas._plotDimensions=this._plotDimensions;for(var pe=0;pe<t.jqplot.preSeriesInitHooks.length;pe++)t.jqplot.preSeriesInitHooks[pe].call(this.series[K],S,this.data,this.options.seriesDefaults,this.options.series[K],this);for(var pe=0;pe<this.preSeriesInitHooks.hooks.length;pe++)this.preSeriesInitHooks.hooks[pe].call(this.series[K],S,this.data,this.options.seriesDefaults,this.options.series[K],this);this.series[K]._plotDimensions=this._plotDimensions,this.series[K].init(K,this.grid.borderWidth,this);for(var pe=0;pe<t.jqplot.postSeriesInitHooks.length;pe++)t.jqplot.postSeriesInitHooks[pe].call(this.series[K],S,this.data,this.options.seriesDefaults,this.options.series[K],this);for(var pe=0;pe<this.postSeriesInitHooks.hooks.length;pe++)this.postSeriesInitHooks.hooks[pe].call(this.series[K],S,this.data,this.options.seriesDefaults,this.options.series[K],this);this._sumy+=this.series[K]._sumy,this._sumx+=this.series[K]._sumx}for(var ae,Ae,K=0,Q=f.length;K<Q;K++)ae=f[K],Ae=this.axes[ae],Ae._plotDimensions=this._plotDimensions,Ae.init(),this.axes[ae].borderColor==null&&(ae.charAt(0)!=="x"&&Ae.useSeriesColor===!0&&Ae.show?Ae.borderColor=Ae._series[0].color:Ae.borderColor=this.grid.borderColor);this.sortData&&v(this.series),this.grid.init(),this.grid._axes=this.axes,this.legend._series=this.series;for(var K=0;K<t.jqplot.postInitHooks.length;K++)t.jqplot.postInitHooks[K].call(this,S,this.data,W);for(var K=0;K<this.postInitHooks.hooks.length;K++)this.postInitHooks.hooks[K].call(this,S,this.data,W)},this.resetAxesScale=function(S,P){var W=P||{},K=S||this.axes;if(K===!0&&(K=this.axes),t.isArray(K))for(var V=0;V<K.length;V++)this.axes[K[V]].resetScale(W[K[V]]);else if(typeof K=="object")for(var ee in K)this.axes[ee].resetScale(W[ee])},this.reInitialize=function(S,P){for(var W=t.extend(!0,{},this.options,P),K=this.targetId.substr(1),V=S??this.data,ee=0;ee<t.jqplot.preInitHooks.length;ee++)t.jqplot.preInitHooks[ee].call(this,K,V,W);for(var ee=0;ee<this.preInitHooks.hooks.length;ee++)this.preInitHooks.hooks[ee].call(this,K,V,W);if(this._height=this.target.height(),this._width=this.target.width(),this._height<=0||this._width<=0||!this._height||!this._width)throw new Error("Target dimension not set");this._plotDimensions.height=this._height,this._plotDimensions.width=this._width,this.grid._plotDimensions=this._plotDimensions,this.title._plotDimensions=this._plotDimensions,this.baseCanvas._plotDimensions=this._plotDimensions,this.eventCanvas._plotDimensions=this._plotDimensions,this.legend._plotDimensions=this._plotDimensions;for(var Q,fe,oe,pe,ee=0,ae=f.length;ee<ae;ee++){Q=f[ee],pe=this.axes[Q],fe=pe._ticks;for(var oe=0,Ae=fe.length;oe<Ae;oe++){var Se=fe[oe]._elem;Se&&(t.jqplot.use_excanvas&&window.G_vmlCanvasManager.uninitElement!==e&&window.G_vmlCanvasManager.uninitElement(Se.get(0)),Se.emptyForce(),Se=null,fe._elem=null)}fe=null,delete pe.ticks,delete pe._ticks,this.axes[Q]=new u(Q),this.axes[Q]._plotWidth=this._width,this.axes[Q]._plotHeight=this._height}S&&(W.dataRenderer&&t.isFunction(W.dataRenderer)&&(W.dataRendererOptions&&(this.dataRendererOptions=W.dataRendererOptions),this.dataRenderer=W.dataRenderer,S=this.dataRenderer(S,this,this.dataRendererOptions)),this.data=t.extend(!0,[],S)),P&&this.parseOptions(W),this.title._plotWidth=this._width,this.textColor&&this.target.css("color",this.textColor),this.fontFamily&&this.target.css("font-family",this.fontFamily),this.fontSize&&this.target.css("font-size",this.fontSize),this.title.init(),this.legend.init(),this._sumy=0,this._sumx=0,this.seriesStack=[],this.previousSeriesStack=[],this.computePlotData();for(var ee=0,ae=this.series.length;ee<ae;ee++){this.seriesStack.push(ee),this.previousSeriesStack.push(ee),this.series[ee].shadowCanvas._plotDimensions=this._plotDimensions,this.series[ee].canvas._plotDimensions=this._plotDimensions;for(var oe=0;oe<t.jqplot.preSeriesInitHooks.length;oe++)t.jqplot.preSeriesInitHooks[oe].call(this.series[ee],K,this.data,this.options.seriesDefaults,this.options.series[ee],this);for(var oe=0;oe<this.preSeriesInitHooks.hooks.length;oe++)this.preSeriesInitHooks.hooks[oe].call(this.series[ee],K,this.data,this.options.seriesDefaults,this.options.series[ee],this);this.series[ee]._plotDimensions=this._plotDimensions,this.series[ee].init(ee,this.grid.borderWidth,this);for(var oe=0;oe<t.jqplot.postSeriesInitHooks.length;oe++)t.jqplot.postSeriesInitHooks[oe].call(this.series[ee],K,this.data,this.options.seriesDefaults,this.options.series[ee],this);for(var oe=0;oe<this.postSeriesInitHooks.hooks.length;oe++)this.postSeriesInitHooks.hooks[oe].call(this.series[ee],K,this.data,this.options.seriesDefaults,this.options.series[ee],this);this._sumy+=this.series[ee]._sumy,this._sumx+=this.series[ee]._sumx}for(var ee=0,ae=f.length;ee<ae;ee++)Q=f[ee],pe=this.axes[Q],pe._plotDimensions=this._plotDimensions,pe.init(),pe.borderColor==null&&(Q.charAt(0)!=="x"&&pe.useSeriesColor===!0&&pe.show?pe.borderColor=pe._series[0].color:pe.borderColor=this.grid.borderColor);this.sortData&&v(this.series),this.grid.init(),this.grid._axes=this.axes,this.legend._series=this.series;for(var ee=0,ae=t.jqplot.postInitHooks.length;ee<ae;ee++)t.jqplot.postInitHooks[ee].call(this,K,this.data,W);for(var ee=0,ae=this.postInitHooks.hooks.length;ee<ae;ee++)this.postInitHooks.hooks[ee].call(this,K,this.data,W)},this.quickInit=function(){if(this._height=this.target.height(),this._width=this.target.width(),this._height<=0||this._width<=0||!this._height||!this._width)throw new Error("Target dimension not set");this._plotDimensions.height=this._height,this._plotDimensions.width=this._width,this.grid._plotDimensions=this._plotDimensions,this.title._plotDimensions=this._plotDimensions,this.baseCanvas._plotDimensions=this._plotDimensions,this.eventCanvas._plotDimensions=this._plotDimensions,this.legend._plotDimensions=this._plotDimensions;for(var S in this.axes)this.axes[S]._plotWidth=this._width,this.axes[S]._plotHeight=this._height;this.title._plotWidth=this._width,this.textColor&&this.target.css("color",this.textColor),this.fontFamily&&this.target.css("font-family",this.fontFamily),this.fontSize&&this.target.css("font-size",this.fontSize),this._sumy=0,this._sumx=0,this.computePlotData();for(var P=0;P<this.series.length;P++)this.series[P]._type==="line"&&this.series[P].renderer.bands.show&&this.series[P].renderer.initBands.call(this.series[P],this.series[P].renderer.options,this),this.series[P]._plotDimensions=this._plotDimensions,this.series[P].canvas._plotDimensions=this._plotDimensions,this._sumy+=this.series[P]._sumy,this._sumx+=this.series[P]._sumx;for(var W,K=0;K<12;K++){W=f[K];for(var V=this.axes[W]._ticks,P=0;P<V.length;P++){var ee=V[P]._elem;ee&&(t.jqplot.use_excanvas&&window.G_vmlCanvasManager.uninitElement!==e&&window.G_vmlCanvasManager.uninitElement(ee.get(0)),ee.emptyForce(),ee=null,V._elem=null)}V=null,this.axes[W]._plotDimensions=this._plotDimensions,this.axes[W]._ticks=[]}this.sortData&&v(this.series),this.grid._axes=this.axes,this.legend._series=this.series};function v(S){for(var P,W=0;W<S.length;W++)for(var K,V=[S[W].data,S[W]._stackData,S[W]._plotData,S[W]._prevPlotData],ee=0;ee<4;ee++)if(K=!0,P=V[ee],S[W]._stackAxis=="x"){for(var Q=0;Q<P.length;Q++)if(typeof P[Q][1]!="number"){K=!1;break}K&&P.sort(function(fe,oe){return fe[1]-oe[1]})}else{for(var Q=0;Q<P.length;Q++)if(typeof P[Q][0]!="number"){K=!1;break}K&&P.sort(function(fe,oe){return fe[0]-oe[0]})}}this.computePlotData=function(){this._plotData=[],this._stackData=[];var S,P,W;for(P=0,W=this.series.length;P<W;P++){S=this.series[P],this._plotData.push([]),this._stackData.push([]);var K=S.data;this._plotData[P]=t.extend(!0,[],K),this._stackData[P]=t.extend(!0,[],K),S._plotData=this._plotData[P],S._stackData=this._stackData[P];var V={x:[],y:[]};if(this.stackSeries&&!S.disableStack){S._stack=!0;for(var ee=S._stackAxis==="x"?0:1,Q=0,fe=K.length;Q<fe;Q++){var oe=K[Q][ee];if(oe==null&&(oe=0),this._plotData[P][Q][ee]=oe,this._stackData[P][Q][ee]=oe,P>0)for(var pe=P;pe--;){var ae=this._plotData[pe][Q][ee];if(oe*ae>=0){this._plotData[P][Q][ee]+=ae,this._stackData[P][Q][ee]+=ae;break}}}}else{for(var Ae=0;Ae<S.data.length;Ae++)V.x.push(S.data[Ae][0]),V.y.push(S.data[Ae][1]);this._stackData.push(S.data),this.series[P]._stackData=S.data,this._plotData.push(S.data),S._plotData=S.data,S._plotValues=V}for(P>0&&(S._prevPlotData=this.series[P-1]._plotData),S._sumy=0,S._sumx=0,Ae=S.data.length-1;Ae>-1;Ae--)S._sumy+=S.data[Ae][1],S._sumx+=S.data[Ae][0]}},this.populatePlotData=function(S,P){this._plotData=[],this._stackData=[],S._stackData=[],S._plotData=[];var W={x:[],y:[]};if(this.stackSeries&&!S.disableStack){S._stack=!0;for(var K=S._stackAxis==="x"?0:1,V=t.extend(!0,[],S.data),ee=t.extend(!0,[],S.data),Q,fe,oe,pe,ae=0;ae<P;ae++)for(var Ae=this.series[ae].data,Se=0;Se<Ae.length;Se++)oe=Ae[Se],Q=oe[0]!=null?oe[0]:0,fe=oe[1]!=null?oe[1]:0,V[Se][0]+=Q,V[Se][1]+=fe,pe=K?fe:Q,S.data[Se][K]*pe>=0&&(ee[Se][K]+=pe);for(var ze=0;ze<ee.length;ze++)W.x.push(ee[ze][0]),W.y.push(ee[ze][1]);this._plotData.push(ee),this._stackData.push(V),S._stackData=V,S._plotData=ee,S._plotValues=W}else{for(var ze=0;ze<S.data.length;ze++)W.x.push(S.data[ze][0]),W.y.push(S.data[ze][1]);this._stackData.push(S.data),this.series[P]._stackData=S.data,this._plotData.push(S.data),S._plotData=S.data,S._plotValues=W}for(P>0&&(S._prevPlotData=this.series[P-1]._plotData),S._sumy=0,S._sumx=0,ze=S.data.length-1;ze>-1;ze--)S._sumy+=S.data[ze][1],S._sumx+=S.data[ze][0]},this.getNextSeriesColor=function(S){var P=0,W=S.seriesColors;return function(){return P<W.length||(P=0),W[P++]}}(this),this.parseOptions=function(S){for(var P=0;P<this.preParseOptionsHooks.hooks.length;P++)this.preParseOptionsHooks.hooks[P].call(this,S);for(var P=0;P<t.jqplot.preParseOptionsHooks.length;P++)t.jqplot.preParseOptionsHooks[P].call(this,S);this.options=t.extend(!0,{},this.defaults,S);var W=this.options;if(this.animate=W.animate,this.animateReplot=W.animateReplot,this.stackSeries=W.stackSeries,t.isPlainObject(W.fillBetween))for(var K=["series1","series2","color","baseSeries","fill"],V,P=0,ee=K.length;P<ee;P++)V=K[P],W.fillBetween[V]!=null&&(this.fillBetween[V]=W.fillBetween[V]);W.seriesColors&&(this.seriesColors=W.seriesColors),W.negativeSeriesColors&&(this.negativeSeriesColors=W.negativeSeriesColors),W.captureRightClick&&(this.captureRightClick=W.captureRightClick),this.defaultAxisStart=S&&S.defaultAxisStart!=null?S.defaultAxisStart:this.defaultAxisStart,this.colorGenerator.setColors(this.seriesColors),this.negativeColorGenerator.setColors(this.negativeSeriesColors),t.extend(!0,this._gridPadding,W.gridPadding),this.sortData=W.sortData!=null?W.sortData:this.sortData;for(var P=0;P<12;P++){var Q=f[P],fe=this.axes[Q];fe._options=t.extend(!0,{},W.axesDefaults,W.axes[Q]),t.extend(!0,fe,W.axesDefaults,W.axes[Q]),fe._plotWidth=this._width,fe._plotHeight=this._height}var oe=function(Se,ze,Ve){var Me=[],Le,Be;if(ze=ze||"vertical",t.isArray(Se[0]))t.extend(!0,Me,Se);else for(Le=0,Be=Se.length;Le<Be;Le++)ze=="vertical"?Me.push([Ve+Le,Se[Le]]):Me.push([Se[Le],Ve+Le]);return Me};this.series=[];for(var P=0;P<this.data.length;P++){for(var pe=t.extend(!0,{index:P},{seriesColors:this.seriesColors,negativeSeriesColors:this.negativeSeriesColors},this.options.seriesDefaults,this.options.series[P],{rendererOptions:{animation:{show:this.animate}}}),K=new s,ae=0;ae<t.jqplot.preParseSeriesOptionsHooks.length;ae++)t.jqplot.preParseSeriesOptionsHooks[ae].call(K,this.options.seriesDefaults,this.options.series[P]);for(var ae=0;ae<this.preParseSeriesOptionsHooks.hooks.length;ae++)this.preParseSeriesOptionsHooks.hooks[ae].call(K,this.options.seriesDefaults,this.options.series[P]);t.extend(!0,K,pe);var Ae="vertical";switch(K.renderer===t.jqplot.BarRenderer&&K.rendererOptions&&K.rendererOptions.barDirection=="horizontal"&&(Ae="horizontal",K._stackAxis="x",K._primaryAxis="_yaxis"),K.data=oe(this.data[P],Ae,this.defaultAxisStart),K.xaxis){case"xaxis":K._xaxis=this.axes.xaxis;break;case"x2axis":K._xaxis=this.axes.x2axis;break}K._yaxis=this.axes[K.yaxis],K._xaxis._series.push(K),K._yaxis._series.push(K),K.show?(K._xaxis.show=!0,K._yaxis.show=!0):(K._xaxis.scaleToHiddenSeries&&(K._xaxis.show=!0),K._yaxis.scaleToHiddenSeries&&(K._yaxis.show=!0)),K.label||(K.label="Series "+(P+1).toString()),this.series.push(K);for(var ae=0;ae<t.jqplot.postParseSeriesOptionsHooks.length;ae++)t.jqplot.postParseSeriesOptionsHooks[ae].call(this.series[P],this.options.seriesDefaults,this.options.series[P]);for(var ae=0;ae<this.postParseSeriesOptionsHooks.hooks.length;ae++)this.postParseSeriesOptionsHooks.hooks[ae].call(this.series[P],this.options.seriesDefaults,this.options.series[P])}t.extend(!0,this.grid,this.options.grid);for(var P=0,ee=f.length;P<ee;P++){var Q=f[P],fe=this.axes[Q];fe.borderWidth==null&&(fe.borderWidth=this.grid.borderWidth)}typeof this.options.title=="string"?this.title.text=this.options.title:typeof this.options.title=="object"&&t.extend(!0,this.title,this.options.title),this.title._plotWidth=this._width,this.legend.setOptions(this.options.legend);for(var P=0;P<t.jqplot.postParseOptionsHooks.length;P++)t.jqplot.postParseOptionsHooks[P].call(this,S);for(var P=0;P<this.postParseOptionsHooks.hooks.length;P++)this.postParseOptionsHooks.hooks[P].call(this,S)},this.destroy=function(){this.canvasManager.freeAllCanvases(),this.eventCanvas&&this.eventCanvas._elem&&this.eventCanvas._elem.unbind(),this.target.empty(),this.target[0].innerHTML=""},this.replot=function(S){var P=S||{},W=P.data||null,K=P.clear!==!1,V=P.resetAxes||!1;delete P.data,delete P.clear,delete P.resetAxes,this.target.trigger("jqplotPreReplot"),K&&this.destroy(),W||!t.isEmptyObject(P)?this.reInitialize(W,P):this.quickInit(),V&&this.resetAxesScale(V,P.axes),this.draw(),this.target.trigger("jqplotPostReplot")},this.redraw=function(S){S=S??!0,this.target.trigger("jqplotPreRedraw"),S&&(this.canvasManager.freeAllCanvases(),this.eventCanvas._elem.unbind(),this.target.empty());for(var P in this.axes)this.axes[P]._ticks=[];this.computePlotData(),this._sumy=0,this._sumx=0;for(var W=0,K=this.series.length;W<K;W++)this._sumy+=this.series[W]._sumy,this._sumx+=this.series[W]._sumx;this.draw(),this.target.trigger("jqplotPostRedraw")},this.draw=function(){if(this.drawIfHidden||this.target.is(":visible")){this.target.trigger("jqplotPreDraw");var S,P,W;for(S=0,W=t.jqplot.preDrawHooks.length;S<W;S++)t.jqplot.preDrawHooks[S].call(this);for(S=0,W=this.preDrawHooks.hooks.length;S<W;S++)this.preDrawHooks.hooks[S].apply(this,this.preDrawSeriesHooks.args[S]);this.target.append(this.baseCanvas.createElement({left:0,right:0,top:0,bottom:0},"jqplot-base-canvas",null,this)),this.baseCanvas.setContext(),this.target.append(this.title.draw()),this.title.pack({top:0,left:0});var K=this.legend.draw({},this),V={top:0,left:0,bottom:0,right:0};if(this.legend.placement=="outsideGrid"){switch(this.target.append(K),this.legend.location){case"n":V.top+=this.legend.getHeight();break;case"s":V.bottom+=this.legend.getHeight();break;case"ne":case"e":case"se":V.right+=this.legend.getWidth();break;case"nw":case"w":case"sw":V.left+=this.legend.getWidth();break;default:V.right+=this.legend.getWidth();break}K=K.detach()}var ee=this.axes,Q;for(S=0;S<12;S++)Q=f[S],this.target.append(ee[Q].draw(this.baseCanvas._ctx,this)),ee[Q].set();ee.yaxis.show&&(V.left+=ee.yaxis.getWidth());var fe=["y2axis","y3axis","y4axis","y5axis","y6axis","y7axis","y8axis","y9axis"],oe=[0,0,0,0,0,0,0,0],pe=0,ae;for(ae=0;ae<8;ae++)ee[fe[ae]].show&&(pe+=ee[fe[ae]].getWidth(),oe[ae]=pe);if(V.right+=pe,ee.x2axis.show&&(V.top+=ee.x2axis.getHeight()),this.title.show&&(V.top+=this.title.getHeight()),ee.xaxis.show&&(V.bottom+=ee.xaxis.getHeight()),this.options.gridDimensions&&t.isPlainObject(this.options.gridDimensions)){var Ae=parseInt(this.options.gridDimensions.width,10)||0,Se=parseInt(this.options.gridDimensions.height,10)||0,ze=(this._width-V.left-V.right-Ae)/2,Ve=(this._height-V.top-V.bottom-Se)/2;Ve>=0&&ze>=0&&(V.top+=Ve,V.bottom+=Ve,V.left+=ze,V.right+=ze)}var Me=["top","bottom","left","right"];for(var ae in Me)this._gridPadding[Me[ae]]==null&&V[Me[ae]]>0?this._gridPadding[Me[ae]]=V[Me[ae]]:this._gridPadding[Me[ae]]==null&&(this._gridPadding[Me[ae]]=this._defaultGridPadding[Me[ae]]);var Le=this._gridPadding;for(this.legend.placement==="outsideGrid"&&(Le={top:this.title.getHeight(),left:0,right:0,bottom:0},this.legend.location==="s"&&(Le.left=this._gridPadding.left,Le.right=this._gridPadding.right)),ee.xaxis.pack({position:"absolute",bottom:this._gridPadding.bottom-ee.xaxis.getHeight(),left:0,width:this._width},{min:this._gridPadding.left,max:this._width-this._gridPadding.right}),ee.yaxis.pack({position:"absolute",top:0,left:this._gridPadding.left-ee.yaxis.getWidth(),height:this._height},{min:this._height-this._gridPadding.bottom,max:this._gridPadding.top}),ee.x2axis.pack({position:"absolute",top:this._gridPadding.top-ee.x2axis.getHeight(),left:0,width:this._width},{min:this._gridPadding.left,max:this._width-this._gridPadding.right}),S=8;S>0;S--)ee[fe[S-1]].pack({position:"absolute",top:0,right:this._gridPadding.right-oe[S-1]},{min:this._height-this._gridPadding.bottom,max:this._gridPadding.top});var Be=(this._width-this._gridPadding.left-this._gridPadding.right)/2+this._gridPadding.left-ee.yMidAxis.getWidth()/2;ee.yMidAxis.pack({position:"absolute",top:0,left:Be,zIndex:9,textAlign:"center"},{min:this._height-this._gridPadding.bottom,max:this._gridPadding.top}),this.target.append(this.grid.createElement(this._gridPadding,this)),this.grid.draw();var Je=this.series,Ue=Je.length;for(S=0,W=Ue;S<W;S++)P=this.seriesStack[S],this.target.append(Je[P].shadowCanvas.createElement(this._gridPadding,"jqplot-series-shadowCanvas",null,this)),Je[P].shadowCanvas.setContext(),Je[P].shadowCanvas._elem.data("seriesIndex",P);for(S=0,W=Ue;S<W;S++)P=this.seriesStack[S],this.target.append(Je[P].canvas.createElement(this._gridPadding,"jqplot-series-canvas",null,this)),Je[P].canvas.setContext(),Je[P].canvas._elem.data("seriesIndex",P);this.target.append(this.eventCanvas.createElement(this._gridPadding,"jqplot-event-canvas",null,this)),this.eventCanvas.setContext(),this.eventCanvas._ctx.fillStyle="rgba(0,0,0,0)",this.eventCanvas._ctx.fillRect(0,0,this.eventCanvas._ctx.canvas.width,this.eventCanvas._ctx.canvas.height),this.bindCustomEvents(),this.legend.preDraw?(this.eventCanvas._elem.before(K),this.legend.pack(Le),this.legend._elem?this.drawSeries({legendInfo:{location:this.legend.location,placement:this.legend.placement,width:this.legend.getWidth(),height:this.legend.getHeight(),xoffset:this.legend.xoffset,yoffset:this.legend.yoffset}}):this.drawSeries()):(this.drawSeries(),Ue&&t(Je[Ue-1].canvas._elem).after(K),this.legend.pack(Le));for(var S=0,W=t.jqplot.eventListenerHooks.length;S<W;S++)this.eventCanvas._elem.bind(t.jqplot.eventListenerHooks[S][0],{plot:this},t.jqplot.eventListenerHooks[S][1]);for(var S=0,W=this.eventListenerHooks.hooks.length;S<W;S++)this.eventCanvas._elem.bind(this.eventListenerHooks.hooks[S][0],{plot:this},this.eventListenerHooks.hooks[S][1]);var Ge=this.fillBetween;Ge.fill&&Ge.series1!==Ge.series2&&Ge.series1<Ue&&Ge.series2<Ue&&Je[Ge.series1]._type==="line"&&Je[Ge.series2]._type==="line"&&this.doFillBetweenLines();for(var S=0,W=t.jqplot.postDrawHooks.length;S<W;S++)t.jqplot.postDrawHooks[S].call(this);for(var S=0,W=this.postDrawHooks.hooks.length;S<W;S++)this.postDrawHooks.hooks[S].apply(this,this.postDrawHooks.args[S]);this.target.is(":visible")&&(this._drawCount+=1);var lt,et,vt,Ft;for(S=0,W=Ue;S<W;S++)lt=Je[S],et=lt.renderer,vt=".jqplot-point-label.jqplot-series-"+S,et.animation&&et.animation._supported&&et.animation.show&&(this._drawCount<2||this.animateReplot)&&(Ft=this.target.find(vt),Ft.stop(!0,!0).hide(),lt.canvas._elem.stop(!0,!0).hide(),lt.shadowCanvas._elem.stop(!0,!0).hide(),lt.canvas._elem.jqplotEffect("blind",{mode:"show",direction:et.animation.direction},et.animation.speed),lt.shadowCanvas._elem.jqplotEffect("blind",{mode:"show",direction:et.animation.direction},et.animation.speed),Ft.fadeIn(et.animation.speed*.8));Ft=null,this.target.trigger("jqplotPostDraw",[this])}},n.prototype.doFillBetweenLines=function(){var S=this.fillBetween,P=S.series1,W=S.series2,K=P<W?P:W,V=W>P?W:P,ee=this.series[K],Q=this.series[V];if(Q.renderer.smooth)var fe=Q.renderer._smoothedData.slice(0).reverse();else var fe=Q.gridData.slice(0).reverse();if(ee.renderer.smooth)var oe=ee.renderer._smoothedData.concat(fe);else var oe=ee.gridData.concat(fe);var pe=S.color!==null?S.color:this.series[P].fillColor,ae=S.baseSeries!==null?S.baseSeries:K,Ae=this.series[ae].renderer.shapeRenderer,Se={fillStyle:pe,fill:!0,closePath:!0};Ae.draw(ee.shadowCanvas._ctx,oe,Se)},this.bindCustomEvents=function(){this.eventCanvas._elem.bind("click",{plot:this},this.onClick),this.eventCanvas._elem.bind("dblclick",{plot:this},this.onDblClick),this.eventCanvas._elem.bind("mousedown",{plot:this},this.onMouseDown),this.eventCanvas._elem.bind("mousemove",{plot:this},this.onMouseMove),this.eventCanvas._elem.bind("mouseenter",{plot:this},this.onMouseEnter),this.eventCanvas._elem.bind("mouseleave",{plot:this},this.onMouseLeave),this.captureRightClick?(this.eventCanvas._elem.bind("mouseup",{plot:this},this.onRightClick),this.eventCanvas._elem.get(0).oncontextmenu=function(){return!1}):this.eventCanvas._elem.bind("mouseup",{plot:this},this.onMouseUp)};function E(S){var P=S.data.plot,W=P.eventCanvas._elem.offset(),K={x:S.pageX-W.left,y:S.pageY-W.top},V={xaxis:null,yaxis:null,x2axis:null,y2axis:null,y3axis:null,y4axis:null,y5axis:null,y6axis:null,y7axis:null,y8axis:null,y9axis:null,yMidAxis:null},ee=["xaxis","yaxis","x2axis","y2axis","y3axis","y4axis","y5axis","y6axis","y7axis","y8axis","y9axis","yMidAxis"],Q=P.axes,fe,oe;for(fe=11;fe>0;fe--)oe=ee[fe-1],Q[oe].show&&(V[oe]=Q[oe].series_p2u(K[oe.charAt(0)]));return{offsets:W,gridPos:K,dataPos:V}}function L(S,P){var W=P.series,K,V,ee,Q,fe,oe,pe,ae,Ae,Se,ze,Ve,Me,Le,Be,Je,Ue,Ge,lt;for(ee=P.seriesStack.length-1;ee>=0;ee--)switch(K=P.seriesStack[ee],Q=W[K],Ue=Q._highlightThreshold,Q.renderer.constructor){case t.jqplot.BarRenderer:for(oe=S.x,pe=S.y,V=0;V<Q._barPoints.length;V++)if(Je=Q._barPoints[V],Be=Q.gridData[V],oe>Je[0][0]&&oe<Je[2][0]&&pe>Je[2][1]&&pe<Je[0][1])return{seriesIndex:Q.index,pointIndex:V,gridData:Be,data:Q.data[V],points:Q._barPoints[V]};break;case t.jqplot.PyramidRenderer:for(oe=S.x,pe=S.y,V=0;V<Q._barPoints.length;V++)if(Je=Q._barPoints[V],Be=Q.gridData[V],oe>Je[0][0]+Ue[0][0]&&oe<Je[2][0]+Ue[2][0]&&pe>Je[2][1]&&pe<Je[0][1])return{seriesIndex:Q.index,pointIndex:V,gridData:Be,data:Q.data[V],points:Q._barPoints[V]};break;case t.jqplot.DonutRenderer:if(Se=Q.startAngle/180*Math.PI,oe=S.x-Q._center[0],pe=S.y-Q._center[1],fe=Math.sqrt(Math.pow(oe,2)+Math.pow(pe,2)),oe>0&&-pe>=0?ae=2*Math.PI-Math.atan(-pe/oe):oe>0&&-pe<0?ae=-Math.atan(-pe/oe):oe<0?ae=Math.PI-Math.atan(-pe/oe):oe==0&&-pe>0?ae=3*Math.PI/2:oe==0&&-pe<0?ae=Math.PI/2:oe==0&&pe==0&&(ae=0),Se&&(ae-=Se,ae<0?ae+=2*Math.PI:ae>2*Math.PI&&(ae-=2*Math.PI)),Ae=Q.sliceMargin/180*Math.PI,fe<Q._radius&&fe>Q._innerRadius){for(V=0;V<Q.gridData.length;V++)if(ze=V>0?Q.gridData[V-1][1]+Ae:Ae,Ve=Q.gridData[V][1],ae>ze&&ae<Ve)return{seriesIndex:Q.index,pointIndex:V,gridData:[S.x,S.y],data:Q.data[V]}}break;case t.jqplot.PieRenderer:if(Se=Q.startAngle/180*Math.PI,oe=S.x-Q._center[0],pe=S.y-Q._center[1],fe=Math.sqrt(Math.pow(oe,2)+Math.pow(pe,2)),oe>0&&-pe>=0?ae=2*Math.PI-Math.atan(-pe/oe):oe>0&&-pe<0?ae=-Math.atan(-pe/oe):oe<0?ae=Math.PI-Math.atan(-pe/oe):oe==0&&-pe>0?ae=3*Math.PI/2:oe==0&&-pe<0?ae=Math.PI/2:oe==0&&pe==0&&(ae=0),Se&&(ae-=Se,ae<0?ae+=2*Math.PI:ae>2*Math.PI&&(ae-=2*Math.PI)),Ae=Q.sliceMargin/180*Math.PI,fe<Q._radius){for(V=0;V<Q.gridData.length;V++)if(ze=V>0?Q.gridData[V-1][1]+Ae:Ae,Ve=Q.gridData[V][1],ae>ze&&ae<Ve)return{seriesIndex:Q.index,pointIndex:V,gridData:[S.x,S.y],data:Q.data[V]}}break;case t.jqplot.BubbleRenderer:oe=S.x,pe=S.y;var et=null;if(Q.show){for(var V=0;V<Q.gridData.length;V++)Be=Q.gridData[V],Le=Math.sqrt((oe-Be[0])*(oe-Be[0])+(pe-Be[1])*(pe-Be[1])),Le<=Be[2]&&(Le<=Me||Me==null)&&(Me=Le,et={seriesIndex:K,pointIndex:V,gridData:Be,data:Q.data[V]});if(et!=null)return et}break;case t.jqplot.FunnelRenderer:let Dr=function(tr,h0,k0){var Mr=(h0[1]-k0[1])/(h0[0]-k0[0]),rr=h0[1]-Mr*h0[0],R0=tr+h0[1];return[(R0-rr)/Mr,R0]};var Uu=Dr;oe=S.x,pe=S.y;var vt=Q._vertices,Ft=vt[0],bt=vt[vt.length-1],Ht,kt,Bt;for(Ht=Dr(pe,Ft[0],bt[3]),kt=Dr(pe,Ft[1],bt[2]),V=0;V<vt.length;V++)if(Bt=vt[V],pe>=Bt[0][1]&&pe<=Bt[3][1]&&oe>=Ht[0]&&oe<=kt[0])return{seriesIndex:Q.index,pointIndex:V,gridData:null,data:Q.data[V]};break;case t.jqplot.LineRenderer:if(oe=S.x,pe=S.y,fe=Q.renderer,Q.show)if((Q.fill||Q.renderer.bands.show&&Q.renderer.bands.fill)&&(!P.plugins.highlighter||!P.plugins.highlighter.show)){var st=!1;if(oe>Q._boundingBox[0][0]&&oe<Q._boundingBox[1][0]&&pe>Q._boundingBox[1][1]&&pe<Q._boundingBox[0][1])for(var Vt=Q._areaPoints.length,it,V=Vt-1,it=0;it<Vt;it++){var St=[Q._areaPoints[it][0],Q._areaPoints[it][1]],It=[Q._areaPoints[V][0],Q._areaPoints[V][1]];(St[1]<pe&&It[1]>=pe||It[1]<pe&&St[1]>=pe)&&St[0]+(pe-St[1])/(It[1]-St[1])*(It[0]-St[0])<oe&&(st=!st),V=it}if(st)return{seriesIndex:K,pointIndex:null,gridData:Q.gridData,data:Q.data,points:Q._areaPoints};break}else{lt=Q.markerRenderer.size/2+Q.neighborThreshold,Ge=lt>0?lt:0;for(var V=0;V<Q.gridData.length;V++)if(Be=Q.gridData[V],fe.constructor==t.jqplot.OHLCRenderer)if(fe.candleStick){var Dt=Q._yaxis.series_u2p;if(oe>=Be[0]-fe._bodyWidth/2&&oe<=Be[0]+fe._bodyWidth/2&&pe>=Dt(Q.data[V][2])&&pe<=Dt(Q.data[V][3]))return{seriesIndex:K,pointIndex:V,gridData:Be,data:Q.data[V]}}else if(fe.hlc){var Dt=Q._yaxis.series_u2p;if(oe>=Be[0]-fe._tickLength&&oe<=Be[0]+fe._tickLength&&pe>=Dt(Q.data[V][1])&&pe<=Dt(Q.data[V][2]))return{seriesIndex:K,pointIndex:V,gridData:Be,data:Q.data[V]}}else{var Dt=Q._yaxis.series_u2p;if(oe>=Be[0]-fe._tickLength&&oe<=Be[0]+fe._tickLength&&pe>=Dt(Q.data[V][2])&&pe<=Dt(Q.data[V][3]))return{seriesIndex:K,pointIndex:V,gridData:Be,data:Q.data[V]}}else if(Be[0]!=null&&Be[1]!=null&&(Le=Math.sqrt((oe-Be[0])*(oe-Be[0])+(pe-Be[1])*(pe-Be[1])),Le<=Ge&&(Le<=Me||Me==null)))return Me=Le,{seriesIndex:K,pointIndex:V,gridData:Be,data:Q.data[V]}}break;default:if(oe=S.x,pe=S.y,fe=Q.renderer,Q.show){lt=Q.markerRenderer.size/2+Q.neighborThreshold,Ge=lt>0?lt:0;for(var V=0;V<Q.gridData.length;V++)if(Be=Q.gridData[V],fe.constructor==t.jqplot.OHLCRenderer)if(fe.candleStick){var Dt=Q._yaxis.series_u2p;if(oe>=Be[0]-fe._bodyWidth/2&&oe<=Be[0]+fe._bodyWidth/2&&pe>=Dt(Q.data[V][2])&&pe<=Dt(Q.data[V][3]))return{seriesIndex:K,pointIndex:V,gridData:Be,data:Q.data[V]}}else if(fe.hlc){var Dt=Q._yaxis.series_u2p;if(oe>=Be[0]-fe._tickLength&&oe<=Be[0]+fe._tickLength&&pe>=Dt(Q.data[V][1])&&pe<=Dt(Q.data[V][2]))return{seriesIndex:K,pointIndex:V,gridData:Be,data:Q.data[V]}}else{var Dt=Q._yaxis.series_u2p;if(oe>=Be[0]-fe._tickLength&&oe<=Be[0]+fe._tickLength&&pe>=Dt(Q.data[V][2])&&pe<=Dt(Q.data[V][3]))return{seriesIndex:K,pointIndex:V,gridData:Be,data:Q.data[V]}}else if(Le=Math.sqrt((oe-Be[0])*(oe-Be[0])+(pe-Be[1])*(pe-Be[1])),Le<=Ge&&(Le<=Me||Me==null))return Me=Le,{seriesIndex:K,pointIndex:V,gridData:Be,data:Q.data[V]}}break}return null}this.onClick=function(S){var P=E(S),W=S.data.plot,K=L(P.gridPos,W),V=t.Event("jqplotClick");V.pageX=S.pageX,V.pageY=S.pageY,t(this).trigger(V,[P.gridPos,P.dataPos,K,W])},this.onDblClick=function(S){var P=E(S),W=S.data.plot,K=L(P.gridPos,W),V=t.Event("jqplotDblClick");V.pageX=S.pageX,V.pageY=S.pageY,t(this).trigger(V,[P.gridPos,P.dataPos,K,W])},this.onMouseDown=function(S){var P=E(S),W=S.data.plot,K=L(P.gridPos,W),V=t.Event("jqplotMouseDown");V.pageX=S.pageX,V.pageY=S.pageY,t(this).trigger(V,[P.gridPos,P.dataPos,K,W])},this.onMouseUp=function(S){var P=E(S),W=t.Event("jqplotMouseUp");W.pageX=S.pageX,W.pageY=S.pageY,t(this).trigger(W,[P.gridPos,P.dataPos,null,S.data.plot])},this.onRightClick=function(S){var P=E(S),W=S.data.plot,K=L(P.gridPos,W);if(W.captureRightClick)if(S.which==3){var V=t.Event("jqplotRightClick");V.pageX=S.pageX,V.pageY=S.pageY,t(this).trigger(V,[P.gridPos,P.dataPos,K,W])}else{var V=t.Event("jqplotMouseUp");V.pageX=S.pageX,V.pageY=S.pageY,t(this).trigger(V,[P.gridPos,P.dataPos,K,W])}},this.onMouseMove=function(S){var P=E(S),W=S.data.plot,K=L(P.gridPos,W),V=t.Event("jqplotMouseMove");V.pageX=S.pageX,V.pageY=S.pageY,t(this).trigger(V,[P.gridPos,P.dataPos,K,W])},this.onMouseEnter=function(S){var P=E(S),W=S.data.plot,K=t.Event("jqplotMouseEnter");K.pageX=S.pageX,K.pageY=S.pageY,K.relatedTarget=S.relatedTarget,t(this).trigger(K,[P.gridPos,P.dataPos,null,W])},this.onMouseLeave=function(S){var P=E(S),W=S.data.plot,K=t.Event("jqplotMouseLeave");K.pageX=S.pageX,K.pageY=S.pageY,K.relatedTarget=S.relatedTarget,t(this).trigger(K,[P.gridPos,P.dataPos,null,W])},this.drawSeries=function(S,P){var W,K,V;if(P=typeof S=="number"&&P==null?S:P,S=typeof S=="object"?S:{},P!=e)K=this.series[P],V=K.shadowCanvas._ctx,V.clearRect(0,0,V.canvas.width,V.canvas.height),K.drawShadow(V,S,this),V=K.canvas._ctx,V.clearRect(0,0,V.canvas.width,V.canvas.height),K.draw(V,S,this),K.renderer.constructor==t.jqplot.BezierCurveRenderer&&P<this.series.length-1&&this.drawSeries(P+1);else for(W=0;W<this.series.length;W++)K=this.series[W],V=K.shadowCanvas._ctx,V.clearRect(0,0,V.canvas.width,V.canvas.height),K.drawShadow(V,S,this),V=K.canvas._ctx,V.clearRect(0,0,V.canvas.width,V.canvas.height),K.draw(V,S,this);S=P=W=K=V=null},this.moveSeriesToFront=function(S){S=parseInt(S,10);var P=t.inArray(S,this.seriesStack);if(P!=-1){if(P==this.seriesStack.length-1){this.previousSeriesStack=this.seriesStack.slice(0);return}var W=this.seriesStack[this.seriesStack.length-1],K=this.series[S].canvas._elem.detach(),V=this.series[S].shadowCanvas._elem.detach();this.series[W].shadowCanvas._elem.after(V),this.series[W].canvas._elem.after(K),this.previousSeriesStack=this.seriesStack.slice(0),this.seriesStack.splice(P,1),this.seriesStack.push(S)}},this.moveSeriesToBack=function(S){S=parseInt(S,10);var P=t.inArray(S,this.seriesStack);if(!(P==0||P==-1)){var W=this.seriesStack[0],K=this.series[S].canvas._elem.detach(),V=this.series[S].shadowCanvas._elem.detach();this.series[W].shadowCanvas._elem.before(V),this.series[W].canvas._elem.before(K),this.previousSeriesStack=this.seriesStack.slice(0),this.seriesStack.splice(P,1),this.seriesStack.unshift(S)}},this.restorePreviousSeriesOrder=function(){var S,P,W,K,V,ee;if(this.seriesStack!=this.previousSeriesStack){for(S=1;S<this.previousSeriesStack.length;S++)V=this.previousSeriesStack[S],ee=this.previousSeriesStack[S-1],P=this.series[V].canvas._elem.detach(),W=this.series[V].shadowCanvas._elem.detach(),this.series[ee].shadowCanvas._elem.after(W),this.series[ee].canvas._elem.after(P);K=this.seriesStack.slice(0),this.seriesStack=this.previousSeriesStack.slice(0),this.previousSeriesStack=K}},this.restoreOriginalSeriesOrder=function(){var S,P=[],W,K;for(S=0;S<this.series.length;S++)P.push(S);if(this.seriesStack!=P)for(this.previousSeriesStack=this.seriesStack.slice(0),this.seriesStack=P,S=1;S<this.seriesStack.length;S++)W=this.series[S].canvas._elem.detach(),K=this.series[S].shadowCanvas._elem.detach(),this.series[S-1].shadowCanvas._elem.after(K),this.series[S-1].canvas._elem.after(W)},this.activateTheme=function(S){this.themeEngine.activate(this,S)}}t.jqplot.computeHighlightColors=function(v){var E;if(t.isArray(v)){E=[];for(var L=0;L<v.length;L++){for(var S=t.jqplot.getColorComponents(v[L]),P=[S[0],S[1],S[2]],W=P[0]+P[1]+P[2],K=0;K<3;K++)P[K]=W>660?P[K]*.85:.73*P[K]+90,P[K]=parseInt(P[K],10),P[K]>255||P[K];P[3]=.3+.35*S[3],E.push("rgba("+P[0]+","+P[1]+","+P[2]+","+P[3]+")")}}else{for(var S=t.jqplot.getColorComponents(v),P=[S[0],S[1],S[2]],W=P[0]+P[1]+P[2],K=0;K<3;K++)P[K]=W>660?P[K]*.85:.73*P[K]+90,P[K]=parseInt(P[K],10),P[K]>255||P[K];P[3]=.3+.35*S[3],E="rgba("+P[0]+","+P[1]+","+P[2]+","+P[3]+")"}return E},t.jqplot.ColorGenerator=function(v){v=v||t.jqplot.config.defaultColors;var E=0;this.next=function(){return E<v.length||(E=0),v[E++]},this.previous=function(){return E>0?v[E--]:(E=v.length-1,v[E])},this.get=function(L){var S=L-v.length*Math.floor(L/v.length);return v[S]},this.setColors=function(L){v=L},this.reset=function(){E=0},this.getIndex=function(){return E},this.setIndex=function(L){E=L}},t.jqplot.hex2rgb=function(v,E){v=v.replace("#",""),v.length==3&&(v=v.charAt(0)+v.charAt(0)+v.charAt(1)+v.charAt(1)+v.charAt(2)+v.charAt(2));var L;return L="rgba("+parseInt(v.slice(0,2),16)+", "+parseInt(v.slice(2,4),16)+", "+parseInt(v.slice(4,6),16),E&&(L+=", "+E),L+=")",L},t.jqplot.rgb2hex=function(v){for(var E=/rgba?\( *([0-9]{1,3}\.?[0-9]*%?) *, *([0-9]{1,3}\.?[0-9]*%?) *, *([0-9]{1,3}\.?[0-9]*%?) *(?:, *[0-9.]*)?\)/,L=v.match(E),S="#",P=1;P<4;P++){var W;L[P].search(/%/)!=-1?(W=parseInt(255*L[P]/100,10).toString(16),W.length==1&&(W="0"+W)):(W=parseInt(L[P],10).toString(16),W.length==1&&(W="0"+W)),S+=W}return S},t.jqplot.normalize2rgb=function(v,E){if(v.search(/^ *rgba?\(/)!=-1)return v;if(v.search(/^ *#?[0-9a-fA-F]?[0-9a-fA-F]/)!=-1)return t.jqplot.hex2rgb(v,E);throw new Error("Invalid color spec")},t.jqplot.getColorComponents=function(v){v=t.jqplot.colorKeywordMap[v]||v;for(var E=t.jqplot.normalize2rgb(v),L=/rgba?\( *([0-9]{1,3}\.?[0-9]*%?) *, *([0-9]{1,3}\.?[0-9]*%?) *, *([0-9]{1,3}\.?[0-9]*%?) *,? *([0-9.]* *)?\)/,S=E.match(L),P=[],W=1;W<4;W++)S[W].search(/%/)!=-1?P[W-1]=parseInt(255*S[W]/100,10):P[W-1]=parseInt(S[W],10);return P[3]=parseFloat(S[4])?parseFloat(S[4]):1,P},t.jqplot.colorKeywordMap={aliceblue:"rgb(240, 248, 255)",antiquewhite:"rgb(250, 235, 215)",aqua:"rgb( 0, 255, 255)",aquamarine:"rgb(127, 255, 212)",azure:"rgb(240, 255, 255)",beige:"rgb(245, 245, 220)",bisque:"rgb(255, 228, 196)",black:"rgb( 0, 0, 0)",blanchedalmond:"rgb(255, 235, 205)",blue:"rgb( 0, 0, 255)",blueviolet:"rgb(138, 43, 226)",brown:"rgb(165, 42, 42)",burlywood:"rgb(222, 184, 135)",cadetblue:"rgb( 95, 158, 160)",chartreuse:"rgb(127, 255, 0)",chocolate:"rgb(210, 105, 30)",coral:"rgb(255, 127, 80)",cornflowerblue:"rgb(100, 149, 237)",cornsilk:"rgb(255, 248, 220)",crimson:"rgb(220, 20, 60)",cyan:"rgb( 0, 255, 255)",darkblue:"rgb( 0, 0, 139)",darkcyan:"rgb( 0, 139, 139)",darkgoldenrod:"rgb(184, 134, 11)",darkgray:"rgb(169, 169, 169)",darkgreen:"rgb( 0, 100, 0)",darkgrey:"rgb(169, 169, 169)",darkkhaki:"rgb(189, 183, 107)",darkmagenta:"rgb(139, 0, 139)",darkolivegreen:"rgb( 85, 107, 47)",darkorange:"rgb(255, 140, 0)",darkorchid:"rgb(153, 50, 204)",darkred:"rgb(139, 0, 0)",darksalmon:"rgb(233, 150, 122)",darkseagreen:"rgb(143, 188, 143)",darkslateblue:"rgb( 72, 61, 139)",darkslategray:"rgb( 47, 79, 79)",darkslategrey:"rgb( 47, 79, 79)",darkturquoise:"rgb( 0, 206, 209)",darkviolet:"rgb(148, 0, 211)",deeppink:"rgb(255, 20, 147)",deepskyblue:"rgb( 0, 191, 255)",dimgray:"rgb(105, 105, 105)",dimgrey:"rgb(105, 105, 105)",dodgerblue:"rgb( 30, 144, 255)",firebrick:"rgb(178, 34, 34)",floralwhite:"rgb(255, 250, 240)",forestgreen:"rgb( 34, 139, 34)",fuchsia:"rgb(255, 0, 255)",gainsboro:"rgb(220, 220, 220)",ghostwhite:"rgb(248, 248, 255)",gold:"rgb(255, 215, 0)",goldenrod:"rgb(218, 165, 32)",gray:"rgb(128, 128, 128)",grey:"rgb(128, 128, 128)",green:"rgb( 0, 128, 0)",greenyellow:"rgb(173, 255, 47)",honeydew:"rgb(240, 255, 240)",hotpink:"rgb(255, 105, 180)",indianred:"rgb(205, 92, 92)",indigo:"rgb( 75, 0, 130)",ivory:"rgb(255, 255, 240)",khaki:"rgb(240, 230, 140)",lavender:"rgb(230, 230, 250)",lavenderblush:"rgb(255, 240, 245)",lawngreen:"rgb(124, 252, 0)",lemonchiffon:"rgb(255, 250, 205)",lightblue:"rgb(173, 216, 230)",lightcoral:"rgb(240, 128, 128)",lightcyan:"rgb(224, 255, 255)",lightgoldenrodyellow:"rgb(250, 250, 210)",lightgray:"rgb(211, 211, 211)",lightgreen:"rgb(144, 238, 144)",lightgrey:"rgb(211, 211, 211)",lightpink:"rgb(255, 182, 193)",lightsalmon:"rgb(255, 160, 122)",lightseagreen:"rgb( 32, 178, 170)",lightskyblue:"rgb(135, 206, 250)",lightslategray:"rgb(119, 136, 153)",lightslategrey:"rgb(119, 136, 153)",lightsteelblue:"rgb(176, 196, 222)",lightyellow:"rgb(255, 255, 224)",lime:"rgb( 0, 255, 0)",limegreen:"rgb( 50, 205, 50)",linen:"rgb(250, 240, 230)",magenta:"rgb(255, 0, 255)",maroon:"rgb(128, 0, 0)",mediumaquamarine:"rgb(102, 205, 170)",mediumblue:"rgb( 0, 0, 205)",mediumorchid:"rgb(186, 85, 211)",mediumpurple:"rgb(147, 112, 219)",mediumseagreen:"rgb( 60, 179, 113)",mediumslateblue:"rgb(123, 104, 238)",mediumspringgreen:"rgb( 0, 250, 154)",mediumturquoise:"rgb( 72, 209, 204)",mediumvioletred:"rgb(199, 21, 133)",midnightblue:"rgb( 25, 25, 112)",mintcream:"rgb(245, 255, 250)",mistyrose:"rgb(255, 228, 225)",moccasin:"rgb(255, 228, 181)",navajowhite:"rgb(255, 222, 173)",navy:"rgb( 0, 0, 128)",oldlace:"rgb(253, 245, 230)",olive:"rgb(128, 128, 0)",olivedrab:"rgb(107, 142, 35)",orange:"rgb(255, 165, 0)",orangered:"rgb(255, 69, 0)",orchid:"rgb(218, 112, 214)",palegoldenrod:"rgb(238, 232, 170)",palegreen:"rgb(152, 251, 152)",paleturquoise:"rgb(175, 238, 238)",palevioletred:"rgb(219, 112, 147)",papayawhip:"rgb(255, 239, 213)",peachpuff:"rgb(255, 218, 185)",peru:"rgb(205, 133, 63)",pink:"rgb(255, 192, 203)",plum:"rgb(221, 160, 221)",powderblue:"rgb(176, 224, 230)",purple:"rgb(128, 0, 128)",red:"rgb(255, 0, 0)",rosybrown:"rgb(188, 143, 143)",royalblue:"rgb( 65, 105, 225)",saddlebrown:"rgb(139, 69, 19)",salmon:"rgb(250, 128, 114)",sandybrown:"rgb(244, 164, 96)",seagreen:"rgb( 46, 139, 87)",seashell:"rgb(255, 245, 238)",sienna:"rgb(160, 82, 45)",silver:"rgb(192, 192, 192)",skyblue:"rgb(135, 206, 235)",slateblue:"rgb(106, 90, 205)",slategray:"rgb(112, 128, 144)",slategrey:"rgb(112, 128, 144)",snow:"rgb(255, 250, 250)",springgreen:"rgb( 0, 255, 127)",steelblue:"rgb( 70, 130, 180)",tan:"rgb(210, 180, 140)",teal:"rgb( 0, 128, 128)",thistle:"rgb(216, 191, 216)",tomato:"rgb(255, 99, 71)",turquoise:"rgb( 64, 224, 208)",violet:"rgb(238, 130, 238)",wheat:"rgb(245, 222, 179)",white:"rgb(255, 255, 255)",whitesmoke:"rgb(245, 245, 245)",yellow:"rgb(255, 255, 0)",yellowgreen:"rgb(154, 205, 50)"},t.jqplot.AxisLabelRenderer=function(v){t.jqplot.ElemContainer.call(this),this.axis,this.show=!0,this.label="",this.fontFamily=null,this.fontSize=null,this.textColor=null,this._elem,this.escapeHTML=!1,t.extend(!0,this,v)},t.jqplot.AxisLabelRenderer.prototype=new t.jqplot.ElemContainer,t.jqplot.AxisLabelRenderer.prototype.constructor=t.jqplot.AxisLabelRenderer,t.jqplot.AxisLabelRenderer.prototype.init=function(v){t.extend(!0,this,v)},t.jqplot.AxisLabelRenderer.prototype.draw=function(v,E){return this._elem&&(this._elem.emptyForce(),this._elem=null),this._elem=t('<div style="position:absolute;" class="jqplot-'+this.axis+'-label"></div>'),Number(this.label)&&this._elem.css("white-space","nowrap"),this.escapeHTML?this._elem.text(this.label):this._elem.html(this.label),this.fontFamily&&this._elem.css("font-family",this.fontFamily),this.fontSize&&this._elem.css("font-size",this.fontSize),this.textColor&&this._elem.css("color",this.textColor),this._elem},t.jqplot.AxisLabelRenderer.prototype.pack=function(){},t.jqplot.AxisTickRenderer=function(v){t.jqplot.ElemContainer.call(this),this.mark="outside",this.axis,this.showMark=!0,this.showGridline=!0,this.isMinorTick=!1,this.size=4,this.markSize=6,this.show=!0,this.showLabel=!0,this.label=null,this.value=null,this._styles={},this.formatter=t.jqplot.DefaultTickFormatter,this.prefix="",this.suffix="",this.formatString="",this.fontFamily,this.fontSize,this.textColor,this.escapeHTML=!1,this._elem,this._breakTick=!1,t.extend(!0,this,v)},t.jqplot.AxisTickRenderer.prototype.init=function(v){t.extend(!0,this,v)},t.jqplot.AxisTickRenderer.prototype=new t.jqplot.ElemContainer,t.jqplot.AxisTickRenderer.prototype.constructor=t.jqplot.AxisTickRenderer,t.jqplot.AxisTickRenderer.prototype.setTick=function(v,E,L){return this.value=v,this.axis=E,L&&(this.isMinorTick=!0),this},t.jqplot.AxisTickRenderer.prototype.draw=function(){this.label===null&&(this.label=this.prefix+this.formatter(this.formatString,this.value)+this.suffix);var v={position:"absolute"};Number(this.label)&&(v.whitSpace="nowrap"),this._elem&&(this._elem.emptyForce(),this._elem=null),this._elem=t(document.createElement("div")),this._elem.addClass("jqplot-"+this.axis+"-tick"),this.escapeHTML?this._elem.text(this.label):this._elem.html(this.label),this._elem.css(v);for(var E in this._styles)this._elem.css(E,this._styles[E]);return this.fontFamily&&this._elem.css("font-family",this.fontFamily),this.fontSize&&this._elem.css("font-size",this.fontSize),this.textColor&&this._elem.css("color",this.textColor),this._breakTick&&this._elem.addClass("jqplot-breakTick"),this._elem},t.jqplot.DefaultTickFormatter=function(v,E){return typeof E=="number"?(v||(v=t.jqplot.config.defaultTickFormatString),t.jqplot.sprintf(v,E)):String(E)},t.jqplot.PercentTickFormatter=function(v,E){return typeof E=="number"?(E=100*E,v||(v=t.jqplot.config.defaultTickFormatString),t.jqplot.sprintf(v,E)):String(E)},t.jqplot.AxisTickRenderer.prototype.pack=function(){},t.jqplot.CanvasGridRenderer=function(){this.shadowRenderer=new t.jqplot.ShadowRenderer},t.jqplot.CanvasGridRenderer.prototype.init=function(v){this._ctx,t.extend(!0,this,v);var E={lineJoin:"miter",lineCap:"round",fill:!1,isarc:!1,angle:this.shadowAngle,offset:this.shadowOffset,alpha:this.shadowAlpha,depth:this.shadowDepth,lineWidth:this.shadowWidth,closePath:!1,strokeStyle:this.shadowColor};this.renderer.shadowRenderer.init(E)},t.jqplot.CanvasGridRenderer.prototype.createElement=function(v){var E;this._elem&&(t.jqplot.use_excanvas&&window.G_vmlCanvasManager.uninitElement!==e&&(E=this._elem.get(0),window.G_vmlCanvasManager.uninitElement(E),E=null),this._elem.emptyForce(),this._elem=null),E=v.canvasManager.getCanvas();var L=this._plotDimensions.width,S=this._plotDimensions.height;return E.width=L,E.height=S,this._elem=t(E),this._elem.addClass("jqplot-grid-canvas"),this._elem.css({position:"absolute",left:0,top:0}),E=v.canvasManager.initCanvas(E),this._top=this._offsets.top,this._bottom=S-this._offsets.bottom,this._left=this._offsets.left,this._right=L-this._offsets.right,this._width=this._right-this._left,this._height=this._bottom-this._top,E=null,this._elem},t.jqplot.CanvasGridRenderer.prototype.draw=function(){this._ctx=this._elem.get(0).getContext("2d");var v=this._ctx,E=this._axes;v.save(),v.clearRect(0,0,this._plotDimensions.width,this._plotDimensions.height),v.fillStyle=this.backgroundColor||this.background,v.fillRect(this._left,this._top,this._width,this._height),v.save(),v.lineJoin="miter",v.lineCap="butt",v.lineWidth=this.gridLineWidth,v.strokeStyle=this.gridLineColor;for(var L,S,P,W,K=["xaxis","yaxis","x2axis","y2axis"],V=4;V>0;V--){var ee=K[V-1],Q=E[ee],fe=Q._ticks,oe=fe.length;if(Q.show){if(Q.drawBaseline){var pe={};switch(Q.baselineWidth!==null&&(pe.lineWidth=Q.baselineWidth),Q.baselineColor!==null&&(pe.strokeStyle=Q.baselineColor),ee){case"xaxis":Be(this._left,this._bottom,this._right,this._bottom,pe);break;case"yaxis":Be(this._left,this._bottom,this._left,this._top,pe);break;case"x2axis":Be(this._left,this._bottom,this._right,this._bottom,pe);break;case"y2axis":Be(this._right,this._bottom,this._right,this._top,pe);break}}for(var ae=oe;ae>0;ae--){var Ae=fe[ae-1];if(Ae.show){var Se=Math.round(Q.u2p(Ae.value))+.5;switch(ee){case"xaxis":if(Ae.showGridline&&this.drawGridlines&&(!Ae.isMinorTick&&Q.drawMajorGridlines||Ae.isMinorTick&&Q.drawMinorGridlines)&&Be(Se,this._top,Se,this._bottom),Ae.showMark&&Ae.mark&&(!Ae.isMinorTick&&Q.drawMajorTickMarks||Ae.isMinorTick&&Q.drawMinorTickMarks)){P=Ae.markSize,W=Ae.mark;var Se=Math.round(Q.u2p(Ae.value))+.5;switch(W){case"outside":L=this._bottom,S=this._bottom+P;break;case"inside":L=this._bottom-P,S=this._bottom;break;case"cross":L=this._bottom-P,S=this._bottom+P;break;default:L=this._bottom,S=this._bottom+P;break}this.shadow&&this.renderer.shadowRenderer.draw(v,[[Se,L],[Se,S]],{lineCap:"butt",lineWidth:this.gridLineWidth,offset:this.gridLineWidth*.75,depth:2,fill:!1,closePath:!1}),Be(Se,L,Se,S)}break;case"yaxis":if(Ae.showGridline&&this.drawGridlines&&(!Ae.isMinorTick&&Q.drawMajorGridlines||Ae.isMinorTick&&Q.drawMinorGridlines)&&Be(this._right,Se,this._left,Se),Ae.showMark&&Ae.mark&&(!Ae.isMinorTick&&Q.drawMajorTickMarks||Ae.isMinorTick&&Q.drawMinorTickMarks)){P=Ae.markSize,W=Ae.mark;var Se=Math.round(Q.u2p(Ae.value))+.5;switch(W){case"outside":L=this._left-P,S=this._left;break;case"inside":L=this._left,S=this._left+P;break;case"cross":L=this._left-P,S=this._left+P;break;default:L=this._left-P,S=this._left;break}this.shadow&&this.renderer.shadowRenderer.draw(v,[[L,Se],[S,Se]],{lineCap:"butt",lineWidth:this.gridLineWidth*1.5,offset:this.gridLineWidth*.75,fill:!1,closePath:!1}),Be(L,Se,S,Se,{strokeStyle:Q.borderColor})}break;case"x2axis":if(Ae.showGridline&&this.drawGridlines&&(!Ae.isMinorTick&&Q.drawMajorGridlines||Ae.isMinorTick&&Q.drawMinorGridlines)&&Be(Se,this._bottom,Se,this._top),Ae.showMark&&Ae.mark&&(!Ae.isMinorTick&&Q.drawMajorTickMarks||Ae.isMinorTick&&Q.drawMinorTickMarks)){P=Ae.markSize,W=Ae.mark;var Se=Math.round(Q.u2p(Ae.value))+.5;switch(W){case"outside":L=this._top-P,S=this._top;break;case"inside":L=this._top,S=this._top+P;break;case"cross":L=this._top-P,S=this._top+P;break;default:L=this._top-P,S=this._top;break}this.shadow&&this.renderer.shadowRenderer.draw(v,[[Se,L],[Se,S]],{lineCap:"butt",lineWidth:this.gridLineWidth,offset:this.gridLineWidth*.75,depth:2,fill:!1,closePath:!1}),Be(Se,L,Se,S)}break;case"y2axis":if(Ae.showGridline&&this.drawGridlines&&(!Ae.isMinorTick&&Q.drawMajorGridlines||Ae.isMinorTick&&Q.drawMinorGridlines)&&Be(this._left,Se,this._right,Se),Ae.showMark&&Ae.mark&&(!Ae.isMinorTick&&Q.drawMajorTickMarks||Ae.isMinorTick&&Q.drawMinorTickMarks)){P=Ae.markSize,W=Ae.mark;var Se=Math.round(Q.u2p(Ae.value))+.5;switch(W){case"outside":L=this._right,S=this._right+P;break;case"inside":L=this._right-P,S=this._right;break;case"cross":L=this._right-P,S=this._right+P;break;default:L=this._right,S=this._right+P;break}this.shadow&&this.renderer.shadowRenderer.draw(v,[[L,Se],[S,Se]],{lineCap:"butt",lineWidth:this.gridLineWidth*1.5,offset:this.gridLineWidth*.75,fill:!1,closePath:!1}),Be(L,Se,S,Se,{strokeStyle:Q.borderColor})}break}}}Ae=null}Q=null,fe=null}K=["y3axis","y4axis","y5axis","y6axis","y7axis","y8axis","y9axis","yMidAxis"];for(var V=7;V>0;V--){var Q=E[K[V-1]],fe=Q._ticks;if(Q.show){var ze=fe[Q.numberTicks-1],Ve=fe[0],Me=Q.getLeft(),Le=[[Me,ze.getTop()+ze.getHeight()/2],[Me,Ve.getTop()+Ve.getHeight()/2+1]];this.shadow&&this.renderer.shadowRenderer.draw(v,Le,{lineCap:"butt",fill:!1,closePath:!1}),Be(Le[0][0],Le[0][1],Le[1][0],Le[1][1],{lineCap:"butt",strokeStyle:Q.borderColor,lineWidth:Q.borderWidth});for(var ae=fe.length;ae>0;ae--){var Ae=fe[ae-1];P=Ae.markSize,W=Ae.mark;var Se=Math.round(Q.u2p(Ae.value))+.5;if(Ae.showMark&&Ae.mark){switch(W){case"outside":L=Me,S=Me+P;break;case"inside":L=Me-P,S=Me;break;case"cross":L=Me-P,S=Me+P;break;default:L=Me,S=Me+P;break}Le=[[L,Se],[S,Se]],this.shadow&&this.renderer.shadowRenderer.draw(v,Le,{lineCap:"butt",lineWidth:this.gridLineWidth*1.5,offset:this.gridLineWidth*.75,fill:!1,closePath:!1}),Be(L,Se,S,Se,{strokeStyle:Q.borderColor})}Ae=null}Ve=null}Q=null,fe=null}v.restore();function Be(Je,Ue,Ge,lt,et){v.save(),et=et||{},(et.lineWidth==null||et.lineWidth!=0)&&(t.extend(!0,v,et),v.beginPath(),v.moveTo(Je,Ue),v.lineTo(Ge,lt),v.stroke(),v.restore())}if(this.shadow){var Le=[[this._left,this._bottom],[this._right,this._bottom],[this._right,this._top]];this.renderer.shadowRenderer.draw(v,Le)}this.borderWidth!=0&&this.drawBorder&&(Be(this._left,this._top,this._right,this._top,{lineCap:"round",strokeStyle:E.x2axis.borderColor,lineWidth:E.x2axis.borderWidth}),Be(this._right,this._top,this._right,this._bottom,{lineCap:"round",strokeStyle:E.y2axis.borderColor,lineWidth:E.y2axis.borderWidth}),Be(this._right,this._bottom,this._left,this._bottom,{lineCap:"round",strokeStyle:E.xaxis.borderColor,lineWidth:E.xaxis.borderWidth}),Be(this._left,this._bottom,this._left,this._top,{lineCap:"round",strokeStyle:E.yaxis.borderColor,lineWidth:E.yaxis.borderWidth})),v.restore(),v=null,E=null},t.jqplot.DivTitleRenderer=function(){},t.jqplot.DivTitleRenderer.prototype.init=function(v){t.extend(!0,this,v)},t.jqplot.DivTitleRenderer.prototype.draw=function(){this._elem&&(this._elem.emptyForce(),this._elem=null),this.renderer;var v=document.createElement("div");if(this._elem=t(v),this._elem.addClass("jqplot-title"),!this.text)this.show=!1,this._elem.height(0),this._elem.width(0);else if(this.text){var E;this.color?E=this.color:this.textColor&&(E=this.textColor);var L={position:"absolute",top:"0px",left:"0px"};this._plotWidth&&(L.width=this._plotWidth+"px"),this.fontSize&&(L.fontSize=this.fontSize),typeof this.textAlign=="string"?L.textAlign=this.textAlign:L.textAlign="center",E&&(L.color=E),this.paddingBottom&&(L.paddingBottom=this.paddingBottom),this.fontFamily&&(L.fontFamily=this.fontFamily),this._elem.css(L),this.escapeHtml?this._elem.text(this.text):this._elem.html(this.text)}return v=null,this._elem},t.jqplot.DivTitleRenderer.prototype.pack=function(){};var h=.1;t.jqplot.LinePattern=function(v,E){var L={dotted:[h,t.jqplot.config.dotGapLength],dashed:[t.jqplot.config.dashLength,t.jqplot.config.gapLength],solid:null};if(typeof E=="string")if(E[0]==="."||E[0]==="-"){var S=E;E=[];for(var P=0,W=S.length;P<W;P++){if(S[P]===".")E.push(h);else if(S[P]==="-")E.push(t.jqplot.config.dashLength);else continue;E.push(t.jqplot.config.gapLength)}}else E=L[E];if(!(E&&E.length))return v;var K=0,V=E[0],ee=0,Q=0,fe=0,oe=0,pe=function(ze,Ve){v.moveTo(ze,Ve),ee=ze,Q=Ve,fe=ze,oe=Ve},ae=function(ze,Ve){var Me=v.lineWidth,Le=ze-ee,Be=Ve-Q,Je=Math.sqrt(Le*Le+Be*Be);if(Je>0&&Me>0)for(Le/=Je,Be/=Je;;){var Ue=Me*V;if(Ue<Je)ee+=Ue*Le,Q+=Ue*Be,K&1?v.moveTo(ee,Q):v.lineTo(ee,Q),Je-=Ue,K++,K>=E.length&&(K=0),V=E[K];else{ee=ze,Q=Ve,K&1?v.moveTo(ee,Q):v.lineTo(ee,Q),V-=Je/Me;break}}},Ae=function(){v.beginPath()},Se=function(){ae(fe,oe)};return{moveTo:pe,lineTo:ae,beginPath:Ae,closePath:Se}},t.jqplot.LineRenderer=function(){this.shapeRenderer=new t.jqplot.ShapeRenderer,this.shadowRenderer=new t.jqplot.ShadowRenderer},t.jqplot.LineRenderer.prototype.init=function(v,E){v=v||{},this._type="line",this.renderer.animation={show:!1,direction:"left",speed:2500,_supported:!0},this.renderer.smooth=!1,this.renderer.tension=null,this.renderer.constrainSmoothing=!0,this.renderer._smoothedData=[],this.renderer._smoothedPlotData=[],this.renderer._hiBandGridData=[],this.renderer._lowBandGridData=[],this.renderer._hiBandSmoothedData=[],this.renderer._lowBandSmoothedData=[],this.renderer.bandData=[],this.renderer.bands={show:!1,hiData:[],lowData:[],color:this.color,showLines:!1,fill:!0,fillColor:null,_min:null,_max:null,interval:"3%"};var L={highlightMouseOver:v.highlightMouseOver,highlightMouseDown:v.highlightMouseDown,highlightColor:v.highlightColor};delete v.highlightMouseOver,delete v.highlightMouseDown,delete v.highlightColor,t.extend(!0,this.renderer,v),this.renderer.options=v,this.renderer.bandData.length>1&&(!v.bands||v.bands.show==null)?this.renderer.bands.show=!0:v.bands&&v.bands.show==null&&v.bands.interval!=null&&(this.renderer.bands.show=!0),this.fill&&(this.renderer.bands.show=!1),this.renderer.bands.show&&this.renderer.initBands.call(this,this.renderer.options,E),this._stack&&(this.renderer.smooth=!1);var S={lineJoin:this.lineJoin,lineCap:this.lineCap,fill:this.fill,isarc:!1,strokeStyle:this.color,fillStyle:this.fillColor,lineWidth:this.lineWidth,linePattern:this.linePattern,closePath:this.fill};this.renderer.shapeRenderer.init(S);var P=v.shadowOffset;P==null&&(this.lineWidth>2.5?P=1.25*(1+(Math.atan(this.lineWidth/2.5)/.785398163-1)*.6):P=1.25*Math.atan(this.lineWidth/2.5)/.785398163);var W={lineJoin:this.lineJoin,lineCap:this.lineCap,fill:this.fill,isarc:!1,angle:this.shadowAngle,offset:P,alpha:this.shadowAlpha,depth:this.shadowDepth,lineWidth:this.lineWidth,linePattern:this.linePattern,closePath:this.fill};if(this.renderer.shadowRenderer.init(W),this._areaPoints=[],this._boundingBox=[[],[]],!this.isTrendline&&this.fill||this.renderer.bands.show){if(this.highlightMouseOver=!0,this.highlightMouseDown=!1,this.highlightColor=null,L.highlightMouseDown&&L.highlightMouseOver==null&&(L.highlightMouseOver=!1),t.extend(!0,this,{highlightMouseOver:L.highlightMouseOver,highlightMouseDown:L.highlightMouseDown,highlightColor:L.highlightColor}),!this.highlightColor){var K=this.renderer.bands.show?this.renderer.bands.fillColor:this.fillColor;this.highlightColor=t.jqplot.computeHighlightColors(K)}this.highlighter&&(this.highlighter.show=!1)}!this.isTrendline&&E&&(E.plugins.lineRenderer={},E.postInitHooks.addOnce(a),E.postDrawHooks.addOnce(F),E.eventListenerHooks.addOnce("jqplotMouseMove",b),E.eventListenerHooks.addOnce("jqplotMouseDown",C),E.eventListenerHooks.addOnce("jqplotMouseUp",k),E.eventListenerHooks.addOnce("jqplotClick",T),E.eventListenerHooks.addOnce("jqplotRightClick",w))},t.jqplot.LineRenderer.prototype.initBands=function(v,E){var L=v.bandData||[],S=this.renderer.bands;S.hiData=[],S.lowData=[];var P=this.data;if(S._max=null,S._min=null,L.length==2)if(t.isArray(L[0][0])){for(var W,K=0,V=0,ee=0,Q=L[0].length;ee<Q;ee++)W=L[0][ee],(W[1]!=null&&W[1]>S._max||S._max==null)&&(S._max=W[1]),(W[1]!=null&&W[1]<S._min||S._min==null)&&(S._min=W[1]);for(var ee=0,Q=L[1].length;ee<Q;ee++)W=L[1][ee],(W[1]!=null&&W[1]>S._max||S._max==null)&&(S._max=W[1],V=1),(W[1]!=null&&W[1]<S._min||S._min==null)&&(S._min=W[1],K=1);V===K&&(S.show=!1),S.hiData=L[V],S.lowData=L[K]}else if(L[0].length===P.length&&L[1].length===P.length)for(var fe=L[0][0]>L[1][0]?0:1,oe=fe?0:1,ee=0,Q=P.length;ee<Q;ee++)S.hiData.push([P[ee][0],L[fe][ee]]),S.lowData.push([P[ee][0],L[oe][ee]]);else S.show=!1;else if(L.length>2&&!t.isArray(L[0][0]))for(var fe=L[0][0]>L[0][1]?0:1,oe=fe?0:1,ee=0,Q=L.length;ee<Q;ee++)S.hiData.push([P[ee][0],L[ee][fe]]),S.lowData.push([P[ee][0],L[ee][oe]]);else{var pe=S.interval,ae=null,Ae=null,Se=null,ze=null;if(t.isArray(pe)?(ae=pe[0],Ae=pe[1]):ae=pe,isNaN(ae)?ae.charAt(ae.length-1)==="%"&&(Se="multiply",ae=parseFloat(ae)/100+1):(ae=parseFloat(ae),Se="add"),Ae!==null&&isNaN(Ae)?Ae.charAt(Ae.length-1)==="%"&&(ze="multiply",Ae=parseFloat(Ae)/100+1):Ae!==null&&(Ae=parseFloat(Ae),ze="add"),ae!==null){if(Ae===null&&(Ae=-ae,ze=Se,ze==="multiply"&&(Ae+=2)),ae<Ae){var Ve=ae;ae=Ae,Ae=Ve,Ve=Se,Se=ze,ze=Ve}for(var ee=0,Q=P.length;ee<Q;ee++){switch(Se){case"add":S.hiData.push([P[ee][0],P[ee][1]+ae]);break;case"multiply":S.hiData.push([P[ee][0],P[ee][1]*ae]);break}switch(ze){case"add":S.lowData.push([P[ee][0],P[ee][1]+Ae]);break;case"multiply":S.lowData.push([P[ee][0],P[ee][1]*Ae]);break}}}else S.show=!1}for(var Me=S.hiData,Le=S.lowData,ee=0,Q=Me.length;ee<Q;ee++)(Me[ee][1]!=null&&Me[ee][1]>S._max||S._max==null)&&(S._max=Me[ee][1]);for(var ee=0,Q=Le.length;ee<Q;ee++)(Le[ee][1]!=null&&Le[ee][1]<S._min||S._min==null)&&(S._min=Le[ee][1]);if(S.fillColor===null){var Be=t.jqplot.getColorComponents(S.color);Be[3]=Be[3]*.5,S.fillColor="rgba("+Be[0]+", "+Be[1]+", "+Be[2]+", "+Be[3]+")"}};function g(v,E){return(3.4182054+E)*Math.pow(v,-.3534992)}function d(v){var E=(Math.exp(2*v)-1)/(Math.exp(2*v)+1);return E}function l(v){var E=this.renderer.smooth,L=this.canvas.getWidth(),S=this._xaxis.series_p2u,P=this._yaxis.series_p2u,W=null,K=v.length/L,V=[],ee=[];isNaN(parseFloat(E))?W=g(K,.5):W=parseFloat(E);for(var Q=[],fe=[],oe=0,pe=v.length;oe<pe;oe++)Q.push(v[oe][1]),fe.push(v[oe][0]);function ae(Ft,bt){return Ft-bt==0?Math.pow(10,10):Ft-bt}for(var Ae,Se,ze,Ve,Me=v.length-1,Le=1,Be=v.length;Le<Be;Le++){for(var Je=[],Ue=[],Ge=0;Ge<2;Ge++){var oe=Le-1+Ge;oe==0||oe==Me?Je[Ge]=Math.pow(10,10):Q[oe+1]-Q[oe]==0||Q[oe]-Q[oe-1]==0||(fe[oe+1]-fe[oe])/(Q[oe+1]-Q[oe])+(fe[oe]-fe[oe-1])/(Q[oe]-Q[oe-1])==0||(Q[oe+1]-Q[oe])*(Q[oe]-Q[oe-1])<0?Je[Ge]=0:Je[Ge]=2/(ae(fe[oe+1],fe[oe])/(Q[oe+1]-Q[oe])+ae(fe[oe],fe[oe-1])/(Q[oe]-Q[oe-1]))}Le==1?Je[0]=3/2*(Q[1]-Q[0])/ae(fe[1],fe[0])-Je[1]/2:Le==Me&&(Je[1]=3/2*(Q[Me]-Q[Me-1])/ae(fe[Me],fe[Me-1])-Je[0]/2),Ue[0]=-2*(Je[1]+2*Je[0])/ae(fe[Le],fe[Le-1])+6*(Q[Le]-Q[Le-1])/Math.pow(ae(fe[Le],fe[Le-1]),2),Ue[1]=2*(2*Je[1]+Je[0])/ae(fe[Le],fe[Le-1])-6*(Q[Le]-Q[Le-1])/Math.pow(ae(fe[Le],fe[Le-1]),2),Ve=1/6*(Ue[1]-Ue[0])/ae(fe[Le],fe[Le-1]),ze=1/2*(fe[Le]*Ue[0]-fe[Le-1]*Ue[1])/ae(fe[Le],fe[Le-1]),Se=(Q[Le]-Q[Le-1]-ze*(Math.pow(fe[Le],2)-Math.pow(fe[Le-1],2))-Ve*(Math.pow(fe[Le],3)-Math.pow(fe[Le-1],3)))/ae(fe[Le],fe[Le-1]),Ae=Q[Le-1]-Se*fe[Le-1]-ze*Math.pow(fe[Le-1],2)-Ve*Math.pow(fe[Le-1],3);for(var lt=(fe[Le]-fe[Le-1])/W,et,vt,Ge=0,pe=W;Ge<pe;Ge++)et=[],vt=fe[Le-1]+Ge*lt,et.push(vt),et.push(Ae+Se*vt+ze*Math.pow(vt,2)+Ve*Math.pow(vt,3)),V.push(et),ee.push([S(et[0]),P(et[1])])}return V.push(v[oe]),ee.push([S(v[oe][0]),P(v[oe][1])]),[V,ee]}function c(v){var E=this.renderer.smooth,L=this.renderer.tension,S=this.canvas.getWidth(),P=this._xaxis.series_p2u,W=this._yaxis.series_p2u,K=null,V=null,ee=null,Q=null,fe=null,oe=null,pe=null,ae,Ae,Se,ze,Ve,Me,Le,Be,Je,Ue,Ge,lt,et,vt=v.length/S,Ft,bt,Ht,kt,Bt,st=[],Vt=[];isNaN(parseFloat(E))?K=g(vt,.5):K=parseFloat(E),isNaN(parseFloat(L))||(L=parseFloat(L));for(var it=0,St=v.length-1;it<St;it++)for(L===null?(fe=Math.abs((v[it+1][1]-v[it][1])/(v[it+1][0]-v[it][0])),Ft=.3,bt=.6,Ht=(bt-Ft)/2,kt=2.5,Bt=-1.4,pe=fe/kt+Bt,ee=Ht*d(pe)-Ht*d(Bt)+Ft,it>0&&(oe=Math.abs((v[it][1]-v[it-1][1])/(v[it][0]-v[it-1][0]))),pe=oe/kt+Bt,Q=Ht*d(pe)-Ht*d(Bt)+Ft,V=(ee+Q)/2):V=L,ae=0;ae<K;ae++)Ae=ae/K,Se=(1+2*Ae)*Math.pow(1-Ae,2),ze=Ae*Math.pow(1-Ae,2),Ve=Math.pow(Ae,2)*(3-2*Ae),Me=Math.pow(Ae,2)*(Ae-1),v[it-1]?(Le=V*(v[it+1][0]-v[it-1][0]),Be=V*(v[it+1][1]-v[it-1][1])):(Le=V*(v[it+1][0]-v[it][0]),Be=V*(v[it+1][1]-v[it][1])),v[it+2]?(Je=V*(v[it+2][0]-v[it][0]),Ue=V*(v[it+2][1]-v[it][1])):(Je=V*(v[it+1][0]-v[it][0]),Ue=V*(v[it+1][1]-v[it][1])),Ge=Se*v[it][0]+Ve*v[it+1][0]+ze*Le+Me*Je,lt=Se*v[it][1]+Ve*v[it+1][1]+ze*Be+Me*Ue,et=[Ge,lt],st.push(et),Vt.push([P(Ge),W(lt)]);return st.push(v[St]),Vt.push([P(v[St][0]),W(v[St][1])]),[st,Vt]}t.jqplot.LineRenderer.prototype.setGridData=function(v){var E=this._xaxis.series_u2p,L=this._yaxis.series_u2p,S=this._plotData,P=this._prevPlotData;this.gridData=[],this._prevGridData=[],this.renderer._smoothedData=[],this.renderer._smoothedPlotData=[],this.renderer._hiBandGridData=[],this.renderer._lowBandGridData=[],this.renderer._hiBandSmoothedData=[],this.renderer._lowBandSmoothedData=[];for(var W=this.renderer.bands,K=!1,V=0,ee=S.length;V<ee;V++)S[V][0]!=null&&S[V][1]!=null?this.gridData.push([E.call(this._xaxis,S[V][0]),L.call(this._yaxis,S[V][1])]):S[V][0]==null?(K=!0,this.gridData.push([null,L.call(this._yaxis,S[V][1])])):S[V][1]==null&&(K=!0,this.gridData.push([E.call(this._xaxis,S[V][0]),null])),P[V]!=null&&P[V][0]!=null&&P[V][1]!=null?this._prevGridData.push([E.call(this._xaxis,P[V][0]),L.call(this._yaxis,P[V][1])]):P[V]!=null&&P[V][0]==null?this._prevGridData.push([null,L.call(this._yaxis,P[V][1])]):P[V]!=null&&P[V][0]!=null&&P[V][1]==null&&this._prevGridData.push([E.call(this._xaxis,P[V][0]),null]);if(K&&(this.renderer.smooth=!1,this._type==="line"&&(W.show=!1)),this._type==="line"&&W.show){for(var V=0,ee=W.hiData.length;V<ee;V++)this.renderer._hiBandGridData.push([E.call(this._xaxis,W.hiData[V][0]),L.call(this._yaxis,W.hiData[V][1])]);for(var V=0,ee=W.lowData.length;V<ee;V++)this.renderer._lowBandGridData.push([E.call(this._xaxis,W.lowData[V][0]),L.call(this._yaxis,W.lowData[V][1])])}if(this._type==="line"&&this.renderer.smooth&&this.gridData.length>2){var Q;this.renderer.constrainSmoothing?(Q=l.call(this,this.gridData),this.renderer._smoothedData=Q[0],this.renderer._smoothedPlotData=Q[1],W.show&&(Q=l.call(this,this.renderer._hiBandGridData),this.renderer._hiBandSmoothedData=Q[0],Q=l.call(this,this.renderer._lowBandGridData),this.renderer._lowBandSmoothedData=Q[0]),Q=null):(Q=c.call(this,this.gridData),this.renderer._smoothedData=Q[0],this.renderer._smoothedPlotData=Q[1],W.show&&(Q=c.call(this,this.renderer._hiBandGridData),this.renderer._hiBandSmoothedData=Q[0],Q=c.call(this,this.renderer._lowBandGridData),this.renderer._lowBandSmoothedData=Q[0]),Q=null)}},t.jqplot.LineRenderer.prototype.makeGridData=function(v,E){var L=this._xaxis.series_u2p,S=this._yaxis.series_u2p,P=[];this.renderer._smoothedData=[],this.renderer._smoothedPlotData=[],this.renderer._hiBandGridData=[],this.renderer._lowBandGridData=[],this.renderer._hiBandSmoothedData=[],this.renderer._lowBandSmoothedData=[];for(var W=this.renderer.bands,K=!1,V=0;V<v.length;V++)v[V][0]!=null&&v[V][1]!=null?P.push([L.call(this._xaxis,v[V][0]),S.call(this._yaxis,v[V][1])]):v[V][0]==null?(K=!0,P.push([null,S.call(this._yaxis,v[V][1])])):v[V][1]==null&&(K=!0,P.push([L.call(this._xaxis,v[V][0]),null]));if(K&&(this.renderer.smooth=!1,this._type==="line"&&(W.show=!1)),this._type==="line"&&W.show){for(var V=0,ee=W.hiData.length;V<ee;V++)this.renderer._hiBandGridData.push([L.call(this._xaxis,W.hiData[V][0]),S.call(this._yaxis,W.hiData[V][1])]);for(var V=0,ee=W.lowData.length;V<ee;V++)this.renderer._lowBandGridData.push([L.call(this._xaxis,W.lowData[V][0]),S.call(this._yaxis,W.lowData[V][1])])}if(this._type==="line"&&this.renderer.smooth&&P.length>2){var Q;this.renderer.constrainSmoothing?(Q=l.call(this,P),this.renderer._smoothedData=Q[0],this.renderer._smoothedPlotData=Q[1],W.show&&(Q=l.call(this,this.renderer._hiBandGridData),this.renderer._hiBandSmoothedData=Q[0],Q=l.call(this,this.renderer._lowBandGridData),this.renderer._lowBandSmoothedData=Q[0]),Q=null):(Q=c.call(this,P),this.renderer._smoothedData=Q[0],this.renderer._smoothedPlotData=Q[1],W.show&&(Q=c.call(this,this.renderer._hiBandGridData),this.renderer._hiBandSmoothedData=Q[0],Q=c.call(this,this.renderer._lowBandGridData),this.renderer._lowBandSmoothedData=Q[0]),Q=null)}return P},t.jqplot.LineRenderer.prototype.draw=function(v,E,L,S){var P,W=t.extend(!0,{},L),K=W.shadow!=e?W.shadow:this.shadow,V=W.showLine!=e?W.showLine:this.showLine,ee=W.fill!=e?W.fill:this.fill,Q=W.fillAndStroke!=e?W.fillAndStroke:this.fillAndStroke,fe,oe,pe,ae;if(v.save(),E.length){if(V)if(ee){if(this.fillToZero){var Ae=this.negativeColor;this.useNegativeColors||(Ae=W.fillStyle);var Se=W.fillStyle;if(Q)var ze=E.slice(0);if(this.index==0||!this._stack){var Ve=[],Me=this.renderer.smooth?this.renderer._smoothedPlotData:this._plotData;this._areaPoints=[];var Le=this._yaxis.series_u2p(this.fillToValue);if(this._xaxis.series_u2p(this.fillToValue),W.closePath=!0,this.fillAxis=="y"){Ve.push([E[0][0],Le]),this._areaPoints.push([E[0][0],Le]);for(var P=0;P<E.length-1;P++)if(Ve.push(E[P]),this._areaPoints.push(E[P]),Me[P][1]*Me[P+1][1]<=0){Me[P][1]<0?W.fillStyle=Ae:W.fillStyle=Se;var Be=E[P][0]+(E[P+1][0]-E[P][0])*(Le-E[P][1])/(E[P+1][1]-E[P][1]);Ve.push([Be,Le]),this._areaPoints.push([Be,Le]),K&&this.renderer.shadowRenderer.draw(v,Ve,W),this.renderer.shapeRenderer.draw(v,Ve,W),Ve=[[Be,Le]]}Me[E.length-1][1]<0?W.fillStyle=Ae:W.fillStyle=Se,Ve.push(E[E.length-1]),this._areaPoints.push(E[E.length-1]),Ve.push([E[E.length-1][0],Le]),this._areaPoints.push([E[E.length-1][0],Le])}K&&this.renderer.shadowRenderer.draw(v,Ve,W),this.renderer.shapeRenderer.draw(v,Ve,W)}else{for(var Je=this._prevGridData,P=Je.length;P>0;P--)E.push(Je[P-1]);K&&this.renderer.shadowRenderer.draw(v,E,W),this._areaPoints=E,this.renderer.shapeRenderer.draw(v,E,W)}}else{if(Q)var ze=E.slice(0);if(this.index==0||!this._stack){var Ue=v.canvas.height;E.unshift([E[0][0],Ue]);var Ge=E.length;E.push([E[Ge-1][0],Ue])}else for(var Je=this._prevGridData,P=Je.length;P>0;P--)E.push(Je[P-1]);this._areaPoints=E,K&&this.renderer.shadowRenderer.draw(v,E,W),this.renderer.shapeRenderer.draw(v,E,W)}if(Q){var lt=t.extend(!0,{},W,{fill:!1,closePath:!1});if(this.renderer.shapeRenderer.draw(v,ze,lt),this.markerRenderer.show)for(this.renderer.smooth&&(ze=this.gridData),P=0;P<ze.length;P++)this.markerRenderer.draw(ze[P][0],ze[P][1],v,W.markerOptions)}}else{if(this.renderer.bands.show){var et,vt=t.extend(!0,{},W);this.renderer.bands.showLines&&(et=this.renderer.smooth?this.renderer._hiBandSmoothedData:this.renderer._hiBandGridData,this.renderer.shapeRenderer.draw(v,et,W),et=this.renderer.smooth?this.renderer._lowBandSmoothedData:this.renderer._lowBandGridData,this.renderer.shapeRenderer.draw(v,et,vt)),this.renderer.bands.fill&&(this.renderer.smooth?et=this.renderer._hiBandSmoothedData.concat(this.renderer._lowBandSmoothedData.reverse()):et=this.renderer._hiBandGridData.concat(this.renderer._lowBandGridData.reverse()),this._areaPoints=et,vt.closePath=!0,vt.fill=!0,vt.fillStyle=this.renderer.bands.fillColor,this.renderer.shapeRenderer.draw(v,et,vt))}K&&this.renderer.shadowRenderer.draw(v,E,W),this.renderer.shapeRenderer.draw(v,E,W)}var fe=pe=oe=ae=null;for(P=0;P<this._areaPoints.length;P++){var Ft=this._areaPoints[P];(fe>Ft[0]||fe==null)&&(fe=Ft[0]),(ae<Ft[1]||ae==null)&&(ae=Ft[1]),(pe<Ft[0]||pe==null)&&(pe=Ft[0]),(oe>Ft[1]||oe==null)&&(oe=Ft[1])}if(this.type==="line"&&this.renderer.bands.show&&(ae=this._yaxis.series_u2p(this.renderer.bands._min),oe=this._yaxis.series_u2p(this.renderer.bands._max)),this._boundingBox=[[fe,ae],[pe,oe]],this.markerRenderer.show&&!ee)for(this.renderer.smooth&&(E=this.gridData),P=0;P<E.length;P++)E[P][0]!=null&&E[P][1]!=null&&this.markerRenderer.draw(E[P][0],E[P][1],v,W.markerOptions)}v.restore()},t.jqplot.LineRenderer.prototype.drawShadow=function(v,E,L){};function a(v,E,L){for(var S=0;S<this.series.length;S++)this.series[S].renderer.constructor==t.jqplot.LineRenderer&&this.series[S].highlightMouseOver&&(this.series[S].highlightMouseDown=!1)}function F(){this.plugins.lineRenderer&&this.plugins.lineRenderer.highlightCanvas&&(this.plugins.lineRenderer.highlightCanvas.resetCanvas(),this.plugins.lineRenderer.highlightCanvas=null),this.plugins.lineRenderer.highlightedSeriesIndex=null,this.plugins.lineRenderer.highlightCanvas=new t.jqplot.GenericCanvas,this.eventCanvas._elem.before(this.plugins.lineRenderer.highlightCanvas.createElement(this._gridPadding,"jqplot-lineRenderer-highlight-canvas",this._plotDimensions,this)),this.plugins.lineRenderer.highlightCanvas.setContext(),this.eventCanvas._elem.bind("mouseleave",{plot:this},function(v){m(v.data.plot)})}function p(v,E,L,S){var P=v.series[E],W=v.plugins.lineRenderer.highlightCanvas;W._ctx.clearRect(0,0,W._ctx.canvas.width,W._ctx.canvas.height),P._highlightedPoint=L,v.plugins.lineRenderer.highlightedSeriesIndex=E;var K={fillStyle:P.highlightColor};P.type==="line"&&P.renderer.bands.show&&(K.fill=!0,K.closePath=!0),P.renderer.shapeRenderer.draw(W._ctx,S,K),W=null}function m(v){var E=v.plugins.lineRenderer.highlightCanvas;E._ctx.clearRect(0,0,E._ctx.canvas.width,E._ctx.canvas.height);for(var L=0;L<v.series.length;L++)v.series[L]._highlightedPoint=null;v.plugins.lineRenderer.highlightedSeriesIndex=null,v.target.trigger("jqplotDataUnhighlight"),E=null}function b(v,E,L,S,P){if(S){var W=[S.seriesIndex,S.pointIndex,S.data],K=ke.Event("jqplotDataMouseOver");if(K.pageX=v.pageX,K.pageY=v.pageY,P.target.trigger(K,W),P.series[W[0]].highlightMouseOver&&W[0]!=P.plugins.lineRenderer.highlightedSeriesIndex){var V=ke.Event("jqplotDataHighlight");V.which=v.which,V.pageX=v.pageX,V.pageY=v.pageY,P.target.trigger(V,W),p(P,S.seriesIndex,S.pointIndex,S.points)}}else S==null&&m(P)}function C(v,E,L,S,P){if(S){var W=[S.seriesIndex,S.pointIndex,S.data];if(P.series[W[0]].highlightMouseDown&&W[0]!=P.plugins.lineRenderer.highlightedSeriesIndex){var K=ke.Event("jqplotDataHighlight");K.which=v.which,K.pageX=v.pageX,K.pageY=v.pageY,P.target.trigger(K,W),p(P,S.seriesIndex,S.pointIndex,S.points)}}else S==null&&m(P)}function k(v,E,L,S,P){var W=P.plugins.lineRenderer.highlightedSeriesIndex;W!=null&&P.series[W].highlightMouseDown&&m(P)}function T(v,E,L,S,P){if(S){var W=[S.seriesIndex,S.pointIndex,S.data],K=ke.Event("jqplotDataClick");K.which=v.which,K.pageX=v.pageX,K.pageY=v.pageY,P.target.trigger(K,W)}}function w(v,E,L,S,P){if(S){var W=[S.seriesIndex,S.pointIndex,S.data],K=P.plugins.lineRenderer.highlightedSeriesIndex;K!=null&&P.series[K].highlightMouseDown&&m(P);var V=ke.Event("jqplotDataRightClick");V.which=v.which,V.pageX=v.pageX,V.pageY=v.pageY,P.target.trigger(V,W)}}t.jqplot.LinearAxisRenderer=function(){},t.jqplot.LinearAxisRenderer.prototype.init=function(v){this.breakPoints=null,this.breakTickLabel="&asymp;",this.drawBaseline=!0,this.baselineWidth=null,this.baselineColor=null,this.forceTickAt0=!1,this.forceTickAt100=!1,this.tickInset=0,this.minorTicks=0,this.alignTicks=!1,this._autoFormatString="",this._overrideFormatString=!1,this._scalefact=1,t.extend(!0,this,v),this.breakPoints&&(t.isArray(this.breakPoints)?(this.breakPoints.length<2||this.breakPoints[1]<=this.breakPoints[0])&&(this.breakPoints=null):this.breakPoints=null),this.numberTicks!=null&&this.numberTicks<2&&(this.numberTicks=2),this.resetDataBounds()},t.jqplot.LinearAxisRenderer.prototype.draw=function(v,E){if(this.show){if(this.renderer.createTicks.call(this,E),this._elem&&(this._elem.emptyForce(),this._elem=null),this._elem=t(document.createElement("div")),this._elem.addClass("jqplot-axis jqplot-"+this.name),this._elem.css("position","absolute"),this.name=="xaxis"||this.name=="x2axis"?this._elem.width(this._plotDimensions.width):this._elem.height(this._plotDimensions.height),this.labelOptions.axis=this.name,this._label=new this.labelRenderer(this.labelOptions),this._label.show){var L=this._label.draw(v,E);L.appendTo(this._elem),L=null}for(var S=this._ticks,P,W=0;W<S.length;W++)P=S[W],P.show&&P.showLabel&&(!P.isMinorTick||this.showMinorTicks)&&this._elem.append(P.draw(v,E));P=null,S=null}return this._elem},t.jqplot.LinearAxisRenderer.prototype.reset=function(){this.min=this._options.min,this.max=this._options.max,this.tickInterval=this._options.tickInterval,this.numberTicks=this._options.numberTicks,this._autoFormatString="",this._overrideFormatString&&this.tickOptions&&this.tickOptions.formatString&&(this.tickOptions.formatString="")},t.jqplot.LinearAxisRenderer.prototype.set=function(){var v=0,E,L=0,S=0,P=this._label==null?!1:this._label.show;if(this.show){for(var W=this._ticks,K,V=0;V<W.length;V++)K=W[V],!K._breakTick&&K.show&&K.showLabel&&(!K.isMinorTick||this.showMinorTicks)&&(this.name=="xaxis"||this.name=="x2axis"?E=K._elem.outerHeight(!0):E=K._elem.outerWidth(!0),E>v&&(v=E));K=null,W=null,P&&(L=this._label._elem.outerWidth(!0),S=this._label._elem.outerHeight(!0)),this.name=="xaxis"?(v=v+S,this._elem.css({height:v+"px",left:"0px",bottom:"0px"})):this.name=="x2axis"?(v=v+S,this._elem.css({height:v+"px",left:"0px",top:"0px"})):this.name=="yaxis"?(v=v+L,this._elem.css({width:v+"px",left:"0px",top:"0px"}),P&&this._label.constructor==t.jqplot.AxisLabelRenderer&&this._label._elem.css("width",L+"px")):(v=v+L,this._elem.css({width:v+"px",right:"0px",top:"0px"}),P&&this._label.constructor==t.jqplot.AxisLabelRenderer&&this._label._elem.css("width",L+"px"))}},t.jqplot.LinearAxisRenderer.prototype.createTicks=function(v){this._ticks;var E=this.ticks,L=this.name,S=this._dataBounds,P=this.name.charAt(0)==="x"?this._plotDimensions.width:this._plotDimensions.height,W,K,V,ee,Q=this.min,fe=this.max,oe=this.numberTicks,pe=this.tickInterval,ae=30;if(this._scalefact=(Math.max(P,ae+1)-ae)/300,E.length){for(ee=0;ee<E.length;ee++){var Ae=E[ee],Se=new this.tickRenderer(this.tickOptions);t.isArray(Ae)?(Se.value=Ae[0],this.breakPoints?Ae[0]==this.breakPoints[0]?(Se.label=this.breakTickLabel,Se._breakTick=!0,Se.showGridline=!1,Se.showMark=!1):(Ae[0]>this.breakPoints[0]&&Ae[0]<=this.breakPoints[1]&&(Se.show=!1,Se.showGridline=!1),Se.label=Ae[1]):Se.label=Ae[1],Se.setTick(Ae[0],this.name),this._ticks.push(Se)):t.isPlainObject(Ae)?(t.extend(!0,Se,Ae),Se.axis=this.name,this._ticks.push(Se)):(Se.value=Ae,this.breakPoints&&(Ae==this.breakPoints[0]?(Se.label=this.breakTickLabel,Se._breakTick=!0,Se.showGridline=!1,Se.showMark=!1):Ae>this.breakPoints[0]&&Ae<=this.breakPoints[1]&&(Se.show=!1,Se.showGridline=!1)),Se.setTick(Ae,this.name),this._ticks.push(Se))}this.numberTicks=E.length,this.min=this._ticks[0].value,this.max=this._ticks[this.numberTicks-1].value,this.tickInterval=(this.max-this.min)/(this.numberTicks-1)}else{L=="xaxis"||L=="x2axis"?P=this._plotDimensions.width:P=this._plotDimensions.height;var ze=this.numberTicks;this.alignTicks&&(this.name==="x2axis"&&v.axes.xaxis.show?ze=v.axes.xaxis.numberTicks:this.name.charAt(0)==="y"&&this.name!=="yaxis"&&this.name!=="yMidAxis"&&v.axes.yaxis.show&&(ze=v.axes.yaxis.numberTicks)),W=this.min!=null?this.min:S.min,K=this.max!=null?this.max:S.max;var Ve=K-W,Me,Le,Be;if((this.tickOptions==null||!this.tickOptions.formatString)&&(this._overrideFormatString=!0),this.min==null||this.max==null&&this.tickInterval==null&&!this.autoscale){this.forceTickAt0&&(W>0&&(W=0),K<0&&(K=0)),this.forceTickAt100&&(W>100&&(W=100),K<100&&(K=100));var Je=!1,Ue=!1;this.min!=null?Je=!0:this.max!=null&&(Ue=!0);var Ge=t.jqplot.LinearTickGenerator(W,K,this._scalefact,ze,Je,Ue),lt=this.min!=null?W:W+Ve*(this.padMin-1),et=this.max!=null?K:K-Ve*(this.padMax-1);(W<lt||K>et)&&(lt=this.min!=null?W:W-Ve*(this.padMin-1),et=this.max!=null?K:K+Ve*(this.padMax-1),Ge=t.jqplot.LinearTickGenerator(lt,et,this._scalefact,ze,Je,Ue)),this.min=Ge[0],this.max=Ge[1],this.numberTicks=Ge[2],this._autoFormatString=Ge[3],this.tickInterval=Ge[4]}else{if(W==K){var vt=.05;W>0&&(vt=Math.max(Math.log(W)/Math.LN10,.05)),W-=vt,K+=vt}if(this.autoscale&&this.min==null&&this.max==null){for(var Ft,bt,Ht,kt=!1,Bt=!1,ee=0;ee<this._series.length;ee++){var st=this._series[ee],Vt=st.fillAxis=="x"?st._xaxis.name:st._yaxis.name;if(this.name==Vt){for(var it=st._plotValues[st.fillAxis],St=it[0],It=it[0],Dt=1;Dt<it.length;Dt++)it[Dt]<St?St=it[Dt]:it[Dt]>It&&(It=it[Dt]);var Uu=(It-St)/It;st.renderer.constructor==t.jqplot.BarRenderer?St>=0&&(st.fillToZero||Uu>.1)?kt=!0:(kt=!1,st.fill&&st.fillToZero&&St<0&&It>0?Bt=!0:Bt=!1):st.fill?St>=0&&(st.fillToZero||Uu>.1)?kt=!0:St<0&&It>0&&st.fillToZero?(kt=!1,Bt=!0):(kt=!1,Bt=!1):St<0&&(kt=!1)}}if(kt)this.numberTicks=2+Math.ceil((P-(this.tickSpacing-1))/this.tickSpacing),this.min=0,Q=0,bt=K/(this.numberTicks-1),Be=Math.pow(10,Math.abs(Math.floor(Math.log(bt)/Math.LN10))),bt/Be==parseInt(bt/Be,10)&&(bt+=Be),this.tickInterval=Math.ceil(bt/Be)*Be,this.max=this.tickInterval*(this.numberTicks-1);else if(Bt){this.numberTicks=2+Math.ceil((P-(this.tickSpacing-1))/this.tickSpacing);var Dr=Math.ceil(Math.abs(W)/Ve*(this.numberTicks-1)),tr=this.numberTicks-1-Dr;bt=Math.max(Math.abs(W/Dr),Math.abs(K/tr)),Be=Math.pow(10,Math.abs(Math.floor(Math.log(bt)/Math.LN10))),this.tickInterval=Math.ceil(bt/Be)*Be,this.max=this.tickInterval*tr,this.min=-this.tickInterval*Dr}else this.numberTicks==null&&(this.tickInterval?this.numberTicks=3+Math.ceil(Ve/this.tickInterval):this.numberTicks=2+Math.ceil((P-(this.tickSpacing-1))/this.tickSpacing)),this.tickInterval==null?(bt=Ve/(this.numberTicks-1),bt<1?Be=Math.pow(10,Math.abs(Math.floor(Math.log(bt)/Math.LN10))):Be=1,this.tickInterval=Math.ceil(bt*Be*this.pad)/Be):Be=1/this.tickInterval,Ft=this.tickInterval*(this.numberTicks-1),Ht=(Ft-Ve)/2,this.min==null&&(this.min=Math.floor(Be*(W-Ht))/Be),this.max==null&&(this.max=this.min+Ft);var h0=t.jqplot.getSignificantFigures(this.tickInterval),k0;if(h0.digitsLeft>=h0.significantDigits)k0="%d";else{var Be=Math.max(0,5-h0.digitsLeft);Be=Math.min(Be,h0.digitsRight),k0="%."+Be+"f"}this._autoFormatString=k0}else{Me=this.min!=null?this.min:W-Ve*(this.padMin-1),Le=this.max!=null?this.max:K+Ve*(this.padMax-1),Ve=Le-Me,this.numberTicks==null&&(this.tickInterval!=null?this.numberTicks=Math.ceil((Le-Me)/this.tickInterval)+1:P>100?this.numberTicks=parseInt(3+(P-100)/75,10):this.numberTicks=2),this.tickInterval==null&&(this.tickInterval=Ve/(this.numberTicks-1)),this.max==null&&(Le=Me+this.tickInterval*(this.numberTicks-1)),this.min==null&&(Me=Le-this.tickInterval*(this.numberTicks-1));var h0=t.jqplot.getSignificantFigures(this.tickInterval),k0;if(h0.digitsLeft>=h0.significantDigits)k0="%d";else{var Be=Math.max(0,5-h0.digitsLeft);Be=Math.min(Be,h0.digitsRight),k0="%."+Be+"f"}this._autoFormatString=k0,this.min=Me,this.max=Le}if(this.renderer.constructor==t.jqplot.LinearAxisRenderer&&this._autoFormatString==""){Ve=this.max-this.min;var Mr=new this.tickRenderer(this.tickOptions),rr=Mr.formatString||t.jqplot.config.defaultTickFormatString,rr=rr.match(t.jqplot.sprintf.regex)[0],R0=0;if(rr){if(rr.search(/[fFeEgGpP]/)>-1){var zr=rr.match(/\%\.(\d{0,})?[eEfFgGpP]/);zr?R0=parseInt(zr[1],10):R0=6}else rr.search(/[di]/)>-1&&(R0=0);var Tr=Math.pow(10,-R0);if(this.tickInterval<Tr&&oe==null&&pe==null)if(this.tickInterval=Tr,fe==null&&Q==null){this.min=Math.floor(this._dataBounds.min/Tr)*Tr,this.min==this._dataBounds.min&&(this.min=this._dataBounds.min-this.tickInterval),this.max=Math.ceil(this._dataBounds.max/Tr)*Tr,this.max==this._dataBounds.max&&(this.max=this._dataBounds.max+this.tickInterval);var f0=(this.max-this.min)/this.tickInterval;f0=f0.toFixed(11),f0=Math.ceil(f0),this.numberTicks=f0+1}else if(fe==null){var f0=(this._dataBounds.max-this.min)/this.tickInterval;f0=f0.toFixed(11),this.numberTicks=Math.ceil(f0)+2,this.max=this.min+this.tickInterval*(this.numberTicks-1)}else if(Q==null){var f0=(this.max-this._dataBounds.min)/this.tickInterval;f0=f0.toFixed(11),this.numberTicks=Math.ceil(f0)+2,this.min=this.max-this.tickInterval*(this.numberTicks-1)}else this.numberTicks=Math.ceil((fe-Q)/this.tickInterval)+1,this.min=Math.floor(Q*Math.pow(10,R0))/Math.pow(10,R0),this.max=Math.ceil(fe*Math.pow(10,R0))/Math.pow(10,R0),this.numberTicks=Math.ceil((this.max-this.min)/this.tickInterval)+1}}}this._overrideFormatString&&this._autoFormatString!=""&&(this.tickOptions=this.tickOptions||{},this.tickOptions.formatString=this._autoFormatString);for(var Se,qu,ee=0;ee<this.numberTicks;ee++){if(V=this.min+ee*this.tickInterval,Se=new this.tickRenderer(this.tickOptions),Se.setTick(V,this.name),this._ticks.push(Se),ee<this.numberTicks-1)for(var Dt=0;Dt<this.minorTicks;Dt++)V+=this.tickInterval/(this.minorTicks+1),qu=t.extend(!0,{},this.tickOptions,{name:this.name,value:V,label:"",isMinorTick:!0}),Se=new this.tickRenderer(qu),this._ticks.push(Se);Se=null}}this.tickInset&&(this.min=this.min-this.tickInset*this.tickInterval,this.max=this.max+this.tickInset*this.tickInterval)},t.jqplot.LinearAxisRenderer.prototype.resetTickValues=function(v){if(t.isArray(v)&&v.length==this._ticks.length){for(var E,L=0;L<v.length;L++)E=this._ticks[L],E.value=v[L],E.label=E.formatter(E.formatString,v[L]),E.label=E.prefix+E.label,E._elem.html(E.label);E=null,this.min=t.jqplot.arrayMin(v),this.max=t.jqplot.arrayMax(v),this.pack()}},t.jqplot.LinearAxisRenderer.prototype.pack=function(v,E){v=v||{},E=E||this._offsets;var L=this._ticks,S=this.max,P=this.min,W=E.max,K=E.min,V=this._label==null?!1:this._label.show;for(var ee in v)this._elem.css(ee,v[ee]);this._offsets=E;var Q=W-K,fe=S-P;if(this.breakPoints?(fe=fe-this.breakPoints[1]+this.breakPoints[0],this.p2u=function(Me){return(Me-K)*fe/Q+P},this.u2p=function(Me){return Me>this.breakPoints[0]&&Me<this.breakPoints[1]&&(Me=this.breakPoints[0]),Me<=this.breakPoints[0]?(Me-P)*Q/fe+K:(Me-this.breakPoints[1]+this.breakPoints[0]-P)*Q/fe+K},this.name.charAt(0)=="x"?(this.series_u2p=function(Me){return Me>this.breakPoints[0]&&Me<this.breakPoints[1]&&(Me=this.breakPoints[0]),Me<=this.breakPoints[0]?(Me-P)*Q/fe:(Me-this.breakPoints[1]+this.breakPoints[0]-P)*Q/fe},this.series_p2u=function(Me){return Me*fe/Q+P}):(this.series_u2p=function(Me){return Me>this.breakPoints[0]&&Me<this.breakPoints[1]&&(Me=this.breakPoints[0]),Me>=this.breakPoints[1]?(Me-S)*Q/fe:(Me+this.breakPoints[1]-this.breakPoints[0]-S)*Q/fe},this.series_p2u=function(Me){return Me*fe/Q+S})):(this.p2u=function(Me){return(Me-K)*fe/Q+P},this.u2p=function(Me){return(Me-P)*Q/fe+K},this.name=="xaxis"||this.name=="x2axis"?(this.series_u2p=function(Me){return(Me-P)*Q/fe},this.series_p2u=function(Me){return Me*fe/Q+P}):(this.series_u2p=function(Me){return(Me-S)*Q/fe},this.series_p2u=function(Me){return Me*fe/Q+S})),this.show)if(this.name=="xaxis"||this.name=="x2axis"){for(var oe=0;oe<L.length;oe++){var pe=L[oe];if(pe.show&&pe.showLabel){var ae;if(pe.constructor==t.jqplot.CanvasAxisTickRenderer&&pe.angle){var Ae=this.name=="xaxis"?1:-1;switch(pe.labelPosition){case"auto":Ae*pe.angle<0?ae=-pe.getWidth()+pe._textRenderer.height*Math.sin(-pe._textRenderer.angle)/2:ae=-pe._textRenderer.height*Math.sin(pe._textRenderer.angle)/2;break;case"end":ae=-pe.getWidth()+pe._textRenderer.height*Math.sin(-pe._textRenderer.angle)/2;break;case"start":ae=-pe._textRenderer.height*Math.sin(pe._textRenderer.angle)/2;break;case"middle":ae=-pe.getWidth()/2+pe._textRenderer.height*Math.sin(-pe._textRenderer.angle)/2;break;default:ae=-pe.getWidth()/2+pe._textRenderer.height*Math.sin(-pe._textRenderer.angle)/2;break}}else ae=-pe.getWidth()/2;var Se=this.u2p(pe.value)+ae+"px";pe._elem.css("left",Se),pe.pack()}}if(V){var ze=this._label._elem.outerWidth(!0);this._label._elem.css("left",K+Q/2-ze/2+"px"),this.name=="xaxis"?this._label._elem.css("bottom","0px"):this._label._elem.css("top","0px"),this._label.pack()}}else{for(var oe=0;oe<L.length;oe++){var pe=L[oe];if(pe.show&&pe.showLabel){var ae;if(pe.constructor==t.jqplot.CanvasAxisTickRenderer&&pe.angle){var Ae=this.name=="yaxis"?1:-1;switch(pe.labelPosition){case"auto":case"end":Ae*pe.angle<0?ae=-pe._textRenderer.height*Math.cos(-pe._textRenderer.angle)/2:ae=-pe.getHeight()+pe._textRenderer.height*Math.cos(pe._textRenderer.angle)/2;break;case"start":pe.angle>0?ae=-pe._textRenderer.height*Math.cos(-pe._textRenderer.angle)/2:ae=-pe.getHeight()+pe._textRenderer.height*Math.cos(pe._textRenderer.angle)/2;break;case"middle":ae=-pe.getHeight()/2;break;default:ae=-pe.getHeight()/2;break}}else ae=-pe.getHeight()/2;var Se=this.u2p(pe.value)+ae+"px";pe._elem.css("top",Se),pe.pack()}}if(V){var Ve=this._label._elem.outerHeight(!0);this._label._elem.css("top",W-Q/2-Ve/2+"px"),this.name=="yaxis"?this._label._elem.css("left","0px"):this._label._elem.css("right","0px"),this._label.pack()}}L=null};function A(v){var E;if(v=Math.abs(v),v>=10)E="%d";else if(v>1)v===parseInt(v,10)?E="%d":E="%.1f";else{var L=-Math.floor(Math.log(v)/Math.LN10);E="%."+L+"f"}return E}function M(v,E,L){for(var S=Math.floor(L/2),P=Math.ceil(L*1.5),W=Number.MAX_VALUE,K=E-v,V,ee,Q,fe=t.jqplot.getSignificantFigures,oe,pe,ae,Ae,Se=0,ze=P-S+1;Se<ze;Se++)ae=S+Se,V=K/(ae-1),ee=fe(V),V=Math.abs(L-ae)+ee.digitsRight,V<W?(W=V,Q=ae,Ae=ee.digitsRight):V===W&&ee.digitsRight<Ae&&(Q=ae,Ae=ee.digitsRight);return oe=Math.max(Ae,Math.max(fe(v).digitsRight,fe(E).digitsRight)),oe===0?pe="%d":pe="%."+oe+"f",V=K/(Q-1),[v,E,Q,pe,V]}function x(v,E){E=E||7;var L=v/(E-1),S=Math.pow(10,Math.floor(Math.log(L)/Math.LN10)),P=L/S,W;return S<1?P>5?W=10*S:P>2?W=5*S:P>1?W=2*S:W=S:P>5?W=10*S:P>4?W=5*S:P>3?W=4*S:P>2?W=3*S:P>1?W=2*S:W=S,W}function R(v,E){E=E||1;var L=Math.floor(Math.log(v)/Math.LN10),S=Math.pow(10,L),P=v/S,W;return P=P/E,P<=.38?W=.1:P<=1.6?W=.2:P<=4?W=.5:P<=8?W=1:P<=16?W=2:W=5,W*S}function N(v,E){var L=Math.floor(Math.log(v)/Math.LN10),S=Math.pow(10,L),P=v/S,W,K;return P=P/E,P<=.38?K=.1:P<=1.6?K=.2:P<=4?K=.5:P<=8?K=1:P<=16?K=2:K=5,W=K*S,[W,K,S]}t.jqplot.LinearTickGenerator=function(v,E,L,S,P,W){if(P=P===null?!1:P,W=W===null||P?!1:W,v===E&&(E=E?0:1),L=L||1,E<v){var K=E;E=v,v=K}var V=[],ee=R(E-v,L),Q=t.jqplot.getSignificantFigures;if(S==null){if(!P&&!W)V[0]=Math.floor(v/ee)*ee,V[1]=Math.ceil(E/ee)*ee,V[2]=Math.round((V[1]-V[0])/ee+1),V[3]=A(ee),V[4]=ee;else if(P){V[0]=v,V[2]=Math.ceil((E-v)/ee+1),V[1]=v+(V[2]-1)*ee;var fe=Q(v).digitsRight,oe=Q(ee).digitsRight;fe<oe?V[3]=A(ee):V[3]="%."+fe+"f",V[4]=ee}else if(W){V[1]=E,V[2]=Math.ceil((E-v)/ee+1),V[0]=E-(V[2]-1)*ee;var pe=Q(E).digitsRight,oe=Q(ee).digitsRight;pe<oe?V[3]=A(ee):V[3]="%."+pe+"f",V[4]=ee}}else{var ae=[];if(ae[0]=Math.floor(v/ee)*ee,ae[1]=Math.ceil(E/ee)*ee,ae[2]=Math.round((ae[1]-ae[0])/ee+1),ae[3]=A(ee),ae[4]=ee,ae[2]===S)V=ae;else{var Ae=x(ae[1]-ae[0],S);V[0]=ae[0],V[2]=S,V[4]=Ae,V[3]=A(Ae),V[1]=V[0]+(V[2]-1)*V[4]}}return V},t.jqplot.LinearTickGenerator.bestLinearInterval=R,t.jqplot.LinearTickGenerator.bestInterval=x,t.jqplot.LinearTickGenerator.bestLinearComponents=N,t.jqplot.LinearTickGenerator.bestConstrainedInterval=M,t.jqplot.MarkerRenderer=function(v){this.show=!0,this.style="filledCircle",this.lineWidth=2,this.size=9,this.color="#666666",this.shadow=!0,this.shadowAngle=45,this.shadowOffset=1,this.shadowDepth=3,this.shadowAlpha="0.07",this.shadowRenderer=new t.jqplot.ShadowRenderer,this.shapeRenderer=new t.jqplot.ShapeRenderer,t.extend(!0,this,v)},t.jqplot.MarkerRenderer.prototype.init=function(v){t.extend(!0,this,v);var E={angle:this.shadowAngle,offset:this.shadowOffset,alpha:this.shadowAlpha,lineWidth:this.lineWidth,depth:this.shadowDepth,closePath:!0};this.style.indexOf("filled")!=-1&&(E.fill=!0),this.style.indexOf("ircle")!=-1&&(E.isarc=!0,E.closePath=!1),this.shadowRenderer.init(E);var L={fill:!1,isarc:!1,strokeStyle:this.color,fillStyle:this.color,lineWidth:this.lineWidth,closePath:!0};this.style.indexOf("filled")!=-1&&(L.fill=!0),this.style.indexOf("ircle")!=-1&&(L.isarc=!0,L.closePath=!1),this.shapeRenderer.init(L)},t.jqplot.MarkerRenderer.prototype.drawDiamond=function(v,E,L,S,P){var W=1.2,K=this.size/2/W,V=this.size/2*W,ee=[[v-K,E],[v,E+V],[v+K,E],[v,E-V]];this.shadow&&this.shadowRenderer.draw(L,ee),this.shapeRenderer.draw(L,ee,P)},t.jqplot.MarkerRenderer.prototype.drawPlus=function(v,E,L,S,P){var W=1,K=this.size/2*W,V=this.size/2*W,ee=[[v,E-V],[v,E+V]],Q=[[v+K,E],[v-K,E]],fe=t.extend(!0,{},this.options,{closePath:!1});this.shadow&&(this.shadowRenderer.draw(L,ee,{closePath:!1}),this.shadowRenderer.draw(L,Q,{closePath:!1})),this.shapeRenderer.draw(L,ee,fe),this.shapeRenderer.draw(L,Q,fe)},t.jqplot.MarkerRenderer.prototype.drawX=function(v,E,L,S,P){var W=1,K=this.size/2*W,V=this.size/2*W,ee=t.extend(!0,{},this.options,{closePath:!1}),Q=[[v-K,E-V],[v+K,E+V]],fe=[[v-K,E+V],[v+K,E-V]];this.shadow&&(this.shadowRenderer.draw(L,Q,{closePath:!1}),this.shadowRenderer.draw(L,fe,{closePath:!1})),this.shapeRenderer.draw(L,Q,ee),this.shapeRenderer.draw(L,fe,ee)},t.jqplot.MarkerRenderer.prototype.drawDash=function(v,E,L,S,P){var W=1,K=this.size/2*W;this.size/2*W;var V=[[v-K,E],[v+K,E]];this.shadow&&this.shadowRenderer.draw(L,V),this.shapeRenderer.draw(L,V,P)},t.jqplot.MarkerRenderer.prototype.drawLine=function(v,E,L,S,P){var W=[v,E];this.shadow&&this.shadowRenderer.draw(L,W),this.shapeRenderer.draw(L,W,P)},t.jqplot.MarkerRenderer.prototype.drawSquare=function(v,E,L,S,P){var W=1,K=this.size/2/W,V=this.size/2*W,ee=[[v-K,E-V],[v-K,E+V],[v+K,E+V],[v+K,E-V]];this.shadow&&this.shadowRenderer.draw(L,ee),this.shapeRenderer.draw(L,ee,P)},t.jqplot.MarkerRenderer.prototype.drawCircle=function(v,E,L,S,P){var W=this.size/2,K=2*Math.PI,V=[v,E,W,0,K,!0];this.shadow&&this.shadowRenderer.draw(L,V),this.shapeRenderer.draw(L,V,P)},t.jqplot.MarkerRenderer.prototype.draw=function(v,E,L,S){if(S=S||{},S.show==null||S.show!=!1)switch(S.color&&!S.fillStyle&&(S.fillStyle=S.color),S.color&&!S.strokeStyle&&(S.strokeStyle=S.color),this.style){case"diamond":this.drawDiamond(v,E,L,!1,S);break;case"filledDiamond":this.drawDiamond(v,E,L,!0,S);break;case"circle":this.drawCircle(v,E,L,!1,S);break;case"filledCircle":this.drawCircle(v,E,L,!0,S);break;case"square":this.drawSquare(v,E,L,!1,S);break;case"filledSquare":this.drawSquare(v,E,L,!0,S);break;case"x":this.drawX(v,E,L,!0,S);break;case"plus":this.drawPlus(v,E,L,!0,S);break;case"dash":this.drawDash(v,E,L,!0,S);break;case"line":this.drawLine(v,E,L,!1,S);break;default:this.drawDiamond(v,E,L,!1,S);break}},t.jqplot.ShadowRenderer=function(v){this.angle=45,this.offset=1,this.alpha=.07,this.lineWidth=1.5,this.lineJoin="miter",this.lineCap="round",this.closePath=!1,this.fill=!1,this.depth=3,this.strokeStyle="rgba(0,0,0,0.1)",this.isarc=!1,t.extend(!0,this,v)},t.jqplot.ShadowRenderer.prototype.init=function(v){t.extend(!0,this,v)},t.jqplot.ShadowRenderer.prototype.draw=function(v,E,L){v.save();var S=L??{},P=S.fill!=null?S.fill:this.fill,W=S.fillRect!=null?S.fillRect:this.fillRect,K=S.closePath!=null?S.closePath:this.closePath,V=S.offset!=null?S.offset:this.offset,ee=S.alpha!=null?S.alpha:this.alpha,Q=S.depth!=null?S.depth:this.depth,fe=S.isarc!=null?S.isarc:this.isarc,oe=S.linePattern!=null?S.linePattern:this.linePattern;v.lineWidth=S.lineWidth!=null?S.lineWidth:this.lineWidth,v.lineJoin=S.lineJoin!=null?S.lineJoin:this.lineJoin,v.lineCap=S.lineCap!=null?S.lineCap:this.lineCap,v.strokeStyle=S.strokeStyle||this.strokeStyle||"rgba(0,0,0,"+ee+")",v.fillStyle=S.fillStyle||this.fillStyle||"rgba(0,0,0,"+ee+")";for(var pe=0;pe<Q;pe++){var ae=t.jqplot.LinePattern(v,oe);if(v.translate(Math.cos(this.angle*Math.PI/180)*V,Math.sin(this.angle*Math.PI/180)*V),ae.beginPath(),fe)v.arc(E[0],E[1],E[2],E[3],E[4],!0);else if(W)W&&v.fillRect(E[0],E[1],E[2],E[3]);else if(E&&E.length)for(var Ae=!0,Se=0;Se<E.length;Se++)E[Se][0]!=null&&E[Se][1]!=null?Ae?(ae.moveTo(E[Se][0],E[Se][1]),Ae=!1):ae.lineTo(E[Se][0],E[Se][1]):Ae=!0;K&&ae.closePath(),P?v.fill():v.stroke()}v.restore()},t.jqplot.ShapeRenderer=function(v){this.lineWidth=1.5,this.linePattern="solid",this.lineJoin="miter",this.lineCap="round",this.closePath=!1,this.fill=!1,this.isarc=!1,this.fillRect=!1,this.strokeRect=!1,this.clearRect=!1,this.strokeStyle="#999999",this.fillStyle="#999999",t.extend(!0,this,v)},t.jqplot.ShapeRenderer.prototype.init=function(v){t.extend(!0,this,v)},t.jqplot.ShapeRenderer.prototype.draw=function(v,E,L){v.save();var S=L??{},P=S.fill!=null?S.fill:this.fill,W=S.closePath!=null?S.closePath:this.closePath,K=S.fillRect!=null?S.fillRect:this.fillRect,V=S.strokeRect!=null?S.strokeRect:this.strokeRect,ee=S.clearRect!=null?S.clearRect:this.clearRect,Q=S.isarc!=null?S.isarc:this.isarc,fe=S.linePattern!=null?S.linePattern:this.linePattern,oe=t.jqplot.LinePattern(v,fe);if(v.lineWidth=S.lineWidth||this.lineWidth,v.lineJoin=S.lineJoin||this.lineJoin,v.lineCap=S.lineCap||this.lineCap,v.strokeStyle=S.strokeStyle||S.color||this.strokeStyle,v.fillStyle=S.fillStyle||this.fillStyle,v.beginPath(),Q){v.arc(E[0],E[1],E[2],E[3],E[4],!0),W&&v.closePath(),P?v.fill():v.stroke(),v.restore();return}else if(ee){v.clearRect(E[0],E[1],E[2],E[3]),v.restore();return}else if(K||V){if(K&&v.fillRect(E[0],E[1],E[2],E[3]),V){v.strokeRect(E[0],E[1],E[2],E[3]),v.restore();return}}else if(E&&E.length){for(var pe=!0,ae=0;ae<E.length;ae++)E[ae][0]!=null&&E[ae][1]!=null?pe?(oe.moveTo(E[ae][0],E[ae][1]),pe=!1):oe.lineTo(E[ae][0],E[ae][1]):pe=!0;W&&oe.closePath(),P?v.fill():v.stroke()}v.restore()},t.jqplot.TableLegendRenderer=function(){},t.jqplot.TableLegendRenderer.prototype.init=function(v){t.extend(!0,this,v)},t.jqplot.TableLegendRenderer.prototype.addrow=function(v,E,L,S){var P=L?this.rowSpacing+"px":"0px",W,K,V,ee,Q;V=document.createElement("tr"),W=t(V),W.addClass("jqplot-table-legend"),V=null,S?W.prependTo(this._elem):W.appendTo(this._elem),this.showSwatches&&(K=t(document.createElement("td")),K.addClass("jqplot-table-legend jqplot-table-legend-swatch"),K.css({textAlign:"center",paddingTop:P}),ee=t(document.createElement("div")),ee.addClass("jqplot-table-legend-swatch-outline"),Q=t(document.createElement("div")),Q.addClass("jqplot-table-legend-swatch"),Q.css({backgroundColor:E,borderColor:E}),W.append(K.append(ee.append(Q)))),this.showLabels&&(K=t(document.createElement("td")),K.addClass("jqplot-table-legend jqplot-table-legend-label"),K.css("paddingTop",P),W.append(K),this.escapeHtml?K.text(v):K.html(v)),K=null,ee=null,Q=null,W=null,V=null},t.jqplot.TableLegendRenderer.prototype.draw=function(){if(this._elem&&(this._elem.emptyForce(),this._elem=null),this.show){var v=this._series,E=document.createElement("table");this._elem=t(E),this._elem.addClass("jqplot-table-legend");var L={position:"absolute"};this.background&&(L.background=this.background),this.border&&(L.border=this.border),this.fontSize&&(L.fontSize=this.fontSize),this.fontFamily&&(L.fontFamily=this.fontFamily),this.textColor&&(L.textColor=this.textColor),this.marginTop!=null&&(L.marginTop=this.marginTop),this.marginBottom!=null&&(L.marginBottom=this.marginBottom),this.marginLeft!=null&&(L.marginLeft=this.marginLeft),this.marginRight!=null&&(L.marginRight=this.marginRight);for(var S=!1,P=!1,W,K=0;K<v.length;K++)if(W=v[K],(W._stack||W.renderer.constructor==t.jqplot.BezierCurveRenderer)&&(P=!0),W.show&&W.showLabel){var V=this.labels[K]||W.label.toString();if(V){var ee=W.color;P&&K<v.length-1?S=!0:P&&K==v.length-1&&(S=!1),this.renderer.addrow.call(this,V,ee,S,P),S=!0}for(var Q=0;Q<t.jqplot.addLegendRowHooks.length;Q++){var fe=t.jqplot.addLegendRowHooks[Q].call(this,W);fe&&(this.renderer.addrow.call(this,fe.label,fe.color,S),S=!0)}V=null}}return this._elem},t.jqplot.TableLegendRenderer.prototype.pack=function(v){if(this.show)if(this.placement=="insideGrid")switch(this.location){case"nw":var E=v.left,L=v.top;this._elem.css("left",E),this._elem.css("top",L);break;case"n":var E=(v.left+(this._plotDimensions.width-v.right))/2-this.getWidth()/2,L=v.top;this._elem.css("left",E),this._elem.css("top",L);break;case"ne":var E=v.right,L=v.top;this._elem.css({right:E,top:L});break;case"e":var E=v.right,L=(v.top+(this._plotDimensions.height-v.bottom))/2-this.getHeight()/2;this._elem.css({right:E,top:L});break;case"se":var E=v.right,L=v.bottom;this._elem.css({right:E,bottom:L});break;case"s":var E=(v.left+(this._plotDimensions.width-v.right))/2-this.getWidth()/2,L=v.bottom;this._elem.css({left:E,bottom:L});break;case"sw":var E=v.left,L=v.bottom;this._elem.css({left:E,bottom:L});break;case"w":var E=v.left,L=(v.top+(this._plotDimensions.height-v.bottom))/2-this.getHeight()/2;this._elem.css({left:E,top:L});break;default:var E=v.right,L=v.bottom;this._elem.css({right:E,bottom:L});break}else if(this.placement=="outside")switch(this.location){case"nw":var E=this._plotDimensions.width-v.left,L=v.top;this._elem.css("right",E),this._elem.css("top",L);break;case"n":var E=(v.left+(this._plotDimensions.width-v.right))/2-this.getWidth()/2,L=this._plotDimensions.height-v.top;this._elem.css("left",E),this._elem.css("bottom",L);break;case"ne":var E=this._plotDimensions.width-v.right,L=v.top;this._elem.css({left:E,top:L});break;case"e":var E=this._plotDimensions.width-v.right,L=(v.top+(this._plotDimensions.height-v.bottom))/2-this.getHeight()/2;this._elem.css({left:E,top:L});break;case"se":var E=this._plotDimensions.width-v.right,L=v.bottom;this._elem.css({left:E,bottom:L});break;case"s":var E=(v.left+(this._plotDimensions.width-v.right))/2-this.getWidth()/2,L=this._plotDimensions.height-v.bottom;this._elem.css({left:E,top:L});break;case"sw":var E=this._plotDimensions.width-v.left,L=v.bottom;this._elem.css({right:E,bottom:L});break;case"w":var E=this._plotDimensions.width-v.left,L=(v.top+(this._plotDimensions.height-v.bottom))/2-this.getHeight()/2;this._elem.css({right:E,top:L});break;default:var E=v.right,L=v.bottom;this._elem.css({right:E,bottom:L});break}else switch(this.location){case"nw":this._elem.css({left:0,top:v.top});break;case"n":var E=(v.left+(this._plotDimensions.width-v.right))/2-this.getWidth()/2;this._elem.css({left:E,top:v.top});break;case"ne":this._elem.css({right:0,top:v.top});break;case"e":var L=(v.top+(this._plotDimensions.height-v.bottom))/2-this.getHeight()/2;this._elem.css({right:v.right,top:L});break;case"se":this._elem.css({right:v.right,bottom:v.bottom});break;case"s":var E=(v.left+(this._plotDimensions.width-v.right))/2-this.getWidth()/2;this._elem.css({left:E,bottom:v.bottom});break;case"sw":this._elem.css({left:v.left,bottom:v.bottom});break;case"w":var L=(v.top+(this._plotDimensions.height-v.bottom))/2-this.getHeight()/2;this._elem.css({left:v.left,top:L});break;default:this._elem.css({right:v.right,bottom:v.bottom});break}},t.jqplot.ThemeEngine=function(){this.themes={},this.activeTheme=null},t.jqplot.ThemeEngine.prototype.init=function(){var v=new t.jqplot.Theme({_name:"Default"}),E,L,S;for(E in v.target)E=="textColor"?v.target[E]=this.target.css("color"):v.target[E]=this.target.css(E);if(this.title.show&&this.title._elem)for(E in v.title)E=="textColor"?v.title[E]=this.title._elem.css("color"):v.title[E]=this.title._elem.css(E);for(E in v.grid)v.grid[E]=this.grid[E];if(v.grid.backgroundColor==null&&this.grid.background!=null&&(v.grid.backgroundColor=this.grid.background),this.legend.show&&this.legend._elem)for(E in v.legend)E=="textColor"?v.legend[E]=this.legend._elem.css("color"):v.legend[E]=this.legend._elem.css(E);var P;for(L=0;L<this.series.length;L++){P=this.series[L],P.renderer.constructor==t.jqplot.LineRenderer?v.series.push(new le):P.renderer.constructor==t.jqplot.BarRenderer?v.series.push(new de):P.renderer.constructor==t.jqplot.PieRenderer?v.series.push(new he):P.renderer.constructor==t.jqplot.DonutRenderer?v.series.push(new Fe):P.renderer.constructor==t.jqplot.FunnelRenderer?v.series.push(new ge):P.renderer.constructor==t.jqplot.MeterGaugeRenderer?v.series.push(new ye):v.series.push({});for(E in v.series[L])v.series[L][E]=P[E]}var W,K;for(E in this.axes){if(K=this.axes[E],W=v.axes[E]=new U,W.borderColor=K.borderColor,W.borderWidth=K.borderWidth,K._ticks&&K._ticks[0])for(S in W.ticks)K._ticks[0].hasOwnProperty(S)?W.ticks[S]=K._ticks[0][S]:K._ticks[0]._elem&&(W.ticks[S]=K._ticks[0]._elem.css(S));if(K._label&&K._label.show)for(S in W.label)K._label[S]?W.label[S]=K._label[S]:K._label._elem&&(S=="textColor"?W.label[S]=K._label._elem.css("color"):W.label[S]=K._label._elem.css(S))}this.themeEngine._add(v),this.themeEngine.activeTheme=this.themeEngine.themes[v._name]},t.jqplot.ThemeEngine.prototype.get=function(v){return v?this.themes[v]:this.activeTheme};function j(v,E){return v-E}t.jqplot.ThemeEngine.prototype.getThemeNames=function(){var v=[];for(var E in this.themes)v.push(E);return v.sort(j)},t.jqplot.ThemeEngine.prototype.getThemes=function(){var v=[],E=[];for(var L in this.themes)v.push(L);v.sort(j);for(var S=0;S<v.length;S++)E.push(this.themes[v[S]]);return E},t.jqplot.ThemeEngine.prototype.activate=function(v,E){var L=!1;if(!E&&this.activeTheme&&this.activeTheme._name&&(E=this.activeTheme._name),this.themes.hasOwnProperty(E)){var S=this.themes[E];this.activeTheme=S;var P,W=["xaxis","x2axis","yaxis","y2axis"];for(Ae=0;Ae<W.length;Ae++){var K=W[Ae];S.axesStyles.borderColor!=null&&(v.axes[K].borderColor=S.axesStyles.borderColor),S.axesStyles.borderWidth!=null&&(v.axes[K].borderWidth=S.axesStyles.borderWidth)}for(var V in v.axes){var ee=v.axes[V];if(ee.show){var Q=S.axes[V]||{},fe=S.axesStyles,oe=t.jqplot.extend(!0,{},Q,fe);if(P=S.axesStyles.borderColor!=null?S.axesStyles.borderColor:oe.borderColor,oe.borderColor!=null&&(ee.borderColor=oe.borderColor,L=!0),P=S.axesStyles.borderWidth!=null?S.axesStyles.borderWidth:oe.borderWidth,oe.borderWidth!=null&&(ee.borderWidth=oe.borderWidth,L=!0),ee._ticks&&ee._ticks[0])for(var pe in oe.ticks)P=oe.ticks[pe],P!=null&&(ee.tickOptions[pe]=P,ee._ticks=[],L=!0);if(ee._label&&ee._label.show)for(var pe in oe.label)P=oe.label[pe],P!=null&&(ee.labelOptions[pe]=P,L=!0)}}for(var ae in S.grid)S.grid[ae]!=null&&(v.grid[ae]=S.grid[ae]);if(L||v.grid.draw(),v.legend.show)for(ae in S.legend)S.legend[ae]!=null&&(v.legend[ae]=S.legend[ae]);if(v.title.show)for(ae in S.title)S.title[ae]!=null&&(v.title[ae]=S.title[ae]);var Ae;for(Ae=0;Ae<S.series.length;Ae++){var Se={};for(ae in S.series[Ae])P=S.seriesStyles[ae]!=null?S.seriesStyles[ae]:S.series[Ae][ae],P!=null&&(Se[ae]=P,ae=="color"?(v.series[Ae].renderer.shapeRenderer.fillStyle=P,v.series[Ae].renderer.shapeRenderer.strokeStyle=P,v.series[Ae][ae]=P):ae=="lineWidth"||ae=="linePattern"?(v.series[Ae].renderer.shapeRenderer[ae]=P,v.series[Ae][ae]=P):ae=="markerOptions"?(q(v.series[Ae].markerOptions,P),q(v.series[Ae].markerRenderer,P)):v.series[Ae][ae]=P,L=!0)}L&&(v.target.empty(),v.draw());for(ae in S.target)S.target[ae]!=null&&v.target.css(ae,S.target[ae])}else throw new Error("No theme of that name")},t.jqplot.ThemeEngine.prototype._add=function(v,E){if(E&&(v._name=E),v._name||(v._name=Date.parse(new Date)),!this.themes.hasOwnProperty(v._name))this.themes[v._name]=v;else throw new Error("jqplot.ThemeEngine Error: Theme already in use")},t.jqplot.ThemeEngine.prototype.remove=function(v){return v=="Default"?!1:delete this.themes[v]},t.jqplot.ThemeEngine.prototype.newTheme=function(v,E){typeof v=="object"&&(E=E||v,v=null),E&&E._name?v=E._name:v=v||Date.parse(new Date);var L=this.copy(this.themes.Default._name,v);return t.jqplot.extend(L,E),L};function B(v){if(v==null||typeof v!="object")return v;var E=new v.constructor;for(var L in v)E[L]=B(v[L]);return E}t.jqplot.clone=B;function q(v,E){if(!(E==null||typeof E!="object"))for(var L in E)L=="highlightColors"&&(v[L]=B(E[L])),E[L]!=null&&typeof E[L]=="object"?(v.hasOwnProperty(L)||(v[L]={}),q(v[L],E[L])):v[L]=E[L]}t.jqplot.merge=q,t.jqplot.extend=function(){var v=arguments[0]||{},E=1,L=arguments.length,S=!1,P;for(typeof v=="boolean"&&(S=v,v=arguments[1]||{},E=2),typeof v!="object"&&!toString.call(v)==="[object Function]"&&(v={});E<L;E++)if((P=arguments[E])!=null)for(var W in P){var K=v[W],V=P[W];v!==V&&(S&&V&&typeof V=="object"&&!V.nodeType?v[W]=t.jqplot.extend(S,K||(V.length!=null?[]:{}),V):V!==e&&(v[W]=V))}return v},t.jqplot.ThemeEngine.prototype.rename=function(v,E){if(v=="Default"||E=="Default")throw new Error("jqplot.ThemeEngine Error: Cannot rename from/to Default");if(this.themes.hasOwnProperty(E))throw new Error("jqplot.ThemeEngine Error: New name already in use.");if(this.themes.hasOwnProperty(v)){var L=this.copy(v,E);return this.remove(v),L}throw new Error("jqplot.ThemeEngine Error: Old name or new name invalid")},t.jqplot.ThemeEngine.prototype.copy=function(v,E,L){if(E=="Default")throw new Error("jqplot.ThemeEngine Error: Cannot copy over Default theme");if(!this.themes.hasOwnProperty(v)){var S="jqplot.ThemeEngine Error: Source name invalid";throw new Error(S)}if(this.themes.hasOwnProperty(E)){var S="jqplot.ThemeEngine Error: Target name invalid";throw new Error(S)}else{var P=B(this.themes[v]);return P._name=E,t.jqplot.extend(!0,P,L),this._add(P),P}},t.jqplot.Theme=function(v,E){typeof v=="object"&&(E=E||v,v=null),v=v||Date.parse(new Date),this._name=v,this.target={backgroundColor:null},this.legend={textColor:null,fontFamily:null,fontSize:null,border:null,background:null},this.title={textColor:null,fontFamily:null,fontSize:null,textAlign:null},this.seriesStyles={},this.series=[],this.grid={drawGridlines:null,gridLineColor:null,gridLineWidth:null,backgroundColor:null,borderColor:null,borderWidth:null,shadow:null},this.axesStyles={label:{},ticks:{}},this.axes={},typeof E=="string"?this._name=E:typeof E=="object"&&t.jqplot.extend(!0,this,E)};var U=function(){this.borderColor=null,this.borderWidth=null,this.ticks=new Z,this.label=new re},Z=function(){this.show=null,this.showGridline=null,this.showLabel=null,this.showMark=null,this.size=null,this.textColor=null,this.whiteSpace=null,this.fontSize=null,this.fontFamily=null},re=function(){this.textColor=null,this.whiteSpace=null,this.fontSize=null,this.fontFamily=null,this.fontWeight=null},le=function(){this.color=null,this.lineWidth=null,this.linePattern=null,this.shadow=null,this.fillColor=null,this.showMarker=null,this.markerOptions=new ce},ce=function(){this.show=null,this.style=null,this.lineWidth=null,this.size=null,this.color=null,this.shadow=null},de=function(){this.color=null,this.seriesColors=null,this.lineWidth=null,this.shadow=null,this.barPadding=null,this.barMargin=null,this.barWidth=null,this.highlightColors=null},he=function(){this.seriesColors=null,this.padding=null,this.sliceMargin=null,this.fill=null,this.shadow=null,this.startAngle=null,this.lineWidth=null,this.highlightColors=null},Fe=function(){this.seriesColors=null,this.padding=null,this.sliceMargin=null,this.fill=null,this.shadow=null,this.startAngle=null,this.lineWidth=null,this.innerDiameter=null,this.thickness=null,this.ringMargin=null,this.highlightColors=null},ge=function(){this.color=null,this.lineWidth=null,this.shadow=null,this.padding=null,this.sectionMargin=null,this.seriesColors=null,this.highlightColors=null},ye=function(){this.padding=null,this.backgroundColor=null,this.ringColor=null,this.tickColor=null,this.ringWidth=null,this.intervalColors=null,this.intervalInnerRadius=null,this.intervalOuterRadius=null,this.hubRadius=null,this.needleThickness=null,this.needlePad=null};t.fn.jqplotChildText=function(){return t(this).contents().filter(function(){return this.nodeType==3}).text()},t.fn.jqplotGetComputedFontStyle=function(){for(var v=window.getComputedStyle?window.getComputedStyle(this[0],""):this[0].currentStyle,E=v["font-style"]?["font-style","font-weight","font-size","font-family"]:["fontStyle","fontWeight","fontSize","fontFamily"],L=[],S=0;S<E.length;++S){var P=String(v[E[S]]);P&&P!="normal"&&L.push(P)}return L.join(" ")},t.fn.jqplotToImageCanvas=function(v){v=v||{};var E=v.x_offset==null?0:v.x_offset,L=v.y_offset==null?0:v.y_offset,S=v.backgroundColor==null?"rgb(255,255,255)":v.backgroundColor;if(t(this).width()==0||t(this).height()==0||t.jqplot.use_excanvas)return null;for(var P=document.createElement("canvas"),W=t(this).outerHeight(!0),K=t(this).outerWidth(!0),V=t(this).offset(),ee=V.left,Q=V.top,fe=0,oe=0,pe=["jqplot-table-legend","jqplot-xaxis-tick","jqplot-x2axis-tick","jqplot-yaxis-tick","jqplot-y2axis-tick","jqplot-y3axis-tick","jqplot-y4axis-tick","jqplot-y5axis-tick","jqplot-y6axis-tick","jqplot-y7axis-tick","jqplot-y8axis-tick","jqplot-y9axis-tick","jqplot-xaxis-label","jqplot-x2axis-label","jqplot-yaxis-label","jqplot-y2axis-label","jqplot-y3axis-label","jqplot-y4axis-label","jqplot-y5axis-label","jqplot-y6axis-label","jqplot-y7axis-label","jqplot-y8axis-label","jqplot-y9axis-label"],ae,Ae,Se,ze,Ve=0;Ve<pe.length;Ve++)t(this).find("."+pe[Ve]).each(function(){ae=t(this).offset().top-Q,Ae=t(this).offset().left-ee,ze=Ae+t(this).outerWidth(!0)+fe,Se=ae+t(this).outerHeight(!0)+oe,Ae<-fe&&(K=K-fe-Ae,fe=-Ae),ae<-oe&&(W=W-oe-ae,oe=-ae),ze>K&&(K=ze),Se>W&&(W=Se)});P.width=K+Number(E),P.height=W+Number(L);var Me=P.getContext("2d");Me.save(),Me.fillStyle=S,Me.fillRect(0,0,P.width,P.height),Me.restore(),Me.translate(fe,oe),Me.textAlign="left",Me.textBaseline="top";function Le(Ue){var Ge=parseInt(t(Ue).css("line-height"),10);return isNaN(Ge)&&(Ge=parseInt(t(Ue).css("font-size"),10)*1.2),Ge}function Be(Ue,Ge,lt,et,vt,Ft){var bt=Le(Ue),Ht=t(Ue).innerWidth();t(Ue).innerHeight();for(var kt=lt.split(/\s+/),Bt=kt.length,st="",Vt=[],it=vt,St=et,It=0;It<Bt;It++)st+=kt[It],Ge.measureText(st).width>Ht&&(Vt.push(It),st="",It--);if(Vt.length===0)t(Ue).css("textAlign")==="center"&&(St=et+(Ft-Ge.measureText(st).width)/2-fe),Ge.fillText(lt,St,vt);else{st=kt.slice(0,Vt[0]).join(" "),t(Ue).css("textAlign")==="center"&&(St=et+(Ft-Ge.measureText(st).width)/2-fe),Ge.fillText(st,St,it),it+=bt;for(var It=1,Dt=Vt.length;It<Dt;It++)st=kt.slice(Vt[It-1],Vt[It]).join(" "),t(Ue).css("textAlign")==="center"&&(St=et+(Ft-Ge.measureText(st).width)/2-fe),Ge.fillText(st,St,it),it+=bt;st=kt.slice(Vt[It-1],kt.length).join(" "),t(Ue).css("textAlign")==="center"&&(St=et+(Ft-Ge.measureText(st).width)/2-fe),Ge.fillText(st,St,it)}}function Je(Ue,Ge,lt){var et=Ue.tagName.toLowerCase(),vt=t(Ue).position(),Ft=window.getComputedStyle?window.getComputedStyle(Ue,""):Ue.currentStyle,bt=Ge+vt.left+parseInt(Ft.marginLeft,10)+parseInt(Ft.borderLeftWidth,10)+parseInt(Ft.paddingLeft,10),Ht=lt+vt.top+parseInt(Ft.marginTop,10)+parseInt(Ft.borderTopWidth,10)+parseInt(Ft.paddingTop,10),kt=P.width;if((et=="div"||et=="span")&&!t(Ue).hasClass("jqplot-highlighter-tooltip")){t(Ue).children().each(function(){Je(this,bt,Ht)});var Bt=t(Ue).jqplotChildText();Bt&&(Me.font=t(Ue).jqplotGetComputedFontStyle(),Me.fillStyle=t(Ue).css("color"),Be(Ue,Me,Bt,bt,Ht,kt))}else et==="table"&&t(Ue).hasClass("jqplot-table-legend")?(Me.strokeStyle=t(Ue).css("border-top-color"),Me.fillStyle=t(Ue).css("background-color"),Me.fillRect(bt,Ht,t(Ue).innerWidth(),t(Ue).innerHeight()),parseInt(t(Ue).css("border-top-width"),10)>0&&Me.strokeRect(bt,Ht,t(Ue).innerWidth(),t(Ue).innerHeight()),t(Ue).find("div.jqplot-table-legend-swatch-outline").each(function(){var st=t(this);Me.strokeStyle=st.css("border-top-color");var Vt=bt+st.position().left,it=Ht+st.position().top;Me.strokeRect(Vt,it,st.innerWidth(),st.innerHeight()),Vt+=parseInt(st.css("padding-left"),10),it+=parseInt(st.css("padding-top"),10);var St=st.innerHeight()-2*parseInt(st.css("padding-top"),10),It=st.innerWidth()-2*parseInt(st.css("padding-left"),10),Dt=st.children("div.jqplot-table-legend-swatch");Me.fillStyle=Dt.css("background-color"),Me.fillRect(Vt,it,It,St)}),t(Ue).find("td.jqplot-table-legend-label").each(function(){var st=t(this),Vt=bt+st.position().left,it=Ht+st.position().top+parseInt(st.css("padding-top"),10);Me.font=st.jqplotGetComputedFontStyle(),Me.fillStyle=st.css("color"),Be(st,Me,st.text(),Vt,it,kt)})):et=="canvas"&&Me.drawImage(Ue,bt,Ht)}return t(this).children().each(function(){Je(this,E,L)}),P},t.fn.jqplotToImageStr=function(v){var E=t(this).jqplotToImageCanvas(v);return E?E.toDataURL("image/png"):null},t.fn.jqplotToImageElem=function(v){var E=document.createElement("img"),L=t(this).jqplotToImageStr(v);return E.src=L,E},t.fn.jqplotToImageElemStr=function(v){var E="<img src="+t(this).jqplotToImageStr(v)+" />";return E},t.fn.jqplotSaveImage=function(){var v=t(this).jqplotToImageStr({});v&&(window.location.href=v.replace("image/png","image/octet-stream"))},t.fn.jqplotViewImage=function(){var v=t(this).jqplotToImageElemStr({});if(t(this).jqplotToImageStr({}),v){var E=window.open("");E.document.open("image/png"),E.document.write(v),E.document.close(),E=null}};var Y=function(){switch(this.syntax=Y.config.syntax,this._type="jsDate",this.proxy=new Date,this.options={},this.locale=Y.regional.getLocale(),this.formatString="",this.defaultCentury=Y.config.defaultCentury,arguments.length){case 0:break;case 1:if(Pe(arguments[0])=="[object Object]"&&arguments[0]._type!="jsDate"){var v=this.options=arguments[0];this.syntax=v.syntax||this.syntax,this.defaultCentury=v.defaultCentury||this.defaultCentury,this.proxy=Y.createDate(v.date)}else this.proxy=Y.createDate(arguments[0]);break;default:for(var E=[],L=0;L<arguments.length;L++)E.push(arguments[L]);this.proxy=new Date,this.proxy.setFullYear.apply(this.proxy,E.slice(0,3)),E.slice(3).length&&this.proxy.setHours.apply(this.proxy,E.slice(3));break}};Y.config={defaultLocale:"en",syntax:"perl",defaultCentury:1900},Y.prototype.add=function(v,E){var L=ne[E]||ne.day;return typeof L=="number"?this.proxy.setTime(this.proxy.getTime()+L*v):L.add(this,v),this},Y.prototype.clone=function(){return new Y(this.proxy.getTime())},Y.prototype.getUtcOffset=function(){return this.proxy.getTimezoneOffset()*6e4},Y.prototype.diff=function(v,E,L){if(v=new Y(v),v===null)return null;var S=ne[E]||ne.day;if(typeof S=="number")var P=(this.proxy.getTime()-v.proxy.getTime())/S;else var P=S.diff(this.proxy,v.proxy);return L?P:Math[P>0?"floor":"ceil"](P)},Y.prototype.getAbbrDayName=function(){return Y.regional[this.locale].dayNamesShort[this.proxy.getDay()]},Y.prototype.getAbbrMonthName=function(){return Y.regional[this.locale].monthNamesShort[this.proxy.getMonth()]},Y.prototype.getAMPM=function(){return this.proxy.getHours()>=12?"PM":"AM"},Y.prototype.getAmPm=function(){return this.proxy.getHours()>=12?"pm":"am"},Y.prototype.getCentury=function(){return parseInt(this.proxy.getFullYear()/100,10)},Y.prototype.getDate=function(){return this.proxy.getDate()},Y.prototype.getDay=function(){return this.proxy.getDay()},Y.prototype.getDayOfWeek=function(){var v=this.proxy.getDay();return v===0?7:v},Y.prototype.getDayOfYear=function(){var v=this.proxy,E=v-new Date(""+v.getFullYear()+"/1/1 GMT");return E+=v.getTimezoneOffset()*6e4,v=null,parseInt(E/6e4/60/24,10)+1},Y.prototype.getDayName=function(){return Y.regional[this.locale].dayNames[this.proxy.getDay()]},Y.prototype.getFullWeekOfYear=function(){var v=this.proxy,E=this.getDayOfYear(),L=6-v.getDay(),S=parseInt((E+L)/7,10);return S},Y.prototype.getFullYear=function(){return this.proxy.getFullYear()},Y.prototype.getGmtOffset=function(){var v=this.proxy.getTimezoneOffset()/60,E=v<0?"+":"-";return v=Math.abs(v),E+Ee(Math.floor(v),2)+":"+Ee(v%1*60,2)},Y.prototype.getHours=function(){return this.proxy.getHours()},Y.prototype.getHours12=function(){var v=this.proxy.getHours();return v>12?v-12:v==0?12:v},Y.prototype.getIsoWeek=function(){var v=this.proxy,E=this.getWeekOfYear(),L=new Date(""+v.getFullYear()+"/1/1").getDay(),S=E+(L>4||L<=1?0:1);return S==53&&new Date(""+v.getFullYear()+"/12/31").getDay()<4?S=1:S===0&&(v=new Y(new Date(""+(v.getFullYear()-1)+"/12/31")),S=v.getIsoWeek()),v=null,S},Y.prototype.getMilliseconds=function(){return this.proxy.getMilliseconds()},Y.prototype.getMinutes=function(){return this.proxy.getMinutes()},Y.prototype.getMonth=function(){return this.proxy.getMonth()},Y.prototype.getMonthName=function(){return Y.regional[this.locale].monthNames[this.proxy.getMonth()]},Y.prototype.getMonthNumber=function(){return this.proxy.getMonth()+1},Y.prototype.getSeconds=function(){return this.proxy.getSeconds()},Y.prototype.getShortYear=function(){return this.proxy.getYear()%100},Y.prototype.getTime=function(){return this.proxy.getTime()},Y.prototype.getTimezoneAbbr=function(){return this.proxy.toString().replace(/^.*\(([^)]+)\)$/,"$1")},Y.prototype.getTimezoneName=function(){var v=/(?:\((.+)\)$| ([A-Z]{3}) )/.exec(this.toString());return v[1]||v[2]||"GMT"+this.getGmtOffset()},Y.prototype.getTimezoneOffset=function(){return this.proxy.getTimezoneOffset()},Y.prototype.getWeekOfYear=function(){var v=this.getDayOfYear(),E=7-this.getDayOfWeek(),L=parseInt((v+E)/7,10);return L},Y.prototype.getUnix=function(){return Math.round(this.proxy.getTime()/1e3,0)},Y.prototype.getYear=function(){return this.proxy.getYear()},Y.prototype.next=function(v){return v=v||"day",this.clone().add(1,v)},Y.prototype.set=function(){switch(arguments.length){case 0:this.proxy=new Date;break;case 1:if(Pe(arguments[0])=="[object Object]"&&arguments[0]._type!="jsDate"){var v=this.options=arguments[0];this.syntax=v.syntax||this.syntax,this.defaultCentury=v.defaultCentury||this.defaultCentury,this.proxy=Y.createDate(v.date)}else this.proxy=Y.createDate(arguments[0]);break;default:for(var E=[],L=0;L<arguments.length;L++)E.push(arguments[L]);this.proxy=new Date,this.proxy.setFullYear.apply(this.proxy,E.slice(0,3)),E.slice(3).length&&this.proxy.setHours.apply(this.proxy,E.slice(3));break}return this},Y.prototype.setDate=function(v){return this.proxy.setDate(v),this},Y.prototype.setFullYear=function(){return this.proxy.setFullYear.apply(this.proxy,arguments),this},Y.prototype.setHours=function(){return this.proxy.setHours.apply(this.proxy,arguments),this},Y.prototype.setMilliseconds=function(v){return this.proxy.setMilliseconds(v),this},Y.prototype.setMinutes=function(){return this.proxy.setMinutes.apply(this.proxy,arguments),this},Y.prototype.setMonth=function(){return this.proxy.setMonth.apply(this.proxy,arguments),this},Y.prototype.setSeconds=function(){return this.proxy.setSeconds.apply(this.proxy,arguments),this},Y.prototype.setTime=function(v){return this.proxy.setTime(v),this},Y.prototype.setYear=function(){return this.proxy.setYear.apply(this.proxy,arguments),this},Y.prototype.strftime=function(v){return v=v||this.formatString||Y.regional[this.locale].formatString,Y.strftime(this,v,this.syntax)},Y.prototype.toString=function(){return this.proxy.toString()},Y.prototype.toYmdInt=function(){return this.proxy.getFullYear()*1e4+this.getMonthNumber()*100+this.proxy.getDate()},Y.regional={en:{monthNames:["January","February","March","April","May","June","July","August","September","October","November","December"],monthNamesShort:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayNames:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayNamesShort:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],formatString:"%Y-%m-%d %H:%M:%S"},fr:{monthNames:["Janvier","Février","Mars","Avril","Mai","Juin","Juillet","Août","Septembre","Octobre","Novembre","Décembre"],monthNamesShort:["Jan","Fév","Mar","Avr","Mai","Jun","Jul","Aoû","Sep","Oct","Nov","Déc"],dayNames:["Dimanche","Lundi","Mardi","Mercredi","Jeudi","Vendredi","Samedi"],dayNamesShort:["Dim","Lun","Mar","Mer","Jeu","Ven","Sam"],formatString:"%Y-%m-%d %H:%M:%S"},de:{monthNames:["Januar","Februar","März","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember"],monthNamesShort:["Jan","Feb","Mär","Apr","Mai","Jun","Jul","Aug","Sep","Okt","Nov","Dez"],dayNames:["Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag"],dayNamesShort:["So","Mo","Di","Mi","Do","Fr","Sa"],formatString:"%Y-%m-%d %H:%M:%S"},es:{monthNames:["Enero","Febrero","Marzo","Abril","Mayo","Junio","Julio","Agosto","Septiembre","Octubre","Noviembre","Diciembre"],monthNamesShort:["Ene","Feb","Mar","Abr","May","Jun","Jul","Ago","Sep","Oct","Nov","Dic"],dayNames:["Domingo","Lunes","Martes","Mi&eacute;rcoles","Jueves","Viernes","S&aacute;bado"],dayNamesShort:["Dom","Lun","Mar","Mi&eacute;","Juv","Vie","S&aacute;b"],formatString:"%Y-%m-%d %H:%M:%S"},ru:{monthNames:["Январь","Февраль","Март","Апрель","Май","Июнь","Июль","Август","Сентябрь","Октябрь","Ноябрь","Декабрь"],monthNamesShort:["Янв","Фев","Мар","Апр","Май","Июн","Июл","Авг","Сен","Окт","Ноя","Дек"],dayNames:["воскресенье","понедельник","вторник","среда","четверг","пятница","суббота"],dayNamesShort:["вск","пнд","втр","срд","чтв","птн","сбт"],formatString:"%Y-%m-%d %H:%M:%S"},ar:{monthNames:["كانون الثاني","شباط","آذار","نيسان","آذار","حزيران","تموز","آب","أيلول","تشرين الأول","تشرين الثاني","كانون الأول"],monthNamesShort:["1","2","3","4","5","6","7","8","9","10","11","12"],dayNames:["السبت","الأحد","الاثنين","الثلاثاء","الأربعاء","الخميس","الجمعة"],dayNamesShort:["سبت","أحد","اثنين","ثلاثاء","أربعاء","خميس","جمعة"],formatString:"%Y-%m-%d %H:%M:%S"},pt:{monthNames:["Janeiro","Fevereiro","Mar&ccedil;o","Abril","Maio","Junho","Julho","Agosto","Setembro","Outubro","Novembro","Dezembro"],monthNamesShort:["Jan","Fev","Mar","Abr","Mai","Jun","Jul","Ago","Set","Out","Nov","Dez"],dayNames:["Domingo","Segunda-feira","Ter&ccedil;a-feira","Quarta-feira","Quinta-feira","Sexta-feira","S&aacute;bado"],dayNamesShort:["Dom","Seg","Ter","Qua","Qui","Sex","S&aacute;b"],formatString:"%Y-%m-%d %H:%M:%S"},"pt-BR":{monthNames:["Janeiro","Fevereiro","Mar&ccedil;o","Abril","Maio","Junho","Julho","Agosto","Setembro","Outubro","Novembro","Dezembro"],monthNamesShort:["Jan","Fev","Mar","Abr","Mai","Jun","Jul","Ago","Set","Out","Nov","Dez"],dayNames:["Domingo","Segunda-feira","Ter&ccedil;a-feira","Quarta-feira","Quinta-feira","Sexta-feira","S&aacute;bado"],dayNamesShort:["Dom","Seg","Ter","Qua","Qui","Sex","S&aacute;b"],formatString:"%Y-%m-%d %H:%M:%S"},pl:{monthNames:["Styczeń","Luty","Marzec","Kwiecień","Maj","Czerwiec","Lipiec","Sierpień","Wrzesień","Październik","Listopad","Grudzień"],monthNamesShort:["Sty","Lut","Mar","Kwi","Maj","Cze","Lip","Sie","Wrz","Paź","Lis","Gru"],dayNames:["Niedziela","Poniedziałek","Wtorek","Środa","Czwartek","Piątek","Sobota"],dayNamesShort:["Ni","Pn","Wt","Śr","Cz","Pt","Sb"],formatString:"%Y-%m-%d %H:%M:%S"},nl:{monthNames:["Januari","Februari","Maart","April","Mei","Juni","July","Augustus","September","Oktober","November","December"],monthNamesShort:["Jan","Feb","Mar","Apr","Mei","Jun","Jul","Aug","Sep","Okt","Nov","Dec"],dayNames:",".Zaterdag,dayNamesShort:["Zo","Ma","Di","Wo","Do","Vr","Za"],formatString:"%Y-%m-%d %H:%M:%S"},sv:{monthNames:["januari","februari","mars","april","maj","juni","juli","augusti","september","oktober","november","december"],monthNamesShort:["jan","feb","mar","apr","maj","jun","jul","aug","sep","okt","nov","dec"],dayNames:["söndag","måndag","tisdag","onsdag","torsdag","fredag","lördag"],dayNamesShort:["sön","mån","tis","ons","tor","fre","lör"],formatString:"%Y-%m-%d %H:%M:%S"}},Y.regional["en-US"]=Y.regional["en-GB"]=Y.regional.en,Y.regional.getLocale=function(){var v=Y.config.defaultLocale;return document&&document.getElementsByTagName("html")&&document.getElementsByTagName("html")[0].lang&&(v=document.getElementsByTagName("html")[0].lang,Y.regional.hasOwnProperty(v)||(v=Y.config.defaultLocale)),v};var ue=24*60*60*1e3,Ee=function(v,E){v=String(v);var L=E-v.length,S=String(Math.pow(10,L)).slice(1);return S.concat(v)},ne={millisecond:1,second:1e3,minute:60*1e3,hour:60*60*1e3,day:ue,week:7*ue,month:{add:function(v,E){ne.year.add(v,Math[E>0?"floor":"ceil"](E/12));var L=v.getMonth()+E%12;L==12?(L=0,v.setYear(v.getFullYear()+1)):L==-1&&(L=11,v.setYear(v.getFullYear()-1)),v.setMonth(L)},diff:function(v,E){var L=v.getFullYear()-E.getFullYear(),S=v.getMonth()-E.getMonth()+L*12,P=v.getDate()-E.getDate();return S+P/30}},year:{add:function(v,E){v.setYear(v.getFullYear()+Math[E>0?"floor":"ceil"](E))},diff:function(v,E){return ne.month.diff(v,E)/12}}};for(var me in ne)me.substring(me.length-1)!="s"&&(ne[me+"s"]=ne[me]);var se=function(v,E,L){if(Y.formats[L].shortcuts[E])return Y.strftime(v,Y.formats[L].shortcuts[E],L);var S=(Y.formats[L].codes[E]||"").split("."),P=v["get"+S[0]]?v["get"+S[0]]():"";return S[1]&&(P=Ee(P,S[1])),P};Y.strftime=function(v,E,L,S){var P="perl",W=Y.regional.getLocale();L&&Y.formats.hasOwnProperty(L)?P=L:L&&Y.regional.hasOwnProperty(L)&&(W=L),S&&Y.formats.hasOwnProperty(S)?P=S:S&&Y.regional.hasOwnProperty(S)&&(W=S),(Pe(v)!="[object Object]"||v._type!="jsDate")&&(v=new Y(v),v.locale=W),E||(E=v.formatString||Y.regional[W].formatString);for(var K=E||"%Y-%m-%d",V="",ee;K.length>0;)(ee=K.match(Y.formats[P].codes.matcher))?(V+=K.slice(0,ee.index),V+=(ee[1]||"")+se(v,ee[2],P),K=K.slice(ee.index+ee[0].length)):(V+=K,K="");return V},Y.formats={ISO:"%Y-%m-%dT%H:%M:%S.%N%G",SQL:"%Y-%m-%d %H:%M:%S"},Y.formats.perl={codes:{matcher:/()%(#?(%|[a-z]))/i,Y:"FullYear",y:"ShortYear.2",m:"MonthNumber.2","#m":"MonthNumber",B:"MonthName",b:"AbbrMonthName",d:"Date.2","#d":"Date",e:"Date",A:"DayName",a:"AbbrDayName",w:"Day",H:"Hours.2","#H":"Hours",I:"Hours12.2","#I":"Hours12",p:"AMPM",M:"Minutes.2","#M":"Minutes",S:"Seconds.2","#S":"Seconds",s:"Unix",N:"Milliseconds.3","#N":"Milliseconds",O:"TimezoneOffset",Z:"TimezoneName",G:"GmtOffset"},shortcuts:{F:"%Y-%m-%d",T:"%H:%M:%S",X:"%H:%M:%S",x:"%m/%d/%y",D:"%m/%d/%y","#c":"%a %b %e %H:%M:%S %Y",v:"%e-%b-%Y",R:"%H:%M",r:"%I:%M:%S %p",t:"	",n:`
`,"%":"%"}},Y.formats.php={codes:{matcher:/()%((%|[a-z]))/i,a:"AbbrDayName",A:"DayName",d:"Date.2",e:"Date",j:"DayOfYear.3",u:"DayOfWeek",w:"Day",U:"FullWeekOfYear.2",V:"IsoWeek.2",W:"WeekOfYear.2",b:"AbbrMonthName",B:"MonthName",m:"MonthNumber.2",h:"AbbrMonthName",C:"Century.2",y:"ShortYear.2",Y:"FullYear",H:"Hours.2",I:"Hours12.2",l:"Hours12",p:"AMPM",P:"AmPm",M:"Minutes.2",S:"Seconds.2",s:"Unix",O:"TimezoneOffset",z:"GmtOffset",Z:"TimezoneAbbr"},shortcuts:{D:"%m/%d/%y",F:"%Y-%m-%d",T:"%H:%M:%S",X:"%H:%M:%S",x:"%m/%d/%y",R:"%H:%M",r:"%I:%M:%S %p",t:"	",n:`
`,"%":"%"}},Y.createDate=function(v){if(v==null)return new Date;if(v instanceof Date)return v;if(typeof v=="number")return new Date(v);var E=String(v).replace(/^\s*(.+)\s*$/g,"$1");E=E.replace(/^([0-9]{1,4})-([0-9]{1,2})-([0-9]{1,4})/,"$1/$2/$3"),E=E.replace(/^(3[01]|[0-2]?\d)[-\/]([a-z]{3,})[-\/](\d{4})/i,"$1 $2 $3");var W=E.match(/^(3[01]|[0-2]?\d)[-\/]([a-z]{3,})[-\/](\d{2})\D*/i);if(W&&W.length>3){var L=parseFloat(W[3]),S=Y.config.defaultCentury+L;S=String(S),E=E.replace(/^(3[01]|[0-2]?\d)[-\/]([a-z]{3,})[-\/](\d{2})\D*/i,W[1]+" "+W[2]+" "+S)}W=E.match(/^([0-9]{1,2})[-\/]([0-9]{1,2})[-\/]([0-9]{1,2})[^0-9]/);function P(pe,ae){var Ae=parseFloat(ae[1]),Se=parseFloat(ae[2]),ze=parseFloat(ae[3]),Ve=Y.config.defaultCentury,Me,Le,Be,Je;return Ae>31?(Le=ze,Be=Se,Me=Ve+Ae):(Le=Se,Be=Ae,Me=Ve+ze),Je=Be+"/"+Le+"/"+Me,pe.replace(/^([0-9]{1,2})[-\/]([0-9]{1,2})[-\/]([0-9]{1,2})/,Je)}W&&W.length>3&&(E=P(E,W));var W=E.match(/^([0-9]{1,2})[-\/]([0-9]{1,2})[-\/]([0-9]{1,2})$/);W&&W.length>3&&(E=P(E,W));for(var K=0,V=Y.matchers.length,ee,Q,fe=E,oe;K<V;){if(Q=Date.parse(fe),!isNaN(Q))return new Date(Q);if(ee=Y.matchers[K],typeof ee=="function"){if(oe=ee.call(Y,fe),oe instanceof Date)return oe}else fe=E.replace(ee[0],ee[1]);K++}return NaN},Y.daysInMonth=function(v,E){return E==2?new Date(v,1,29).getDate()==29?29:28:[e,31,e,31,30,31,30,31,31,30,31,30,31][E]},Y.matchers=[[/(3[01]|[0-2]\d)\s*\.\s*(1[0-2]|0\d)\s*\.\s*([1-9]\d{3})/,"$2/$1/$3"],[/([1-9]\d{3})\s*-\s*(1[0-2]|0\d)\s*-\s*(3[01]|[0-2]\d)/,"$2/$3/$1"],function(v){var E=v.match(/^(?:(.+)\s+)?([012]?\d)(?:\s*\:\s*(\d\d))?(?:\s*\:\s*(\d\d(\.\d*)?))?\s*(am|pm)?\s*$/i);if(E){if(E[1]){var L=this.createDate(E[1]);if(isNaN(L))return}else{var L=new Date;L.setMilliseconds(0)}var S=parseFloat(E[2]);return E[6]&&(S=E[6].toLowerCase()=="am"?S==12?0:S:S==12?12:S+12),L.setHours(S,parseInt(E[3]||0,10),parseInt(E[4]||0,10),(parseFloat(E[5]||0)||0)*1e3),L}else return v},function(v){var E=v.match(/^(?:(.+))[T|\s+]([012]\d)(?:\:(\d\d))(?:\:(\d\d))(?:\.\d+)([\+\-]\d\d\:\d\d)$/i);if(E){if(E[1]){var L=this.createDate(E[1]);if(isNaN(L))return}else{var L=new Date;L.setMilliseconds(0)}var S=parseFloat(E[2]);return L.setHours(S,parseInt(E[3],10),parseInt(E[4],10),parseFloat(E[5])*1e3),L}else return v},function(v){var E=v.match(/^([0-3]?\d)\s*[-\/.\s]{1}\s*([a-zA-Z]{3,9})\s*[-\/.\s]{1}\s*([0-3]?\d)$/);if(E){var L=new Date,S=Y.config.defaultCentury,P=parseFloat(E[1]),W=parseFloat(E[3]),K,V,ee;P>31?(V=W,K=S+P):(V=P,K=S+W);var ee=ve(E[2],Y.regional[Y.regional.getLocale()].monthNamesShort);return ee==-1&&(ee=ve(E[2],Y.regional[Y.regional.getLocale()].monthNames)),L.setFullYear(K,ee,V),L.setHours(0,0,0,0),L}else return v}];function ve(v,E){if(E.indexOf)return E.indexOf(v);for(var L=0,S=E.length;L<S;L++)if(E[L]===v)return L;return-1}function Pe(v){return v===null?"[object Null]":Object.prototype.toString.call(v)}t.jsDate=Y,t.jqplot.sprintf=function(){function v(ee,Q,fe,oe){var pe=ee.length>=Q?"":Array(1+Q-ee.length>>>0).join(fe);return oe?ee+pe:pe+ee}function E(ee){for(var Q=new String(ee),fe=10;fe>0&&Q!=(Q=Q.replace(/^(\d+)(\d{3})/,"$1"+t.jqplot.sprintf.thousandsSeparator+"$2"));fe--);return Q}function L(ee,Q,fe,oe,pe,ae){var Ae=oe-ee.length;if(Ae>0){var Se=" ";ae&&(Se="&nbsp;"),fe||!pe?ee=v(ee,oe,Se,fe):ee=ee.slice(0,Q.length)+v("",Ae,"0",!0)+ee.slice(Q.length)}return ee}function S(ee,Q,fe,oe,pe,ae,Ae,Se){var ze=ee>>>0;return fe=fe&&ze&&{2:"0b",8:"0",16:"0x"}[Q]||"",ee=fe+v(ze.toString(Q),ae||0,"0",!1),L(ee,fe,oe,pe,Ae,Se)}function P(ee,Q,fe,oe,pe,ae){return oe!=null&&(ee=ee.slice(0,oe)),L(ee,"",Q,fe,pe,ae)}var W=arguments,K=0,V=W[K++];return V.replace(t.jqplot.sprintf.regex,function(ee,Q,fe,oe,pe,ae,Ae){if(ee=="%%")return"%";for(var Se=!1,ze="",Ve=!1,Me=!1,Le=!1,Be=!1,Je=0;fe&&Je<fe.length;Je++)switch(fe.charAt(Je)){case" ":ze=" ";break;case"+":ze="+";break;case"-":Se=!0;break;case"0":Ve=!0;break;case"#":Me=!0;break;case"&":Le=!0;break;case"'":Be=!0;break}if(oe?oe=="*"?oe=+W[K++]:oe.charAt(0)=="*"?oe=+W[oe.slice(1,-1)]:oe=+oe:oe=0,oe<0&&(oe=-oe,Se=!0),!isFinite(oe))throw new Error("$.jqplot.sprintf: (minimum-)width must be finite");ae?ae=="*"?ae=+W[K++]:ae.charAt(0)=="*"?ae=+W[ae.slice(1,-1)]:ae=+ae:ae="fFeE".indexOf(Ae)>-1?6:Ae=="d"?0:void 0;var Ue=Q?W[Q.slice(0,-1)]:W[K++];switch(Ae){case"s":return Ue==null?"":P(String(Ue),Se,oe,ae,Ve,Le);case"c":return P(String.fromCharCode(+Ue),Se,oe,ae,Ve,Le);case"b":return S(Ue,2,Me,Se,oe,ae,Ve,Le);case"o":return S(Ue,8,Me,Se,oe,ae,Ve,Le);case"x":return S(Ue,16,Me,Se,oe,ae,Ve,Le);case"X":return S(Ue,16,Me,Se,oe,ae,Ve,Le).toUpperCase();case"u":return S(Ue,10,Me,Se,oe,ae,Ve,Le);case"i":{var Ge=parseInt(+Ue,10);if(isNaN(Ge))return"";var lt=Ge<0?"-":ze,et=Be?E(String(Math.abs(Ge))):String(Math.abs(Ge));return Ue=lt+v(et,ae,"0",!1),L(Ue,lt,Se,oe,Ve,Le)}case"d":{var Ge=Math.round(+Ue);if(isNaN(Ge))return"";var lt=Ge<0?"-":ze,et=Be?E(String(Math.abs(Ge))):String(Math.abs(Ge));return Ue=lt+v(et,ae,"0",!1),L(Ue,lt,Se,oe,Ve,Le)}case"e":case"E":case"f":case"F":case"g":case"G":{var Ge=+Ue;if(isNaN(Ge))return"";var lt=Ge<0?"-":ze,vt=["toExponential","toFixed","toPrecision"]["efg".indexOf(Ae.toLowerCase())],Ft=["toString","toUpperCase"]["eEfFgG".indexOf(Ae)%2],et=Math.abs(Ge)[vt](ae),bt=et.toString().split(".");bt[0]=Be?E(bt[0]):bt[0],et=bt.join(t.jqplot.sprintf.decimalMark),Ue=lt+et;var Ht=L(Ue,lt,Se,oe,Ve,Le)[Ft]();return Ht}case"p":case"P":{var Ge=+Ue;if(isNaN(Ge))return"";var lt=Ge<0?"-":ze,bt=String(Number(Math.abs(Ge)).toExponential()).split(/e|E/),kt=bt[0].indexOf(".")!=-1?bt[0].length-1:String(Ge).length,Bt=bt[1]<0?-bt[1]-1:0;if(Math.abs(Ge)<1)kt+Bt<=ae?Ue=lt+Math.abs(Ge).toPrecision(kt):kt<=ae-1?Ue=lt+Math.abs(Ge).toExponential(kt-1):Ue=lt+Math.abs(Ge).toExponential(ae-1);else{var st=kt<=ae?kt:ae;Ue=lt+Math.abs(Ge).toPrecision(st)}var Ft=["toString","toUpperCase"]["pP".indexOf(Ae)%2];return L(Ue,lt,Se,oe,Ve,Le)[Ft]()}case"n":return"";default:return ee}})},t.jqplot.sprintf.thousandsSeparator=",",t.jqplot.sprintf.decimalMark=".",t.jqplot.sprintf.regex=/%%|%(\d+\$)?([-+#0&\' ]*)(\*\d+\$|\*|\d+)?(\.(\*\d+\$|\*|\d+))?([nAscboxXuidfegpEGP])/g,t.jqplot.getSignificantFigures=function(v){var E=String(Number(Math.abs(v)).toExponential()).split(/e|E/),L=E[0].indexOf(".")!=-1?E[0].length-1:E[0].length,S=E[1]<0?-E[1]-1:0,P=parseInt(E[1],10),W=P+1>0?P+1:0,K=L<=W?0:L-P-1;return{significantDigits:L,digitsLeft:W,digitsRight:K,zeros:S,exponent:P}},t.jqplot.getPrecision=function(v){return t.jqplot.getSignificantFigures(v).digitsRight};var Ie=t.uiBackCompat!==!1;t.jqplot.effects={effect:{}};var z="jqplot.storage.";t.extend(t.jqplot.effects,{version:"1.9pre",save:function(v,E){for(var L=0;L<E.length;L++)E[L]!==null&&v.data(z+E[L],v[0].style[E[L]])},restore:function(v,E){for(var L=0;L<E.length;L++)E[L]!==null&&v.css(E[L],v.data(z+E[L]))},setMode:function(v,E){return E==="toggle"&&(E=v.is(":hidden")?"show":"hide"),E},createWrapper:function(v){if(v.parent().is(".ui-effects-wrapper"))return v.parent();var E={width:v.outerWidth(!0),height:v.outerHeight(!0),float:v.css("float")},L=t("<div></div>").addClass("ui-effects-wrapper").css({fontSize:"100%",background:"transparent",border:"none",margin:0,padding:0}),S={width:v.width(),height:v.height()},P=document.activeElement;return v.wrap(L),(v[0]===P||t.contains(v[0],P))&&t(P).focus(),L=v.parent(),v.css("position")==="static"?(L.css({position:"relative"}),v.css({position:"relative"})):(t.extend(E,{position:v.css("position"),zIndex:v.css("z-index")}),t.each(["top","left","bottom","right"],function(W,K){E[K]=v.css(K),isNaN(parseInt(E[K],10))&&(E[K]="auto")}),v.css({position:"relative",top:0,left:0,right:"auto",bottom:"auto"})),v.css(S),L.css(E).show()},removeWrapper:function(v){var E=document.activeElement;return v.parent().is(".ui-effects-wrapper")&&(v.parent().replaceWith(v),(v[0]===E||t.contains(v[0],E))&&t(E).focus()),v}});function G(v,E,L,S){return t.isPlainObject(v)||(v={effect:v},E===e&&(E={}),t.isFunction(E)&&(S=E,L=null,E={}),(t.type(E)==="number"||t.fx.speeds[E])&&(S=L,L=E,E={}),t.isFunction(L)&&(S=L,L=null),E&&t.extend(v,E),L=L||E.duration,v.duration=t.fx.off?0:typeof L=="number"?L:L in t.fx.speeds?t.fx.speeds[L]:t.fx.speeds._default,v.complete=S||E.complete),v}t.fn.extend({jqplotEffect:function(v,E,L,S){var P=G.apply(this,arguments),W=P.mode,K=P.queue,V=t.jqplot.effects.effect[P.effect],ee=!V&&Ie&&t.jqplot.effects[P.effect];if(t.fx.off||!(V||ee))return W?this[W](P.duration,P.complete):this.each(function(){P.complete&&P.complete.call(this)});function Q(fe){var oe=t(this),pe=P.complete,ae=P.mode;function Ae(){t.isFunction(pe)&&pe.call(oe[0]),t.isFunction(fe)&&fe()}(oe.is(":hidden")?ae==="hide":ae==="show")?Ae():V.call(oe[0],P,Ae)}return V?K===!1?this.each(Q):this.queue(K||"fx",Q):ee.call(this,{options:P,duration:P.duration,callback:P.complete,mode:P.mode})}});var O=/up|down|vertical/,I=/up|left|vertical|horizontal/;t.jqplot.effects.effect.blind=function(v,E){var L=t(this),S=["position","top","bottom","left","right","height","width"],P=t.jqplot.effects.setMode(L,v.mode||"hide"),W=v.direction||"up",K=O.test(W),V=K?"height":"width",ee=K?"top":"left",Q=I.test(W),fe={},oe=P==="show",pe,ae,Ae;L.parent().is(".ui-effects-wrapper")?t.jqplot.effects.save(L.parent(),S):t.jqplot.effects.save(L,S),L.show(),Ae=parseInt(L.css("top"),10),pe=t.jqplot.effects.createWrapper(L).css({overflow:"hidden"}),ae=K?pe[V]()+Ae:pe[V](),fe[V]=oe?String(ae):"0",Q||(L.css(K?"bottom":"right",0).css(K?"top":"left","").css({position:"absolute"}),fe[ee]=oe?"0":String(ae)),oe&&(pe.css(V,0),Q||pe.css(ee,ae)),pe.animate(fe,{duration:v.duration,easing:v.easing,queue:!1,complete:function(){P==="hide"&&L.hide(),t.jqplot.effects.restore(L,S),t.jqplot.effects.removeWrapper(L),E()}})}})(ke);(function(t){t.jqplot.PieRenderer=function(){t.jqplot.LineRenderer.call(this)},t.jqplot.PieRenderer.prototype=new t.jqplot.LineRenderer,t.jqplot.PieRenderer.prototype.constructor=t.jqplot.PieRenderer,t.jqplot.PieRenderer.prototype.init=function(a,F){if(this.diameter=null,this.padding=20,this.sliceMargin=0,this.fill=!0,this.shadowOffset=2,this.shadowAlpha=.07,this.shadowDepth=5,this.highlightMouseOver=!0,this.highlightMouseDown=!1,this.highlightColors=[],this.dataLabels="percent",this.showDataLabels=!1,this.dataLabelFormatString=null,this.dataLabelThreshold=3,this.dataLabelPositionFactor=.52,this.dataLabelNudge=2,this.dataLabelCenterOn=!0,this.startAngle=0,this.tickRenderer=t.jqplot.PieTickRenderer,this._drawData=!0,this._type="pie",a.highlightMouseDown&&a.highlightMouseOver==null&&(a.highlightMouseOver=!1),t.extend(!0,this,a),this.sliceMargin<0&&(this.sliceMargin=0),this._diameter=null,this._radius=null,this._sliceAngles=[],this._highlightedPoint=null,this.highlightColors.length==0)for(var p=0;p<this.seriesColors.length;p++){for(var m=t.jqplot.getColorComponents(this.seriesColors[p]),b=[m[0],m[1],m[2]],C=b[0]+b[1]+b[2],k=0;k<3;k++)b[k]=C>570?b[k]*.8:b[k]+.3*(255-b[k]),b[k]=parseInt(b[k],10);this.highlightColors.push("rgb("+b[0]+","+b[1]+","+b[2]+")")}this.highlightColorGenerator=new t.jqplot.ColorGenerator(this.highlightColors),F.postParseOptionsHooks.addOnce(s),F.postInitHooks.addOnce(i),F.eventListenerHooks.addOnce("jqplotMouseMove",n),F.eventListenerHooks.addOnce("jqplotMouseDown",h),F.eventListenerHooks.addOnce("jqplotMouseUp",g),F.eventListenerHooks.addOnce("jqplotClick",d),F.eventListenerHooks.addOnce("jqplotRightClick",l),F.postDrawHooks.addOnce(c)},t.jqplot.PieRenderer.prototype.setGridData=function(a){var F=[],p=[];this.startAngle/180*Math.PI;var m=0;this._drawData=!1;for(var b=0;b<this.data.length;b++)this.data[b][1]!=0&&(this._drawData=!0),F.push(this.data[b][1]),p.push([this.data[b][0]]),b>0&&(F[b]+=F[b-1]),m+=this.data[b][1];for(var C=Math.PI*2/F[F.length-1],b=0;b<F.length;b++)p[b][1]=F[b]*C,p[b][2]=this.data[b][1]/m;this.gridData=p},t.jqplot.PieRenderer.prototype.makeGridData=function(a,F){var p=[],m=[],b=0;this.startAngle/180*Math.PI,this._drawData=!1;for(var C=0;C<a.length;C++)this.data[C][1]!=0&&(this._drawData=!0),p.push(a[C][1]),m.push([a[C][0]]),C>0&&(p[C]+=p[C-1]),b+=a[C][1];for(var k=Math.PI*2/p[p.length-1],C=0;C<p.length;C++)m[C][1]=p[C]*k,m[C][2]=a[C][1]/b;return m};function e(a){return Math.sin((a-(a-Math.PI)/8/Math.PI)/2)}function u(a,F,p,m,b){var C=0,k=F-a,T=Math.abs(k),w=p;return m==!1&&(w+=b),w>0&&T>.01&&T<6.282&&(C=parseFloat(w)/2/e(k)),C}t.jqplot.PieRenderer.prototype.drawSlice=function(a,F,p,m,b){if(this._drawData){var C=this._radius,k=this.fill,T=this.lineWidth,w=this.sliceMargin;this.fill==!1&&(w+=this.lineWidth),a.save(),a.translate(this._center[0],this._center[1]);var A=u(F,p,this.sliceMargin,this.fill,this.lineWidth),M=A*Math.cos((F+p)/2),x=A*Math.sin((F+p)/2);if(p-F<=Math.PI?C-=A:C+=A,a.translate(M,x),b){for(var R=0,N=this.shadowDepth;R<N;R++)a.save(),a.translate(this.shadowOffset*Math.cos(this.shadowAngle/180*Math.PI),this.shadowOffset*Math.sin(this.shadowAngle/180*Math.PI)),j(C);for(var R=0,N=this.shadowDepth;R<N;R++)a.restore()}else j(C);a.restore()}function j(B){p>6.282+this.startAngle&&(p=6.282+this.startAngle,F>p&&(F=6.281+this.startAngle)),!(F>=p)&&(a.beginPath(),a.fillStyle=m,a.strokeStyle=m,a.lineWidth=T,a.arc(0,0,B,F,p,!1),a.lineTo(0,0),a.closePath(),k?a.fill():a.stroke())}},t.jqplot.PieRenderer.prototype.draw=function(a,F,p,m){var b,C=p??{},k=0,T=0,w=1,A=new t.jqplot.ColorGenerator(this.seriesColors);if(p.legendInfo&&p.legendInfo.placement=="insideGrid"){var M=p.legendInfo;switch(M.location){case"nw":k=M.width+M.xoffset;break;case"w":k=M.width+M.xoffset;break;case"sw":k=M.width+M.xoffset;break;case"ne":k=M.width+M.xoffset,w=-1;break;case"e":k=M.width+M.xoffset,w=-1;break;case"se":k=M.width+M.xoffset,w=-1;break;case"n":T=M.height+M.yoffset;break;case"s":T=M.height+M.yoffset,w=-1;break}}C.shadow!=null?C.shadow:this.shadow,C.fill!=null?C.fill:this.fill;var x=a.canvas.width,R=a.canvas.height,N=x-k-2*this.padding,j=R-T-2*this.padding,B=Math.min(N,j),q=B;this._sliceAngles=[];var U=this.sliceMargin;this.fill==!1&&(U+=this.lineWidth);for(var Z,re=0,le,ce,de,he=this.startAngle/180*Math.PI,b=0,Fe=F.length;b<Fe;b++)le=b==0?he:F[b-1][1]+he,ce=F[b][1]+he,this._sliceAngles.push([le,ce]),Z=u(le,ce,this.sliceMargin,this.fill,this.lineWidth),Math.abs(ce-le)>Math.PI&&(re=Math.max(Z,re));if(this.diameter!=null&&this.diameter>0?this._diameter=this.diameter-2*re:this._diameter=q-2*re,this._diameter<6){t.jqplot.log("Diameter of pie too small, not rendering.");return}if(this._radius=this._diameter/2,this._center=[(x-w*k)/2+w*k+re*Math.cos(he),(R-w*T)/2+w*T+re*Math.sin(he)],this.shadow)for(var b=0,Fe=F.length;b<Fe;b++)de="rgba(0,0,0,"+this.shadowAlpha+")",this.renderer.drawSlice.call(this,a,this._sliceAngles[b][0],this._sliceAngles[b][1],de,!0);for(var b=0;b<F.length;b++)if(this.renderer.drawSlice.call(this,a,this._sliceAngles[b][0],this._sliceAngles[b][1],A.next(),!1),this.showDataLabels&&F[b][2]*100>=this.dataLabelThreshold){var ge,ye=(this._sliceAngles[b][0]+this._sliceAngles[b][1])/2,Y;this.dataLabels=="label"?(ge=this.dataLabelFormatString||"%s",Y=t.jqplot.sprintf(ge,F[b][0])):this.dataLabels=="value"?(ge=this.dataLabelFormatString||"%d",Y=t.jqplot.sprintf(ge,this.data[b][1])):this.dataLabels=="percent"?(ge=this.dataLabelFormatString||"%d%%",Y=t.jqplot.sprintf(ge,F[b][2]*100)):this.dataLabels.constructor==Array&&(ge=this.dataLabelFormatString||"%s",Y=t.jqplot.sprintf(ge,this.dataLabels[b]));var ue=this._radius*this.dataLabelPositionFactor+this.sliceMargin+this.dataLabelNudge,Ee=this._center[0]+Math.cos(ye)*ue+this.canvas._offsets.left,ne=this._center[1]+Math.sin(ye)*ue+this.canvas._offsets.top,me=t('<div class="jqplot-pie-series jqplot-data-label" style="position:absolute;">'+Y+"</div>").insertBefore(m.eventCanvas._elem);this.dataLabelCenterOn?(Ee-=me.width()/2,ne-=me.height()/2):(Ee-=me.width()*Math.sin(ye/2),ne-=me.height()/2),Ee=Math.round(Ee),ne=Math.round(ne),me.css({left:Ee,top:ne})}},t.jqplot.PieAxisRenderer=function(){t.jqplot.LinearAxisRenderer.call(this)},t.jqplot.PieAxisRenderer.prototype=new t.jqplot.LinearAxisRenderer,t.jqplot.PieAxisRenderer.prototype.constructor=t.jqplot.PieAxisRenderer,t.jqplot.PieAxisRenderer.prototype.init=function(a){this.tickRenderer=t.jqplot.PieTickRenderer,t.extend(!0,this,a),this._dataBounds={min:0,max:100},this.min=0,this.max=100,this.showTicks=!1,this.ticks=[],this.showMark=!1,this.show=!1},t.jqplot.PieLegendRenderer=function(){t.jqplot.TableLegendRenderer.call(this)},t.jqplot.PieLegendRenderer.prototype=new t.jqplot.TableLegendRenderer,t.jqplot.PieLegendRenderer.prototype.constructor=t.jqplot.PieLegendRenderer,t.jqplot.PieLegendRenderer.prototype.init=function(a){this.numberRows=null,this.numberColumns=null,t.extend(!0,this,a)},t.jqplot.PieLegendRenderer.prototype.draw=function(){if(this.show){var a=this._series;this._elem=t(document.createElement("table")),this._elem.addClass("jqplot-table-legend");var F={position:"absolute"};this.background&&(F.background=this.background),this.border&&(F.border=this.border),this.fontSize&&(F.fontSize=this.fontSize),this.fontFamily&&(F.fontFamily=this.fontFamily),this.textColor&&(F.textColor=this.textColor),this.marginTop!=null&&(F.marginTop=this.marginTop),this.marginBottom!=null&&(F.marginBottom=this.marginBottom),this.marginLeft!=null&&(F.marginLeft=this.marginLeft),this.marginRight!=null&&(F.marginRight=this.marginRight),this._elem.css(F);var p=!1,m=!1,b,C,k=a[0],T=new t.jqplot.ColorGenerator(k.seriesColors);if(k.show){var w=k.data;this.numberRows?(b=this.numberRows,this.numberColumns?C=this.numberColumns:C=Math.ceil(w.length/b)):this.numberColumns?(C=this.numberColumns,b=Math.ceil(w.length/this.numberColumns)):(b=w.length,C=1);var A,M,x,R,N,j,B,q,U=0,Z,re;for(A=0;A<b;A++)for(x=t(document.createElement("tr")),x.addClass("jqplot-table-legend"),m?x.prependTo(this._elem):x.appendTo(this._elem),M=0;M<C;M++)U<w.length&&(j=this.labels[U]||w[U][0].toString(),q=T.next(),m?A==b-1?p=!1:p=!0:A>0?p=!0:p=!1,B=p?this.rowSpacing:"0",R=t(document.createElement("td")),R.addClass("jqplot-table-legend jqplot-table-legend-swatch"),R.css({textAlign:"center",paddingTop:B}),Z=t(document.createElement("div")),Z.addClass("jqplot-table-legend-swatch-outline"),re=t(document.createElement("div")),re.addClass("jqplot-table-legend-swatch"),re.css({backgroundColor:q,borderColor:q}),R.append(Z.append(re)),N=t(document.createElement("td")),N.addClass("jqplot-table-legend jqplot-table-legend-label"),N.css("paddingTop",B),this.escapeHtml?N.text(j):N.html(j),m?(N.prependTo(x),R.prependTo(x)):(R.appendTo(x),N.appendTo(x)),p=!0),U++}}return this._elem},t.jqplot.PieRenderer.prototype.handleMove=function(a,F,p,m,b){if(m){var C=[m.seriesIndex,m.pointIndex,m.data];b.target.trigger("jqplotDataMouseOver",C),b.series[C[0]].highlightMouseOver&&!(C[0]==b.plugins.pieRenderer.highlightedSeriesIndex&&C[1]==b.series[C[0]]._highlightedPoint)&&(b.target.trigger("jqplotDataHighlight",C),o(b,C[0],C[1]))}else m==null&&f(b)};function r(a,F,p){p=p||{},p.axesDefaults=p.axesDefaults||{},p.legend=p.legend||{},p.seriesDefaults=p.seriesDefaults||{};var m=!1;if(p.seriesDefaults.renderer==t.jqplot.PieRenderer)m=!0;else if(p.series)for(var b=0;b<p.series.length;b++)p.series[b].renderer==t.jqplot.PieRenderer&&(m=!0);m&&(p.axesDefaults.renderer=t.jqplot.PieAxisRenderer,p.legend.renderer=t.jqplot.PieLegendRenderer,p.legend.preDraw=!0,p.seriesDefaults.pointLabels={show:!1})}function i(a,F,p){for(var m=0;m<this.series.length;m++)this.series[m].renderer.constructor==t.jqplot.PieRenderer&&this.series[m].highlightMouseOver&&(this.series[m].highlightMouseDown=!1)}function s(a){for(var F=0;F<this.series.length;F++)this.series[F].seriesColors=this.seriesColors,this.series[F].colorGenerator=t.jqplot.colorGenerator}function o(a,F,p){var m=a.series[F],b=a.plugins.pieRenderer.highlightCanvas;b._ctx.clearRect(0,0,b._ctx.canvas.width,b._ctx.canvas.height),m._highlightedPoint=p,a.plugins.pieRenderer.highlightedSeriesIndex=F,m.renderer.drawSlice.call(m,b._ctx,m._sliceAngles[p][0],m._sliceAngles[p][1],m.highlightColorGenerator.get(p),!1)}function f(a){var F=a.plugins.pieRenderer.highlightCanvas;F._ctx.clearRect(0,0,F._ctx.canvas.width,F._ctx.canvas.height);for(var p=0;p<a.series.length;p++)a.series[p]._highlightedPoint=null;a.plugins.pieRenderer.highlightedSeriesIndex=null,a.target.trigger("jqplotDataUnhighlight")}function n(a,F,p,m,b){if(m){var C=[m.seriesIndex,m.pointIndex,m.data],k=ke.Event("jqplotDataMouseOver");if(k.pageX=a.pageX,k.pageY=a.pageY,b.target.trigger(k,C),b.series[C[0]].highlightMouseOver&&!(C[0]==b.plugins.pieRenderer.highlightedSeriesIndex&&C[1]==b.series[C[0]]._highlightedPoint)){var T=ke.Event("jqplotDataHighlight");T.which=a.which,T.pageX=a.pageX,T.pageY=a.pageY,b.target.trigger(T,C),o(b,C[0],C[1])}}else m==null&&f(b)}function h(a,F,p,m,b){if(m){var C=[m.seriesIndex,m.pointIndex,m.data];if(b.series[C[0]].highlightMouseDown&&!(C[0]==b.plugins.pieRenderer.highlightedSeriesIndex&&C[1]==b.series[C[0]]._highlightedPoint)){var k=ke.Event("jqplotDataHighlight");k.which=a.which,k.pageX=a.pageX,k.pageY=a.pageY,b.target.trigger(k,C),o(b,C[0],C[1])}}else m==null&&f(b)}function g(a,F,p,m,b){var C=b.plugins.pieRenderer.highlightedSeriesIndex;C!=null&&b.series[C].highlightMouseDown&&f(b)}function d(a,F,p,m,b){if(m){var C=[m.seriesIndex,m.pointIndex,m.data],k=ke.Event("jqplotDataClick");k.which=a.which,k.pageX=a.pageX,k.pageY=a.pageY,b.target.trigger(k,C)}}function l(a,F,p,m,b){if(m){var C=[m.seriesIndex,m.pointIndex,m.data],k=b.plugins.pieRenderer.highlightedSeriesIndex;k!=null&&b.series[k].highlightMouseDown&&f(b);var T=ke.Event("jqplotDataRightClick");T.which=a.which,T.pageX=a.pageX,T.pageY=a.pageY,b.target.trigger(T,C)}}function c(){this.plugins.pieRenderer&&this.plugins.pieRenderer.highlightCanvas&&(this.plugins.pieRenderer.highlightCanvas.resetCanvas(),this.plugins.pieRenderer.highlightCanvas=null),this.plugins.pieRenderer={highlightedSeriesIndex:null},this.plugins.pieRenderer.highlightCanvas=new t.jqplot.GenericCanvas;var a=t(this.targetId+" .jqplot-data-label");a.length?t(a[0]).before(this.plugins.pieRenderer.highlightCanvas.createElement(this._gridPadding,"jqplot-pieRenderer-highlight-canvas",this._plotDimensions,this)):this.eventCanvas._elem.before(this.plugins.pieRenderer.highlightCanvas.createElement(this._gridPadding,"jqplot-pieRenderer-highlight-canvas",this._plotDimensions,this)),this.plugins.pieRenderer.highlightCanvas.setContext(),this.eventCanvas._elem.bind("mouseleave",{plot:this},function(F){f(F.data.plot)})}t.jqplot.preInitHooks.push(r),t.jqplot.PieTickRenderer=function(){t.jqplot.AxisTickRenderer.call(this)},t.jqplot.PieTickRenderer.prototype=new t.jqplot.AxisTickRenderer,t.jqplot.PieTickRenderer.prototype.constructor=t.jqplot.PieTickRenderer})(ke);function N0(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Or(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function wn(t,e){return Array.isArray(t)?rA(t,e):t&&typeof t=="object"?iA(t):t||""}function rA(t,e){for(var u,r="",i="",s=Array.isArray(e),o=0;o<t.length;o++)(u=wn(t[o]))&&(s&&e[o]&&(u=Or(u)),r=r+i+u,i=" ");return r}function iA(t){var e="",u="";for(var r in t)r&&t[r]&&uA.call(t,r)&&(e=e+u+r,u=" ");return e}function Or(t){var e=""+t,u=sA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var uA=Object.prototype.hasOwnProperty,sA=/["&<>]/;function ip(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void ip(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function nA(t){var e="",u={},r,i,s;try{var o=t||{};(function(f,n,h,g,d,l,c,a,F){s=1,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",u.privacyEditor=r=function(p){var m=this&&this.block,b=this&&this.attributes||{};if(s=2,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-public-container">',s=3,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="radio">',s=4,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<label>",s=5,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<input"+(' id="g-access-private" type="radio" name="privacy"'+N0("checked",a?void 0:"checked",!0,!1))+"/>",s=7,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<i class="icon-lock"></i>',s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"",s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<b>",s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"Private</b>",s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+" &mdash; Access is required to view this ",s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+Or((r=p)==null?"":r)+"</label></div>",s=9,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="radio">',s=10,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<label>",s=11,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<input"+(' id="g-access-public" type="radio" name="privacy"'+N0("checked",a?"checked":void 0,!0,!1))+"/>",s=13,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<i class="icon-globe"></i>',s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"",s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<b>",s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"Public</b>",s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+" &mdash; Anyone can view this ",s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+Or((r=p)==null?"":r)+"</label></div>",s=16,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",f.keys(n).length){s=17,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<a class="g-action-manage-public-flags hide" title="Public access flags">',s=18,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<i class="g-flag-icon icon-flag">',s=19,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug";var C=F&&F.length||0;s=20,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<div"+N0("class",wn(["g-flag-count-indicator",C?null:"hide"],[!1,!0]),!1,!1)+">",s=20,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+Or((r=C)==null?"":r)+"</div></i>",s=21,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+" Manage public access flags...</a>",s=22,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-public-flags-popover-container hide">',s=23,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",function(){var k=n;if(typeof k.length=="number")for(var T=0,w=k.length;T<w;T++){var A=k[T];s=24,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug";var M=f.contains(F,T)?"checked":null;s=25,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug";var x=!l&&A.admin?"disabled":null;s=26,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<div"+N0("class",wn(["checkbox",x],[!1,!0]),!1,!1)+">",s=27,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<label"+(' class="g-flag-label"'+N0("title",A.description,!0,!1))+">",s=28,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<input"+(' class="g-public-flag-checkbox"'+N0("flag",T,!0,!1)+' type="checkbox"'+N0("checked",M,!0,!1)+N0("disabled",x,!0,!1))+"/>",s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<span>",s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+Or((r=A.name)==null?"":r)+"</span></label></div>"}else{var w=0;for(var T in k){w++;var A=k[T];s=24,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug";var M=f.contains(F,T)?"checked":null;s=25,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug";var x=!l&&A.admin?"disabled":null;s=26,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<div"+N0("class",wn(["checkbox",x],[!1,!0]),!1,!1)+">",s=27,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<label"+(' class="g-flag-label"'+N0("title",A.description,!0,!1))+">",s=28,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<input"+(' class="g-public-flag-checkbox"'+N0("flag",T,!0,!1)+' type="checkbox"'+N0("checked",M,!0,!1)+N0("disabled",x,!0,!1))+"/>",s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<span>",s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+Or((r=A.name)==null?"":r)+"</span></label></div>"}}}.call(this),s=30,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<button class="g-close-public-flags-popover btn btn-xs btn-default">',s=30,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"Close</button></div>"}e=e+"</div>"},s=32,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",u.permissionsEditor=r=function(){var p=this&&this.block,m=this&&this.attributes||{};s=33,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-permissions-editor">',s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-ac-list-title">',s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"",s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<i class="icon-key-1"></i>',s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"  Permissions</div>",s=35,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-ac-list">',s=36,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div id="g-ac-list-groups"></div>',s=37,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div id="g-ac-list-users"></div></div>',s=39,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-grant-access-container">',s=40,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<form role="form">',s=41,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="form-group">',s=42,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<label for="addAccess">',s=42,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"Grant access to another group or user</label>",s=43,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-search-field-container"></div></div></form></div></div>'},s=45,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",u.recurseOption=r=function(p){var m=this&&this.block,b=this&&this.attributes||{};s=46,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-recursive-container">',s=47,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="radio">',s=48,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<label>",s=49,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<input id="g-apply-nonrecursive" type="radio" name="recurse" checked="checked"/>',s=50,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"Apply permissions only to this ",s=50,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+Or((r=p)==null?"":r),s=50,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+", not its subfolders</label></div>",s=51,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="radio">',s=52,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<label>",s=53,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<input id="g-apply-recursive" type="radio" name="recurse"/>',s=54,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"Also set permissions on all subfolders to match this ",s=54,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+Or((r=p)==null?"":r),s=54,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"'s permissions</label></div></div>"},s=56,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",u.saveAccessButton=r=function(){var p=this&&this.block,m=this&&this.attributes||{};s=57,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<button class="g-save-access-list btn btn-small btn-primary">',s=57,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"",s=57,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<i class="icon-ok"></i>',s=57,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"  Save</button>"},s=3,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorNonModal.pug",h||(s=4,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorNonModal.pug",u.privacyEditor(c)),s=5,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorNonModal.pug",u.permissionsEditor(),s=7,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorNonModal.pug",g||(s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorNonModal.pug",u.recurseOption(c)),s=10,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorNonModal.pug",d||(s=11,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorNonModal.pug",u.saveAccessButton())}).call(this,"_"in o?o._:typeof _<"u"?_:void 0,"flagList"in o?o.flagList:typeof flagList<"u"?flagList:void 0,"hidePrivacyEditor"in o?o.hidePrivacyEditor:typeof hidePrivacyEditor<"u"?hidePrivacyEditor:void 0,"hideRecurseOption"in o?o.hideRecurseOption:typeof hideRecurseOption<"u"?hideRecurseOption:void 0,"hideSaveButton"in o?o.hideSaveButton:typeof hideSaveButton<"u"?hideSaveButton:void 0,"isAdmin"in o?o.isAdmin:typeof isAdmin<"u"?isAdmin:void 0,"modelType"in o?o.modelType:typeof modelType<"u"?modelType:void 0,"publicFlag"in o?o.publicFlag:typeof publicFlag<"u"?publicFlag:void 0,"publicFlags"in o?o.publicFlags:typeof publicFlags<"u"?publicFlags:void 0)}catch(f){ip(f,i,s)}return e}function W0(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=fr(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function yn(t,e){return Array.isArray(t)?oA(t,e):t&&typeof t=="object"?aA(t):t||""}function oA(t,e){for(var u,r="",i="",s=Array.isArray(e),o=0;o<t.length;o++)(u=yn(t[o]))&&(s&&e[o]&&(u=fr(u)),r=r+i+u,i=" ");return r}function aA(t){var e="",u="";for(var r in t)r&&t[r]&&cA.call(t,r)&&(e=e+u+r,u=" ");return e}function fr(t){var e=""+t,u=lA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var cA=Object.prototype.hasOwnProperty,lA=/["&<>]/;function up(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void up(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function dA(t){var e="",u={},r,i,s;try{var o=t||{};(function(f,n,h,g,d,l,c,a,F){s=1,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",u.privacyEditor=r=function(p){var m=this&&this.block,b=this&&this.attributes||{};if(s=2,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-public-container">',s=3,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="radio">',s=4,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<label>",s=5,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<input"+(' id="g-access-private" type="radio" name="privacy"'+W0("checked",a?void 0:"checked",!0,!1))+"/>",s=7,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<i class="icon-lock"></i>',s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"",s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<b>",s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"Private</b>",s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+" &mdash; Access is required to view this ",s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+fr((r=p)==null?"":r)+"</label></div>",s=9,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="radio">',s=10,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<label>",s=11,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<input"+(' id="g-access-public" type="radio" name="privacy"'+W0("checked",a?"checked":void 0,!0,!1))+"/>",s=13,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<i class="icon-globe"></i>',s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"",s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<b>",s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"Public</b>",s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+" &mdash; Anyone can view this ",s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+fr((r=p)==null?"":r)+"</label></div>",s=16,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",f.keys(n).length){s=17,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<a class="g-action-manage-public-flags hide" title="Public access flags">',s=18,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<i class="g-flag-icon icon-flag">',s=19,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug";var C=F&&F.length||0;s=20,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<div"+W0("class",yn(["g-flag-count-indicator",C?null:"hide"],[!1,!0]),!1,!1)+">",s=20,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+fr((r=C)==null?"":r)+"</div></i>",s=21,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+" Manage public access flags...</a>",s=22,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-public-flags-popover-container hide">',s=23,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",function(){var k=n;if(typeof k.length=="number")for(var T=0,w=k.length;T<w;T++){var A=k[T];s=24,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug";var M=f.contains(F,T)?"checked":null;s=25,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug";var x=!d&&A.admin?"disabled":null;s=26,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<div"+W0("class",yn(["checkbox",x],[!1,!0]),!1,!1)+">",s=27,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<label"+(' class="g-flag-label"'+W0("title",A.description,!0,!1))+">",s=28,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<input"+(' class="g-public-flag-checkbox"'+W0("flag",T,!0,!1)+' type="checkbox"'+W0("checked",M,!0,!1)+W0("disabled",x,!0,!1))+"/>",s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<span>",s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+fr((r=A.name)==null?"":r)+"</span></label></div>"}else{var w=0;for(var T in k){w++;var A=k[T];s=24,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug";var M=f.contains(F,T)?"checked":null;s=25,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug";var x=!d&&A.admin?"disabled":null;s=26,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<div"+W0("class",yn(["checkbox",x],[!1,!0]),!1,!1)+">",s=27,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<label"+(' class="g-flag-label"'+W0("title",A.description,!0,!1))+">",s=28,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<input"+(' class="g-public-flag-checkbox"'+W0("flag",T,!0,!1)+' type="checkbox"'+W0("checked",M,!0,!1)+W0("disabled",x,!0,!1))+"/>",s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<span>",s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+fr((r=A.name)==null?"":r)+"</span></label></div>"}}}.call(this),s=30,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<button class="g-close-public-flags-popover btn btn-xs btn-default">',s=30,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"Close</button></div>"}e=e+"</div>"},s=32,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",u.permissionsEditor=r=function(){var p=this&&this.block,m=this&&this.attributes||{};s=33,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-permissions-editor">',s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-ac-list-title">',s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"",s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<i class="icon-key-1"></i>',s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"  Permissions</div>",s=35,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-ac-list">',s=36,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div id="g-ac-list-groups"></div>',s=37,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div id="g-ac-list-users"></div></div>',s=39,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-grant-access-container">',s=40,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<form role="form">',s=41,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="form-group">',s=42,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<label for="addAccess">',s=42,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"Grant access to another group or user</label>",s=43,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-search-field-container"></div></div></form></div></div>'},s=45,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",u.recurseOption=r=function(p){var m=this&&this.block,b=this&&this.attributes||{};s=46,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="g-recursive-container">',s=47,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="radio">',s=48,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<label>",s=49,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<input id="g-apply-nonrecursive" type="radio" name="recurse" checked="checked"/>',s=50,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"Apply permissions only to this ",s=50,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+fr((r=p)==null?"":r),s=50,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+", not its subfolders</label></div>",s=51,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<div class="radio">',s=52,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"<label>",s=53,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<input id="g-apply-recursive" type="radio" name="recurse"/>',s=54,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"Also set permissions on all subfolders to match this ",s=54,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+fr((r=p)==null?"":r),s=54,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"'s permissions</label></div></div>"},s=56,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",u.saveAccessButton=r=function(){var p=this&&this.block,m=this&&this.attributes||{};s=57,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<button class="g-save-access-list btn btn-small btn-primary">',s=57,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"",s=57,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+'<i class="icon-ok"></i>',s=57,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditorMixins.pug",e=e+"  Save</button>"},s=3,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+'<div class="modal-dialog">',s=4,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+'<div class="modal-content">',s=5,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+'<div class="modal-header">',s=6,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',s=6,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+"&times;</button>",s=7,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+'<h4 class="modal-title">',s=7,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+"Access control</h4>",s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+'<div class="g-dialog-subtitle">',s=9,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",c==="folder"?(s=10,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+'<i class="icon-folder"></i>'):c==="collection"&&(s=12,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+'<i class="icon-sitemap"></i>'),s=13,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+fr((r=l.name())==null?"":r)+"</div></div>",s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+'<div class="modal-body g-access-modal-body">',s=15,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",h||(s=16,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",u.privacyEditor(c)),s=17,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",u.permissionsEditor(),s=18,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",g||(s=19,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",u.recurseOption(c)),e=e+"</div>",s=21,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+'<div class="modal-footer">',s=22,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',s=22,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",e=e+"Close</a>",s=23,i="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEditor.pug",u.saveAccessButton(),e=e+"</div></div></div>"}).call(this,"_"in o?o._:typeof _<"u"?_:void 0,"flagList"in o?o.flagList:typeof flagList<"u"?flagList:void 0,"hidePrivacyEditor"in o?o.hidePrivacyEditor:typeof hidePrivacyEditor<"u"?hidePrivacyEditor:void 0,"hideRecurseOption"in o?o.hideRecurseOption:typeof hideRecurseOption<"u"?hideRecurseOption:void 0,"isAdmin"in o?o.isAdmin:typeof isAdmin<"u"?isAdmin:void 0,"model"in o?o.model:typeof model<"u"?model:void 0,"modelType"in o?o.modelType:typeof modelType<"u"?modelType:void 0,"publicFlag"in o?o.publicFlag:typeof publicFlag<"u"?publicFlag:void 0,"publicFlags"in o?o.publicFlags:typeof publicFlags<"u"?publicFlags:void 0)}catch(f){up(f,i,s)}return e}function Nt(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=$i(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function hu(t,e){return Array.isArray(t)?FA(t,e):t&&typeof t=="object"?hA(t):t||""}function FA(t,e){for(var u,r="",i="",s=Array.isArray(e),o=0;o<t.length;o++)(u=hu(t[o]))&&(s&&e[o]&&(u=$i(u)),r=r+i+u,i=" ");return r}function hA(t){var e="",u="";for(var r in t)r&&t[r]&&gA.call(t,r)&&(e=e+u+r,u=" ");return e}function $i(t){var e=""+t,u=pA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var gA=Object.prototype.hasOwnProperty,pA=/["&<>]/;function sp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void sp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function nn(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h,g,F,l,c,a){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<div"+(Nt("class",hu([`g-${a}-access-entry`],[!0]),!1,!1)+Nt("resourceid",n.id,!0,!1))+">",i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+'<div class="g-access-col-left">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug";var F=a==="group"?"users":"user";i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+'<div class="g-access-icon">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<i"+Nt("class",hu([`icon-${F}`],[!0]),!1,!1)+"></i></div>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+'<div class="g-access-desc">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+'<div class="g-desc-title">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+$i((u=n.title)==null?"":u)+"</div>",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+'<div class="g-desc-subtitle">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+$i((u=n.subtitle)==null?"":u)+"</div></div></div>",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+'<div class="g-access-col-right">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",g||(i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+'<select class="form-control input-sm">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<option"+(Nt("value",f.READ,!0,!1)+Nt("selected",n.level===f.READ?"selected":null,!0,!1))+">",i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"Can view</option>",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<option"+(Nt("value",f.WRITE,!0,!1)+Nt("selected",n.level===f.WRITE?"selected":null,!0,!1))+">",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"Can edit</option>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<option"+(Nt("value",f.ADMIN,!0,!1)+Nt("selected",n.level===f.ADMIN?"selected":null,!0,!1))+">",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"Is owner</option></select>"),i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+'<div class="g-access-action-container">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",!c&&o.keys(h).length&&(i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+'<a class="g-action-manage-flags" title="Access flags">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+'<i class="g-flag-icon icon-flag">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<div"+Nt("class",hu(["g-flag-count-indicator",n.flags&&n.flags.length?null:"hide"],[!1,!0]),!1,!1)+">",i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+$i((u=(n.flags||[]).length)==null?"":u)+"</div></i></a>",i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<div"+(' class="g-flags-popover-container hide"'+Nt("resourcetype",a,!0,!1)+Nt("resourceid",n.id,!0,!1)+' title="Access flags"')+">",i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",function(){var p=h;if(typeof p.length=="number")for(var m=0,b=p.length;m<b;m++){var C=p[m];i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug";var k=o.contains(n.flags,m)?"checked":null;i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug";var T=!l&&C.admin?"disabled":null;i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<div"+Nt("class",hu(["checkbox",T],[!1,!0]),!1,!1)+">",i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<label"+(' class="g-flag-label"'+Nt("title",C.description,!0,!1))+">",i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<input"+(' class="g-flag-checkbox"'+Nt("resourcetype",a,!0,!1)+Nt("resourceid",n.id,!0,!1)+Nt("flag",m,!0,!1)+' type="checkbox"'+Nt("checked",k,!0,!1)+Nt("disabled",T,!0,!1))+"/>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<span>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+$i((u=C.name)==null?"":u)+"</span></label></div>"}else{var b=0;for(var m in p){b++;var C=p[m];i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug";var k=o.contains(n.flags,m)?"checked":null;i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug";var T=!l&&C.admin?"disabled":null;i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<div"+Nt("class",hu(["checkbox",T],[!1,!0]),!1,!1)+">",i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<label"+(' class="g-flag-label"'+Nt("title",C.description,!0,!1))+">",i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<input"+(' class="g-flag-checkbox"'+Nt("resourcetype",a,!0,!1)+Nt("resourceid",n.id,!0,!1)+Nt("flag",m,!0,!1)+' type="checkbox"'+Nt("checked",k,!0,!1)+Nt("disabled",T,!0,!1))+"/>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"<span>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+$i((u=C.name)==null?"":u)+"</span></label></div>"}}}.call(this),i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+'<button class="g-close-flags-popover btn btn-xs btn-default">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+"Close</button></div>"),i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+'<a class="g-action-remove-access" title="Remove access">',i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/accessEntry.pug",e=e+'<i class="icon-cancel"></i></a></div></div></div>'}).call(this,"_"in s?s._:typeof _<"u"?_:void 0,"accessTypes"in s?s.accessTypes:typeof accessTypes<"u"?accessTypes:void 0,"entry"in s?s.entry:typeof entry<"u"?entry:void 0,"flagList"in s?s.flagList:typeof flagList<"u"?flagList:void 0,"hideAccessType"in s?s.hideAccessType:typeof hideAccessType<"u"?hideAccessType:void 0,"icon"in s?s.icon:typeof icon<"u"?icon:void 0,"isAdmin"in s?s.isAdmin:typeof isAdmin<"u"?isAdmin:void 0,"noAccessFlag"in s?s.noAccessFlag:typeof noAccessFlag<"u"?noAccessFlag:void 0,"type"in s?s.type:typeof type<"u"?type:void 0)}catch(o){sp(o,r,i)}return e}function np(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void np(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function fA(t){var e="",u,r;try{r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/loadingAnimation.pug",e=e+'<div id="g-loading-animation">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/widgets/loadingAnimation.pug",e=e+'<div class="g-loading-block" id="g-loading-block-1"></div>',r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/loadingAnimation.pug",e=e+'<div class="g-loading-block" id="g-loading-block-2"></div>',r=4,u="/home/circleci/project/girder/girder/web/src/templates/widgets/loadingAnimation.pug",e=e+'<div class="g-loading-block" id="g-loading-block-3"></div></div>'}catch(i){np(i,u,r)}return e}var Os=Xe.extend({render:function(){return this.$el.html(fA()),this}}),Ao=Xe.extend({events:{"click button.g-save-access-list":function(t){ke(t.currentTarget).girderEnable(!1),this.saveAccessList()},"click .g-close-flags-popover":function(t){ke(t.currentTarget).parents(".g-access-action-container").find(".g-action-manage-flags").popover("hide")},"click .g-close-public-flags-popover":function(t){ke(t.currentTarget).parents(".g-public-container").find(".g-action-manage-public-flags").popover("hide")},"click a.g-action-remove-access":"removeAccessEntry","change .g-public-container .radio input":"privacyChanged","change .g-flag-checkbox":"_toggleAccessFlag","change .g-public-flag-checkbox":"_togglePublicAccessFlag"},initialize:function(t){this.modelType=t.modelType,this.hideRecurseOption=t.hideRecurseOption||!1,this.hideSaveButton=t.hideSaveButton||!1,this.hidePrivacyEditor=t.hidePrivacyEditor||!1,this.hideAccessType=t.hideAccessType||!1,this.noAccessFlag=t.noAccessFlag||!1,this.modal=xe.has(t,"modal")?t.modal:!0,this.currentUser=ft(),this.isAdmin=!!(this.currentUser&&this.currentUser.get("admin")),this.searchWidget=new Xt({placeholder:"Start typing a name...",noResultsPage:!0,modes:["prefix","text"],types:["group","user"],parentView:this}).on("g:resultClicked",this.addEntry,this);var e=null;this.noAccessFlag?this.flagList=[]:e=ut({url:"system/access_flag"}).done(u=>{this.flagList=u}),ke.when(e,this.model.fetchAccess()).done(()=>{this.render()})},render:function(){if(!this.model.get("access")||!this.flagList){new Os({el:this.$el,parentView:this}).render();return}var t;this.modal&&this.modelType==="folder"?(b0("folderaccess"),t=function(){F0("folderaccess")}):this.modal&&(b0("access"),t=function(){F0("access")});var e=this.modal?dA:nA;return this.$el.html(e({_:xe,model:this.model,modelType:this.modelType,publicFlag:this.model.get("public"),publicFlags:this.model.get("publicFlags"),hideRecurseOption:this.hideRecurseOption,hideSaveButton:this.hideSaveButton,hidePrivacyEditor:this.hidePrivacyEditor,flagList:this.flagList,isAdmin:this.isAdmin})),this.modal&&this.$el.girderModal(this).on("hidden.bs.modal",t),xe.each(this.model.get("access").groups,function(u){this.$("#g-ac-list-groups").append(nn({_:xe,accessTypes:nt,type:"group",flagList:this.flagList,isAdmin:this.isAdmin,hideAccessType:this.hideAccessType,noAccessFlag:this.noAccessFlag,entry:xe.extend(u,{title:u.name,subtitle:u.description})}))},this),xe.each(this.model.get("access").users,function(u){this.$("#g-ac-list-users").append(nn({_:xe,accessTypes:nt,type:"user",flagList:this.flagList,isAdmin:this.isAdmin,hideAccessType:this.hideAccessType,noAccessFlag:this.noAccessFlag,entry:xe.extend(u,{title:u.name,subtitle:u.login})}))},this),this._makeTooltips(),this.searchWidget.setElement(this.$(".g-search-field-container")).render(),this.privacyChanged(),this},_makeTooltips:function(){xe.each(this.$(".g-action-manage-flags"),t=>{ke(t).data("bs.popover")||ke(t).popover({trigger:"manual",placement:"left",viewport:{selector:"body",padding:10},content:function(){return ke(this).parent().find(".g-flags-popover-container").html()},html:!0,sanitize:!1}).on("click",function(){ke(this).popover("toggle")})}),xe.each(this.$(".g-action-manage-public-flags"),t=>{ke(t).data("bs.popover")||ke(t).popover({trigger:"manual",placement:"right",viewport:{selector:"body",padding:10},content:function(){return ke(this).parent().find(".g-public-flags-popover-container").html()},html:!0,sanitize:!1}).on("click",function(){ke(this).popover("toggle")})})},addEntry:function(t){this.searchWidget.resetState(),t.type==="user"?this._addUserEntry(t):t.type==="group"&&this._addGroupEntry(t)},_addUserEntry:function(t){var e=!1;if(xe.every(this.$(".g-user-access-entry"),function(r){return ke(r).attr("resourceid")===t.id&&(e=!0),!e},this),!e){var u=new p0;u.set("_id",t.id).on("g:fetched",function(){this.$("#g-ac-list-users").append(nn({_:xe,accessTypes:nt,type:"user",entry:{title:u.name(),subtitle:u.get("login"),id:t.id,level:nt.READ},isAdmin:this.isAdmin,hideAccessType:this.hideAccessType,noAccessFlag:this.noAccessFlag,flagList:this.flagList})),this._makeTooltips()},this).fetch()}},_addGroupEntry:function(t){var e=!1;if(xe.every(this.$(".g-group-access-entry"),function(r){return ke(r).attr("resourceid")===t.id&&(e=!0),!e},this),!e){var u=new Ki;u.set("_id",t.id).on("g:fetched",function(){this.$("#g-ac-list-groups").append(nn({_:xe,accessTypes:nt,type:"group",entry:{title:u.name(),subtitle:u.get("description"),id:t.id,level:nt.READ},isAdmin:this.isAdmin,hideAccessType:this.hideAccessType,noAccessFlag:this.noAccessFlag,flagList:this.flagList})),this._makeTooltips()},this).fetch()}},saveAccessList:function(){var t=this.getAccessList(),e=xe.map(this.$(".g-public-flag-checkbox:checked"),r=>ke(r).attr("flag"));this.model.set({access:t,public:this.$("#g-access-public").is(":checked"),publicFlags:e});var u=this.$("#g-apply-recursive").is(":checked");this.model.off("g:accessListSaved",null,this).on("g:accessListSaved",function(){this.modal&&this.$el.modal("hide"),this.trigger("g:accessListSaved",{recurse:u})},this).updateAccess({recurse:u,progress:!0})},getAccessList:function(){var t={users:[],groups:[]};return xe.each(this.$(".g-group-access-entry"),function(e){var u=ke(e);t.groups.push({name:u.find(".g-desc-title").html(),id:u.attr("resourceid"),level:parseInt(u.find(".g-access-col-right>select").val()||0,10),flags:xe.map(u.find(".g-flag-checkbox:checked"),r=>ke(r).attr("flag"))})},this),xe.each(this.$(".g-user-access-entry"),function(e){var u=ke(e);t.users.push({login:u.find(".g-desc-subtitle").html(),name:u.find(".g-desc-title").html(),id:u.attr("resourceid"),level:parseInt(u.find(".g-access-col-right>select").val()||0,10),flags:xe.map(u.find(".g-flag-checkbox:checked"),r=>ke(r).attr("flag"))})},this),t},removeAccessEntry:function(t){var e=".g-user-access-entry,.g-group-access-entry";ke(t.currentTarget).parents(e).remove()},privacyChanged:function(){this.$(".g-public-container .radio").removeClass("g-selected");var t=this.$(".g-public-container .radio input:checked");t.parents(".radio").addClass("g-selected"),this.$("#g-access-public").is(":checked")?this.$(".g-action-manage-public-flags").removeClass("hide"):this.$(".g-action-manage-public-flags").addClass("hide")},_toggleAccessFlag:function(t){var e=ke(t.currentTarget),u=e.attr("resourcetype"),r=e.attr("resourceid"),i=e.attr("flag"),s=this.$(`.g-flags-popover-container[resourcetype='${u}'][resourceid='${r}']`);s.find(`.g-flag-checkbox[flag="${i}"]`).attr("checked",e.is(":checked")?"checked":null),this._updateFlagCount(s,".g-flag-checkbox")},_togglePublicAccessFlag:function(t){var e=ke(t.currentTarget),u=e.attr("flag"),r=this.$(".g-public-flags-popover-container");r.find(`.g-public-flag-checkbox[flag="${u}"]`).attr("checked",e.is(":checked")?"checked":null),this._updateFlagCount(r,".g-public-flag-checkbox")},_updateFlagCount:function(t,e){const u=t.find(`${e}[checked="checked"]`).length,r=t.parent().find(".g-flag-count-indicator");r.text(u),u?r.removeClass("hide"):r.addClass("hide")}});function on(t){var e=""+t,u=mA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var mA=/["&<>]/;function op(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void op(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function vA(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h,g,d,l,c,a,F){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<li class="g-checked-menu-header dropdown-header" role="presentation">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",n&&(i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<i class="icon-folder"></i>',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<span class="g-checked-folder-count">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+on((u=n)==null?"":u)+"</span>"),i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",h&&(i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<i class="icon-doc-text-inv"></i>',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<span class="g-checked-item-count">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+on((u=h)==null?"":u)+"</span>"),i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",c&&(i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<i class="icon-plus-circled"></i>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<span class="g-checked-picked-count">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+on((u=c)==null?"":u)+"</span>"),e=e+"</li>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",(n||h)&&(i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+"<li>",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<a class="g-download-checked">',i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<i class="icon-download"></i>',i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+"Download checked resources</a></li>",i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+"<li>",i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<a class="g-pick-checked">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<i class="icon-plus-circled"></i>',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+"Pick checked resources for Move or Copy</a></li>"),i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",f.getPickedResources()&&(i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<li class="g-admin divider"></li>',i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",F&&(i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+"<li>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<a class="g-move-picked">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<i class="icon-move"></i>',i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+"Move picked resources here</a></li>"),i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",l&&(i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+"<li>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<a class="g-copy-picked">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<i class="icon-paste"></i>',i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+"Copy picked resources here</a></li>"),i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+"<li>",i=34,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<a class="g-clear-picked">',i=35,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<i class="icon-minus-circled"></i>',i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+"Clear picked resources",i=37,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",a&&(i=38,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+" (",i=38,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+on((u=a)==null?"":u),i=38,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+")"),e=e+"</a></li>"),i=40,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",(n||h)&&(i=41,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",g>=o.ADMIN&&d>=o.WRITE&&(i=42,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<li class="g-admin divider"></li>',i=43,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<li class="g-admin">',i=44,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<a class="g-delete-checked">',i=45,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+'<i class="icon-trash"></i>',i=46,r="/home/circleci/project/girder/girder/web/src/templates/widgets/checkedActionsMenu.pug",e=e+"Delete checked resources</a></li>"))}).call(this,"AccessType"in s?s.AccessType:typeof AccessType<"u"?AccessType:void 0,"HierarchyWidget"in s?s.HierarchyWidget:typeof HierarchyWidget<"u"?HierarchyWidget:void 0,"folderCount"in s?s.folderCount:typeof folderCount<"u"?folderCount:void 0,"itemCount"in s?s.itemCount:typeof itemCount<"u"?itemCount:void 0,"minFolderLevel"in s?s.minFolderLevel:typeof minFolderLevel<"u"?minFolderLevel:void 0,"minItemLevel"in s?s.minItemLevel:typeof minItemLevel<"u"?minItemLevel:void 0,"pickedCopyAllowed"in s?s.pickedCopyAllowed:typeof pickedCopyAllowed<"u"?pickedCopyAllowed:void 0,"pickedCount"in s?s.pickedCount:typeof pickedCount<"u"?pickedCount:void 0,"pickedDesc"in s?s.pickedDesc:typeof pickedDesc<"u"?pickedDesc:void 0,"pickedMoveAllowed"in s?s.pickedMoveAllowed:typeof pickedMoveAllowed<"u"?pickedMoveAllowed:void 0)}catch(o){op(o,r,i)}return e}var ap=Xe.extend({initialize:function(t){this._fetchAndInit(t),this.dropdownToggle=t.dropdownToggle},render:function(){if(this.folderCount+this.itemCount+this.pickedCount===0){this.dropdownToggle.girderEnable(!1);return}return this.dropdownToggle.girderEnable(!0),this.$el.html(vA({minFolderLevel:this.minFolderLevel,minItemLevel:this.minItemLevel,folderCount:this.folderCount,itemCount:this.itemCount,AccessType:nt,pickedCount:this.pickedCount,pickedCopyAllowed:this.pickedCopyAllowed,pickedMoveAllowed:this.pickedMoveAllowed,pickedDesc:this.pickedDesc,HierarchyWidget:$u})),this},update:function(t){this._fetchAndInit(t),this.render()},_fetchAndInit:function(t){this.minFolderLevel=t.minFolderLevel||nt.READ,this.minItemLevel=t.minItemLevel||nt.READ,this.folderCount=t.folderCount||0,this.itemCount=t.itemCount||0,this.pickedCount=t.pickedCount||0,this.pickedCopyAllowed=t.pickedCopyAllowed||!1,this.pickedMoveAllowed=t.pickedMoveAllowed||!1,this.pickedDesc=t.pickedDesc||""}});function bA(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Di(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Di(t){var e=""+t,u=wA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var wA=/["&<>]/;function cp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void cp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function yA(t){var e="",u={},r,i,s;try{var o=t||{};(function(f,n,h,g,d){s=1,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",u.dateInfo=r=function(l,c){var a=this&&this.block,F=this&&this.attributes||{};s=2,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+"<div"+(' class="g-collection-info-line"'+bA("property",c,!0,!1))+">",s=3,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<i class="icon-clock"></i>',s=4,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+"<span>",s=4,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+Di((r=l)==null?"":r)+"</span>",s=5,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<span class="g-bold-part">',s=5,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+Di((r=h(n.get(c),f))==null?"":r)+"</span></div>"},s=7,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<div class="modal-dialog">',s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<div class="modal-content">',s=9,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<div class="modal-header">',s=10,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true">',s=10,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+"&times;</button>",s=11,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<h4 class="modal-title">',s=11,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+"Collection information</h4>",s=12,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<div class="g-dialog-subtitle">',s=13,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<i class="icon-sitemap"></i>',s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+"<span>",s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+Di((r=n.name())==null?"":r)+"</span></div></div>",s=15,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<div class="modal-body">',s=16,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",n.get("description")&&(s=17,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<div class="g-info-dialog-description">',s=17,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+((r=d(n.get("description")))==null?"":r)+"</div>"),s=19,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<div class="g-collection-info-lines">',s=20,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",u.dateInfo("Created ","created"),s=21,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",n.get("created")!==n.get("updated")&&(s=22,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",u.dateInfo("Last updated ","updated")),s=24,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<div class="g-collection-info-line" property="size">',s=25,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<i class="icon-floppy"></i>',s=26,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+"Total size: ",s=26,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<span class="g-bold-part">',s=26,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+Di((r=g(n.get("size")))==null?"":r)+"</span>",s=26,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+"</div>",s=28,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<div class="g-collection-info-line" property="nFolders">',s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<i class="icon-folder"></i>',s=30,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+"Contains ",s=30,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<span class="g-bold-part">',s=30,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+Di((r=n.get("nFolders"))==null?"":r)+"</span>",s=30,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+" subfolders</div>",s=32,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<div class="g-collection-info-line" property="id">',s=33,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<i class="icon-share"></i>',s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+"Unique ID: ",s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<span class="g-bold-part">',s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+Di((r=n.id)==null?"":r)+"</span>",s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+"</div></div></div>",s=36,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<div class="modal-footer">',s=37,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',s=37,i="/home/circleci/project/girder/girder/web/src/templates/widgets/collectionInfoDialog.pug",e=e+"Close</a></div></div></div>"}).call(this,"DATE_SECOND"in o?o.DATE_SECOND:typeof DATE_SECOND<"u"?DATE_SECOND:void 0,"collection"in o?o.collection:typeof collection<"u"?collection:void 0,"formatDate"in o?o.formatDate:typeof formatDate<"u"?formatDate:void 0,"formatSize"in o?o.formatSize:typeof formatSize<"u"?formatSize:void 0,"renderMarkdown"in o?o.renderMarkdown:typeof renderMarkdown<"u"?renderMarkdown:void 0)}catch(f){cp(f,i,s)}return e}var lp=Xe.extend({initialize:function(){this.needToFetch=!this.model.has("nFolders"),(this.needToFetch||this.timestamp!==this.model.get("updated"))&&this.model.once("g:fetched.details",function(){this.needToFetch=!1,this.timestamp=this.model.get("updated"),this.render()},this).fetch({extraPath:"details"})},render:function(){if(!this.needToFetch)return this.$el.html(yA({collection:this.model,formatDate:pi,formatSize:Zt,DATE_SECOND:Iu,renderMarkdown:fi})).girderModal(this),this}});function au(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=dp(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function dp(t){var e=""+t,u=CA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var CA=/["&<>]/;function Fp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Fp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function EA(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="g-markdown-widget">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="g-tabs-container">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="g-markdown-tabs-top">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<ul class="nav nav-tabs">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<li class="first active" role="presentation">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+"<a"+(' class="g-write-link"'+au("data-target",`#${n}-write`,!0,!1)+' aria-controls="home" role="tab" data-toggle="tab"')+">",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+"Write</a></li>",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<li role="presentation">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+"<a"+(' class="g-preview-link"'+au("data-target",`#${n}-preview`,!0,!1)+' aria-controls="preview" role="tab" data-toggle="tab"')+">",i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+"Preview</a></li>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="g-markdown-explanation">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+"Supports",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<a href="https://daringfireball.net/projects/markdown/syntax" tabindex="-1" target="_blank">',i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+" Markdown</a></div></ul></div>",i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="tab-content">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+"<div"+(' class="tab-pane active" role="tabpanel"'+au("id",`${n}-write`,!0,!1))+">",i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="g-markdown-drop-zone">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+"<textarea"+(' class="form-control g-markdown-text"'+au("upload-enabled",o?"true":null,!0,!1)+au("placeholder",f,!0,!1))+">",i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+dp((u=h)==null?"":u)+"</textarea>",i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",o&&(i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="g-upload-overlay hide">',i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="g-upload-progress-container">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="g-markdown-upload-progress progress progress-striped">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="progress-bar progress-bar-info" role="progressbar"></div></div>',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="g-markdown-upload-progress-message">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+"Starting upload...</div></div></div>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="g-upload-footer">',i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+"",i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<i class="icon-picture"></i>',i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+" Add an image by ",i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<a class="g-browse">',i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+"clicking here</a>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+", or drag",i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+`
`,i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+"and drop one into the editor.</div>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="hide">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<input class="g-file-input" type="file"/></div>'),e=e+"</div></div>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+"<div"+(' class="tab-pane" role="tabpanel"'+au("id",`${n}-preview`,!0,!1))+">",i=34,r="/home/circleci/project/girder/girder/web/src/templates/widgets/markdownWidget.pug",e=e+'<div class="g-markdown-preview"></div></div></div></div></div>'}).call(this,"enableUploads"in s?s.enableUploads:typeof enableUploads<"u"?enableUploads:void 0,"placeholder"in s?s.placeholder:typeof placeholder<"u"?placeholder:void 0,"prefix"in s?s.prefix:typeof prefix<"u"?prefix:void 0,"text"in s?s.text:typeof text<"u"?text:void 0)}catch(o){Fp(o,r,i)}return e}+function(t){var e=function(s){this.element=t(s)};e.VERSION="3.4.1",e.TRANSITION_DURATION=150,e.prototype.show=function(){var s=this.element,o=s.closest("ul:not(.dropdown-menu)"),f=s.data("target");if(f||(f=s.attr("href"),f=f&&f.replace(/.*(?=#[^\s]*$)/,"")),!s.parent("li").hasClass("active")){var n=o.find(".active:last a"),h=t.Event("hide.bs.tab",{relatedTarget:s[0]}),g=t.Event("show.bs.tab",{relatedTarget:n[0]});if(n.trigger(h),s.trigger(g),!(g.isDefaultPrevented()||h.isDefaultPrevented())){var d=t(document).find(f);this.activate(s.closest("li"),o),this.activate(d,d.parent(),function(){n.trigger({type:"hidden.bs.tab",relatedTarget:s[0]}),s.trigger({type:"shown.bs.tab",relatedTarget:n[0]})})}}},e.prototype.activate=function(s,o,f){var n=o.find("> .active"),h=f&&t.support.transition&&(n.length&&n.hasClass("fade")||!!o.find("> .fade").length);function g(){n.removeClass("active").find("> .dropdown-menu > .active").removeClass("active").end().find('[data-toggle="tab"]').attr("aria-expanded",!1),s.addClass("active").find('[data-toggle="tab"]').attr("aria-expanded",!0),h?(s[0].offsetWidth,s.addClass("in")):s.removeClass("fade"),s.parent(".dropdown-menu").length&&s.closest("li.dropdown").addClass("active").end().find('[data-toggle="tab"]').attr("aria-expanded",!0),f&&f()}n.length&&h?n.one("bsTransitionEnd",g).emulateTransitionEnd(e.TRANSITION_DURATION):g(),n.removeClass("in")};function u(s){return this.each(function(){var o=t(this),f=o.data("bs.tab");f||o.data("bs.tab",f=new e(this)),typeof s=="string"&&f[s]()})}var r=t.fn.tab;t.fn.tab=u,t.fn.tab.Constructor=e,t.fn.tab.noConflict=function(){return t.fn.tab=r,this};var i=function(s){s.preventDefault(),u.call(t(this),"show")};t(document).on("click.bs.tab.data-api",'[data-toggle="tab"]',i).on("click.bs.tab.data-api",'[data-toggle="pill"]',i)}(ke);var xo=Xe.extend({events:{"show.bs.tab .g-preview-link":function(){fi(this.val().trim()||"Nothing to show",this.$(".g-markdown-preview"))},"shown.bs.tab .g-write-link":function(){this.$(".g-markdown-text").trigger("focus")},"click .g-browse":function(){this.$(".g-file-input").trigger("click")},"change .g-file-input":function(t){var e=t.target.files;e.length&&(this.files=e,this.filesAdded())},"dragenter .g-markdown-drop-zone":function(t){t.stopPropagation(),t.preventDefault(),t.originalEvent.dataTransfer.dropEffect="copy",this.$(".g-markdown-text,.g-upload-footer").addClass("dragover")},"dragleave .g-markdown-drop-zone":function(t){t.stopPropagation(),t.preventDefault(),this.$(".g-markdown-text,.g-upload-footer").removeClass("dragover")},"dragover .g-markdown-drop-zone":function(t){t.originalEvent.dataTransfer.dropEffect="copy",this.$(".g-markdown-text,.g-upload-footer").addClass("dragover")},"drop .g-markdown-drop-zone":function(t){t.stopPropagation(),t.preventDefault(),this.$(".g-markdown-text,.g-upload-footer").removeClass("dragover"),this.files=t.originalEvent.dataTransfer.files,this.filesAdded()}},initialize:function(t){this.text=t.text||"",this.placeholder=t.placeholder||"",this.prefix=t.prefix||"markdown",this.enableUploads=t.enableUploads||!1,this.parent=t.parent||null,this.maxUploadSize=t.maxUploadSize||1024*1024*10,this.allowedExtensions=t.allowedExtensions||null,this.files=[]},filesAdded:function(){try{this.validateFiles()}catch(u){He.trigger("g:alert",{type:"danger",text:u.message,icon:"cancel",timeout:5e3});return}var t=this.files[0],e=new Eo;e.on("g:upload.complete",function(){var u=this.$(".g-markdown-text").val();u+="!["+t.name+"]("+e.downloadUrl()+`)
`,this.$(".g-upload-overlay").addClass("hide"),this.$(".g-markdown-text").girderEnable(!0).val(u),this.trigger("g:fileUploaded",{file:t,model:e})},this).on("g:upload.progress",function(u){var r=u.startByte+u.loaded;this.$(".g-markdown-upload-progress>.progress-bar").css("width",Math.ceil(100*r/u.total)+"%"),this.$(".g-markdown-upload-progress-message").text("Uploading "+u.file.name+" - "+Zt(r)+" / "+Zt(u.total))},this).on("g:upload.error",function(u){He.trigger("g:alert",{type:"danger",text:u.message,icon:"cancel",timeout:5e3}),this.$(".g-upload-overlay").addClass("hide"),this.$(".g-markdown-text").girderEnable(!0)},this).on("g:upload.errorStarting",function(u){He.trigger("g:alert",{type:"danger",text:u.message,icon:"cancel",timeout:5e3}),this.$(".g-upload-overlay").addClass("hide"),this.$(".g-markdown-text").girderEnable(!0)},this).upload(this.parent,t),this.$(".g-upload-overlay").removeClass("hide"),this.$(".g-markdown-text").girderEnable(!1)},validateFiles:function(t){if(t=t||this.files,this.files.length!==1)throw new Error("Please add only one file at a time.");var e=t[0],u=e.name.split(".").pop().toLowerCase();if(this.maxUploadSize&&e.size>this.maxUploadSize)throw new Error("That file is too large. You may only attach files up to "+Zt(this.maxUploadSize)+".");if(this.allowedExtensions&&!xe.contains(this.allowedExtensions,u))throw new Error("Only files with the following extensions are allowed: "+this.allowedExtensions.join(", ")+".")},render:function(){return this.$el.html(EA({text:this.text,placeholder:this.placeholder,prefix:this.prefix,enableUploads:this.enableUploads})),this},val:function(){return arguments.length?this.$(".g-markdown-text").val(arguments[0]):this.$(".g-markdown-text").val()},saveText:function(){this.text=this.val()}});function hp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void hp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function AA(t){var e="",u,r;try{var i=t||{};(function(s){r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<div class="modal-dialog">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<div class="modal-content">',r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<form class="modal-form" id="g-collection-edit-form" role="form">',r=4,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<div class="modal-header">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+"&times;</button>",r=6,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<h4 class="modal-title">',r=7,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",s?(r=8,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+"Create collection"):(r=10,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+"Edit collection"),e=e+"</h4></div>",r=11,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<div class="modal-body">',r=12,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<div class="form-group">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<label class="control-label" for="g-name">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+"Name</label>",r=14,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<input class="input-sm form-control" id="g-name" type="text" placeholder="Enter collection name"/></div>',r=15,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<div class="form-group">',r=16,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<label class="control-label">',r=16,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+"Description (optional)</label>",r=17,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<div class="g-description-editor-container"></div></div>',r=18,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<div class="g-validation-failed-message"></div></div>',r=19,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<div class="modal-footer">',r=20,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',r=20,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+"Cancel</a>",r=21,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<button class="g-save-collection btn btn-small btn-primary" type="submit">',r=22,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",s?(r=23,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<i class="icon-plus-squared"></i>',r=24,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+"Create"):(r=26,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+'<i class="icon-edit"></i>',r=27,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editCollectionWidget.pug",e=e+"Save"),e=e+"</button></div></form></div></div>"}).call(this,"create"in i?i.create:typeof create<"u"?create:void 0)}catch(s){hp(s,u,r)}return e}const ko=Xe.extend({events:{"submit #g-collection-edit-form":function(t){t.preventDefault();const e={name:this.$("#g-name").val(),description:this.descriptionEditor.val()};this.descriptionEditor.saveText(),this.$("button.g-save-collection").girderEnable(!1),this.$(".g-validation-failed-message").text(""),this._saveCollection(e).always(()=>{this.$("button.g-save-collection").girderEnable(!0)}).done(()=>{this.$el.modal("hide")}).fail(u=>{this.$(".g-validation-failed-message").text(u.responseJSON.message),this.$("#g-"+u.responseJSON.field).trigger("focus")})}},initialize:function(t){this.create=!t.model,this.model=t.model||new ai,this.descriptionEditor=new xo({text:this.model?this.model.get("description"):"",prefix:"collection-description",placeholder:"Enter a description",enableUploads:!1,parentView:this})},render:function(){this.$el.html(AA({create:this.create,collection:this.model}));const t=this.$el.girderModal(this).on("shown.bs.modal",()=>{this.$("#g-name").trigger("focus")}).on("hidden.bs.modal",()=>{F0(this.create?"create":"edit")}).on("ready.girder.modal",()=>{this.create||(this.$("#g-name").val(this.model.get("name")),this.$("#g-description").val(this.model.get("description")))});return t.trigger(ke.Event("ready.girder.modal",{relatedTarget:t})),this.descriptionEditor.setElement(this.$(".g-description-editor-container")).render(),this.$("#g-name").trigger("focus"),b0(this.create?"create":"edit"),this},_saveCollection:function(t){return this.model.set(t),this.model.save().done(()=>{this.trigger("g:saved",this.model)})}});function gp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void gp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function xA(t){var e="",u,r;try{var i=t||{};(function(s){r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<div class="modal-dialog">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<div class="modal-content">',r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<form class="modal-form" id="g-folder-edit-form" role="form">',r=4,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<div class="modal-header">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+"&times;</button>",r=6,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<h4 class="modal-title">',r=7,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",s?(r=8,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+"Edit folder"):(r=10,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+"Create folder"),e=e+"</h4></div>",r=11,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<div class="modal-body">',r=12,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<div class="form-group">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<label class="control-label" for="g-name">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+"Name</label>",r=14,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<input class="input-sm form-control" id="g-name" type="text" placeholder="Enter folder name"/></div>',r=15,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<div class="form-group">',r=16,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<label class="control-label">',r=16,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+"Description (optional)</label>",r=17,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<div class="g-description-editor-container"></div></div>',r=18,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<div class="g-validation-failed-message"></div></div>',r=19,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<div class="modal-footer">',r=20,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',r=20,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+"Cancel</a>",r=21,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<button class="g-save-folder btn btn-small btn-primary" type="submit">',r=22,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",s?(r=23,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<i class="icon-edit"></i>',r=24,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+"Save"):(r=26,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+'<i class="icon-plus-squared"></i>',r=27,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFolderWidget.pug",e=e+"Create"),e=e+"</button></div></form></div></div>"}).call(this,"folder"in i?i.folder:typeof folder<"u"?folder:void 0)}catch(s){gp(s,u,r)}return e}var Ja=Xe.extend({events:{"submit #g-folder-edit-form":function(t){t.preventDefault();var e={name:this.$("#g-name").val(),description:this.descriptionEditor.val()};this.folder?this.updateFolder(e):this.createFolder(e),this.descriptionEditor.saveText(),this.$("button.g-save-folder").girderEnable(!1),this.$(".g-validation-failed-message").text("")}},initialize:function(t){this.folder=t.folder||null,this.parentModel=t.parentModel,this.descriptionEditor=new xo({text:this.folder?this.folder.get("description"):"",prefix:"folder-description",placeholder:"Enter a description",parent:this.folder,allowedExtensions:["png","jpg","jpeg","gif"],enableUploads:!!this.folder,parentView:this}).on("g:fileUploaded",function(e){this.trigger("g:fileUploaded",e)},this)},render:function(){var t=this.$el.html(xA({folder:this.folder})).girderModal(this).on("shown.bs.modal",()=>{this.$("#g-name").trigger("focus"),this.folder?b0("folderedit"):b0("foldercreate")}).on("hidden.bs.modal",()=>{this.create?F0("foldercreate"):F0("folderedit")}).on("ready.girder.modal",()=>{this.folder?(this.$("#g-name").val(this.folder.get("name")),this.descriptionEditor.val(this.folder.get("description")),this.create=!1):this.create=!0});return t.trigger(ke.Event("ready.girder.modal",{relatedTarget:t})),this.$("#g-name").trigger("focus"),this.descriptionEditor.setElement(this.$(".g-description-editor-container")).render(),this},createFolder:function(t){var e=new Sr;e.set(xe.extend(t,{parentType:this.parentModel.resourceName,parentId:this.parentModel.get("_id")})),e.on("g:saved",function(){this.$el.modal("hide"),this.trigger("g:saved",e)},this).on("g:error",function(u){this.$(".g-validation-failed-message").text(u.responseJSON.message),this.$("button.g-save-folder").girderEnable(!0),this.$("#g-"+u.responseJSON.field).trigger("focus")},this).save()},updateFolder:function(t){this.folder.set(t),this.folder.off().on("g:saved",function(){this.$el.modal("hide"),this.trigger("g:saved",this.folder)},this).on("g:error",function(e){this.$(".g-validation-failed-message").text(e.responseJSON.message),this.$("button.g-save-folder").girderEnable(!0),this.$("#g-"+e.responseJSON.field).trigger("focus")},this).save()}});function pp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void pp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function kA(t){var e="",u,r;try{var i=t||{};(function(s){r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<div class="modal-dialog">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<div class="modal-content">',r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<form class="modal-form" id="g-item-edit-form" role="form">',r=4,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<div class="modal-header">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+"&times;</button>",r=6,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<h4 class="modal-title">',r=7,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",s?(r=8,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+"Edit item"):(r=10,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+"Create item"),e=e+"</h4></div>",r=11,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<div class="modal-body">',r=12,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<div class="form-group">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<label class="control-label" for="g-name">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+"Name</label>",r=14,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<input class="input-sm form-control" id="g-name" type="text" placeholder="Enter item name"/></div>',r=15,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<div class="form-group">',r=16,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<label class="control-label">',r=16,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+"Description (optional)</label>",r=17,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<div class="g-description-editor-container"></div></div>',r=18,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<div class="g-validation-failed-message"></div></div>',r=19,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<div class="modal-footer">',r=20,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',r=20,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+"Cancel</a>",r=21,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<button class="g-save-item btn btn-small btn-primary" type="submit">',r=22,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",s?(r=23,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<i class="icon-edit"></i>',r=24,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+"Save"):(r=26,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+'<i class="icon-plus-squared"></i>',r=27,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editItemWidget.pug",e=e+"Create"),e=e+"</button></div></form></div></div>"}).call(this,"item"in i?i.item:typeof item<"u"?item:void 0)}catch(s){pp(s,u,r)}return e}var El=Xe.extend({events:{"submit #g-item-edit-form":function(){var t={name:this.$("#g-name").val(),description:this.descriptionEditor.val()};return this.item?this.updateItem(t):this.createItem(t),this.descriptionEditor.saveText(),this.$("button.g-save-item").girderEnable(!1),this.$(".g-validation-failed-message").empty(),!1}},initialize:function(t){this.item=t.item||null,this.parentModel=t.parentModel,this.descriptionEditor=new xo({text:this.item?this.item.get("description"):"",prefix:"item-description",placeholder:"Enter a description",enableUploads:!1,parentView:this})},render:function(){var t=this.$el.html(kA({item:this.item})).girderModal(this).on("shown.bs.modal",()=>{this.$("#g-name").trigger("focus"),this.item?b0("itemedit"):b0("itemcreate")}).on("hidden.bs.modal",()=>{this.create?F0("itemcreate"):F0("itemedit")}).on("ready.girder.modal",()=>{this.item?(this.$("#g-name").val(this.item.get("name")),this.$("#g-description").val(this.item.get("description")),this.create=!1):this.create=!0});return t.trigger(ke.Event("ready.girder.modal",{relatedTarget:t})),this.descriptionEditor.setElement(this.$(".g-description-editor-container")).render(),this},createItem:function(t){var e=new iu;e.set(xe.extend(t,{folderId:this.parentModel.get("_id")})),e.on("g:saved",function(){this.$el.modal("hide"),this.trigger("g:saved",e)},this).on("g:error",function(u){this.$(".g-validation-failed-message").text(u.responseJSON.message),this.$("button.g-save-item").girderEnable(!0),this.$("#g-"+u.responseJSON.field).trigger("focus")},this).save()},updateItem:function(t){this.item.set(t),this.item.off().on("g:saved",function(){this.$el.modal("hide"),this.trigger("g:saved",this.item)},this).on("g:error",function(e){this.$(".g-validation-failed-message").text(e.responseJSON.message),this.$("button.g-save-item").girderEnable(!0),this.$("#g-"+e.responseJSON.field).trigger("focus")},this).save()}});function jA(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Zr(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Zr(t){var e=""+t,u=SA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var SA=/["&<>]/;function fp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void fp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function _A(t){var e="",u={},r,i,s;try{var o=t||{};(function(f,n,h,g,d){s=1,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",u.dateInfo=r=function(l,c){var a=this&&this.block,F=this&&this.attributes||{};s=2,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+"<div"+(' class="g-folder-info-line"'+jA("property",c,!0,!1))+">",s=3,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<i class="icon-clock"></i>',s=4,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+"<span>",s=4,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+Zr((r=l)==null?"":r)+"</span>",s=5,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<span class="g-bold-part">',s=5,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+Zr((r=h(n.get(c),f))==null?"":r)+"</span></div>"},s=7,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<div class="modal-dialog">',s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<div class="modal-content">',s=9,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<div class="modal-header">',s=10,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true">',s=10,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+"&times;</button>",s=11,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<h4 class="modal-title">',s=11,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+"Folder information</h4>",s=12,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<div class="g-dialog-subtitle">',s=13,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<i class="icon-folder"></i>',s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+"<span>",s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+Zr((r=n.name())==null?"":r)+"</span></div></div>",s=15,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<div class="modal-body">',s=16,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",n.get("description")&&(s=17,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<div class="g-info-dialog-description g-folder-description">',s=17,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+((r=d(n.get("description")))==null?"":r)+"</div>"),s=19,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<div class="g-folder-info-lines">',s=20,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",u.dateInfo("Created ","created"),s=21,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",n.get("created")!==n.get("updated")&&(s=22,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",u.dateInfo("Last updated ","updated")),s=24,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<div class="g-folder-info-line" property="nItems">',s=25,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<i class="icon-doc-text-inv"></i>',s=26,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+"<span>",s=26,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+"Contains</span>",s=27,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<span class="g-bold-part">',s=27,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+" ",s=27,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+Zr((r=n.get("nItems"))==null?"":r),s=27,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+" items</span>",s=28,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+"<span>",s=28,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+" totaling</span>",s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<span class="g-bold-part">',s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+" ",s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+Zr((r=g(n.get("size")))==null?"":r)+"</span></div>",s=31,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<div class="g-folder-info-line" property="nFolders">',s=32,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<i class="icon-folder"></i>',s=33,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+"<span>",s=33,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+"Contains</span>",s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<span class="g-bold-part">',s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+" ",s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+Zr((r=n.get("nFolders"))==null?"":r),s=34,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+" subfolders</span></div>",s=36,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<div class="g-folder-info-line" property="id">',s=37,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<i class="icon-share"></i>',s=38,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+"<span>",s=38,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+"Unique ID:</span>",s=39,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<span class="g-bold-part">',s=39,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+" ",s=39,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+Zr((r=n.id)==null?"":r)+"</span></div></div></div>",s=41,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<div class="modal-footer">',s=42,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',s=42,i="/home/circleci/project/girder/girder/web/src/templates/widgets/folderInfoDialog.pug",e=e+"Close</a></div></div></div>"}).call(this,"DATE_SECOND"in o?o.DATE_SECOND:typeof DATE_SECOND<"u"?DATE_SECOND:void 0,"folder"in o?o.folder:typeof folder<"u"?folder:void 0,"formatDate"in o?o.formatDate:typeof formatDate<"u"?formatDate:void 0,"formatSize"in o?o.formatSize:typeof formatSize<"u"?formatSize:void 0,"renderMarkdown"in o?o.renderMarkdown:typeof renderMarkdown<"u"?renderMarkdown:void 0)}catch(f){fp(f,i,s)}return e}var mp=Xe.extend({initialize:function(){this.needToFetch=!this.model.has("nItems")||!this.model.has("nFolders"),this.needToFetch&&this.model.once("g:fetched.details",function(){this.needToFetch=!1,this.render()},this).fetch({extraPath:"details"})},render:function(){return this.needToFetch?this:(this.$el.html(_A({folder:this.model,formatDate:pi,formatSize:Zt,renderMarkdown:fi,DATE_SECOND:Iu})).girderModal(this),this)}});function Jr(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Qa(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Qa(t){var e=""+t,u=DA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var DA=/["&<>]/;function vp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void vp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function MA(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<ul class="g-folder-list">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",function(){var h=f;if(typeof h.length=="number")for(var g=0,d=h.length;g<d;g++){var l=h[g];i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+"<li"+(' class="g-folder-list-entry"'+Jr("public",l.get("public")?"true":"false",!0,!1))+">",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",o&&(i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+"<input"+(' class="g-list-checkbox" type="checkbox"'+Jr("g-folder-cid",l.cid,!0,!1))+"/>"),i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+"<a"+(' class="g-folder-list-link"'+Jr("g-folder-cid",l.cid,!0,!1)+Jr("href",`#folder/${l.id}`,!0,!1))+">",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<i class="icon-folder"></i>',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+Qa((u=l.get("name"))==null?"":u),i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<i class="icon-right-dir"></i></a>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<div class="g-folder-privacy">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",l.get("public")?(i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<i class="icon-globe"></i>',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+"Public"):(i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<i class="icon-lock"></i>',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+"Private"),e=e+"</div></li>"}else{var d=0;for(var g in h){d++;var l=h[g];i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+"<li"+(' class="g-folder-list-entry"'+Jr("public",l.get("public")?"true":"false",!0,!1))+">",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",o&&(i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+"<input"+(' class="g-list-checkbox" type="checkbox"'+Jr("g-folder-cid",l.cid,!0,!1))+"/>"),i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+"<a"+(' class="g-folder-list-link"'+Jr("g-folder-cid",l.cid,!0,!1)+Jr("href",`#folder/${l.id}`,!0,!1))+">",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<i class="icon-folder"></i>',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+Qa((u=l.get("name"))==null?"":u),i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<i class="icon-right-dir"></i></a>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<div class="g-folder-privacy">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",l.get("public")?(i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<i class="icon-globe"></i>',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+"Public"):(i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<i class="icon-lock"></i>',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+"Private"),e=e+"</div></li>"}}}.call(this),i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",n&&(i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<li class="g-show-more">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<a class="g-show-more-folders">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+'<i class="icon-level-down"></i>',i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/folderList.pug",e=e+"Show more folders...</a></li>"),e=e+"</ul>"}).call(this,"checkboxes"in s?s.checkboxes:typeof checkboxes<"u"?checkboxes:void 0,"folders"in s?s.folders:typeof folders<"u"?folders:void 0,"hasMore"in s?s.hasMore:typeof hasMore<"u"?hasMore:void 0)}catch(o){vp(o,r,i)}return e}var bp=Xe.extend({events:{"click a.g-folder-list-link":function(t){t.preventDefault();var e=ke(t.currentTarget).attr("g-folder-cid");this.trigger("g:folderClicked",this.collection.get(e))},"click a.g-show-more-folders":function(){this.collection.fetchNextPage()},"change .g-list-checkbox":function(t){const e=ke(t.currentTarget),u=e.attr("g-folder-cid");if(e.prop("checked"))this.checked.push(u);else{const r=this.checked.indexOf(u);r!==-1&&this.checked.splice(r,1)}this.trigger("g:checkboxesChanged")}},initialize:function(t){this.checked=[],this._checkboxes=t.checkboxes,new Os({el:this.$el,parentView:this}).render(),this.collection=new fg,this.collection.append=!0,this.collection.filterFunc=t.folderFilter,this.collection.on("g:changed",function(){this.render(),this.trigger("g:changed")},this).fetch({parentType:t.parentType||"folder",parentId:t.parentId})},render:function(){return this.checked=[],this.$el.html(MA({folders:this.collection.toArray(),hasMore:this.collection.hasNextPage(),checkboxes:this._checkboxes})),this},insertFolder:function(t){this.collection.add(t),this.trigger("g:changed"),this.render()},checkAll:function(t){this.$(".g-list-checkbox").prop("checked",t),this.checked=[],t&&this.collection.each(function(e){this.checked.push(e.cid)},this),this.trigger("g:checkboxesChanged")},recomputeChecked:function(){this.checked=xe.map(this.$(".g-list-checkbox:checked"),function(t){return ke(t).attr("g-folder-cid")},this)}});function g0(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=ri(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Xa(t,e){return Array.isArray(t)?TA(t,e):t&&typeof t=="object"?PA(t):t||""}function TA(t,e){for(var u,r="",i="",s=Array.isArray(e),o=0;o<t.length;o++)(u=Xa(t[o]))&&(s&&e[o]&&(u=ri(u)),r=r+i+u,i=" ");return r}function PA(t){var e="",u="";for(var r in t)r&&t[r]&&LA.call(t,r)&&(e=e+u+r,u=" ");return e}function ri(t){var e=""+t,u=RA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var LA=Object.prototype.hasOwnProperty,RA=/["&<>]/;function wp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void wp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function BA(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h,g,d,l,c,a,F,p){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<ul class="g-item-list">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",function(){var m=l;if(typeof m.length=="number")for(var b=0,C=m.length;b<C;b++){var k=m[b];i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+"<li"+(g0("class",Xa(["g-item-list-entry",g&&k.id===a?"g-selected":""],[!1,!0]),!1,!1)+g0("public",d?"true":"false",!0,!1))+">",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",o&&(i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+"<input"+(' class="g-list-checkbox" type="checkbox"'+g0("g-item-cid",k.cid,!0,!1))+"/>"),i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",f||p?(i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+"<a"+(' class="g-item-list-link g-right-border"'+g0("g-item-cid",k.cid,!0,!1)+g0("href",`#item/${k.id}`,!0,!1))+">",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<i class="icon-doc-text-inv"></i>',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+ri((u=k.name())==null?"":u)+"</a>"):(i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+"<a"+(' class="g-item-list-link"'+g0("g-item-cid",k.cid,!0,!1)+g0("href","#item/"+k.id,!0,!1))+">",i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<i class="icon-doc-text-inv"></i>',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+ri((u=k.name())==null?"":u)+"</a>"),i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",f&&(i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+"<a"+(' title="Download item"'+g0("href",k.downloadUrl(),!0,!1))+">",i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<i class="icon-download"></i></a>'),i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",p&&(i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+"<a"+(' class="g-view-inline" title="View in browser" target="_blank" rel="noopener noreferrer"'+g0("href",k.downloadUrl({contentDisposition:"inline"}),!0,!1))+">",i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<i class="icon-eye"></i></a>'),i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",F&&(i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<div class="g-item-size">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+ri((u=n(k.get("size")))==null?"":u)+"</div>"),e=e+"</li>"}else{var C=0;for(var b in m){C++;var k=m[b];i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+"<li"+(g0("class",Xa(["g-item-list-entry",g&&k.id===a?"g-selected":""],[!1,!0]),!1,!1)+g0("public",d?"true":"false",!0,!1))+">",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",o&&(i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+"<input"+(' class="g-list-checkbox" type="checkbox"'+g0("g-item-cid",k.cid,!0,!1))+"/>"),i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",f||p?(i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+"<a"+(' class="g-item-list-link g-right-border"'+g0("g-item-cid",k.cid,!0,!1)+g0("href",`#item/${k.id}`,!0,!1))+">",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<i class="icon-doc-text-inv"></i>',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+ri((u=k.name())==null?"":u)+"</a>"):(i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+"<a"+(' class="g-item-list-link"'+g0("g-item-cid",k.cid,!0,!1)+g0("href","#item/"+k.id,!0,!1))+">",i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<i class="icon-doc-text-inv"></i>',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+ri((u=k.name())==null?"":u)+"</a>"),i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",f&&(i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+"<a"+(' title="Download item"'+g0("href",k.downloadUrl(),!0,!1))+">",i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<i class="icon-download"></i></a>'),i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",p&&(i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+"<a"+(' class="g-view-inline" title="View in browser" target="_blank" rel="noopener noreferrer"'+g0("href",k.downloadUrl({contentDisposition:"inline"}),!0,!1))+">",i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<i class="icon-eye"></i></a>'),i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",F&&(i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<div class="g-item-size">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+ri((u=n(k.get("size")))==null?"":u)+"</div>"),e=e+"</li>"}}}.call(this),i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",h&&!c&&(i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<li class="g-show-more">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<a class="g-show-more-items">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+'<i class="icon-level-down"></i>',i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemList.pug",e=e+"Show more items...</a></li>"),e=e+"</ul>"}).call(this,"checkboxes"in s?s.checkboxes:typeof checkboxes<"u"?checkboxes:void 0,"downloadLinks"in s?s.downloadLinks:typeof downloadLinks<"u"?downloadLinks:void 0,"formatSize"in s?s.formatSize:typeof formatSize<"u"?formatSize:void 0,"hasMore"in s?s.hasMore:typeof hasMore<"u"?hasMore:void 0,"highlightItem"in s?s.highlightItem:typeof highlightItem<"u"?highlightItem:void 0,"isParentPublic"in s?s.isParentPublic:typeof isParentPublic<"u"?isParentPublic:void 0,"items"in s?s.items:typeof items<"u"?items:void 0,"paginated"in s?s.paginated:typeof paginated<"u"?paginated:void 0,"selectedItemId"in s?s.selectedItemId:typeof selectedItemId<"u"?selectedItemId:void 0,"showSizes"in s?s.showSizes:typeof showSizes<"u"?showSizes:void 0,"viewLinks"in s?s.viewLinks:typeof viewLinks<"u"?viewLinks:void 0)}catch(o){wp(o,r,i)}return e}var yp=Xe.extend({events:{"click a.g-item-list-link":function(t){t.preventDefault();var e=ke(t.currentTarget).attr("g-item-cid");this.trigger("g:itemClicked",this.collection.get(e),t)},"click a.g-show-more-items":function(){this.collection.fetchNextPage()},"change .g-list-checkbox":function(t){const e=ke(t.currentTarget),u=e.attr("g-item-cid");if(e.prop("checked"))this.checked.push(u);else{const r=this.checked.indexOf(u);r!==-1&&this.checked.splice(r,1)}this.trigger("g:checkboxesChanged")}},initialize:function(t){this.checked=[],this._checkboxes=t.checkboxes,this._downloadLinks=xe.has(t,"downloadLinks")?t.downloadLinks:!0,this._viewLinks=xe.has(t,"viewLinks")?t.viewLinks:!0,this._showSizes=xe.has(t,"showSizes")?t.showSizes:!0,this._highlightItem=xe.has(t,"highlightItem")?t.highlightItem:!1,this._paginated=xe.has(t,"paginated")?t.paginated:!1,this.accessLevel=t.accessLevel,this.public=t.public,this._selectedItem=t.selectedItem,new Os({el:this.$el,parentView:this}).render(),this.collection=new vg,this.collection.append=!0,this.collection.filterFunc=t.itemFilter,this.currentPage=1,this._paginated&&(this.collection.filterFunc?(console.warn("Pagination cannot be used with a filter function"),this._paginated=!1):this.collection.append=!1),this.collection.fetch({folderId:t.folderId}).done(()=>{this._totalPages=Math.ceil(this.collection.getTotalCount()/this.collection.pageLimit),this._paginated&&this.collection.hasNextPage()?(this.trigger("g:paginated"),this._selectedItem?ut({url:`item/${this._selectedItem.get("_id")}/position`,method:"GET",data:{folderId:this._selectedItem.get("folderId"),sort:"name"}}).done(e=>{if(e=Number(e),e>=this.collection.pageLimit){const u=this.collection.pageLimit,r=1+Math.ceil((e-e%u)/u);return this.collection.fetchPage(r-1)}}).done(()=>this.bindOnChanged()):this.bindOnChanged()):this.bindOnChanged()})},bindOnChanged:function(){this.collection.on("g:changed",this.changedFunc,this),this.changedFunc()},changedFunc:function(){this.accessLevel!==void 0&&this.collection.each(t=>{t.set("_accessLevel",this.accessLevel)}),this._paginated&&(this.currentPage=this.collection.pageNum()+1),this.render(),this.trigger("g:changed")},render:function(){return this.checked=[],this._selectedItem&&this._highlightItem&&this.scrollPositionObserver(),this.$el.html(BA({items:this.collection.toArray(),isParentPublic:this.public,hasMore:this.collection.hasNextPage(),formatSize:Zt,checkboxes:this._checkboxes,downloadLinks:this._downloadLinks,viewLinks:this._viewLinks,showSizes:this._showSizes,highlightItem:this._highlightItem,selectedItemId:(this._selectedItem||{}).id,paginated:this._paginated})),this},getNumPages(){return this._totalPages||1},getCurrentPage(){return this.currentPage||1},setPage(t){if(this._paginated&&this.collection&&this.collection.fetchPage)return this.currentPage=t,this.collection.fetchPage(t-1).then(()=>this.$el.parents(".g-hierarchy-widget-container").scrollTop(0))},insertItem:function(t){this.accessLevel!==void 0&&t.set("_accessLevel",this.accessLevel),this.collection.add(t),this.trigger("g:changed"),this.render()},checkAll:function(t){this.$(".g-list-checkbox").prop("checked",t),this.checked=[],t&&this.collection.each(function(e){this.checked.push(e.cid)},this),this.trigger("g:checkboxesChanged")},selectItem:function(t){this.$("li.g-item-list-entry").removeClass("g-selected"),this.$("a.g-item-list-link[g-item-cid="+t.cid+"]").parents("li.g-item-list-entry").addClass("g-selected")},getSelectedItem:function(){var t=this.$("li.g-item-list-entry.g-selected");if(!t.length)return null;var e=ke(".g-item-list-link",ke(t[0])).attr("g-item-cid");return this.collection.get(e)},recomputeChecked:function(){this.checked=xe.map(this.$(".g-list-checkbox:checked"),function(t){return ke(t).attr("g-item-cid")},this)},centerSelected:function(){const t=this.$el.parents(".g-hierarchy-widget-container"),e=this.$("li.g-item-list-entry.g-selected");if(t.length>0&&e.length>0){const u=ke(".g-folder-list").length?ke(".g-folder-list").height():0,r=ke(".g-hierarchy-breadcrumb-bar").length?ke(".g-hierarchy-breadcrumb-bar").height():0,s=e.position().top+u+r,o=t.height()/2-u/2-r/2-e.outerHeight()/2,f=s-o;this.tempScrollPos===void 0&&(this.tempScrollPos=f);const n=new CustomEvent("scroll",{detail:"selected_item_scroll"});t[0].scrollTop=f,t[0].dispatchEvent(n)}},scrollPositionObserver:function(){const t=this.$(".g-item-list");if(window.MutationObserver&&t.length>0){const e=this.$el.parents(".g-hierarchy-widget-container");this.observer&&this.observer.disconnect&&this.observer.disconnect();const u=()=>{this.observer&&this.centerSelected()};this.observer=new MutationObserver(i=>{xe.each(i,s=>{s.addedNodes&&xe.each(s.addedNodes,o=>{o.className&&o.className.indexOf("g-item-list")!==-1&&(window.requestIdleCallback?requestIdleCallback(()=>{this.centerSelected()},{timeout:2e3}):this.centerSelected()),xe.isFunction(o.getElementsByTagName)&&this.$("img",o).on("load",u)})})}),this.observer.observe(t.parent()[0],{childList:!0,subtree:!0});const r=()=>{this.observer&&(e.unbind("scroll.observerscroll"),e.unbind("wheel.observerscroll"),e.unbind("click.observerscroll"),this.observer.disconnect(),this.observer=null,this.tempScrollPos=void 0,this._highlightItem=!1)};e.bind("scroll.observerscroll",i=>{this.tempScrollPos!==void 0&&this.tempScrollPos!==e[0].scrollTop&&(this.tempScrollPos=e[0].scrollTop,i.detail!=="selected_item_scroll"&&r())}),e.bind("wheel.selectionobserver",r),e.bind("click.selectionobserver",r)}}});function IA(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=OA(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function OA(t){var e=""+t,u=$A.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var $A=/["&<>]/;function Cp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Cp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function NA(t){var e="",u,r;try{var i=t||{};(function(s,o){r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumEditWidget.pug",e=e+"<input"+(' class="input-sm form-control g-widget-metadata-key-input" type="text"'+IA("value",s,!0,!1)+' placeholder="Key"')+"/>",r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumEditWidget.pug",e=e+'<div class="g-json-editor"></div>',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumEditWidget.pug",e=e+'<button class="btn btn-sm btn-warning g-widget-metadata-cancel-button" title="Cancel">',r=6,u="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumEditWidget.pug",e=e+'<i class="icon-cancel"></i></button>',r=7,u="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumEditWidget.pug",e=e+'<button class="btn btn-sm btn-primary g-widget-metadata-save-button" title="Accept">',r=8,u="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumEditWidget.pug",e=e+'<i class="icon-ok"></i></button>',r=9,u="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumEditWidget.pug",o||(r=10,u="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumEditWidget.pug",e=e+'<button class="btn btn-sm btn-primary g-widget-metadata-toggle-button" title="Convert to Simple">',r=11,u="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumEditWidget.pug",e=e+'<i class="icon-cog"></i></button>',r=12,u="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumEditWidget.pug",e=e+'<button class="btn btn-sm btn-danger g-widget-metadata-delete-button" title="Delete">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumEditWidget.pug",e=e+'<i class="icon-trash"></i></button>')}).call(this,"key"in i?i.key:typeof key<"u"?key:void 0,"newDatum"in i?i.newDatum:typeof newDatum<"u"?newDatum:void 0)}catch(s){Cp(s,u,r)}return e}function zd(t){var e=""+t,u=WA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var WA=/["&<>]/;function Ep(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Ep(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function HA(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumView.pug",f>=o.WRITE&&(i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumView.pug",e=e+'<button class="btn btn-sm btn-default g-widget-metadata-edit-button">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumView.pug",e=e+'<i class="icon-pencil"></i></button>'),i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumView.pug",e=e+'<span class="g-widget-metadata-key">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumView.pug",e=e+zd((u=n)==null?"":u)+"</span>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumView.pug",e=e+'<span class="g-widget-metadata-value">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumView.pug",e=e+"<pre>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/jsonMetadatumView.pug",e=e+zd((u=h)==null?"":u)+"</pre></span>"}).call(this,"AccessType"in s?s.AccessType:typeof AccessType<"u"?AccessType:void 0,"accessLevel"in s?s.accessLevel:typeof accessLevel<"u"?accessLevel:void 0,"key"in s?s.key:typeof key<"u"?key:void 0,"value"in s?s.value:typeof value<"u"?value:void 0)}catch(o){Ep(o,r,i)}return e}function UA(t){var e=""+t,u=qA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var qA=/["&<>]/;function Ap(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Ap(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function zA(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",f>=o.WRITE&&(i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+'<div class="btn-group pull-right">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+'<button class="g-widget-metadata-add-button btn btn-sm btn-primary btn-default dropdown-toggle" data-toggle="dropdown" title="Add Metadata">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+'<i class="icon-plus"></i></button>',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+'<ul class="dropdown-menu pull-right" role="menu">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+'<li role="presentation">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+'<a class="g-add-simple-metadata" role="menuitem">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+"Simple</a></li>",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+'<li role="presentation">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+'<a class="g-add-json-metadata">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+"JSON</a></li></ul></div>"),i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+'<div class="g-widget-metadata-header">',i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+'<i class="icon-tags"></i>',i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+" ",i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+UA((u=n)==null?"":u)+"</div>",i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadataWidget.pug",e=e+'<div class="g-widget-metadata-container"></div>'}).call(this,"AccessType"in s?s.AccessType:typeof AccessType<"u"?AccessType:void 0,"accessLevel"in s?s.accessLevel:typeof accessLevel<"u"?accessLevel:void 0,"title"in s?s.title:typeof title<"u"?title:void 0)}catch(o){Ap(o,r,i)}return e}function Vd(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=xp(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function xp(t){var e=""+t,u=VA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var VA=/["&<>]/;function kp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void kp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function GA(t){var e="",u,r,i;try{var s=t||{};(function(o,f,g,h){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumEditWidget.pug",e=e+"<input"+(' class="input-sm form-control g-widget-metadata-key-input" type="text"'+Vd("value",o,!0,!1)+' placeholder="Key"')+"/>",i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumEditWidget.pug";var g=h.length<=40?1:h.length<=100?3:5;i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumEditWidget.pug",e=e+"<textarea"+(' class="input-sm form-control g-widget-metadata-value-input" placeholder="Value"'+Vd("rows",g,!0,!1))+">",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumEditWidget.pug",e=e+xp((u=h)==null?"":u)+"</textarea>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumEditWidget.pug",e=e+'<button class="btn btn-sm btn-warning g-widget-metadata-cancel-button" title="Cancel">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumEditWidget.pug",e=e+'<i class="icon-cancel"></i></button>',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumEditWidget.pug",e=e+'<button class="btn btn-sm btn-primary g-widget-metadata-save-button" title="Accept">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumEditWidget.pug",e=e+'<i class="icon-ok"></i></button>',i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumEditWidget.pug",f||(i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumEditWidget.pug",e=e+'<button class="btn btn-sm btn-primary g-widget-metadata-toggle-button" title="Convert to JSON">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumEditWidget.pug",e=e+'<i class="icon-cog"></i></button>',i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumEditWidget.pug",e=e+'<button class="btn btn-sm btn-danger g-widget-metadata-delete-button" title="Delete">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumEditWidget.pug",e=e+'<i class="icon-trash"></i></button>')}).call(this,"key"in s?s.key:typeof key<"u"?key:void 0,"newDatum"in s?s.newDatum:typeof newDatum<"u"?newDatum:void 0,"rows"in s?s.rows:typeof rows<"u"?rows:void 0,"value"in s?s.value:typeof value<"u"?value:void 0)}catch(o){kp(o,r,i)}return e}function Gd(t){var e=""+t,u=KA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var KA=/["&<>]/;function jp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void jp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function YA(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumView.pug",f>=o.WRITE&&(i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumView.pug",e=e+'<button class="btn btn-sm btn-default g-widget-metadata-edit-button">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumView.pug",e=e+'<i class="icon-pencil"></i></button>'),i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumView.pug",e=e+'<span class="g-widget-metadata-key">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumView.pug",e=e+Gd((u=n)==null?"":u)+"</span>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumView.pug",e=e+'<span class="g-widget-metadata-value">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/metadatumView.pug",e=e+Gd((u=h)==null?"":u)+"</span>"}).call(this,"AccessType"in s?s.AccessType:typeof AccessType<"u"?AccessType:void 0,"accessLevel"in s?s.accessLevel:typeof accessLevel<"u"?accessLevel:void 0,"key"in s?s.key:typeof key<"u"?key:void 0,"value"in s?s.value:typeof value<"u"?value:void 0)}catch(o){jp(o,r,i)}return e}var Sp={exports:{}};/*!
 * jsoneditor.js
 *
 * @brief
 * JSONEditor is a web-based tool to view, edit, format, and validate JSON.
 * It has various modes such as a tree editor, a code editor, and a plain text
 * editor.
 *
 * Supported browsers: Chrome, Firefox, Safari, Opera, Internet Explorer 8+
 *
 * @license
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy
 * of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 *
 * Copyright (c) 2011-2017 Jos de Jong, http://jsoneditoronline.org
 *
 * @author  Jos de Jong, <wjosdejong@gmail.com>
 * @version 5.9.6
 * @date    2017-09-16
 */(function(t,e){(function(r,i){t.exports=i()})(yr,function(){return function(u){var r={};function i(s){if(r[s])return r[s].exports;var o=r[s]={exports:{},id:s,loaded:!1};return u[s].call(o.exports,o,o.exports,i),o.loaded=!0,o.exports}return i.m=u,i.c=r,i.p="",i(0)}([function(u,r,i){var s;try{s=i(1)}catch{}var o=i(54),f=i(66),n=i(57);function h(g,d,l){if(!(this instanceof h))throw new Error('JSONEditor constructor called without "new".');var c=n.getInternetExplorerVersion();if(c!=-1&&c<9)throw new Error("Unsupported browser, IE9 or newer required. Please install the newest version of your browser.");if(d&&(d.error&&(console.warn('Option "error" has been renamed to "onError"'),d.onError=d.error,delete d.error),d.change&&(console.warn('Option "change" has been renamed to "onChange"'),d.onChange=d.change,delete d.change),d.editable&&(console.warn('Option "editable" has been renamed to "onEditable"'),d.onEditable=d.editable,delete d.editable),d)){var a=["ajv","schema","schemaRefs","templates","ace","theme","autocomplete","onChange","onEditable","onError","onModeChange","escapeUnicode","history","search","mode","modes","name","indentation","sortObjectKeys"];Object.keys(d).forEach(function(F){a.indexOf(F)===-1&&console.warn('Unknown option "'+F+'". This option will be ignored')})}arguments.length&&this._create(g,d,l)}h.modes={},h.prototype.DEBOUNCE_INTERVAL=150,h.prototype._create=function(g,d,l){this.container=g,this.options=d||{},this.json=l||{};var c=this.options.mode||this.options.modes&&this.options.modes[0]||"tree";this.setMode(c)},h.prototype.destroy=function(){},h.prototype.set=function(g){this.json=g},h.prototype.get=function(){return this.json},h.prototype.setText=function(g){this.json=n.parse(g)},h.prototype.getText=function(){return JSON.stringify(this.json)},h.prototype.setName=function(g){this.options||(this.options={}),this.options.name=g},h.prototype.getName=function(){return this.options&&this.options.name},h.prototype.setMode=function(g){var d=this.container,l=n.extend({},this.options),c=l.mode,a,F;l.mode=g;var p=h.modes[g];if(p)try{var m=p.data=="text";if(F=this.getName(),a=this[m?"getText":"get"](),this.destroy(),n.clear(this),n.extend(this,p.mixin),this.create(d,l),this.setName(F),this[m?"setText":"set"](a),typeof p.load=="function")try{p.load.call(this)}catch(b){console.error(b)}if(typeof l.onModeChange=="function"&&g!==c)try{l.onModeChange(g,c)}catch(b){console.error(b)}}catch(b){this._onError(b)}else throw new Error('Unknown mode "'+l.mode+'"')},h.prototype.getMode=function(){return this.options.mode},h.prototype._onError=function(g){if(this.options&&typeof this.options.onError=="function")this.options.onError(g);else throw g},h.prototype.setSchema=function(g,d){if(g){var l;try{l=this.options.ajv||s({allErrors:!0,verbose:!0})}catch{console.warn("Failed to create an instance of Ajv, JSON Schema validation is not available. Please use a JSONEditor bundle including Ajv, or pass an instance of Ajv as via the configuration option `ajv`.")}if(l){if(d){for(var c in d)l.removeSchema(c),d[c]&&l.addSchema(d[c],c);this.options.schemaRefs=d}this.validateSchema=l.compile(g),this.options.schema=g,this.validate()}this.refresh()}else this.validateSchema=null,this.options.schema=null,this.options.schemaRefs=null,this.validate(),this.refresh()},h.prototype.validate=function(){},h.prototype.refresh=function(){},h.registerMode=function(g){var d,l;if(n.isArray(g))for(d=0;d<g.length;d++)h.registerMode(g[d]);else{if(!("mode"in g))throw new Error('Property "mode" missing');if(!("mixin"in g))throw new Error('Property "mixin" missing');if(!("data"in g))throw new Error('Property "data" missing');var c=g.mode;if(c in h.modes)throw new Error('Mode "'+c+'" already registered');if(typeof g.mixin.create!="function")throw new Error('Required function "create" missing on mixin');var a=["setMode","registerMode","modes"];for(d=0;d<a.length;d++)if(l=a[d],l in g.mixin)throw new Error('Reserved property "'+l+'" not allowed in mixin');h.modes[c]=g}},h.registerMode(o),h.registerMode(f),u.exports=h},function(u,r,i){var s=i(2),o=i(3),f=i(22),n=i(13),h=i(16),g=i(23),d=i(24),l=i(47),c=i(48),a=i(11),F=i(21);u.exports=T,T.prototype.validate=w,T.prototype.compile=A,T.prototype.addSchema=M,T.prototype.addMetaSchema=x,T.prototype.validateSchema=R,T.prototype.getSchema=j,T.prototype.removeSchema=U,T.prototype.addFormat=ye,T.prototype.errorsText=ge,T.prototype._addSchema=re,T.prototype._compile=le,T.prototype.compileAsync=i(49);var p=i(50);T.prototype.addKeyword=p.add,T.prototype.getKeyword=p.get,T.prototype.removeKeyword=p.remove;var m=i(15);T.ValidationError=m.Validation,T.MissingRefError=m.MissingRef,T.$dataMetaSchema=l;var b="http://json-schema.org/draft-06/schema",C=["removeAdditional","useDefaults","coerceTypes"],k=["/properties"];function T(se){if(!(this instanceof T))return new T(se);se=this._opts=a.copy(se)||{},this._schemas={},this._refs={},this._fragments={},this._formats=g(se.format);var ve=this._schemaUriFormat=this._formats["uri-reference"];this._schemaUriFormatFunc=function(Pe){return ve.test(Pe)},this._cache=se.cache||new f,this._loadingSchemas={},this._compilations=[],this.RULES=d(),this._getId=ce(se),se.loopRequired=se.loopRequired||1/0,se.errorDataPath=="property"&&(se._errorDataPathProperty=!0),se.serialize===void 0&&(se.serialize=h),this._metaOpts=me(this),se.formats&&Ee(this),Y(this),typeof se.meta=="object"&&this.addMetaSchema(se.meta),ue(this),se.patternGroups&&c(this)}function w(se,ve){var Pe;if(typeof se=="string"){if(Pe=this.getSchema(se),!Pe)throw new Error('no schema with key or ref "'+se+'"')}else{var Ie=this._addSchema(se);Pe=Ie.validate||this._compile(Ie)}var z=Pe(ve);return Pe.$async===!0?this._opts.async=="*"?F(z):z:(this.errors=Pe.errors,z)}function A(se,ve){var Pe=this._addSchema(se,void 0,ve);return Pe.validate||this._compile(Pe)}function M(se,ve,Pe,Ie){if(Array.isArray(se)){for(var z=0;z<se.length;z++)this.addSchema(se[z],void 0,Pe,Ie);return}var G=this._getId(se);if(G!==void 0&&typeof G!="string")throw new Error("schema id must be string");ve=o.normalizeId(ve||G),ne(this,ve),this._schemas[ve]=this._addSchema(se,Pe,Ie,!0)}function x(se,ve,Pe){this.addSchema(se,ve,Pe,!0)}function R(se,ve){var Pe=se.$schema;if(Pe!==void 0&&typeof Pe!="string")throw new Error("$schema must be a string");if(Pe=Pe||this._opts.defaultMeta||N(this),!Pe)return console.warn("meta-schema not available"),this.errors=null,!0;var Ie=this._formats.uri;this._formats.uri=typeof Ie=="function"?this._schemaUriFormatFunc:this._schemaUriFormat;var z;try{z=this.validate(Pe,se)}finally{this._formats.uri=Ie}if(!z&&ve){var G="schema is invalid: "+this.errorsText();if(this._opts.validateSchema=="log")console.error(G);else throw new Error(G)}return z}function N(se){var ve=se._opts.meta;return se._opts.defaultMeta=typeof ve=="object"?se._getId(ve)||ve:se.getSchema(b)?b:void 0,se._opts.defaultMeta}function j(se){var ve=q(this,se);switch(typeof ve){case"object":return ve.validate||this._compile(ve);case"string":return this.getSchema(ve);case"undefined":return B(this,se)}}function B(se,ve){var Pe=o.schema.call(se,{schema:{}},ve);if(Pe){var Ie=Pe.schema,z=Pe.root,G=Pe.baseId,O=s.call(se,Ie,z,void 0,G);return se._fragments[ve]=new n({ref:ve,fragment:!0,schema:Ie,root:z,baseId:G,validate:O}),O}}function q(se,ve){return ve=o.normalizeId(ve),se._schemas[ve]||se._refs[ve]||se._fragments[ve]}function U(se){if(se instanceof RegExp){Z(this,this._schemas,se),Z(this,this._refs,se);return}switch(typeof se){case"undefined":Z(this,this._schemas),Z(this,this._refs),this._cache.clear();return;case"string":var ve=q(this,se);ve&&this._cache.del(ve.cacheKey),delete this._schemas[se],delete this._refs[se];return;case"object":var Pe=this._opts.serialize,Ie=Pe?Pe(se):se;this._cache.del(Ie);var z=this._getId(se);z&&(z=o.normalizeId(z),delete this._schemas[z],delete this._refs[z])}}function Z(se,ve,Pe){for(var Ie in ve){var z=ve[Ie];!z.meta&&(!Pe||Pe.test(Ie))&&(se._cache.del(z.cacheKey),delete ve[Ie])}}function re(se,ve,Pe,Ie){if(typeof se!="object"&&typeof se!="boolean")throw new Error("schema should be object or boolean");var z=this._opts.serialize,G=z?z(se):se,O=this._cache.get(G);if(O)return O;Ie=Ie||this._opts.addUsedSchema!==!1;var I=o.normalizeId(this._getId(se));I&&Ie&&ne(this,I);var v=this._opts.validateSchema!==!1&&!ve,E;v&&!(E=I&&I==o.normalizeId(se.$schema))&&this.validateSchema(se,!0);var L=o.ids.call(this,se),S=new n({id:I,schema:se,localRefs:L,cacheKey:G,meta:Pe});return I[0]!="#"&&Ie&&(this._refs[I]=S),this._cache.put(G,S),v&&E&&this.validateSchema(se,!0),S}function le(se,ve){if(se.compiling)return se.validate=z,z.schema=se.schema,z.errors=null,z.root=ve||z,se.schema.$async===!0&&(z.$async=!0),z;se.compiling=!0;var Pe;se.meta&&(Pe=this._opts,this._opts=this._metaOpts);var Ie;try{Ie=s.call(this,se.schema,ve,se.localRefs)}finally{se.compiling=!1,se.meta&&(this._opts=Pe)}return se.validate=Ie,se.refs=Ie.refs,se.refVal=Ie.refVal,se.root=Ie.root,Ie;function z(){var G=se.validate,O=G.apply(null,arguments);return z.errors=G.errors,O}}function ce(se){switch(se.schemaId){case"$id":return he;case"id":return de;default:return Fe}}function de(se){return se.$id&&console.warn("schema $id ignored",se.$id),se.id}function he(se){return se.id&&console.warn("schema id ignored",se.id),se.$id}function Fe(se){if(se.$id&&se.id&&se.$id!=se.id)throw new Error("schema $id is different from id");return se.$id||se.id}function ge(se,ve){if(se=se||this.errors,!se)return"No errors";ve=ve||{};for(var Pe=ve.separator===void 0?", ":ve.separator,Ie=ve.dataVar===void 0?"data":ve.dataVar,z="",G=0;G<se.length;G++){var O=se[G];O&&(z+=Ie+O.dataPath+" "+O.message+Pe)}return z.slice(0,-Pe.length)}function ye(se,ve){typeof ve=="string"&&(ve=new RegExp(ve)),this._formats[se]=ve}function Y(se){var ve;if(se._opts.$data&&(ve=i(52),se.addMetaSchema(ve,ve.$id,!0)),se._opts.meta!==!1){var Pe=i(53);se._opts.$data&&(Pe=l(Pe,k)),se.addMetaSchema(Pe,b,!0),se._refs["http://json-schema.org/schema"]=b}}function ue(se){var ve=se._opts.schemas;if(ve)if(Array.isArray(ve))se.addSchema(ve);else for(var Pe in ve)se.addSchema(ve[Pe],Pe)}function Ee(se){for(var ve in se._opts.formats){var Pe=se._opts.formats[ve];se.addFormat(ve,Pe)}}function ne(se,ve){if(se._schemas[ve]||se._refs[ve])throw new Error('schema with key or id "'+ve+'" already exists')}function me(se){for(var ve=a.copy(se._opts),Pe=0;Pe<C.length;Pe++)delete ve[C[Pe]];return ve}},function(u,r,i){var s=i(3),o=i(11),f=i(15),n=i(16),h=i(20),g=i(21),d=o.ucs2length,l=i(10),c=f.Validation;u.exports=a;function a(A,M,x,R){var N=this,j=this._opts,B=[void 0],q={},U=[],Z={},re=[],le={},ce=[];M=M||{schema:A,refVal:B,refs:q};var de=F.call(this,A,M,R),he=this._compilations[de.index];if(de.compiling)return he.callValidate=ue;var Fe=this._formats,ge=this.RULES;try{var ye=Ee(A,M,x,R);he.validate=ye;var Y=he.callValidate;return Y&&(Y.schema=ye.schema,Y.errors=null,Y.refs=ye.refs,Y.refVal=ye.refVal,Y.root=ye.root,Y.$async=ye.$async,j.sourceCode&&(Y.source=ye.source)),ye}finally{p.call(this,A,M,R)}function ue(){var G=he.validate,O=G.apply(null,arguments);return ue.errors=G.errors,O}function Ee(G,O,I,v){var E=!O||O&&O.schema==G;if(O.schema!=M.schema)return a.call(N,G,O,I,v);var L=G.$async===!0,S=h({isTop:!0,schema:G,isRoot:E,baseId:v,root:O,schemaPath:"",errSchemaPath:"#",errorPath:'""',MissingRefError:f.MissingRef,RULES:ge,validate:h,util:o,resolve:s,resolveRef:ne,usePattern:Pe,useDefault:Ie,useCustomRule:z,opts:j,formats:Fe,self:N});S=w(B,k)+w(U,b)+w(re,C)+w(ce,T)+S,j.processCode&&(S=j.processCode(S));var P;try{var W=new Function("self","RULES","formats","root","refVal","defaults","customRules","co","equal","ucs2length","ValidationError",S);P=W(N,ge,Fe,M,B,re,ce,g,l,d,c),B[0]=P}catch(K){throw console.error("Error compiling schema, function code:",S),K}return P.schema=G,P.errors=null,P.refs=q,P.refVal=B,P.root=E?P:O,L&&(P.$async=!0),j.sourceCode===!0&&(P.source={code:S,patterns:U,defaults:re}),P}function ne(G,O,I){O=s.url(G,O);var v=q[O],E,L;if(v!==void 0)return E=B[v],L="refVal["+v+"]",ve(E,L);if(!I&&M.refs){var S=M.refs[O];if(S!==void 0)return E=M.refVal[S],L=me(O,E),ve(E,L)}L=me(O);var P=s.call(N,Ee,M,O);if(P===void 0){var W=x&&x[O];W&&(P=s.inlineRef(W,j.inlineRefs)?W:a.call(N,W,M,x,G))}if(P!==void 0)return se(O,P),ve(P,L)}function me(G,O){var I=B.length;return B[I]=O,q[G]=I,"refVal"+I}function se(G,O){var I=q[G];B[I]=O}function ve(G,O){return typeof G=="object"||typeof G=="boolean"?{code:O,schema:G,inline:!0}:{code:O,$async:G&&G.$async}}function Pe(G){var O=Z[G];return O===void 0&&(O=Z[G]=U.length,U[O]=G),"pattern"+O}function Ie(G){switch(typeof G){case"boolean":case"number":return""+G;case"string":return o.toQuotedString(G);case"object":if(G===null)return"null";var O=n(G),I=le[O];return I===void 0&&(I=le[O]=re.length,re[I]=G),"default"+I}}function z(G,O,I,v){var E=G.definition.validateSchema;if(E&&N._opts.validateSchema!==!1){var L=E(O);if(!L){var S="keyword schema is invalid: "+N.errorsText(E.errors);if(N._opts.validateSchema=="log")console.error(S);else throw new Error(S)}}var P=G.definition.compile,W=G.definition.inline,K=G.definition.macro,V;if(P)V=P.call(N,O,I,v);else if(K)V=K.call(N,O,I,v),j.validateSchema!==!1&&N.validateSchema(V,!0);else if(W)V=W.call(N,v,G.keyword,O,I);else if(V=G.definition.validate,!V)return;if(V===void 0)throw new Error('custom keyword "'+G.keyword+'"failed to compile');var ee=ce.length;return ce[ee]=V,{code:"customRule"+ee,validate:V}}}function F(A,M,x){var R=m.call(this,A,M,x);return R>=0?{index:R,compiling:!0}:(R=this._compilations.length,this._compilations[R]={schema:A,root:M,baseId:x},{index:R,compiling:!1})}function p(A,M,x){var R=m.call(this,A,M,x);R>=0&&this._compilations.splice(R,1)}function m(A,M,x){for(var R=0;R<this._compilations.length;R++){var N=this._compilations[R];if(N.schema==A&&N.root==M&&N.baseId==x)return R}return-1}function b(A,M){return"var pattern"+A+" = new RegExp("+o.toQuotedString(M[A])+");"}function C(A){return"var default"+A+" = defaults["+A+"];"}function k(A,M){return M[A]===void 0?"":"var refVal"+A+" = refVal["+A+"];"}function T(A){return"var customRule"+A+" = customRules["+A+"];"}function w(A,M){if(!A.length)return"";for(var x="",R=0;R<A.length;R++)x+=M(R,A);return x}},function(u,r,i){var s=i(4),o=i(10),f=i(11),n=i(13),h=i(14);u.exports=g,g.normalizeId=w,g.fullPath=C,g.url=A,g.ids=M,g.inlineRef=p,g.schema=d;function g(x,R,N){var j=this._refs[N];if(typeof j=="string")if(this._refs[j])j=this._refs[j];else return g.call(this,x,R,j);if(j=j||this._schemas[N],j instanceof n)return p(j.schema,this._opts.inlineRefs)?j.schema:j.validate||this._compile(j);var B=d.call(this,R,N),q,U,Z;return B&&(q=B.schema,R=B.root,Z=B.baseId),q instanceof n?U=q.validate||x.call(this,q.schema,R,void 0,Z):q!==void 0&&(U=p(q,this._opts.inlineRefs)?q:x.call(this,q,R,void 0,Z)),U}function d(x,R){var N=s.parse(R,!1,!0),j=k(N),B=C(this._getId(x.schema));if(j!==B){var q=w(j),U=this._refs[q];if(typeof U=="string")return l.call(this,x,U,N);if(U instanceof n)U.validate||this._compile(U),x=U;else if(U=this._schemas[q],U instanceof n){if(U.validate||this._compile(U),q==w(R))return{schema:U,root:x,baseId:B};x=U}else return;if(!x.schema)return;B=C(this._getId(x.schema))}return a.call(this,N,B,x.schema,x)}function l(x,R,N){var j=d.call(this,x,R);if(j){var B=j.schema,q=j.baseId;x=j.root;var U=this._getId(B);return U&&(q=A(q,U)),a.call(this,N,q,B,x)}}var c=f.toHash(["properties","patternProperties","enum","dependencies","definitions"]);function a(x,R,N,j){if(x.hash=x.hash||"",x.hash.slice(0,2)=="#/"){for(var B=x.hash.split("/"),q=1;q<B.length;q++){var U=B[q];if(U){if(U=f.unescapeFragment(U),N=N[U],N===void 0)break;var Z;if(!c[U]&&(Z=this._getId(N),Z&&(R=A(R,Z)),N.$ref)){var re=A(R,N.$ref),le=d.call(this,j,re);le&&(N=le.schema,j=le.root,R=le.baseId)}}}if(N!==void 0&&N!==j.schema)return{schema:N,root:j,baseId:R}}}var F=f.toHash(["type","format","pattern","maxLength","minLength","maxProperties","minProperties","maxItems","minItems","maximum","minimum","uniqueItems","multipleOf","required","enum"]);function p(x,R){if(R===!1)return!1;if(R===void 0||R===!0)return m(x);if(R)return b(x)<=R}function m(x){var R;if(Array.isArray(x)){for(var N=0;N<x.length;N++)if(R=x[N],typeof R=="object"&&!m(R))return!1}else for(var j in x)if(j=="$ref"||(R=x[j],typeof R=="object"&&!m(R)))return!1;return!0}function b(x){var R=0,N;if(Array.isArray(x)){for(var j=0;j<x.length;j++)if(N=x[j],typeof N=="object"&&(R+=b(N)),R==1/0)return 1/0}else for(var B in x){if(B=="$ref")return 1/0;if(F[B])R++;else if(N=x[B],typeof N=="object"&&(R+=b(N)+1),R==1/0)return 1/0}return R}function C(x,R){R!==!1&&(x=w(x));var N=s.parse(x,!1,!0);return k(N)}function k(x){var R=x.protocol||x.href.slice(0,2)=="//"?"//":"";return(x.protocol||"")+R+(x.host||"")+(x.path||"")+"#"}var T=/#\/?$/;function w(x){return x?x.replace(T,""):""}function A(x,R){return R=w(R),s.resolve(x,R)}function M(x){var R=w(this._getId(x)),N={"":R},j={"":C(R,!1)},B={},q=this;return h(x,{allKeys:!0},function(U,Z,re,le,ce,de,he){if(Z!==""){var Fe=q._getId(U),ge=N[le],ye=j[le]+"/"+ce;if(he!==void 0&&(ye+="/"+(typeof he=="number"?he:f.escapeFragment(he))),typeof Fe=="string"){Fe=ge=w(ge?s.resolve(ge,Fe):Fe);var Y=q._refs[Fe];if(typeof Y=="string"&&(Y=q._refs[Y]),Y&&Y.schema){if(!o(U,Y.schema))throw new Error('id "'+Fe+'" resolves to more than one schema')}else if(Fe!=w(ye))if(Fe[0]=="#"){if(B[Fe]&&!o(U,B[Fe]))throw new Error('id "'+Fe+'" resolves to more than one schema');B[Fe]=U}else q._refs[Fe]=ye}N[Z]=ge,j[Z]=ye}}),B}},function(u,r,i){var s=i(5);r.parse=T,r.resolve=A,r.resolveObject=M,r.format=w,r.Url=o;function o(){this.protocol=null,this.slashes=null,this.auth=null,this.host=null,this.port=null,this.hostname=null,this.hash=null,this.search=null,this.query=null,this.pathname=null,this.path=null,this.href=null}var f=/^([a-z0-9.+-]+:)/i,n=/:[0-9]*$/,h=["<",">",'"',"`"," ","\r",`
`,"	"],g=["{","}","|","\\","^","`"].concat(h),d=["'"].concat(g),l=["%","/","?",";","#"].concat(d),c=["/","?","#"],a=255,F=/^[a-z0-9A-Z_-]{0,63}$/,p=/^([a-z0-9A-Z_-]{0,63})(.*)$/,m={javascript:!0,"javascript:":!0},b={javascript:!0,"javascript:":!0},C={http:!0,https:!0,ftp:!0,gopher:!0,file:!0,"http:":!0,"https:":!0,"ftp:":!0,"gopher:":!0,"file:":!0},k=i(7);function T(B,q,U){if(B&&R(B)&&B instanceof o)return B;var Z=new o;return Z.parse(B,q,U),Z}o.prototype.parse=function(B,q,U){if(!x(B))throw new TypeError("Parameter 'url' must be a string, not "+typeof B);var Z=B;Z=Z.trim();var re=f.exec(Z);if(re){re=re[0];var le=re.toLowerCase();this.protocol=le,Z=Z.substr(re.length)}if(U||re||Z.match(/^\/\/[^@\/]+@[^@\/]+/)){var ce=Z.substr(0,2)==="//";ce&&!(re&&b[re])&&(Z=Z.substr(2),this.slashes=!0)}if(!b[re]&&(ce||re&&!C[re])){for(var de=-1,he=0;he<c.length;he++){var Fe=Z.indexOf(c[he]);Fe!==-1&&(de===-1||Fe<de)&&(de=Fe)}var ge,ye;de===-1?ye=Z.lastIndexOf("@"):ye=Z.lastIndexOf("@",de),ye!==-1&&(ge=Z.slice(0,ye),Z=Z.slice(ye+1),this.auth=decodeURIComponent(ge)),de=-1;for(var he=0;he<l.length;he++){var Fe=Z.indexOf(l[he]);Fe!==-1&&(de===-1||Fe<de)&&(de=Fe)}de===-1&&(de=Z.length),this.host=Z.slice(0,de),Z=Z.slice(de),this.parseHost(),this.hostname=this.hostname||"";var Y=this.hostname[0]==="["&&this.hostname[this.hostname.length-1]==="]";if(!Y)for(var ue=this.hostname.split(/\./),he=0,Ee=ue.length;he<Ee;he++){var ne=ue[he];if(ne&&!ne.match(F)){for(var me="",se=0,ve=ne.length;se<ve;se++)ne.charCodeAt(se)>127?me+="x":me+=ne[se];if(!me.match(F)){var Pe=ue.slice(0,he),Ie=ue.slice(he+1),z=ne.match(p);z&&(Pe.push(z[1]),Ie.unshift(z[2])),Ie.length&&(Z="/"+Ie.join(".")+Z),this.hostname=Pe.join(".");break}}}if(this.hostname.length>a?this.hostname="":this.hostname=this.hostname.toLowerCase(),!Y){for(var G=this.hostname.split("."),O=[],he=0;he<G.length;++he){var I=G[he];O.push(I.match(/[^A-Za-z0-9_-]/)?"xn--"+s.encode(I):I)}this.hostname=O.join(".")}var v=this.port?":"+this.port:"",E=this.hostname||"";this.host=E+v,this.href+=this.host,Y&&(this.hostname=this.hostname.substr(1,this.hostname.length-2),Z[0]!=="/"&&(Z="/"+Z))}if(!m[le])for(var he=0,Ee=d.length;he<Ee;he++){var L=d[he],S=encodeURIComponent(L);S===L&&(S=escape(L)),Z=Z.split(L).join(S)}var P=Z.indexOf("#");P!==-1&&(this.hash=Z.substr(P),Z=Z.slice(0,P));var W=Z.indexOf("?");if(W!==-1?(this.search=Z.substr(W),this.query=Z.substr(W+1),q&&(this.query=k.parse(this.query)),Z=Z.slice(0,W)):q&&(this.search="",this.query={}),Z&&(this.pathname=Z),C[le]&&this.hostname&&!this.pathname&&(this.pathname="/"),this.pathname||this.search){var v=this.pathname||"",I=this.search||"";this.path=v+I}return this.href=this.format(),this};function w(B){return x(B)&&(B=T(B)),B instanceof o?B.format():o.prototype.format.call(B)}o.prototype.format=function(){var B=this.auth||"";B&&(B=encodeURIComponent(B),B=B.replace(/%3A/i,":"),B+="@");var q=this.protocol||"",U=this.pathname||"",Z=this.hash||"",re=!1,le="";this.host?re=B+this.host:this.hostname&&(re=B+(this.hostname.indexOf(":")===-1?this.hostname:"["+this.hostname+"]"),this.port&&(re+=":"+this.port)),this.query&&R(this.query)&&Object.keys(this.query).length&&(le=k.stringify(this.query));var ce=this.search||le&&"?"+le||"";return q&&q.substr(-1)!==":"&&(q+=":"),this.slashes||(!q||C[q])&&re!==!1?(re="//"+(re||""),U&&U.charAt(0)!=="/"&&(U="/"+U)):re||(re=""),Z&&Z.charAt(0)!=="#"&&(Z="#"+Z),ce&&ce.charAt(0)!=="?"&&(ce="?"+ce),U=U.replace(/[?#]/g,function(de){return encodeURIComponent(de)}),ce=ce.replace("#","%23"),q+re+U+ce+Z};function A(B,q){return T(B,!1,!0).resolve(q)}o.prototype.resolve=function(B){return this.resolveObject(T(B,!1,!0)).format()};function M(B,q){return B?T(B,!1,!0).resolveObject(q):q}o.prototype.resolveObject=function(B){if(x(B)){var q=new o;q.parse(B,!1,!0),B=q}var U=new o;if(Object.keys(this).forEach(function(ve){U[ve]=this[ve]},this),U.hash=B.hash,B.href==="")return U.href=U.format(),U;if(B.slashes&&!B.protocol)return Object.keys(B).forEach(function(ve){ve!=="protocol"&&(U[ve]=B[ve])}),C[U.protocol]&&U.hostname&&!U.pathname&&(U.path=U.pathname="/"),U.href=U.format(),U;if(B.protocol&&B.protocol!==U.protocol){if(!C[B.protocol])return Object.keys(B).forEach(function(ve){U[ve]=B[ve]}),U.href=U.format(),U;if(U.protocol=B.protocol,!B.host&&!b[B.protocol]){for(var ge=(B.pathname||"").split("/");ge.length&&!(B.host=ge.shift()););B.host||(B.host=""),B.hostname||(B.hostname=""),ge[0]!==""&&ge.unshift(""),ge.length<2&&ge.unshift(""),U.pathname=ge.join("/")}else U.pathname=B.pathname;if(U.search=B.search,U.query=B.query,U.host=B.host||"",U.auth=B.auth,U.hostname=B.hostname||B.host,U.port=B.port,U.pathname||U.search){var Z=U.pathname||"",re=U.search||"";U.path=Z+re}return U.slashes=U.slashes||B.slashes,U.href=U.format(),U}var le=U.pathname&&U.pathname.charAt(0)==="/",ce=B.host||B.pathname&&B.pathname.charAt(0)==="/",de=ce||le||U.host&&B.pathname,he=de,Fe=U.pathname&&U.pathname.split("/")||[],ge=B.pathname&&B.pathname.split("/")||[],ye=U.protocol&&!C[U.protocol];if(ye&&(U.hostname="",U.port=null,U.host&&(Fe[0]===""?Fe[0]=U.host:Fe.unshift(U.host)),U.host="",B.protocol&&(B.hostname=null,B.port=null,B.host&&(ge[0]===""?ge[0]=B.host:ge.unshift(B.host)),B.host=null),de=de&&(ge[0]===""||Fe[0]==="")),ce)U.host=B.host||B.host===""?B.host:U.host,U.hostname=B.hostname||B.hostname===""?B.hostname:U.hostname,U.search=B.search,U.query=B.query,Fe=ge;else if(ge.length)Fe||(Fe=[]),Fe.pop(),Fe=Fe.concat(ge),U.search=B.search,U.query=B.query;else if(!j(B.search)){if(ye){U.hostname=U.host=Fe.shift();var Y=U.host&&U.host.indexOf("@")>0?U.host.split("@"):!1;Y&&(U.auth=Y.shift(),U.host=U.hostname=Y.shift())}return U.search=B.search,U.query=B.query,(!N(U.pathname)||!N(U.search))&&(U.path=(U.pathname?U.pathname:"")+(U.search?U.search:"")),U.href=U.format(),U}if(!Fe.length)return U.pathname=null,U.search?U.path="/"+U.search:U.path=null,U.href=U.format(),U;for(var ue=Fe.slice(-1)[0],Ee=(U.host||B.host)&&(ue==="."||ue==="..")||ue==="",ne=0,me=Fe.length;me>=0;me--)ue=Fe[me],ue=="."?Fe.splice(me,1):ue===".."?(Fe.splice(me,1),ne++):ne&&(Fe.splice(me,1),ne--);if(!de&&!he)for(;ne--;ne)Fe.unshift("..");de&&Fe[0]!==""&&(!Fe[0]||Fe[0].charAt(0)!=="/")&&Fe.unshift(""),Ee&&Fe.join("/").substr(-1)!=="/"&&Fe.push("");var se=Fe[0]===""||Fe[0]&&Fe[0].charAt(0)==="/";if(ye){U.hostname=U.host=se?"":Fe.length?Fe.shift():"";var Y=U.host&&U.host.indexOf("@")>0?U.host.split("@"):!1;Y&&(U.auth=Y.shift(),U.host=U.hostname=Y.shift())}return de=de||U.host&&Fe.length,de&&!se&&Fe.unshift(""),Fe.length?U.pathname=Fe.join("/"):(U.pathname=null,U.path=null),(!N(U.pathname)||!N(U.search))&&(U.path=(U.pathname?U.pathname:"")+(U.search?U.search:"")),U.auth=B.auth||U.auth,U.slashes=U.slashes||B.slashes,U.href=U.format(),U},o.prototype.parseHost=function(){var B=this.host,q=n.exec(B);q&&(q=q[0],q!==":"&&(this.port=q.substr(1)),B=B.substr(0,B.length-q.length)),B&&(this.hostname=B)};function x(B){return typeof B=="string"}function R(B){return typeof B=="object"&&B!==null}function N(B){return B===null}function j(B){return B==null}},function(u,r,i){var s;(function(o,f){/*! https://mths.be/punycode v1.3.2 by @mathias */(function(n){typeof r=="object"&&r&&r.nodeType,typeof o=="object"&&o&&o.nodeType;var h=typeof f=="object"&&f;h.global===h||h.window===h||h.self;var g,d=2147483647,l=36,c=1,a=26,F=38,p=700,m=72,b=128,C="-",k=/^xn--/,T=/[^\x20-\x7E]/,w=/[\x2E\u3002\uFF0E\uFF61]/g,A={overflow:"Overflow: input needs wider integers to process","not-basic":"Illegal input >= 0x80 (not a basic code point)","invalid-input":"Invalid input"},M=l-c,x=Math.floor,R=String.fromCharCode;function N(ge){throw RangeError(A[ge])}function j(ge,ye){for(var Y=ge.length,ue=[];Y--;)ue[Y]=ye(ge[Y]);return ue}function B(ge,ye){var Y=ge.split("@"),ue="";Y.length>1&&(ue=Y[0]+"@",ge=Y[1]),ge=ge.replace(w,".");var Ee=ge.split("."),ne=j(Ee,ye).join(".");return ue+ne}function q(ge){for(var ye=[],Y=0,ue=ge.length,Ee,ne;Y<ue;)Ee=ge.charCodeAt(Y++),Ee>=55296&&Ee<=56319&&Y<ue?(ne=ge.charCodeAt(Y++),(ne&64512)==56320?ye.push(((Ee&1023)<<10)+(ne&1023)+65536):(ye.push(Ee),Y--)):ye.push(Ee);return ye}function U(ge){return j(ge,function(ye){var Y="";return ye>65535&&(ye-=65536,Y+=R(ye>>>10&1023|55296),ye=56320|ye&1023),Y+=R(ye),Y}).join("")}function Z(ge){return ge-48<10?ge-22:ge-65<26?ge-65:ge-97<26?ge-97:l}function re(ge,ye){return ge+22+75*(ge<26)-((ye!=0)<<5)}function le(ge,ye,Y){var ue=0;for(ge=Y?x(ge/p):ge>>1,ge+=x(ge/ye);ge>M*a>>1;ue+=l)ge=x(ge/M);return x(ue+(M+1)*ge/(ge+F))}function ce(ge){var ye=[],Y=ge.length,ue,Ee=0,ne=b,me=m,se,ve,Pe,Ie,z,G,O,I,v;for(se=ge.lastIndexOf(C),se<0&&(se=0),ve=0;ve<se;++ve)ge.charCodeAt(ve)>=128&&N("not-basic"),ye.push(ge.charCodeAt(ve));for(Pe=se>0?se+1:0;Pe<Y;){for(Ie=Ee,z=1,G=l;Pe>=Y&&N("invalid-input"),O=Z(ge.charCodeAt(Pe++)),(O>=l||O>x((d-Ee)/z))&&N("overflow"),Ee+=O*z,I=G<=me?c:G>=me+a?a:G-me,!(O<I);G+=l)v=l-I,z>x(d/v)&&N("overflow"),z*=v;ue=ye.length+1,me=le(Ee-Ie,ue,Ie==0),x(Ee/ue)>d-ne&&N("overflow"),ne+=x(Ee/ue),Ee%=ue,ye.splice(Ee++,0,ne)}return U(ye)}function de(ge){var ye,Y,ue,Ee,ne,me,se,ve,Pe,Ie,z,G=[],O,I,v,E;for(ge=q(ge),O=ge.length,ye=b,Y=0,ne=m,me=0;me<O;++me)z=ge[me],z<128&&G.push(R(z));for(ue=Ee=G.length,Ee&&G.push(C);ue<O;){for(se=d,me=0;me<O;++me)z=ge[me],z>=ye&&z<se&&(se=z);for(I=ue+1,se-ye>x((d-Y)/I)&&N("overflow"),Y+=(se-ye)*I,ye=se,me=0;me<O;++me)if(z=ge[me],z<ye&&++Y>d&&N("overflow"),z==ye){for(ve=Y,Pe=l;Ie=Pe<=ne?c:Pe>=ne+a?a:Pe-ne,!(ve<Ie);Pe+=l)E=ve-Ie,v=l-Ie,G.push(R(re(Ie+E%v,0))),ve=x(E/v);G.push(R(re(ve,0))),ne=le(Y,I,ue==Ee),Y=0,++ue}++Y,++ye}return G.join("")}function he(ge){return B(ge,function(ye){return k.test(ye)?ce(ye.slice(4).toLowerCase()):ye})}function Fe(ge){return B(ge,function(ye){return T.test(ye)?"xn--"+de(ye):ye})}g={version:"1.3.2",ucs2:{decode:q,encode:U},decode:ce,encode:de,toASCII:Fe,toUnicode:he},s=function(){return g}.call(r,i,r,o),s!==void 0&&(o.exports=s)})()}).call(r,i(6)(u),function(){return this}())},function(u,r){u.exports=function(i){return i.webpackPolyfill||(i.deprecate=function(){},i.paths=[],i.children=[],i.webpackPolyfill=1),i}},function(u,r,i){r.decode=r.parse=i(8),r.encode=r.stringify=i(9)},function(u,r){function i(s,o){return Object.prototype.hasOwnProperty.call(s,o)}u.exports=function(s,o,f,n){o=o||"&",f=f||"=";var h={};if(typeof s!="string"||s.length===0)return h;var g=/\+/g;s=s.split(o);var d=1e3;n&&typeof n.maxKeys=="number"&&(d=n.maxKeys);var l=s.length;d>0&&l>d&&(l=d);for(var c=0;c<l;++c){var a=s[c].replace(g,"%20"),F=a.indexOf(f),p,m,b,C;F>=0?(p=a.substr(0,F),m=a.substr(F+1)):(p=a,m=""),b=decodeURIComponent(p),C=decodeURIComponent(m),i(h,b)?Array.isArray(h[b])?h[b].push(C):h[b]=[h[b],C]:h[b]=C}return h}},function(u,r){var i=function(s){switch(typeof s){case"string":return s;case"boolean":return s?"true":"false";case"number":return isFinite(s)?s:"";default:return""}};u.exports=function(s,o,f,n){return o=o||"&",f=f||"=",s===null&&(s=void 0),typeof s=="object"?Object.keys(s).map(function(h){var g=encodeURIComponent(i(h))+f;return Array.isArray(s[h])?s[h].map(function(d){return g+encodeURIComponent(i(d))}).join(o):g+encodeURIComponent(i(s[h]))}).join(o):n?encodeURIComponent(i(n))+f+encodeURIComponent(i(s)):""}},function(u,r){u.exports=function i(s,o){if(s===o)return!0;var f=Array.isArray(s),n=Array.isArray(o),h;if(f&&n){if(s.length!=o.length)return!1;for(h=0;h<s.length;h++)if(!i(s[h],o[h]))return!1;return!0}if(f!=n)return!1;if(s&&o&&typeof s=="object"&&typeof o=="object"){var g=Object.keys(s);if(g.length!==Object.keys(o).length)return!1;var d=s instanceof Date,l=o instanceof Date;if(d&&l)return s.getTime()==o.getTime();if(d!=l)return!1;var c=s instanceof RegExp,a=o instanceof RegExp;if(c&&a)return s.toString()==o.toString();if(c!=a)return!1;for(h=0;h<g.length;h++)if(!Object.prototype.hasOwnProperty.call(o,g[h]))return!1;for(h=0;h<g.length;h++)if(!i(s[g[h]],o[g[h]]))return!1;return!0}return!1}},function(u,r,i){u.exports={copy:s,checkDataType:o,checkDataTypes:f,coerceToTypes:h,toHash:g,getProperty:c,escapeQuotes:a,equal:i(10),ucs2length:i(12),varOccurences:F,varReplace:p,cleanUpCode:k,finalCleanUpCode:q,schemaHasRules:U,schemaHasRulesExcept:Z,toQuotedString:re,getPathExpr:le,getPath:ce,getData:Fe,unescapeFragment:ye,escapeFragment:Y,escapeJsonPointer:ue};function s(ne,me){me=me||{};for(var se in ne)me[se]=ne[se];return me}function o(ne,me,se){var ve=se?" !== ":" === ",Pe=se?" || ":" && ",Ie=se?"!":"",z=se?"":"!";switch(ne){case"null":return me+ve+"null";case"array":return Ie+"Array.isArray("+me+")";case"object":return"("+Ie+me+Pe+"typeof "+me+ve+'"object"'+Pe+z+"Array.isArray("+me+"))";case"integer":return"(typeof "+me+ve+'"number"'+Pe+z+"("+me+" % 1)"+Pe+me+ve+me+")";default:return"typeof "+me+ve+'"'+ne+'"'}}function f(ne,me){switch(ne.length){case 1:return o(ne[0],me,!0);default:var se="",ve=g(ne);ve.array&&ve.object&&(se=ve.null?"(":"(!"+me+" || ",se+="typeof "+me+' !== "object")',delete ve.null,delete ve.array,delete ve.object),ve.number&&delete ve.integer;for(var Pe in ve)se+=(se?" && ":"")+o(Pe,me,!0);return se}}var n=g(["string","number","integer","boolean","null"]);function h(ne,me){if(Array.isArray(me)){for(var se=[],ve=0;ve<me.length;ve++){var Pe=me[ve];(n[Pe]||ne==="array"&&Pe==="array")&&(se[se.length]=Pe)}if(se.length)return se}else{if(n[me])return[me];if(ne==="array"&&me==="array")return["array"]}}function g(ne){for(var me={},se=0;se<ne.length;se++)me[ne[se]]=!0;return me}var d=/^[a-z$_][a-z$_0-9]*$/i,l=/'|\\/g;function c(ne){return typeof ne=="number"?"["+ne+"]":d.test(ne)?"."+ne:"['"+a(ne)+"']"}function a(ne){return ne.replace(l,"\\$&").replace(/\n/g,"\\n").replace(/\r/g,"\\r").replace(/\f/g,"\\f").replace(/\t/g,"\\t")}function F(ne,me){me+="[^0-9]";var se=ne.match(new RegExp(me,"g"));return se?se.length:0}function p(ne,me,se){return me+="([^0-9])",se=se.replace(/\$/g,"$$$$"),ne.replace(new RegExp(me,"g"),se+"$1")}var m=/else\s*{\s*}/g,b=/if\s*\([^)]+\)\s*\{\s*\}(?!\s*else)/g,C=/if\s*\(([^)]+)\)\s*\{\s*\}\s*else(?!\s*if)/g;function k(ne){return ne.replace(m,"").replace(b,"").replace(C,"if (!($1))")}var T=/[^v\.]errors/g,w=/var errors = 0;|var vErrors = null;|validate.errors = vErrors;/g,A=/var errors = 0;|var vErrors = null;/g,M="return errors === 0;",x="validate.errors = null; return true;",R=/if \(errors === 0\) return data;\s*else throw new ValidationError\(vErrors\);/,N="return data;",j=/[^A-Za-z_$]rootData[^A-Za-z0-9_$]/g,B=/if \(rootData === undefined\) rootData = data;/;function q(ne,me){var se=ne.match(T);return se&&se.length==2&&(ne=me?ne.replace(A,"").replace(R,N):ne.replace(w,"").replace(M,x)),se=ne.match(j),!se||se.length!==3?ne:ne.replace(B,"")}function U(ne,me){if(typeof ne=="boolean")return!ne;for(var se in ne)if(me[se])return!0}function Z(ne,me,se){if(typeof ne=="boolean")return!ne&&se!="not";for(var ve in ne)if(ve!=se&&me[ve])return!0}function re(ne){return"'"+a(ne)+"'"}function le(ne,me,se,ve){var Pe=se?"'/' + "+me+(ve?"":".replace(/~/g, '~0').replace(/\\//g, '~1')"):ve?"'[' + "+me+" + ']'":"'[\\'' + "+me+" + '\\']'";return ge(ne,Pe)}function ce(ne,me,se){var ve=re(se?"/"+ue(me):c(me));return ge(ne,ve)}var de=/^\/(?:[^~]|~0|~1)*$/,he=/^([0-9]+)(#|\/(?:[^~]|~0|~1)*)?$/;function Fe(ne,me,se){var ve,Pe,Ie,z;if(ne==="")return"rootData";if(ne[0]=="/"){if(!de.test(ne))throw new Error("Invalid JSON-pointer: "+ne);Pe=ne,Ie="rootData"}else{if(z=ne.match(he),!z)throw new Error("Invalid JSON-pointer: "+ne);if(ve=+z[1],Pe=z[2],Pe=="#"){if(ve>=me)throw new Error("Cannot access property/index "+ve+" levels up, current level is "+me);return se[me-ve]}if(ve>me)throw new Error("Cannot access data "+ve+" levels up, current level is "+me);if(Ie="data"+(me-ve||""),!Pe)return Ie}for(var G=Ie,O=Pe.split("/"),I=0;I<O.length;I++){var v=O[I];v&&(Ie+=c(Ee(v)),G+=" && "+Ie)}return G}function ge(ne,me){return ne=='""'?me:(ne+" + "+me).replace(/' \+ '/g,"")}function ye(ne){return Ee(decodeURIComponent(ne))}function Y(ne){return encodeURIComponent(ue(ne))}function ue(ne){return ne.replace(/~/g,"~0").replace(/\//g,"~1")}function Ee(ne){return ne.replace(/~1/g,"/").replace(/~0/g,"~")}},function(u,r){u.exports=function(s){for(var o=0,f=s.length,n=0,h;n<f;)o++,h=s.charCodeAt(n++),h>=55296&&h<=56319&&n<f&&(h=s.charCodeAt(n),(h&64512)==56320&&n++);return o}},function(u,r,i){var s=i(11);u.exports=o;function o(f){s.copy(f,this)}},function(u,r){var i=u.exports=function(f,n,h){typeof n=="function"&&(h=n,n={}),s(n,h,f,"",f)};i.keywords={additionalItems:!0,items:!0,contains:!0,additionalProperties:!0,propertyNames:!0,not:!0},i.arrayKeywords={items:!0,allOf:!0,anyOf:!0,oneOf:!0},i.propsKeywords={definitions:!0,properties:!0,patternProperties:!0,dependencies:!0},i.skipKeywords={enum:!0,const:!0,required:!0,maximum:!0,minimum:!0,exclusiveMaximum:!0,exclusiveMinimum:!0,multipleOf:!0,maxLength:!0,minLength:!0,pattern:!0,format:!0,maxItems:!0,minItems:!0,uniqueItems:!0,maxProperties:!0,minProperties:!0};function s(f,n,h,g,d,l,c,a,F){if(h&&typeof h=="object"&&!Array.isArray(h)){n(h,g,d,l,c,a,F);for(var p in h){var m=h[p];if(Array.isArray(m)){if(p in i.arrayKeywords)for(var b=0;b<m.length;b++)s(f,n,m[b],g+"/"+p+"/"+b,d,g,p,h,b)}else if(p in i.propsKeywords){if(m&&typeof m=="object")for(var C in m)s(f,n,m[C],g+"/"+p+"/"+o(C),d,g,p,h,C)}else(p in i.keywords||f.allKeys&&!(p in i.skipKeywords))&&s(f,n,m,g+"/"+p,d,g,p,h)}}}function o(f){return f.replace(/~/g,"~0").replace(/\//g,"~1")}},function(u,r,i){var s=i(3);u.exports={Validation:n(o),MissingRef:n(f)};function o(h){this.message="validation failed",this.errors=h,this.ajv=this.validation=!0}f.message=function(h,g){return"can't resolve reference "+g+" from id "+h};function f(h,g,d){this.message=d||f.message(h,g),this.missingRef=s.url(h,g),this.missingSchema=s.normalizeId(s.fullPath(this.missingRef))}function n(h){return h.prototype=Object.create(Error.prototype),h.prototype.constructor=h,h}},function(u,r,i){var s=typeof JSON<"u"?JSON:i(17);u.exports=function(n,h){h||(h={}),typeof h=="function"&&(h={cmp:h});var g=h.space||"";typeof g=="number"&&(g=Array(g+1).join(" "));var d=typeof h.cycles=="boolean"?h.cycles:!1,l=h.replacer||function(F,p){return p},c=h.cmp&&function(F){return function(p){return function(m,b){var C={key:m,value:p[m]},k={key:b,value:p[b]};return F(C,k)}}}(h.cmp),a=[];return function F(p,m,b,C){var k=g?`
`+new Array(C+1).join(g):"",T=g?": ":":";if(b&&b.toJSON&&typeof b.toJSON=="function"&&(b=b.toJSON()),b=l.call(p,m,b),b!==void 0){if(typeof b!="object"||b===null)return s.stringify(b);if(o(b)){for(var w=[],A=0;A<b.length;A++){var M=F(b,A,b[A],C+1)||s.stringify(null);w.push(k+g+M)}return"["+w.join(",")+k+"]"}else{if(a.indexOf(b)!==-1){if(d)return s.stringify("__cycle__");throw new TypeError("Converting circular structure to JSON")}else a.push(b);for(var x=f(b).sort(c&&c(b)),w=[],A=0;A<x.length;A++){var m=x[A],R=F(b,m,b[m],C+1);if(R){var N=s.stringify(m)+T+R;w.push(k+g+N)}}return a.splice(a.indexOf(b),1),"{"+w.join(",")+k+"}"}}}({"":n},"",n,0)};var o=Array.isArray||function(n){return{}.toString.call(n)==="[object Array]"},f=Object.keys||function(n){var h=Object.prototype.hasOwnProperty||function(){return!0},g=[];for(var d in n)h.call(n,d)&&g.push(d);return g}},function(u,r,i){r.parse=i(18),r.stringify=i(19)},function(u,r){var i,s,o={'"':'"',"\\":"\\","/":"/",b:"\b",f:"\f",n:`
`,r:"\r",t:"	"},f,n=function(m){throw{name:"SyntaxError",message:m,at:i,text:f}},h=function(m){return m&&m!==s&&n("Expected '"+m+"' instead of '"+s+"'"),s=f.charAt(i),i+=1,s},g=function(){var m,b="";for(s==="-"&&(b="-",h("-"));s>="0"&&s<="9";)b+=s,h();if(s===".")for(b+=".";h()&&s>="0"&&s<="9";)b+=s;if(s==="e"||s==="E")for(b+=s,h(),(s==="-"||s==="+")&&(b+=s,h());s>="0"&&s<="9";)b+=s,h();if(m=+b,!isFinite(m))n("Bad number");else return m},d=function(){var m,b,C="",k;if(s==='"')for(;h();){if(s==='"')return h(),C;if(s==="\\")if(h(),s==="u"){for(k=0,b=0;b<4&&(m=parseInt(h(),16),!!isFinite(m));b+=1)k=k*16+m;C+=String.fromCharCode(k)}else if(typeof o[s]=="string")C+=o[s];else break;else C+=s}n("Bad string")},l=function(){for(;s&&s<=" ";)h()},c=function(){switch(s){case"t":return h("t"),h("r"),h("u"),h("e"),!0;case"f":return h("f"),h("a"),h("l"),h("s"),h("e"),!1;case"n":return h("n"),h("u"),h("l"),h("l"),null}n("Unexpected '"+s+"'")},a,F=function(){var m=[];if(s==="["){if(h("["),l(),s==="]")return h("]"),m;for(;s;){if(m.push(a()),l(),s==="]")return h("]"),m;h(","),l()}}n("Bad array")},p=function(){var m,b={};if(s==="{"){if(h("{"),l(),s==="}")return h("}"),b;for(;s;){if(m=d(),l(),h(":"),Object.hasOwnProperty.call(b,m)&&n('Duplicate key "'+m+'"'),b[m]=a(),l(),s==="}")return h("}"),b;h(","),l()}}n("Bad object")};a=function(){switch(l(),s){case"{":return p();case"[":return F();case'"':return d();case"-":return g();default:return s>="0"&&s<="9"?g():c()}},u.exports=function(m,b){var C;return f=m,i=0,s=" ",C=a(),l(),s&&n("Syntax error"),typeof b=="function"?function k(T,w){var A,M,x=T[w];if(x&&typeof x=="object")for(A in x)Object.prototype.hasOwnProperty.call(x,A)&&(M=k(x,A),M!==void 0?x[A]=M:delete x[A]);return b.call(T,w,x)}({"":C},""):C}},function(u,r){var i=/[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,s,o,f={"\b":"\\b","	":"\\t","\n":"\\n","\f":"\\f","\r":"\\r",'"':'\\"',"\\":"\\\\"},n;function h(d){return i.lastIndex=0,i.test(d)?'"'+d.replace(i,function(l){var c=f[l];return typeof c=="string"?c:"\\u"+("0000"+l.charCodeAt(0).toString(16)).slice(-4)})+'"':'"'+d+'"'}function g(d,l){var c,a,F,p,m=s,b,C=l[d];switch(C&&typeof C=="object"&&typeof C.toJSON=="function"&&(C=C.toJSON(d)),typeof n=="function"&&(C=n.call(l,d,C)),typeof C){case"string":return h(C);case"number":return isFinite(C)?String(C):"null";case"boolean":case"null":return String(C);case"object":if(!C)return"null";if(s+=o,b=[],Object.prototype.toString.apply(C)==="[object Array]"){for(p=C.length,c=0;c<p;c+=1)b[c]=g(c,C)||"null";return F=b.length===0?"[]":s?`[
`+s+b.join(`,
`+s)+`
`+m+"]":"["+b.join(",")+"]",s=m,F}if(n&&typeof n=="object")for(p=n.length,c=0;c<p;c+=1)a=n[c],typeof a=="string"&&(F=g(a,C),F&&b.push(h(a)+(s?": ":":")+F));else for(a in C)Object.prototype.hasOwnProperty.call(C,a)&&(F=g(a,C),F&&b.push(h(a)+(s?": ":":")+F));return F=b.length===0?"{}":s?`{
`+s+b.join(`,
`+s)+`
`+m+"}":"{"+b.join(",")+"}",s=m,F}}u.exports=function(d,l,c){var a;if(s="",o="",typeof c=="number")for(a=0;a<c;a+=1)o+=" ";else typeof c=="string"&&(o=c);if(n=l,l&&typeof l!="function"&&(typeof l!="object"||typeof l.length!="number"))throw new Error("JSON.stringify");return g("",{"":d})}},function(u,r){u.exports=function(s,o,f){var n="",h=s.schema.$async===!0,g=s.util.schemaHasRulesExcept(s.schema,s.RULES.all,"$ref"),d=s.self._getId(s.schema);if(s.isTop){if(h){s.async=!0;var l=s.opts.async=="es7";s.yieldAwait=l?"await":"yield"}n+=" var validate = ",h?l?n+=" (async function ":(s.opts.async!="*"&&(n+="co.wrap"),n+="(function* "):n+=" (function ",n+=" (data, dataPath, parentData, parentDataProperty, rootData) { 'use strict'; ",d&&(s.opts.sourceCode||s.opts.processCode)&&(n+=" "+("/*# sourceURL="+d+" */")+" ")}if(typeof s.schema=="boolean"||!(g||s.schema.$ref)){var o="false schema",c=s.level,a=s.dataLevel,F=s.schema[o],p=s.schemaPath+s.util.getProperty(o),m=s.errSchemaPath+"/"+o,A=!s.opts.allErrors,R,b="data"+(a||""),w="valid"+c;if(s.schema===!1){s.isTop?A=!0:n+=" var "+w+" = false; ";var C=C||[];C.push(n),n="",s.createErrors!==!1?(n+=" { keyword: '"+(R||"false schema")+"' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(m)+" , params: {} ",s.opts.messages!==!1&&(n+=" , message: 'boolean schema is false' "),s.opts.verbose&&(n+=" , schema: false , parentSchema: validate.schema"+s.schemaPath+" , data: "+b+" "),n+=" } "):n+=" {} ";var k=n;n=C.pop(),!s.compositeRule&&A?s.async?n+=" throw new ValidationError(["+k+"]); ":n+=" validate.errors = ["+k+"]; return false; ":n+=" var err = "+k+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; "}else s.isTop?h?n+=" return data; ":n+=" validate.errors = null; return true; ":n+=" var "+w+" = true; ";return s.isTop&&(n+=" }); return validate; "),n}if(s.isTop){var T=s.isTop,c=s.level=0,a=s.dataLevel=0,b="data";s.rootId=s.resolve.fullPath(s.self._getId(s.root.schema)),s.baseId=s.baseId||s.rootId,delete s.isTop,s.dataPathArr=[void 0],n+=" var vErrors = null; ",n+=" var errors = 0;     ",n+=" if (rootData === undefined) rootData = data; "}else{var c=s.level,a=s.dataLevel,b="data"+(a||"");if(d&&(s.baseId=s.resolve.url(s.baseId,d)),h&&!s.async)throw new Error("async schema in sync schema");n+=" var errs_"+c+" = errors;"}var w="valid"+c,A=!s.opts.allErrors,M="",x="",R,N=s.schema.type,j=Array.isArray(N);if(j&&N.length==1&&(N=N[0],j=!1),s.schema.$ref&&g){if(s.opts.extendRefs=="fail")throw new Error('$ref: validation keywords used in schema at path "'+s.errSchemaPath+'" (see option extendRefs)');s.opts.extendRefs!==!0&&(g=!1,console.warn('$ref: keywords ignored in schema at path "'+s.errSchemaPath+'"'))}if(N){if(s.opts.coerceTypes)var B=s.util.coerceToTypes(s.opts.coerceTypes,N);var q=s.RULES.types[N];if(B||j||q===!0||q&&!P(q)){var p=s.schemaPath+".type",m=s.errSchemaPath+"/type",p=s.schemaPath+".type",m=s.errSchemaPath+"/type",U=j?"checkDataTypes":"checkDataType";if(n+=" if ("+s.util[U](N,b,!0)+") { ",B){var Z="dataType"+c,re="coerced"+c;n+=" var "+Z+" = typeof "+b+"; ",s.opts.coerceTypes=="array"&&(n+=" if ("+Z+" == 'object' && Array.isArray("+b+")) "+Z+" = 'array'; "),n+=" var "+re+" = undefined; ";var le="",ce=B;if(ce)for(var de,he=-1,Fe=ce.length-1;he<Fe;)de=ce[he+=1],he&&(n+=" if ("+re+" === undefined) { ",le+="}"),s.opts.coerceTypes=="array"&&de!="array"&&(n+=" if ("+Z+" == 'array' && "+b+".length == 1) { "+re+" = "+b+" = "+b+"[0]; "+Z+" = typeof "+b+";  } "),de=="string"?n+=" if ("+Z+" == 'number' || "+Z+" == 'boolean') "+re+" = '' + "+b+"; else if ("+b+" === null) "+re+" = ''; ":de=="number"||de=="integer"?(n+=" if ("+Z+" == 'boolean' || "+b+" === null || ("+Z+" == 'string' && "+b+" && "+b+" == +"+b+" ",de=="integer"&&(n+=" && !("+b+" % 1)"),n+=")) "+re+" = +"+b+"; "):de=="boolean"?n+=" if ("+b+" === 'false' || "+b+" === 0 || "+b+" === null) "+re+" = false; else if ("+b+" === 'true' || "+b+" === 1) "+re+" = true; ":de=="null"?n+=" if ("+b+" === '' || "+b+" === 0 || "+b+" === false) "+re+" = null; ":s.opts.coerceTypes=="array"&&de=="array"&&(n+=" if ("+Z+" == 'string' || "+Z+" == 'number' || "+Z+" == 'boolean' || "+b+" == null) "+re+" = ["+b+"]; ");n+=" "+le+" if ("+re+" === undefined) {   ";var C=C||[];C.push(n),n="",s.createErrors!==!1?(n+=" { keyword: '"+(R||"type")+"' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(m)+" , params: { type: '",j?n+=""+N.join(","):n+=""+N,n+="' } ",s.opts.messages!==!1&&(n+=" , message: 'should be ",j?n+=""+N.join(","):n+=""+N,n+="' "),s.opts.verbose&&(n+=" , schema: validate.schema"+p+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+b+" "),n+=" } "):n+=" {} ";var k=n;n=C.pop(),!s.compositeRule&&A?s.async?n+=" throw new ValidationError(["+k+"]); ":n+=" validate.errors = ["+k+"]; return false; ":n+=" var err = "+k+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" } else {  ";var ge=a?"data"+(a-1||""):"parentData",ye=a?s.dataPathArr[a]:"parentDataProperty";n+=" "+b+" = "+re+"; ",a||(n+="if ("+ge+" !== undefined)"),n+=" "+ge+"["+ye+"] = "+re+"; } "}else{var C=C||[];C.push(n),n="",s.createErrors!==!1?(n+=" { keyword: '"+(R||"type")+"' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(m)+" , params: { type: '",j?n+=""+N.join(","):n+=""+N,n+="' } ",s.opts.messages!==!1&&(n+=" , message: 'should be ",j?n+=""+N.join(","):n+=""+N,n+="' "),s.opts.verbose&&(n+=" , schema: validate.schema"+p+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+b+" "),n+=" } "):n+=" {} ";var k=n;n=C.pop(),!s.compositeRule&&A?s.async?n+=" throw new ValidationError(["+k+"]); ":n+=" validate.errors = ["+k+"]; return false; ":n+=" var err = "+k+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; "}n+=" } "}}if(s.schema.$ref&&!g)n+=" "+s.RULES.all.$ref.code(s,"$ref")+" ",A&&(n+=" } if (errors === ",T?n+="0":n+="errs_"+c,n+=") { ",x+="}");else{s.opts.v5&&s.schema.patternGroups&&console.warn('keyword "patternGroups" is deprecated and disabled. Use option patternGroups: true to enable.');var Y=s.RULES;if(Y){for(var q,ue=-1,Ee=Y.length-1;ue<Ee;)if(q=Y[ue+=1],P(q)){if(q.type&&(n+=" if ("+s.util.checkDataType(q.type,b)+") { "),s.opts.useDefaults&&!s.compositeRule){if(q.type=="object"&&s.schema.properties){var F=s.schema.properties,ne=Object.keys(F),me=ne;if(me)for(var se,ve=-1,Pe=me.length-1;ve<Pe;){se=me[ve+=1];var Ie=F[se];if(Ie.default!==void 0){var z=b+s.util.getProperty(se);n+="  if ("+z+" === undefined) "+z+" = ",s.opts.useDefaults=="shared"?n+=" "+s.useDefault(Ie.default)+" ":n+=" "+JSON.stringify(Ie.default)+" ",n+="; "}}}else if(q.type=="array"&&Array.isArray(s.schema.items)){var G=s.schema.items;if(G){for(var Ie,he=-1,O=G.length-1;he<O;)if(Ie=G[he+=1],Ie.default!==void 0){var z=b+"["+he+"]";n+="  if ("+z+" === undefined) "+z+" = ",s.opts.useDefaults=="shared"?n+=" "+s.useDefault(Ie.default)+" ":n+=" "+JSON.stringify(Ie.default)+" ",n+="; "}}}}var I=q.rules;if(I){for(var v,E=-1,L=I.length-1;E<L;)if(v=I[E+=1],W(v)){var S=v.code(s,v.keyword,q.type);S&&(n+=" "+S+" ",A&&(M+="}"))}}if(A&&(n+=" "+M+" ",M=""),q.type&&(n+=" } ",N&&N===q.type&&!B)){n+=" else { ";var p=s.schemaPath+".type",m=s.errSchemaPath+"/type",C=C||[];C.push(n),n="",s.createErrors!==!1?(n+=" { keyword: '"+(R||"type")+"' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(m)+" , params: { type: '",j?n+=""+N.join(","):n+=""+N,n+="' } ",s.opts.messages!==!1&&(n+=" , message: 'should be ",j?n+=""+N.join(","):n+=""+N,n+="' "),s.opts.verbose&&(n+=" , schema: validate.schema"+p+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+b+" "),n+=" } "):n+=" {} ";var k=n;n=C.pop(),!s.compositeRule&&A?s.async?n+=" throw new ValidationError(["+k+"]); ":n+=" validate.errors = ["+k+"]; return false; ":n+=" var err = "+k+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" } "}A&&(n+=" if (errors === ",T?n+="0":n+="errs_"+c,n+=") { ",x+="}")}}}A&&(n+=" "+x+" "),T?(h?(n+=" if (errors === 0) return data;           ",n+=" else throw new ValidationError(vErrors); "):(n+=" validate.errors = vErrors; ",n+=" return errors === 0;       "),n+=" }); return validate;"):n+=" var "+w+" = errors === errs_"+c+";",n=s.util.cleanUpCode(n),T&&(n=s.util.finalCleanUpCode(n,h));function P(V){for(var ee=V.rules,Q=0;Q<ee.length;Q++)if(W(ee[Q]))return!0}function W(V){return s.schema[V.keyword]!==void 0||V.implements&&K(V)}function K(V){for(var ee=V.implements,Q=0;Q<ee.length;Q++)if(s.schema[ee[Q]]!==void 0)return!0}return n}},function(u,r){var i=Array.prototype.slice;u.exports=s.default=s.co=s,s.wrap=function(a){return F.__generatorFunction__=a,F;function F(){return s.call(this,a.apply(this,arguments))}};function s(a){var F=this,p=i.call(arguments,1);return new Promise(function(m,b){if(typeof a=="function"&&(a=a.apply(F,p)),!a||typeof a.next!="function")return m(a);C();function C(w){var A;try{A=a.next(w)}catch(M){return b(M)}T(A)}function k(w){var A;try{A=a.throw(w)}catch(M){return b(M)}T(A)}function T(w){if(w.done)return m(w.value);var A=o.call(F,w.value);return A&&g(A)?A.then(C,k):k(new TypeError('You may only yield a function, promise, generator, array, or object, but the following object was passed: "'+String(w.value)+'"'))}})}function o(a){return!a||g(a)?a:l(a)||d(a)?s.call(this,a):typeof a=="function"?f.call(this,a):Array.isArray(a)?n.call(this,a):c(a)?h.call(this,a):a}function f(a){var F=this;return new Promise(function(p,m){a.call(F,function(b,C){if(b)return m(b);arguments.length>2&&(C=i.call(arguments,1)),p(C)})})}function n(a){return Promise.all(a.map(o,this))}function h(a){for(var F=new a.constructor,p=Object.keys(a),m=[],b=0;b<p.length;b++){var C=p[b],k=o.call(this,a[C]);k&&g(k)?T(k,C):F[C]=a[C]}return Promise.all(m).then(function(){return F});function T(w,A){F[A]=void 0,m.push(w.then(function(M){F[A]=M}))}}function g(a){return typeof a.then=="function"}function d(a){return typeof a.next=="function"&&typeof a.throw=="function"}function l(a){var F=a.constructor;return F?F.name==="GeneratorFunction"||F.displayName==="GeneratorFunction"?!0:d(F.prototype):!1}function c(a){return Object==a.constructor}},function(u,r){var i=u.exports=function(){this._cache={}};i.prototype.put=function(o,f){this._cache[o]=f},i.prototype.get=function(o){return this._cache[o]},i.prototype.del=function(o){delete this._cache[o]},i.prototype.clear=function(){this._cache={}}},function(u,r,i){var s=i(11),o=/^\d\d\d\d-(\d\d)-(\d\d)$/,f=[0,31,29,31,30,31,30,31,31,30,31,30,31],n=/^(\d\d):(\d\d):(\d\d)(\.\d+)?(z|[+-]\d\d:\d\d)?$/i,h=/^[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?(?:\.[a-z0-9](?:[-0-9a-z]{0,61}[0-9a-z])?)*$/i,g=/^(?:[a-z][a-z0-9+\-.]*:)(?:\/?\/(?:(?:[a-z0-9\-._~!$&'()*+,;=:]|%[0-9a-f]{2})*@)?(?:\[(?:(?:(?:(?:[0-9a-f]{1,4}:){6}|::(?:[0-9a-f]{1,4}:){5}|(?:[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){4}|(?:(?:[0-9a-f]{1,4}:){0,1}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){3}|(?:(?:[0-9a-f]{1,4}:){0,2}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){2}|(?:(?:[0-9a-f]{1,4}:){0,3}[0-9a-f]{1,4})?::[0-9a-f]{1,4}:|(?:(?:[0-9a-f]{1,4}:){0,4}[0-9a-f]{1,4})?::)(?:[0-9a-f]{1,4}:[0-9a-f]{1,4}|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?))|(?:(?:[0-9a-f]{1,4}:){0,5}[0-9a-f]{1,4})?::[0-9a-f]{1,4}|(?:(?:[0-9a-f]{1,4}:){0,6}[0-9a-f]{1,4})?::)|[Vv][0-9a-f]+\.[a-z0-9\-._~!$&'()*+,;=:]+)\]|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)|(?:[a-z0-9\-._~!$&'()*+,;=]|%[0-9a-f]{2})*)(?::\d*)?(?:\/(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})*)*|\/(?:(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})*)*)?|(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'()*+,;=:@]|%[0-9a-f]{2})*)*)(?:\?(?:[a-z0-9\-._~!$&'()*+,;=:@\/?]|%[0-9a-f]{2})*)?(?:\#(?:[a-z0-9\-._~!$&'()*+,;=:@\/?]|%[0-9a-f]{2})*)?$/i,d=/^(?:[a-z][a-z0-9+\-.]*:)?(?:\/?\/(?:(?:[a-z0-9\-._~!$&'()*+,;=:]|%[0-9a-f]{2})*@)?(?:\[(?:(?:(?:(?:[0-9a-f]{1,4}:){6}|::(?:[0-9a-f]{1,4}:){5}|(?:[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){4}|(?:(?:[0-9a-f]{1,4}:){0,1}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){3}|(?:(?:[0-9a-f]{1,4}:){0,2}[0-9a-f]{1,4})?::(?:[0-9a-f]{1,4}:){2}|(?:(?:[0-9a-f]{1,4}:){0,3}[0-9a-f]{1,4})?::[0-9a-f]{1,4}:|(?:(?:[0-9a-f]{1,4}:){0,4}[0-9a-f]{1,4})?::)(?:[0-9a-f]{1,4}:[0-9a-f]{1,4}|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?))|(?:(?:[0-9a-f]{1,4}:){0,5}[0-9a-f]{1,4})?::[0-9a-f]{1,4}|(?:(?:[0-9a-f]{1,4}:){0,6}[0-9a-f]{1,4})?::)|[Vv][0-9a-f]+\.[a-z0-9\-._~!$&'()*+,;=:]+)\]|(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)|(?:[a-z0-9\-._~!$&'"()*+,;=]|%[0-9a-f]{2})*)(?::\d*)?(?:\/(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})*)*|\/(?:(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})*)*)?|(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})+(?:\/(?:[a-z0-9\-._~!$&'"()*+,;=:@]|%[0-9a-f]{2})*)*)?(?:\?(?:[a-z0-9\-._~!$&'"()*+,;=:@\/?]|%[0-9a-f]{2})*)?(?:\#(?:[a-z0-9\-._~!$&'"()*+,;=:@\/?]|%[0-9a-f]{2})*)?$/i,l=/^(?:(?:[^\x00-\x20"'<>%\\^`{|}]|%[0-9a-f]{2})|\{[+#.\/;?&=,!@|]?(?:[a-z0-9_]|%[0-9a-f]{2})+(?:\:[1-9][0-9]{0,3}|\*)?(?:,(?:[a-z0-9_]|%[0-9a-f]{2})+(?:\:[1-9][0-9]{0,3}|\*)?)*\})*$/i,c=/^(?:(?:http[s\u017F]?|ftp):\/\/)(?:(?:[\0-\x08\x0E-\x1F!-\x9F\xA1-\u167F\u1681-\u1FFF\u200B-\u2027\u202A-\u202E\u2030-\u205E\u2060-\u2FFF\u3001-\uD7FF\uE000-\uFEFE\uFF00-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+(?::(?:[\0-\x08\x0E-\x1F!-\x9F\xA1-\u167F\u1681-\u1FFF\u200B-\u2027\u202A-\u202E\u2030-\u205E\u2060-\u2FFF\u3001-\uD7FF\uE000-\uFEFE\uFF00-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])*)?@)?(?:(?!10(?:\.[0-9]{1,3}){3})(?!127(?:\.[0-9]{1,3}){3})(?!169\.254(?:\.[0-9]{1,3}){2})(?!192\.168(?:\.[0-9]{1,3}){2})(?!172\.(?:1[6-9]|2[0-9]|3[01])(?:\.[0-9]{1,3}){2})(?:[1-9][0-9]?|1[0-9][0-9]|2[01][0-9]|22[0-3])(?:\.(?:1?[0-9]{1,2}|2[0-4][0-9]|25[0-5])){2}(?:\.(?:[1-9][0-9]?|1[0-9][0-9]|2[0-4][0-9]|25[0-4]))|(?:(?:(?:[0-9KSa-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+\-?)*(?:[0-9KSa-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+)(?:\.(?:(?:[0-9KSa-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+\-?)*(?:[0-9KSa-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+)*(?:\.(?:(?:[KSa-z\xA1-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]){2,})))(?::[0-9]{2,5})?(?:\/(?:[\0-\x08\x0E-\x1F!-\x9F\xA1-\u167F\u1681-\u1FFF\u200B-\u2027\u202A-\u202E\u2030-\u205E\u2060-\u2FFF\u3001-\uD7FF\uE000-\uFEFE\uFF00-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])*)?$/i,a=/^(?:urn\:uuid\:)?[0-9a-f]{8}-(?:[0-9a-f]{4}-){3}[0-9a-f]{12}$/i,F=/^(?:\/(?:[^~\/]|~0|~1)*)*$|^\#(?:\/(?:[a-z0-9_\-\.!$&'()*+,;:=@]|%[0-9a-f]{2}|~0|~1)*)*$/i,p=/^(?:0|[1-9][0-9]*)(?:\#|(?:\/(?:[^~\/]|~0|~1)*)*)$/;u.exports=m;function m(N){return N=N=="full"?"full":"fast",s.copy(m[N])}m.fast={date:/^\d\d\d\d-[0-1]\d-[0-3]\d$/,time:/^[0-2]\d:[0-5]\d:[0-5]\d(?:\.\d+)?(?:z|[+-]\d\d:\d\d)?$/i,"date-time":/^\d\d\d\d-[0-1]\d-[0-3]\d[t\s][0-2]\d:[0-5]\d:[0-5]\d(?:\.\d+)?(?:z|[+-]\d\d:\d\d)$/i,uri:/^(?:[a-z][a-z0-9+-.]*)(?:\:|\/)\/?[^\s]*$/i,"uri-reference":/^(?:(?:[a-z][a-z0-9+-.]*:)?\/\/)?[^\s]*$/i,"uri-template":l,url:c,email:/^[a-z0-9.!#$%&'*+\/=?^_`{|}~-]+@[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?(?:\.[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?)*$/i,hostname:h,ipv4:/^(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)$/,ipv6:/^\s*(?:(?:(?:[0-9a-f]{1,4}:){7}(?:[0-9a-f]{1,4}|:))|(?:(?:[0-9a-f]{1,4}:){6}(?::[0-9a-f]{1,4}|(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(?:(?:[0-9a-f]{1,4}:){5}(?:(?:(?::[0-9a-f]{1,4}){1,2})|:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(?:(?:[0-9a-f]{1,4}:){4}(?:(?:(?::[0-9a-f]{1,4}){1,3})|(?:(?::[0-9a-f]{1,4})?:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){3}(?:(?:(?::[0-9a-f]{1,4}){1,4})|(?:(?::[0-9a-f]{1,4}){0,2}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){2}(?:(?:(?::[0-9a-f]{1,4}){1,5})|(?:(?::[0-9a-f]{1,4}){0,3}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){1}(?:(?:(?::[0-9a-f]{1,4}){1,6})|(?:(?::[0-9a-f]{1,4}){0,4}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?::(?:(?:(?::[0-9a-f]{1,4}){1,7})|(?:(?::[0-9a-f]{1,4}){0,5}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))(?:%.+)?\s*$/i,regex:R,uuid:a,"json-pointer":F,"relative-json-pointer":p},m.full={date:b,time:C,"date-time":T,uri:M,"uri-reference":d,"uri-template":l,url:c,email:/^[a-z0-9!#$%&'*+\/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&''*+\/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?$/i,hostname:w,ipv4:/^(?:(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(?:25[0-5]|2[0-4]\d|[01]?\d\d?)$/,ipv6:/^\s*(?:(?:(?:[0-9a-f]{1,4}:){7}(?:[0-9a-f]{1,4}|:))|(?:(?:[0-9a-f]{1,4}:){6}(?::[0-9a-f]{1,4}|(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(?:(?:[0-9a-f]{1,4}:){5}(?:(?:(?::[0-9a-f]{1,4}){1,2})|:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(?:(?:[0-9a-f]{1,4}:){4}(?:(?:(?::[0-9a-f]{1,4}){1,3})|(?:(?::[0-9a-f]{1,4})?:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){3}(?:(?:(?::[0-9a-f]{1,4}){1,4})|(?:(?::[0-9a-f]{1,4}){0,2}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){2}(?:(?:(?::[0-9a-f]{1,4}){1,5})|(?:(?::[0-9a-f]{1,4}){0,3}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?:(?:[0-9a-f]{1,4}:){1}(?:(?:(?::[0-9a-f]{1,4}){1,6})|(?:(?::[0-9a-f]{1,4}){0,4}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(?::(?:(?:(?::[0-9a-f]{1,4}){1,7})|(?:(?::[0-9a-f]{1,4}){0,5}:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))(?:%.+)?\s*$/i,regex:R,uuid:a,"json-pointer":F,"relative-json-pointer":p};function b(N){var j=N.match(o);if(!j)return!1;var B=+j[1],q=+j[2];return B>=1&&B<=12&&q>=1&&q<=f[B]}function C(N,j){var B=N.match(n);if(!B)return!1;var q=B[1],U=B[2],Z=B[3],re=B[5];return q<=23&&U<=59&&Z<=59&&(!j||re)}var k=/t|\s/i;function T(N){var j=N.split(k);return j.length==2&&b(j[0])&&C(j[1],!0)}function w(N){return N.length<=255&&h.test(N)}var A=/\/|\:/;function M(N){return A.test(N)&&g.test(N)}var x=/[^\\]\\Z/;function R(N){if(x.test(N))return!1;try{return new RegExp(N),!0}catch{return!1}}},function(u,r,i){var s=i(25),o=i(11).toHash;u.exports=function(){var n=[{type:"number",rules:[{maximum:["exclusiveMaximum"]},{minimum:["exclusiveMinimum"]},"multipleOf","format"]},{type:"string",rules:["maxLength","minLength","pattern","format"]},{type:"array",rules:["maxItems","minItems","uniqueItems","contains","items"]},{type:"object",rules:["maxProperties","minProperties","required","dependencies","propertyNames",{properties:["additionalProperties","patternProperties"]}]},{rules:["$ref","const","enum","not","anyOf","oneOf","allOf"]}],h=["type"],g=["additionalItems","$schema","id","title","description","default","definitions"],d=["number","integer","string","array","object","boolean","null"];return n.all=o(h),n.types=o(d),n.forEach(function(l){l.rules=l.rules.map(function(c){var a;if(typeof c=="object"){var F=Object.keys(c)[0];a=c[F],c=F,a.forEach(function(m){h.push(m),n.all[m]=!0})}h.push(c);var p=n.all[c]={keyword:c,code:s[c],implements:a};return p}),l.type&&(n.types[l.type]=l)}),n.keywords=o(h.concat(g)),n.custom={},n}},function(u,r,i){u.exports={$ref:i(26),allOf:i(27),anyOf:i(28),const:i(29),contains:i(30),dependencies:i(31),enum:i(32),format:i(33),items:i(34),maximum:i(35),minimum:i(35),maxItems:i(36),minItems:i(36),maxLength:i(37),minLength:i(37),maxProperties:i(38),minProperties:i(38),multipleOf:i(39),not:i(40),oneOf:i(41),pattern:i(42),properties:i(43),propertyNames:i(44),required:i(45),uniqueItems:i(46),validate:i(20)}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.errSchemaPath+"/"+o,c=!s.opts.allErrors,a="data"+(g||""),F="valid"+h,p,m;if(d=="#"||d=="#/")s.isRoot?(p=s.async,m="validate"):(p=s.root.schema.$async===!0,m="root.refVal[0]");else{var b=s.resolveRef(s.baseId,d,s.isRoot);if(b===void 0){var C=s.MissingRefError.message(s.baseId,d);if(s.opts.missingRefs=="fail"){console.error(C);var k=k||[];k.push(n),n="",s.createErrors!==!1?(n+=" { keyword: '$ref' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(l)+" , params: { ref: '"+s.util.escapeQuotes(d)+"' } ",s.opts.messages!==!1&&(n+=" , message: 'can\\'t resolve reference "+s.util.escapeQuotes(d)+"' "),s.opts.verbose&&(n+=" , schema: "+s.util.toQuotedString(d)+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+a+" "),n+=" } "):n+=" {} ";var T=n;n=k.pop(),!s.compositeRule&&c?s.async?n+=" throw new ValidationError(["+T+"]); ":n+=" validate.errors = ["+T+"]; return false; ":n+=" var err = "+T+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",c&&(n+=" if (false) { ")}else if(s.opts.missingRefs=="ignore")console.warn(C),c&&(n+=" if (true) { ");else throw new s.MissingRefError(s.baseId,d,C)}else if(b.inline){var w=s.util.copy(s);w.level++;var A="valid"+w.level;w.schema=b.schema,w.schemaPath="",w.errSchemaPath=d;var M=s.validate(w).replace(/validate\.schema/g,b.code);n+=" "+M+" ",c&&(n+=" if ("+A+") { ")}else p=b.$async===!0,m=b.code}if(m){var k=k||[];k.push(n),n="",s.opts.passContext?n+=" "+m+".call(this, ":n+=" "+m+"( ",n+=" "+a+", (dataPath || '')",s.errorPath!='""'&&(n+=" + "+s.errorPath);var x=g?"data"+(g-1||""):"parentData",R=g?s.dataPathArr[g]:"parentDataProperty";n+=" , "+x+" , "+R+", rootData)  ";var N=n;if(n=k.pop(),p){if(!s.async)throw new Error("async schema referenced by sync schema");c&&(n+=" var "+F+"; "),n+=" try { "+s.yieldAwait+" "+N+"; ",c&&(n+=" "+F+" = true; "),n+=" } catch (e) { if (!(e instanceof ValidationError)) throw e; if (vErrors === null) vErrors = e.errors; else vErrors = vErrors.concat(e.errors); errors = vErrors.length; ",c&&(n+=" "+F+" = false; "),n+=" } ",c&&(n+=" if ("+F+") { ")}else n+=" if (!"+N+") { if (vErrors === null) vErrors = "+m+".errors; else vErrors = vErrors.concat("+m+".errors); errors = vErrors.length; } ",c&&(n+=" else { ")}return n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.schema[o],g=s.schemaPath+s.util.getProperty(o),d=s.errSchemaPath+"/"+o,l=!s.opts.allErrors,c=s.util.copy(s),a="";c.level++;var F="valid"+c.level,p=c.baseId,m=!0,b=h;if(b)for(var C,k=-1,T=b.length-1;k<T;)C=b[k+=1],s.util.schemaHasRules(C,s.RULES.all)&&(m=!1,c.schema=C,c.schemaPath=g+"["+k+"]",c.errSchemaPath=d+"/"+k,n+="  "+s.validate(c)+" ",c.baseId=p,l&&(n+=" if ("+F+") { ",a+="}"));return l&&(m?n+=" if (true) { ":n+=" "+a.slice(0,-1)+" "),n=s.util.cleanUpCode(n),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p="valid"+h,m="errs__"+h,b=s.util.copy(s),C="";b.level++;var k="valid"+b.level,T=d.every(function(j){return s.util.schemaHasRules(j,s.RULES.all)});if(T){var w=b.baseId;n+=" var "+m+" = errors; var "+p+" = false;  ";var A=s.compositeRule;s.compositeRule=b.compositeRule=!0;var M=d;if(M)for(var x,R=-1,N=M.length-1;R<N;)x=M[R+=1],b.schema=x,b.schemaPath=l+"["+R+"]",b.errSchemaPath=c+"/"+R,n+="  "+s.validate(b)+" ",b.baseId=w,n+=" "+p+" = "+p+" || "+k+"; if (!"+p+") { ",C+="}";s.compositeRule=b.compositeRule=A,n+=" "+C+" if (!"+p+") {   var err =   ",s.createErrors!==!1?(n+=" { keyword: 'anyOf' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: {} ",s.opts.messages!==!1&&(n+=" , message: 'should match some schema in anyOf' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ",n+=";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",!s.compositeRule&&a&&(s.async?n+=" throw new ValidationError(vErrors); ":n+=" validate.errors = vErrors; return false; "),n+=" } else {  errors = "+m+"; if (vErrors !== null) { if ("+m+") vErrors.length = "+m+"; else vErrors = null; } ",s.opts.allErrors&&(n+=" } "),n=s.util.cleanUpCode(n)}else a&&(n+=" if (true) { ");return n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p="valid"+h,m=s.opts.$data&&d&&d.$data;m&&(n+=" var schema"+h+" = "+s.util.getData(d.$data,g,s.dataPathArr)+"; "),m||(n+=" var schema"+h+" = validate.schema"+l+";"),n+="var "+p+" = equal("+F+", schema"+h+"); if (!"+p+") {   ";var b=b||[];b.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'const' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: {} ",s.opts.messages!==!1&&(n+=" , message: 'should be equal to constant' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var C=n;return n=b.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+C+"]); ":n+=" validate.errors = ["+C+"]; return false; ":n+=" var err = "+C+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" }",a&&(n+=" else { "),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p="valid"+h,m="errs__"+h,b=s.util.copy(s),C="";b.level++;var k="valid"+b.level,T="i"+h,w=b.dataLevel=s.dataLevel+1,A="data"+w,M=s.baseId,x=s.util.schemaHasRules(d,s.RULES.all);if(n+="var "+m+" = errors;var "+p+";",x){var R=s.compositeRule;s.compositeRule=b.compositeRule=!0,b.schema=d,b.schemaPath=l,b.errSchemaPath=c,n+=" var "+k+" = false; for (var "+T+" = 0; "+T+" < "+F+".length; "+T+"++) { ",b.errorPath=s.util.getPathExpr(s.errorPath,T,s.opts.jsonPointers,!0);var N=F+"["+T+"]";b.dataPathArr[w]=T;var j=s.validate(b);b.baseId=M,s.util.varOccurences(j,A)<2?n+=" "+s.util.varReplace(j,A,N)+" ":n+=" var "+A+" = "+N+"; "+j+" ",n+=" if ("+k+") break; }  ",s.compositeRule=b.compositeRule=R,n+=" "+C+" if (!"+k+") {"}else n+=" if ("+F+".length == 0) {";var B=B||[];B.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'contains' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: {} ",s.opts.messages!==!1&&(n+=" , message: 'should contain a valid item' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var q=n;return n=B.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+q+"]); ":n+=" validate.errors = ["+q+"]; return false; ":n+=" var err = "+q+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" } else { ",x&&(n+="  errors = "+m+"; if (vErrors !== null) { if ("+m+") vErrors.length = "+m+"; else vErrors = null; } "),s.opts.allErrors&&(n+=" } "),n=s.util.cleanUpCode(n),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p="errs__"+h,m=s.util.copy(s),b="";m.level++;var C="valid"+m.level,k={},T={},w=s.opts.ownProperties;for(R in d){var A=d[R],M=Array.isArray(A)?T:k;M[R]=A}n+="var "+p+" = errors;";var x=s.errorPath;n+="var missing"+h+";";for(var R in T)if(M=T[R],M.length){if(n+=" if ( "+F+s.util.getProperty(R)+" !== undefined ",w&&(n+=" && Object.prototype.hasOwnProperty.call("+F+", '"+s.util.escapeQuotes(R)+"') "),a){n+=" && ( ";var N=M;if(N)for(var j,B=-1,q=N.length-1;B<q;){j=N[B+=1],B&&(n+=" || ");var U=s.util.getProperty(j),Z=F+U;n+=" ( ( "+Z+" === undefined ",w&&(n+=" || ! Object.prototype.hasOwnProperty.call("+F+", '"+s.util.escapeQuotes(j)+"') "),n+=") && (missing"+h+" = "+s.util.toQuotedString(s.opts.jsonPointers?j:U)+") ) "}n+=")) {  ";var re="missing"+h,le="' + "+re+" + '";s.opts._errorDataPathProperty&&(s.errorPath=s.opts.jsonPointers?s.util.getPathExpr(x,re,!0):x+" + "+re);var ce=ce||[];ce.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'dependencies' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { property: '"+s.util.escapeQuotes(R)+"', missingProperty: '"+le+"', depsCount: "+M.length+", deps: '"+s.util.escapeQuotes(M.length==1?M[0]:M.join(", "))+"' } ",s.opts.messages!==!1&&(n+=" , message: 'should have ",M.length==1?n+="property "+s.util.escapeQuotes(M[0]):n+="properties "+s.util.escapeQuotes(M.join(", ")),n+=" when property "+s.util.escapeQuotes(R)+" is present' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var de=n;n=ce.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+de+"]); ":n+=" validate.errors = ["+de+"]; return false; ":n+=" var err = "+de+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; "}else{n+=" ) { ";var he=M;if(he)for(var j,Fe=-1,ge=he.length-1;Fe<ge;){j=he[Fe+=1];var U=s.util.getProperty(j),le=s.util.escapeQuotes(j),Z=F+U;s.opts._errorDataPathProperty&&(s.errorPath=s.util.getPath(x,j,s.opts.jsonPointers)),n+=" if ( "+Z+" === undefined ",w&&(n+=" || ! Object.prototype.hasOwnProperty.call("+F+", '"+s.util.escapeQuotes(j)+"') "),n+=") {  var err =   ",s.createErrors!==!1?(n+=" { keyword: 'dependencies' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { property: '"+s.util.escapeQuotes(R)+"', missingProperty: '"+le+"', depsCount: "+M.length+", deps: '"+s.util.escapeQuotes(M.length==1?M[0]:M.join(", "))+"' } ",s.opts.messages!==!1&&(n+=" , message: 'should have ",M.length==1?n+="property "+s.util.escapeQuotes(M[0]):n+="properties "+s.util.escapeQuotes(M.join(", ")),n+=" when property "+s.util.escapeQuotes(R)+" is present' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ",n+=";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; } "}}n+=" }   ",a&&(b+="}",n+=" else { ")}s.errorPath=x;var ye=m.baseId;for(var R in k){var A=k[R];s.util.schemaHasRules(A,s.RULES.all)&&(n+=" "+C+" = true; if ( "+F+s.util.getProperty(R)+" !== undefined ",w&&(n+=" && Object.prototype.hasOwnProperty.call("+F+", '"+s.util.escapeQuotes(R)+"') "),n+=") { ",m.schema=A,m.schemaPath=l+s.util.getProperty(R),m.errSchemaPath=c+"/"+s.util.escapeFragment(R),n+="  "+s.validate(m)+" ",m.baseId=ye,n+=" }  ",a&&(n+=" if ("+C+") { ",b+="}"))}return a&&(n+="   "+b+" if ("+p+" == errors) {"),n=s.util.cleanUpCode(n),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p="valid"+h,m=s.opts.$data&&d&&d.$data;m&&(n+=" var schema"+h+" = "+s.util.getData(d.$data,g,s.dataPathArr)+"; ");var b="i"+h,C="schema"+h;m||(n+=" var "+C+" = validate.schema"+l+";"),n+="var "+p+";",m&&(n+=" if (schema"+h+" === undefined) "+p+" = true; else if (!Array.isArray(schema"+h+")) "+p+" = false; else {"),n+=""+p+" = false;for (var "+b+"=0; "+b+"<"+C+".length; "+b+"++) if (equal("+F+", "+C+"["+b+"])) { "+p+" = true; break; }",m&&(n+="  }  "),n+=" if (!"+p+") {   ";var k=k||[];k.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'enum' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { allowedValues: schema"+h+" } ",s.opts.messages!==!1&&(n+=" , message: 'should be equal to one of the allowed values' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var T=n;return n=k.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+T+"]); ":n+=" validate.errors = ["+T+"]; return false; ":n+=" var err = "+T+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" }",a&&(n+=" else { "),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||"");if(s.opts.format===!1)return a&&(n+=" if (true) { "),n;var p=s.opts.$data&&d&&d.$data,m;p?(n+=" var schema"+h+" = "+s.util.getData(d.$data,g,s.dataPathArr)+"; ",m="schema"+h):m=d;var b=s.opts.unknownFormats,C=Array.isArray(b);if(p){var k="format"+h,T="isObject"+h,w="formatType"+h;n+=" var "+k+" = formats["+m+"]; var "+T+" = typeof "+k+" == 'object' && !("+k+" instanceof RegExp) && "+k+".validate; var "+w+" = "+T+" && "+k+".type || 'string'; if ("+T+") { ",s.async&&(n+=" var async"+h+" = "+k+".async; "),n+=" "+k+" = "+k+".validate; } if (  ",p&&(n+=" ("+m+" !== undefined && typeof "+m+" != 'string') || "),n+=" (",b!="ignore"&&(n+=" ("+m+" && !"+k+" ",C&&(n+=" && self._opts.unknownFormats.indexOf("+m+") == -1 "),n+=") || "),n+=" ("+k+" && "+w+" == '"+f+"' && !(typeof "+k+" == 'function' ? ",s.async?n+=" (async"+h+" ? "+s.yieldAwait+" "+k+"("+F+") : "+k+"("+F+")) ":n+=" "+k+"("+F+") ",n+=" : "+k+".test("+F+"))))) {"}else{var k=s.formats[d];if(!k){if(b=="ignore")return console.warn('unknown format "'+d+'" ignored in schema at path "'+s.errSchemaPath+'"'),a&&(n+=" if (true) { "),n;if(C&&b.indexOf(d)>=0)return a&&(n+=" if (true) { "),n;throw new Error('unknown format "'+d+'" is used in schema at path "'+s.errSchemaPath+'"')}var T=typeof k=="object"&&!(k instanceof RegExp)&&k.validate,w=T&&k.type||"string";if(T){var A=k.async===!0;k=k.validate}if(w!=f)return a&&(n+=" if (true) { "),n;if(A){if(!s.async)throw new Error("async format in sync schema");var M="formats"+s.util.getProperty(d)+".validate";n+=" if (!("+s.yieldAwait+" "+M+"("+F+"))) { "}else{n+=" if (! ";var M="formats"+s.util.getProperty(d);T&&(M+=".validate"),typeof k=="function"?n+=" "+M+"("+F+") ":n+=" "+M+".test("+F+") ",n+=") { "}}var x=x||[];x.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'format' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { format:  ",p?n+=""+m:n+=""+s.util.toQuotedString(d),n+="  } ",s.opts.messages!==!1&&(n+=` , message: 'should match format "`,p?n+="' + "+m+" + '":n+=""+s.util.escapeQuotes(d),n+=`"' `),s.opts.verbose&&(n+=" , schema:  ",p?n+="validate.schema"+l:n+=""+s.util.toQuotedString(d),n+="         , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var R=n;return n=x.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+R+"]); ":n+=" validate.errors = ["+R+"]; return false; ":n+=" var err = "+R+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" } ",a&&(n+=" else { "),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p="valid"+h,m="errs__"+h,b=s.util.copy(s),C="";b.level++;var k="valid"+b.level,T="i"+h,w=b.dataLevel=s.dataLevel+1,A="data"+w,M=s.baseId;if(n+="var "+m+" = errors;var "+p+";",Array.isArray(d)){var x=s.schema.additionalItems;if(x===!1){n+=" "+p+" = "+F+".length <= "+d.length+"; ";var R=c;c=s.errSchemaPath+"/additionalItems",n+="  if (!"+p+") {   ";var N=N||[];N.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'additionalItems' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { limit: "+d.length+" } ",s.opts.messages!==!1&&(n+=" , message: 'should NOT have more than "+d.length+" items' "),s.opts.verbose&&(n+=" , schema: false , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var j=n;n=N.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+j+"]); ":n+=" validate.errors = ["+j+"]; return false; ":n+=" var err = "+j+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" } ",c=R,a&&(C+="}",n+=" else { ")}var B=d;if(B){for(var q,U=-1,Z=B.length-1;U<Z;)if(q=B[U+=1],s.util.schemaHasRules(q,s.RULES.all)){n+=" "+k+" = true; if ("+F+".length > "+U+") { ";var re=F+"["+U+"]";b.schema=q,b.schemaPath=l+"["+U+"]",b.errSchemaPath=c+"/"+U,b.errorPath=s.util.getPathExpr(s.errorPath,U,s.opts.jsonPointers,!0),b.dataPathArr[w]=U;var le=s.validate(b);b.baseId=M,s.util.varOccurences(le,A)<2?n+=" "+s.util.varReplace(le,A,re)+" ":n+=" var "+A+" = "+re+"; "+le+" ",n+=" }  ",a&&(n+=" if ("+k+") { ",C+="}")}}if(typeof x=="object"&&s.util.schemaHasRules(x,s.RULES.all)){b.schema=x,b.schemaPath=s.schemaPath+".additionalItems",b.errSchemaPath=s.errSchemaPath+"/additionalItems",n+=" "+k+" = true; if ("+F+".length > "+d.length+") {  for (var "+T+" = "+d.length+"; "+T+" < "+F+".length; "+T+"++) { ",b.errorPath=s.util.getPathExpr(s.errorPath,T,s.opts.jsonPointers,!0);var re=F+"["+T+"]";b.dataPathArr[w]=T;var le=s.validate(b);b.baseId=M,s.util.varOccurences(le,A)<2?n+=" "+s.util.varReplace(le,A,re)+" ":n+=" var "+A+" = "+re+"; "+le+" ",a&&(n+=" if (!"+k+") break; "),n+=" } }  ",a&&(n+=" if ("+k+") { ",C+="}")}}else if(s.util.schemaHasRules(d,s.RULES.all)){b.schema=d,b.schemaPath=l,b.errSchemaPath=c,n+="  for (var "+T+" = 0; "+T+" < "+F+".length; "+T+"++) { ",b.errorPath=s.util.getPathExpr(s.errorPath,T,s.opts.jsonPointers,!0);var re=F+"["+T+"]";b.dataPathArr[w]=T;var le=s.validate(b);b.baseId=M,s.util.varOccurences(le,A)<2?n+=" "+s.util.varReplace(le,A,re)+" ":n+=" var "+A+" = "+re+"; "+le+" ",a&&(n+=" if (!"+k+") break; "),n+=" }"}return a&&(n+=" "+C+" if ("+m+" == errors) {"),n=s.util.cleanUpCode(n),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,M,F="data"+(g||""),p=s.opts.$data&&d&&d.$data,m;p?(n+=" var schema"+h+" = "+s.util.getData(d.$data,g,s.dataPathArr)+"; ",m="schema"+h):m=d;var b=o=="maximum",C=b?"exclusiveMaximum":"exclusiveMinimum",k=s.schema[C],T=s.opts.$data&&k&&k.$data,w=b?"<":">",A=b?">":"<",M=void 0;if(T){var x=s.util.getData(k.$data,g,s.dataPathArr),R="exclusive"+h,N="exclType"+h,j="exclIsNumber"+h,B="op"+h,q="' + "+B+" + '";n+=" var schemaExcl"+h+" = "+x+"; ",x="schemaExcl"+h,n+=" var "+R+"; var "+N+" = typeof "+x+"; if ("+N+" != 'boolean' && "+N+" != 'undefined' && "+N+" != 'number') { ";var M=C,U=U||[];U.push(n),n="",s.createErrors!==!1?(n+=" { keyword: '"+(M||"_exclusiveLimit")+"' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: {} ",s.opts.messages!==!1&&(n+=" , message: '"+C+" should be boolean' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var Z=n;n=U.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+Z+"]); ":n+=" validate.errors = ["+Z+"]; return false; ":n+=" var err = "+Z+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" } else if ( ",p&&(n+=" ("+m+" !== undefined && typeof "+m+" != 'number') || "),n+=" "+N+" == 'number' ? ( ("+R+" = "+m+" === undefined || "+x+" "+w+"= "+m+") ? "+F+" "+A+"= "+x+" : "+F+" "+A+" "+m+" ) : ( ("+R+" = "+x+" === true) ? "+F+" "+A+"= "+m+" : "+F+" "+A+" "+m+" ) || "+F+" !== "+F+") { var op"+h+" = "+R+" ? '"+w+"' : '"+w+"=';"}else{var j=typeof k=="number",q=w;if(j&&p){var B="'"+q+"'";n+=" if ( ",p&&(n+=" ("+m+" !== undefined && typeof "+m+" != 'number') || "),n+=" ( "+m+" === undefined || "+k+" "+w+"= "+m+" ? "+F+" "+A+"= "+k+" : "+F+" "+A+" "+m+" ) || "+F+" !== "+F+") { "}else{j&&d===void 0?(R=!0,M=C,c=s.errSchemaPath+"/"+C,m=k,A+="="):(j&&(m=Math[b?"min":"max"](k,d)),k===(j?m:!0)?(R=!0,M=C,c=s.errSchemaPath+"/"+C,A+="="):(R=!1,q+="="));var B="'"+q+"'";n+=" if ( ",p&&(n+=" ("+m+" !== undefined && typeof "+m+" != 'number') || "),n+=" "+F+" "+A+" "+m+" || "+F+" !== "+F+") { "}}M=M||o;var U=U||[];U.push(n),n="",s.createErrors!==!1?(n+=" { keyword: '"+(M||"_limit")+"' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { comparison: "+B+", limit: "+m+", exclusive: "+R+" } ",s.opts.messages!==!1&&(n+=" , message: 'should be "+q+" ",p?n+="' + "+m:n+=""+m+"'"),s.opts.verbose&&(n+=" , schema:  ",p?n+="validate.schema"+l:n+=""+d,n+="         , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var Z=n;return n=U.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+Z+"]); ":n+=" validate.errors = ["+Z+"]; return false; ":n+=" var err = "+Z+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" } ",a&&(n+=" else { "),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,C,F="data"+(g||""),p=s.opts.$data&&d&&d.$data,m;p?(n+=" var schema"+h+" = "+s.util.getData(d.$data,g,s.dataPathArr)+"; ",m="schema"+h):m=d;var b=o=="maxItems"?">":"<";n+="if ( ",p&&(n+=" ("+m+" !== undefined && typeof "+m+" != 'number') || "),n+=" "+F+".length "+b+" "+m+") { ";var C=o,k=k||[];k.push(n),n="",s.createErrors!==!1?(n+=" { keyword: '"+(C||"_limitItems")+"' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { limit: "+m+" } ",s.opts.messages!==!1&&(n+=" , message: 'should NOT have ",o=="maxItems"?n+="more":n+="less",n+=" than ",p?n+="' + "+m+" + '":n+=""+d,n+=" items' "),s.opts.verbose&&(n+=" , schema:  ",p?n+="validate.schema"+l:n+=""+d,n+="         , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var T=n;return n=k.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+T+"]); ":n+=" validate.errors = ["+T+"]; return false; ":n+=" var err = "+T+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+="} ",a&&(n+=" else { "),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,C,F="data"+(g||""),p=s.opts.$data&&d&&d.$data,m;p?(n+=" var schema"+h+" = "+s.util.getData(d.$data,g,s.dataPathArr)+"; ",m="schema"+h):m=d;var b=o=="maxLength"?">":"<";n+="if ( ",p&&(n+=" ("+m+" !== undefined && typeof "+m+" != 'number') || "),s.opts.unicode===!1?n+=" "+F+".length ":n+=" ucs2length("+F+") ",n+=" "+b+" "+m+") { ";var C=o,k=k||[];k.push(n),n="",s.createErrors!==!1?(n+=" { keyword: '"+(C||"_limitLength")+"' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { limit: "+m+" } ",s.opts.messages!==!1&&(n+=" , message: 'should NOT be ",o=="maxLength"?n+="longer":n+="shorter",n+=" than ",p?n+="' + "+m+" + '":n+=""+d,n+=" characters' "),s.opts.verbose&&(n+=" , schema:  ",p?n+="validate.schema"+l:n+=""+d,n+="         , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var T=n;return n=k.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+T+"]); ":n+=" validate.errors = ["+T+"]; return false; ":n+=" var err = "+T+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+="} ",a&&(n+=" else { "),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,C,F="data"+(g||""),p=s.opts.$data&&d&&d.$data,m;p?(n+=" var schema"+h+" = "+s.util.getData(d.$data,g,s.dataPathArr)+"; ",m="schema"+h):m=d;var b=o=="maxProperties"?">":"<";n+="if ( ",p&&(n+=" ("+m+" !== undefined && typeof "+m+" != 'number') || "),n+=" Object.keys("+F+").length "+b+" "+m+") { ";var C=o,k=k||[];k.push(n),n="",s.createErrors!==!1?(n+=" { keyword: '"+(C||"_limitProperties")+"' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { limit: "+m+" } ",s.opts.messages!==!1&&(n+=" , message: 'should NOT have ",o=="maxProperties"?n+="more":n+="less",n+=" than ",p?n+="' + "+m+" + '":n+=""+d,n+=" properties' "),s.opts.verbose&&(n+=" , schema:  ",p?n+="validate.schema"+l:n+=""+d,n+="         , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var T=n;return n=k.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+T+"]); ":n+=" validate.errors = ["+T+"]; return false; ":n+=" var err = "+T+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+="} ",a&&(n+=" else { "),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p=s.opts.$data&&d&&d.$data,m;p?(n+=" var schema"+h+" = "+s.util.getData(d.$data,g,s.dataPathArr)+"; ",m="schema"+h):m=d,n+="var division"+h+";if (",p&&(n+=" "+m+" !== undefined && ( typeof "+m+" != 'number' || "),n+=" (division"+h+" = "+F+" / "+m+", ",s.opts.multipleOfPrecision?n+=" Math.abs(Math.round(division"+h+") - division"+h+") > 1e-"+s.opts.multipleOfPrecision+" ":n+=" division"+h+" !== parseInt(division"+h+") ",n+=" ) ",p&&(n+="  )  "),n+=" ) {   ";var b=b||[];b.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'multipleOf' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { multipleOf: "+m+" } ",s.opts.messages!==!1&&(n+=" , message: 'should be multiple of ",p?n+="' + "+m:n+=""+m+"'"),s.opts.verbose&&(n+=" , schema:  ",p?n+="validate.schema"+l:n+=""+d,n+="         , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var C=n;return n=b.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+C+"]); ":n+=" validate.errors = ["+C+"]; return false; ":n+=" var err = "+C+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+="} ",a&&(n+=" else { "),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p="errs__"+h,m=s.util.copy(s);m.level++;var b="valid"+m.level;if(s.util.schemaHasRules(d,s.RULES.all)){m.schema=d,m.schemaPath=l,m.errSchemaPath=c,n+=" var "+p+" = errors;  ";var C=s.compositeRule;s.compositeRule=m.compositeRule=!0,m.createErrors=!1;var k;m.opts.allErrors&&(k=m.opts.allErrors,m.opts.allErrors=!1),n+=" "+s.validate(m)+" ",m.createErrors=!0,k&&(m.opts.allErrors=k),s.compositeRule=m.compositeRule=C,n+=" if ("+b+") {   ";var T=T||[];T.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'not' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: {} ",s.opts.messages!==!1&&(n+=" , message: 'should NOT be valid' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var w=n;n=T.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+w+"]); ":n+=" validate.errors = ["+w+"]; return false; ":n+=" var err = "+w+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" } else {  errors = "+p+"; if (vErrors !== null) { if ("+p+") vErrors.length = "+p+"; else vErrors = null; } ",s.opts.allErrors&&(n+=" } ")}else n+="  var err =   ",s.createErrors!==!1?(n+=" { keyword: 'not' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: {} ",s.opts.messages!==!1&&(n+=" , message: 'should NOT be valid' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ",n+=";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",a&&(n+=" if (false) { ");return n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p="valid"+h,m="errs__"+h,b=s.util.copy(s),C="";b.level++;var k="valid"+b.level;n+="var "+m+" = errors;var prevValid"+h+" = false;var "+p+" = false;";var T=b.baseId,w=s.compositeRule;s.compositeRule=b.compositeRule=!0;var A=d;if(A)for(var M,x=-1,R=A.length-1;x<R;)M=A[x+=1],s.util.schemaHasRules(M,s.RULES.all)?(b.schema=M,b.schemaPath=l+"["+x+"]",b.errSchemaPath=c+"/"+x,n+="  "+s.validate(b)+" ",b.baseId=T):n+=" var "+k+" = true; ",x&&(n+=" if ("+k+" && prevValid"+h+") "+p+" = false; else { ",C+="}"),n+=" if ("+k+") "+p+" = prevValid"+h+" = true;";return s.compositeRule=b.compositeRule=w,n+=""+C+"if (!"+p+") {   var err =   ",s.createErrors!==!1?(n+=" { keyword: 'oneOf' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: {} ",s.opts.messages!==!1&&(n+=" , message: 'should match exactly one schema in oneOf' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ",n+=";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",!s.compositeRule&&a&&(s.async?n+=" throw new ValidationError(vErrors); ":n+=" validate.errors = vErrors; return false; "),n+="} else {  errors = "+m+"; if (vErrors !== null) { if ("+m+") vErrors.length = "+m+"; else vErrors = null; }",s.opts.allErrors&&(n+=" } "),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p=s.opts.$data&&d&&d.$data,m;p?(n+=" var schema"+h+" = "+s.util.getData(d.$data,g,s.dataPathArr)+"; ",m="schema"+h):m=d;var b=p?"(new RegExp("+m+"))":s.usePattern(d);n+="if ( ",p&&(n+=" ("+m+" !== undefined && typeof "+m+" != 'string') || "),n+=" !"+b+".test("+F+") ) {   ";var C=C||[];C.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'pattern' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { pattern:  ",p?n+=""+m:n+=""+s.util.toQuotedString(d),n+="  } ",s.opts.messages!==!1&&(n+=` , message: 'should match pattern "`,p?n+="' + "+m+" + '":n+=""+s.util.escapeQuotes(d),n+=`"' `),s.opts.verbose&&(n+=" , schema:  ",p?n+="validate.schema"+l:n+=""+s.util.toQuotedString(d),n+="         , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var k=n;return n=C.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+k+"]); ":n+=" validate.errors = ["+k+"]; return false; ":n+=" var err = "+k+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+="} ",a&&(n+=" else { "),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p="valid"+h,m="errs__"+h,b=s.util.copy(s),C="";b.level++;var k="valid"+b.level,T="key"+h,w="idx"+h,A=b.dataLevel=s.dataLevel+1,M="data"+A,x="dataProperties"+h,R=Object.keys(d||{}),N=s.schema.patternProperties||{},j=Object.keys(N),B=s.schema.additionalProperties,q=R.length||j.length,U=B===!1,Z=typeof B=="object"&&Object.keys(B).length,re=s.opts.removeAdditional,le=U||Z||re,ce=s.opts.ownProperties,de=s.baseId,he=s.schema.required;if(he&&!(s.opts.v5&&he.$data)&&he.length<s.opts.loopRequired)var Fe=s.util.toHash(he);if(s.opts.patternGroups)var ge=s.schema.patternGroups||{},ye=Object.keys(ge);if(n+="var "+m+" = errors;var "+k+" = true;",ce&&(n+=" var "+x+" = undefined;"),le){if(ce?n+=" "+x+" = "+x+" || Object.keys("+F+"); for (var "+w+"=0; "+w+"<"+x+".length; "+w+"++) { var "+T+" = "+x+"["+w+"]; ":n+=" for (var "+T+" in "+F+") { ",q){if(n+=" var isAdditional"+h+" = !(false ",R.length)if(R.length>5)n+=" || validate.schema"+l+"["+T+"] ";else{var Y=R;if(Y)for(var ue,Ee=-1,ne=Y.length-1;Ee<ne;)ue=Y[Ee+=1],n+=" || "+T+" == "+s.util.toQuotedString(ue)+" "}if(j.length){var me=j;if(me)for(var se,ve=-1,Pe=me.length-1;ve<Pe;)se=me[ve+=1],n+=" || "+s.usePattern(se)+".test("+T+") "}if(s.opts.patternGroups&&ye.length){var Ie=ye;if(Ie)for(var z,ve=-1,G=Ie.length-1;ve<G;)z=Ie[ve+=1],n+=" || "+s.usePattern(z)+".test("+T+") "}n+=" ); if (isAdditional"+h+") { "}if(re=="all")n+=" delete "+F+"["+T+"]; ";else{var O=s.errorPath,I="' + "+T+" + '";if(s.opts._errorDataPathProperty&&(s.errorPath=s.util.getPathExpr(s.errorPath,T,s.opts.jsonPointers)),U)if(re)n+=" delete "+F+"["+T+"]; ";else{n+=" "+k+" = false; ";var v=c;c=s.errSchemaPath+"/additionalProperties";var E=E||[];E.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'additionalProperties' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { additionalProperty: '"+I+"' } ",s.opts.messages!==!1&&(n+=" , message: 'should NOT have additional properties' "),s.opts.verbose&&(n+=" , schema: false , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var L=n;n=E.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+L+"]); ":n+=" validate.errors = ["+L+"]; return false; ":n+=" var err = "+L+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",c=v,a&&(n+=" break; ")}else if(Z)if(re=="failing"){n+=" var "+m+" = errors;  ";var S=s.compositeRule;s.compositeRule=b.compositeRule=!0,b.schema=B,b.schemaPath=s.schemaPath+".additionalProperties",b.errSchemaPath=s.errSchemaPath+"/additionalProperties",b.errorPath=s.opts._errorDataPathProperty?s.errorPath:s.util.getPathExpr(s.errorPath,T,s.opts.jsonPointers);var P=F+"["+T+"]";b.dataPathArr[A]=T;var W=s.validate(b);b.baseId=de,s.util.varOccurences(W,M)<2?n+=" "+s.util.varReplace(W,M,P)+" ":n+=" var "+M+" = "+P+"; "+W+" ",n+=" if (!"+k+") { errors = "+m+"; if (validate.errors !== null) { if (errors) validate.errors.length = errors; else validate.errors = null; } delete "+F+"["+T+"]; }  ",s.compositeRule=b.compositeRule=S}else{b.schema=B,b.schemaPath=s.schemaPath+".additionalProperties",b.errSchemaPath=s.errSchemaPath+"/additionalProperties",b.errorPath=s.opts._errorDataPathProperty?s.errorPath:s.util.getPathExpr(s.errorPath,T,s.opts.jsonPointers);var P=F+"["+T+"]";b.dataPathArr[A]=T;var W=s.validate(b);b.baseId=de,s.util.varOccurences(W,M)<2?n+=" "+s.util.varReplace(W,M,P)+" ":n+=" var "+M+" = "+P+"; "+W+" ",a&&(n+=" if (!"+k+") break; ")}s.errorPath=O}q&&(n+=" } "),n+=" }  ",a&&(n+=" if ("+k+") { ",C+="}")}var K=s.opts.useDefaults&&!s.compositeRule;if(R.length){var V=R;if(V)for(var ue,ee=-1,Q=V.length-1;ee<Q;){ue=V[ee+=1];var fe=d[ue];if(s.util.schemaHasRules(fe,s.RULES.all)){var oe=s.util.getProperty(ue),P=F+oe,pe=K&&fe.default!==void 0;b.schema=fe,b.schemaPath=l+oe,b.errSchemaPath=c+"/"+s.util.escapeFragment(ue),b.errorPath=s.util.getPath(s.errorPath,ue,s.opts.jsonPointers),b.dataPathArr[A]=s.util.toQuotedString(ue);var W=s.validate(b);if(b.baseId=de,s.util.varOccurences(W,M)<2){W=s.util.varReplace(W,M,P);var ae=P}else{var ae=M;n+=" var "+M+" = "+P+"; "}if(pe)n+=" "+W+" ";else{if(Fe&&Fe[ue]){n+=" if ( "+ae+" === undefined ",ce&&(n+=" || ! Object.prototype.hasOwnProperty.call("+F+", '"+s.util.escapeQuotes(ue)+"') "),n+=") { "+k+" = false; ";var O=s.errorPath,v=c,Ae=s.util.escapeQuotes(ue);s.opts._errorDataPathProperty&&(s.errorPath=s.util.getPath(O,ue,s.opts.jsonPointers)),c=s.errSchemaPath+"/required";var E=E||[];E.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'required' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { missingProperty: '"+Ae+"' } ",s.opts.messages!==!1&&(n+=" , message: '",s.opts._errorDataPathProperty?n+="is a required property":n+="should have required property \\'"+Ae+"\\'",n+="' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var L=n;n=E.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+L+"]); ":n+=" validate.errors = ["+L+"]; return false; ":n+=" var err = "+L+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",c=v,s.errorPath=O,n+=" } else { "}else a?(n+=" if ( "+ae+" === undefined ",ce&&(n+=" || ! Object.prototype.hasOwnProperty.call("+F+", '"+s.util.escapeQuotes(ue)+"') "),n+=") { "+k+" = true; } else { "):(n+=" if ("+ae+" !== undefined ",ce&&(n+=" &&   Object.prototype.hasOwnProperty.call("+F+", '"+s.util.escapeQuotes(ue)+"') "),n+=" ) { ");n+=" "+W+" } "}}a&&(n+=" if ("+k+") { ",C+="}")}}if(j.length){var Se=j;if(Se)for(var se,ze=-1,Ve=Se.length-1;ze<Ve;){se=Se[ze+=1];var fe=N[se];if(s.util.schemaHasRules(fe,s.RULES.all)){b.schema=fe,b.schemaPath=s.schemaPath+".patternProperties"+s.util.getProperty(se),b.errSchemaPath=s.errSchemaPath+"/patternProperties/"+s.util.escapeFragment(se),ce?n+=" "+x+" = "+x+" || Object.keys("+F+"); for (var "+w+"=0; "+w+"<"+x+".length; "+w+"++) { var "+T+" = "+x+"["+w+"]; ":n+=" for (var "+T+" in "+F+") { ",n+=" if ("+s.usePattern(se)+".test("+T+")) { ",b.errorPath=s.util.getPathExpr(s.errorPath,T,s.opts.jsonPointers);var P=F+"["+T+"]";b.dataPathArr[A]=T;var W=s.validate(b);b.baseId=de,s.util.varOccurences(W,M)<2?n+=" "+s.util.varReplace(W,M,P)+" ":n+=" var "+M+" = "+P+"; "+W+" ",a&&(n+=" if (!"+k+") break; "),n+=" } ",a&&(n+=" else "+k+" = true; "),n+=" }  ",a&&(n+=" if ("+k+") { ",C+="}")}}}if(s.opts.patternGroups&&ye.length){var Me=ye;if(Me)for(var z,Le=-1,Be=Me.length-1;Le<Be;){z=Me[Le+=1];var Je=ge[z],fe=Je.schema;if(s.util.schemaHasRules(fe,s.RULES.all)){b.schema=fe,b.schemaPath=s.schemaPath+".patternGroups"+s.util.getProperty(z)+".schema",b.errSchemaPath=s.errSchemaPath+"/patternGroups/"+s.util.escapeFragment(z)+"/schema",n+=" var pgPropCount"+h+" = 0;  ",ce?n+=" "+x+" = "+x+" || Object.keys("+F+"); for (var "+w+"=0; "+w+"<"+x+".length; "+w+"++) { var "+T+" = "+x+"["+w+"]; ":n+=" for (var "+T+" in "+F+") { ",n+=" if ("+s.usePattern(z)+".test("+T+")) { pgPropCount"+h+"++; ",b.errorPath=s.util.getPathExpr(s.errorPath,T,s.opts.jsonPointers);var P=F+"["+T+"]";b.dataPathArr[A]=T;var W=s.validate(b);b.baseId=de,s.util.varOccurences(W,M)<2?n+=" "+s.util.varReplace(W,M,P)+" ":n+=" var "+M+" = "+P+"; "+W+" ",a&&(n+=" if (!"+k+") break; "),n+=" } ",a&&(n+=" else "+k+" = true; "),n+=" }  ",a&&(n+=" if ("+k+") { ",C+="}");var Ue=Je.minimum,Ge=Je.maximum;if(Ue!==void 0||Ge!==void 0){n+=" var "+p+" = true; ";var v=c;if(Ue!==void 0){var lt=Ue,et="minimum",vt="less";n+=" "+p+" = pgPropCount"+h+" >= "+Ue+"; ",c=s.errSchemaPath+"/patternGroups/minimum",n+="  if (!"+p+") {   ";var E=E||[];E.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'patternGroups' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { reason: '"+et+"', limit: "+lt+", pattern: '"+s.util.escapeQuotes(z)+"' } ",s.opts.messages!==!1&&(n+=" , message: 'should NOT have "+vt+" than "+lt+' properties matching pattern "'+s.util.escapeQuotes(z)+`"' `),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var L=n;n=E.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+L+"]); ":n+=" validate.errors = ["+L+"]; return false; ":n+=" var err = "+L+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" } ",Ge!==void 0&&(n+=" else ")}if(Ge!==void 0){var lt=Ge,et="maximum",vt="more";n+=" "+p+" = pgPropCount"+h+" <= "+Ge+"; ",c=s.errSchemaPath+"/patternGroups/maximum",n+="  if (!"+p+") {   ";var E=E||[];E.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'patternGroups' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { reason: '"+et+"', limit: "+lt+", pattern: '"+s.util.escapeQuotes(z)+"' } ",s.opts.messages!==!1&&(n+=" , message: 'should NOT have "+vt+" than "+lt+' properties matching pattern "'+s.util.escapeQuotes(z)+`"' `),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var L=n;n=E.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+L+"]); ":n+=" validate.errors = ["+L+"]; return false; ":n+=" var err = "+L+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" } "}c=v,a&&(n+=" if ("+p+") { ",C+="}")}}}}return a&&(n+=" "+C+" if ("+m+" == errors) {"),n=s.util.cleanUpCode(n),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p="errs__"+h,m=s.util.copy(s),b="";m.level++;var C="valid"+m.level;if(s.util.schemaHasRules(d,s.RULES.all)){m.schema=d,m.schemaPath=l,m.errSchemaPath=c;var k="key"+h,T="idx"+h,w="i"+h,A="' + "+k+" + '",M=m.dataLevel=s.dataLevel+1,x="data"+M,R="dataProperties"+h,N=s.opts.ownProperties,j=s.baseId;n+=" var "+p+" = errors; ",N&&(n+=" var "+R+" = undefined; "),N?n+=" "+R+" = "+R+" || Object.keys("+F+"); for (var "+T+"=0; "+T+"<"+R+".length; "+T+"++) { var "+k+" = "+R+"["+T+"]; ":n+=" for (var "+k+" in "+F+") { ",n+=" var startErrs"+h+" = errors; ";var B=k,q=s.compositeRule;s.compositeRule=m.compositeRule=!0;var U=s.validate(m);m.baseId=j,s.util.varOccurences(U,x)<2?n+=" "+s.util.varReplace(U,x,B)+" ":n+=" var "+x+" = "+B+"; "+U+" ",s.compositeRule=m.compositeRule=q,n+=" if (!"+C+") { for (var "+w+"=startErrs"+h+"; "+w+"<errors; "+w+"++) { vErrors["+w+"].propertyName = "+k+"; }   var err =   ",s.createErrors!==!1?(n+=" { keyword: 'propertyNames' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { propertyName: '"+A+"' } ",s.opts.messages!==!1&&(n+=" , message: 'property name \\'"+A+"\\' is invalid' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ",n+=";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",!s.compositeRule&&a&&(s.async?n+=" throw new ValidationError(vErrors); ":n+=" validate.errors = vErrors; return false; "),a&&(n+=" break; "),n+=" } }"}return a&&(n+=" "+b+" if ("+p+" == errors) {"),n=s.util.cleanUpCode(n),n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p="valid"+h,m=s.opts.$data&&d&&d.$data;m&&(n+=" var schema"+h+" = "+s.util.getData(d.$data,g,s.dataPathArr)+"; ");var b="schema"+h;if(!m)if(d.length<s.opts.loopRequired&&s.schema.properties&&Object.keys(s.schema.properties).length){var C=[],k=d;if(k)for(var T,w=-1,A=k.length-1;w<A;){T=k[w+=1];var M=s.schema.properties[T];M&&s.util.schemaHasRules(M,s.RULES.all)||(C[C.length]=T)}}else var C=d;if(m||C.length){var x=s.errorPath,R=m||C.length>=s.opts.loopRequired,N=s.opts.ownProperties;if(a)if(n+=" var missing"+h+"; ",R){m||(n+=" var "+b+" = validate.schema"+l+"; ");var j="i"+h,B="schema"+h+"["+j+"]",q="' + "+B+" + '";s.opts._errorDataPathProperty&&(s.errorPath=s.util.getPathExpr(x,B,s.opts.jsonPointers)),n+=" var "+p+" = true; ",m&&(n+=" if (schema"+h+" === undefined) "+p+" = true; else if (!Array.isArray(schema"+h+")) "+p+" = false; else {"),n+=" for (var "+j+" = 0; "+j+" < "+b+".length; "+j+"++) { "+p+" = "+F+"["+b+"["+j+"]] !== undefined ",N&&(n+=" &&   Object.prototype.hasOwnProperty.call("+F+", "+b+"["+j+"]) "),n+="; if (!"+p+") break; } ",m&&(n+="  }  "),n+="  if (!"+p+") {   ";var U=U||[];U.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'required' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { missingProperty: '"+q+"' } ",s.opts.messages!==!1&&(n+=" , message: '",s.opts._errorDataPathProperty?n+="is a required property":n+="should have required property \\'"+q+"\\'",n+="' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var Z=n;n=U.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+Z+"]); ":n+=" validate.errors = ["+Z+"]; return false; ":n+=" var err = "+Z+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" } else { "}else{n+=" if ( ";var re=C;if(re)for(var le,j=-1,ce=re.length-1;j<ce;){le=re[j+=1],j&&(n+=" || ");var de=s.util.getProperty(le),he=F+de;n+=" ( ( "+he+" === undefined ",N&&(n+=" || ! Object.prototype.hasOwnProperty.call("+F+", '"+s.util.escapeQuotes(le)+"') "),n+=") && (missing"+h+" = "+s.util.toQuotedString(s.opts.jsonPointers?le:de)+") ) "}n+=") {  ";var B="missing"+h,q="' + "+B+" + '";s.opts._errorDataPathProperty&&(s.errorPath=s.opts.jsonPointers?s.util.getPathExpr(x,B,!0):x+" + "+B);var U=U||[];U.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'required' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { missingProperty: '"+q+"' } ",s.opts.messages!==!1&&(n+=" , message: '",s.opts._errorDataPathProperty?n+="is a required property":n+="should have required property \\'"+q+"\\'",n+="' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var Z=n;n=U.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+Z+"]); ":n+=" validate.errors = ["+Z+"]; return false; ":n+=" var err = "+Z+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" } else { "}else if(R){m||(n+=" var "+b+" = validate.schema"+l+"; ");var j="i"+h,B="schema"+h+"["+j+"]",q="' + "+B+" + '";s.opts._errorDataPathProperty&&(s.errorPath=s.util.getPathExpr(x,B,s.opts.jsonPointers)),m&&(n+=" if ("+b+" && !Array.isArray("+b+")) {  var err =   ",s.createErrors!==!1?(n+=" { keyword: 'required' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { missingProperty: '"+q+"' } ",s.opts.messages!==!1&&(n+=" , message: '",s.opts._errorDataPathProperty?n+="is a required property":n+="should have required property \\'"+q+"\\'",n+="' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ",n+=";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; } else if ("+b+" !== undefined) { "),n+=" for (var "+j+" = 0; "+j+" < "+b+".length; "+j+"++) { if ("+F+"["+b+"["+j+"]] === undefined ",N&&(n+=" || ! Object.prototype.hasOwnProperty.call("+F+", "+b+"["+j+"]) "),n+=") {  var err =   ",s.createErrors!==!1?(n+=" { keyword: 'required' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { missingProperty: '"+q+"' } ",s.opts.messages!==!1&&(n+=" , message: '",s.opts._errorDataPathProperty?n+="is a required property":n+="should have required property \\'"+q+"\\'",n+="' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ",n+=";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; } } ",m&&(n+="  }  ")}else{var Fe=C;if(Fe)for(var le,ge=-1,ye=Fe.length-1;ge<ye;){le=Fe[ge+=1];var de=s.util.getProperty(le),q=s.util.escapeQuotes(le),he=F+de;s.opts._errorDataPathProperty&&(s.errorPath=s.util.getPath(x,le,s.opts.jsonPointers)),n+=" if ( "+he+" === undefined ",N&&(n+=" || ! Object.prototype.hasOwnProperty.call("+F+", '"+s.util.escapeQuotes(le)+"') "),n+=") {  var err =   ",s.createErrors!==!1?(n+=" { keyword: 'required' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { missingProperty: '"+q+"' } ",s.opts.messages!==!1&&(n+=" , message: '",s.opts._errorDataPathProperty?n+="is a required property":n+="should have required property \\'"+q+"\\'",n+="' "),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ",n+=";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; } "}}s.errorPath=x}else a&&(n+=" if (true) {");return n}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F="data"+(g||""),p="valid"+h,m=s.opts.$data&&d&&d.$data,b;if(m?(n+=" var schema"+h+" = "+s.util.getData(d.$data,g,s.dataPathArr)+"; ",b="schema"+h):b=d,(d||m)&&s.opts.uniqueItems!==!1){m&&(n+=" var "+p+"; if ("+b+" === false || "+b+" === undefined) "+p+" = true; else if (typeof "+b+" != 'boolean') "+p+" = false; else { "),n+=" var "+p+" = true; if ("+F+".length > 1) { var i = "+F+".length, j; outer: for (;i--;) { for (j = i; j--;) { if (equal("+F+"[i], "+F+"[j])) { "+p+" = false; break outer; } } } } ",m&&(n+="  }  "),n+=" if (!"+p+") {   ";var C=C||[];C.push(n),n="",s.createErrors!==!1?(n+=" { keyword: 'uniqueItems' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { i: i, j: j } ",s.opts.messages!==!1&&(n+=" , message: 'should NOT have duplicate items (items ## ' + j + ' and ' + i + ' are identical)' "),s.opts.verbose&&(n+=" , schema:  ",m?n+="validate.schema"+l:n+=""+d,n+="         , parentSchema: validate.schema"+s.schemaPath+" , data: "+F+" "),n+=" } "):n+=" {} ";var k=n;n=C.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+k+"]); ":n+=" validate.errors = ["+k+"]; return false; ":n+=" var err = "+k+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",n+=" } ",a&&(n+=" else { ")}else a&&(n+=" if (true) { ");return n}},function(u,r){var i=["multipleOf","maximum","exclusiveMaximum","minimum","exclusiveMinimum","maxLength","minLength","pattern","additionalItems","maxItems","minItems","uniqueItems","maxProperties","minProperties","required","additionalProperties","enum","format","const"];u.exports=function(s,o){for(var f=0;f<o.length;f++){s=JSON.parse(JSON.stringify(s));var n=o[f].split("/"),h=s,g;for(g=1;g<n.length;g++)h=h[n[g]];for(g=0;g<i.length;g++){var d=i[g],l=h[d];l&&(h[d]={anyOf:[l,{$ref:"https://raw.githubusercontent.com/epoberezkin/ajv/master/lib/refs/$data.json#"}]})}}return s}},function(u,r){var i="http://json-schema.org/draft-06/schema";u.exports=function(s){var o=s._opts.defaultMeta,f=typeof o=="string"?{$ref:o}:s.getSchema(i)?{$ref:i}:{};s.addKeyword("patternGroups",{metaSchema:{type:"object",additionalProperties:{type:"object",required:["schema"],properties:{maximum:{type:"integer",minimum:0},minimum:{type:"integer",minimum:0},schema:f},additionalProperties:!1}}}),s.RULES.all.properties.implements.push("patternGroups")}},function(u,r,i){var s=i(15).MissingRef;u.exports=o;function o(f,n,h){var g=this;if(typeof this._opts.loadSchema!="function")throw new Error("options.loadSchema should be a function");typeof n=="function"&&(h=n,n=void 0);var d=l(f).then(function(){var a=g._addSchema(f,void 0,n);return a.validate||c(a)});return h&&d.then(function(a){h(null,a)},h),d;function l(a){var F=a.$schema;return F&&!g.getSchema(F)?o.call(g,{$ref:F},!0):Promise.resolve()}function c(a){try{return g._compile(a)}catch(p){if(p instanceof s)return F(p);throw p}function F(p){var m=p.missingSchema;if(k(m))throw new Error("Schema "+m+" is loaded but "+p.missingRef+" cannot be resolved");var b=g._loadingSchemas[m];return b||(b=g._loadingSchemas[m]=g._opts.loadSchema(m),b.then(C,C)),b.then(function(T){if(!k(m))return l(T).then(function(){k(m)||g.addSchema(T,m,void 0,n)})}).then(function(){return c(a)});function C(){delete g._loadingSchemas[m]}function k(T){return g._refs[T]||g._schemas[T]}}}}},function(u,r,i){var s=/^[a-z_$][a-z0-9_$\-]*$/i,o=i(51);u.exports={add:f,get:n,remove:h};function f(g,d){var l=this.RULES;if(l.keywords[g])throw new Error("Keyword "+g+" is already defined");if(!s.test(g))throw new Error("Keyword "+g+" is not a valid identifier");if(d){if(d.macro&&d.valid!==void 0)throw new Error('"valid" option cannot be used with macro keywords');var c=d.type;if(Array.isArray(c)){var a,F=c.length;for(a=0;a<F;a++)C(c[a]);for(a=0;a<F;a++)b(g,c[a],d)}else c&&C(c),b(g,c,d);var p=d.$data===!0&&this._opts.$data;if(p&&!d.validate)throw new Error('$data support: "validate" function is not defined');var m=d.metaSchema;m&&(p&&(m={anyOf:[m,{$ref:"https://raw.githubusercontent.com/epoberezkin/ajv/master/lib/refs/$data.json#"}]}),d.validateSchema=this.compile(m,!0))}l.keywords[g]=l.all[g]=!0;function b(k,T,w){for(var A,M=0;M<l.length;M++){var x=l[M];if(x.type==T){A=x;break}}A||(A={type:T,rules:[]},l.push(A));var R={keyword:k,definition:w,custom:!0,code:o,implements:w.implements};A.rules.push(R),l.custom[k]=R}function C(k){if(!l.types[k])throw new Error("Unknown type "+k)}}function n(g){var d=this.RULES.custom[g];return d?d.definition:this.RULES.keywords[g]||!1}function h(g){var d=this.RULES;delete d.keywords[g],delete d.all[g],delete d.custom[g];for(var l=0;l<d.length;l++)for(var c=d[l].rules,a=0;a<c.length;a++)if(c[a].keyword==g){c.splice(a,1);break}}},function(u,r){u.exports=function(s,o,f){var n=" ",h=s.level,g=s.dataLevel,d=s.schema[o],l=s.schemaPath+s.util.getProperty(o),c=s.errSchemaPath+"/"+o,a=!s.opts.allErrors,F,p="data"+(g||""),m="valid"+h,b="errs__"+h,C=s.opts.$data&&d&&d.$data,k;C?(n+=" var schema"+h+" = "+s.util.getData(d.$data,g,s.dataPathArr)+"; ",k="schema"+h):k=d;var T=this,w="definition"+h,A=T.definition,M="",x,R,N,j,B;if(C&&A.$data){B="keywordValidate"+h;var q=A.validateSchema;n+=" var "+w+" = RULES.custom['"+o+"'].definition; var "+B+" = "+w+".validate;"}else{if(j=s.useCustomRule(T,d,s.schema,s),!j)return;k="validate.schema"+l,B=j.code,x=A.compile,R=A.inline,N=A.macro}var U=B+".errors",Z="i"+h,re="ruleErr"+h,le=A.async;if(le&&!s.async)throw new Error("async keyword in sync schema");if(R||N||(n+=""+U+" = null;"),n+="var "+b+" = errors;var "+m+";",C&&A.$data&&(M+="}",n+=" if ("+k+" === undefined) { "+m+" = true; } else { ",q&&(M+="}",n+=" "+m+" = "+w+".validateSchema("+k+"); if ("+m+") { ")),R)A.statements?n+=" "+j.validate+" ":n+=" "+m+" = "+j.validate+"; ";else if(N){var ce=s.util.copy(s),M="";ce.level++;var de="valid"+ce.level;ce.schema=j.validate,ce.schemaPath="";var he=s.compositeRule;s.compositeRule=ce.compositeRule=!0;var Fe=s.validate(ce).replace(/validate\.schema/g,B);s.compositeRule=ce.compositeRule=he,n+=" "+Fe}else{var ge=ge||[];ge.push(n),n="",n+="  "+B+".call( ",s.opts.passContext?n+="this":n+="self",x||A.schema===!1?n+=" , "+p+" ":n+=" , "+k+" , "+p+" , validate.schema"+s.schemaPath+" ",n+=" , (dataPath || '')",s.errorPath!='""'&&(n+=" + "+s.errorPath);var ye=g?"data"+(g-1||""):"parentData",Y=g?s.dataPathArr[g]:"parentDataProperty";n+=" , "+ye+" , "+Y+" , rootData )  ";var ue=n;n=ge.pop(),A.errors===!1?(n+=" "+m+" = ",le&&(n+=""+s.yieldAwait),n+=""+ue+"; "):le?(U="customErrors"+h,n+=" var "+U+" = null; try { "+m+" = "+s.yieldAwait+ue+"; } catch (e) { "+m+" = false; if (e instanceof ValidationError) "+U+" = e.errors; else throw e; } "):n+=" "+U+" = null; "+m+" = "+ue+"; "}if(A.modifying&&(n+=" if ("+ye+") "+p+" = "+ye+"["+Y+"];"),n+=""+M,A.valid)a&&(n+=" if (true) { ");else{n+=" if ( ",A.valid===void 0?(n+=" !",N?n+=""+de:n+=""+m):n+=" "+!A.valid+" ",n+=") { ",F=T.keyword;var ge=ge||[];ge.push(n),n="";var ge=ge||[];ge.push(n),n="",s.createErrors!==!1?(n+=" { keyword: '"+(F||"custom")+"' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { keyword: '"+T.keyword+"' } ",s.opts.messages!==!1&&(n+=` , message: 'should pass "`+T.keyword+`" keyword validation' `),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+p+" "),n+=" } "):n+=" {} ";var Ee=n;n=ge.pop(),!s.compositeRule&&a?s.async?n+=" throw new ValidationError(["+Ee+"]); ":n+=" validate.errors = ["+Ee+"]; return false; ":n+=" var err = "+Ee+";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ";var ne=n;n=ge.pop(),R?A.errors?A.errors!="full"&&(n+="  for (var "+Z+"="+b+"; "+Z+"<errors; "+Z+"++) { var "+re+" = vErrors["+Z+"]; if ("+re+".dataPath === undefined) "+re+".dataPath = (dataPath || '') + "+s.errorPath+"; if ("+re+".schemaPath === undefined) { "+re+'.schemaPath = "'+c+'"; } ',s.opts.verbose&&(n+=" "+re+".schema = "+k+"; "+re+".data = "+p+"; "),n+=" } "):A.errors===!1?n+=" "+ne+" ":(n+=" if ("+b+" == errors) { "+ne+" } else {  for (var "+Z+"="+b+"; "+Z+"<errors; "+Z+"++) { var "+re+" = vErrors["+Z+"]; if ("+re+".dataPath === undefined) "+re+".dataPath = (dataPath || '') + "+s.errorPath+"; if ("+re+".schemaPath === undefined) { "+re+'.schemaPath = "'+c+'"; } ',s.opts.verbose&&(n+=" "+re+".schema = "+k+"; "+re+".data = "+p+"; "),n+=" } } "):N?(n+="   var err =   ",s.createErrors!==!1?(n+=" { keyword: '"+(F||"custom")+"' , dataPath: (dataPath || '') + "+s.errorPath+" , schemaPath: "+s.util.toQuotedString(c)+" , params: { keyword: '"+T.keyword+"' } ",s.opts.messages!==!1&&(n+=` , message: 'should pass "`+T.keyword+`" keyword validation' `),s.opts.verbose&&(n+=" , schema: validate.schema"+l+" , parentSchema: validate.schema"+s.schemaPath+" , data: "+p+" "),n+=" } "):n+=" {} ",n+=";  if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ",!s.compositeRule&&a&&(s.async?n+=" throw new ValidationError(vErrors); ":n+=" validate.errors = vErrors; return false; ")):A.errors===!1?n+=" "+ne+" ":(n+=" if (Array.isArray("+U+")) { if (vErrors === null) vErrors = "+U+"; else vErrors = vErrors.concat("+U+"); errors = vErrors.length;  for (var "+Z+"="+b+"; "+Z+"<errors; "+Z+"++) { var "+re+" = vErrors["+Z+"]; if ("+re+".dataPath === undefined) "+re+".dataPath = (dataPath || '') + "+s.errorPath+";  "+re+'.schemaPath = "'+c+'";  ',s.opts.verbose&&(n+=" "+re+".schema = "+k+"; "+re+".data = "+p+"; "),n+=" } } else { "+ne+" } "),n+=" } ",a&&(n+=" else { ")}return n}},function(u,r){u.exports={$schema:"http://json-schema.org/draft-06/schema#",$id:"https://raw.githubusercontent.com/epoberezkin/ajv/master/lib/refs/$data.json#",description:"Meta-schema for $data reference (JSON-schema extension proposal)",type:"object",required:["$data"],properties:{$data:{type:"string",anyOf:[{format:"relative-json-pointer"},{format:"json-pointer"}]}},additionalProperties:!1}},function(u,r){u.exports={$schema:"http://json-schema.org/draft-06/schema#",$id:"http://json-schema.org/draft-06/schema#",title:"Core schema meta-schema",definitions:{schemaArray:{type:"array",minItems:1,items:{$ref:"#"}},nonNegativeInteger:{type:"integer",minimum:0},nonNegativeIntegerDefault0:{allOf:[{$ref:"#/definitions/nonNegativeInteger"},{default:0}]},simpleTypes:{enum:["array","boolean","integer","null","number","object","string"]},stringArray:{type:"array",items:{type:"string"},uniqueItems:!0,default:[]}},type:["object","boolean"],properties:{$id:{type:"string",format:"uri-reference"},$schema:{type:"string",format:"uri"},$ref:{type:"string",format:"uri-reference"},title:{type:"string"},description:{type:"string"},default:{},multipleOf:{type:"number",exclusiveMinimum:0},maximum:{type:"number"},exclusiveMaximum:{type:"number"},minimum:{type:"number"},exclusiveMinimum:{type:"number"},maxLength:{$ref:"#/definitions/nonNegativeInteger"},minLength:{$ref:"#/definitions/nonNegativeIntegerDefault0"},pattern:{type:"string",format:"regex"},additionalItems:{$ref:"#"},items:{anyOf:[{$ref:"#"},{$ref:"#/definitions/schemaArray"}],default:{}},maxItems:{$ref:"#/definitions/nonNegativeInteger"},minItems:{$ref:"#/definitions/nonNegativeIntegerDefault0"},uniqueItems:{type:"boolean",default:!1},contains:{$ref:"#"},maxProperties:{$ref:"#/definitions/nonNegativeInteger"},minProperties:{$ref:"#/definitions/nonNegativeIntegerDefault0"},required:{$ref:"#/definitions/stringArray"},additionalProperties:{$ref:"#"},definitions:{type:"object",additionalProperties:{$ref:"#"},default:{}},properties:{type:"object",additionalProperties:{$ref:"#"},default:{}},patternProperties:{type:"object",additionalProperties:{$ref:"#"},default:{}},dependencies:{type:"object",additionalProperties:{anyOf:[{$ref:"#"},{$ref:"#/definitions/stringArray"}]}},propertyNames:{$ref:"#"},const:{},enum:{type:"array",minItems:1,uniqueItems:!0},type:{anyOf:[{$ref:"#/definitions/simpleTypes"},{type:"array",items:{$ref:"#/definitions/simpleTypes"},minItems:1,uniqueItems:!0}]},format:{type:"string"},allOf:{$ref:"#/definitions/schemaArray"},anyOf:{$ref:"#/definitions/schemaArray"},oneOf:{$ref:"#/definitions/schemaArray"},not:{$ref:"#"}},default:{}}},function(u,r,i){var s=i(55),o=i(56),f=i(59),n=i(60),h=i(61),g=i(64),d=i(57),l=i(65),c={};c.create=function(a,F){if(!a)throw new Error("No container element provided.");this.container=a,this.dom={},this.highlighter=new s,this.selection=void 0,this.multiselection={nodes:[]},this.validateSchema=null,this.errorNodes=[],this.node=null,this.focusTarget=null,this._setOptions(F),F.autocomplete&&(this.autocomplete=new l(F.autocomplete)),this.options.history&&this.options.mode!=="view"&&(this.history=new o(this)),this._createFrame(),this._createTable()},c.destroy=function(){this.frame&&this.container&&this.frame.parentNode==this.container&&(this.container.removeChild(this.frame),this.frame=null),this.container=null,this.dom=null,this.clear(),this.node=null,this.focusTarget=null,this.selection=null,this.multiselection=null,this.errorNodes=null,this.validateSchema=null,this._debouncedValidate=null,this.history&&(this.history.destroy(),this.history=null),this.searchBox&&(this.searchBox.destroy(),this.searchBox=null),this.modeSwitcher&&(this.modeSwitcher.destroy(),this.modeSwitcher=null)},c._setOptions=function(a){if(this.options={search:!0,history:!0,mode:"tree",name:void 0,schema:null,schemaRefs:null,autocomplete:null},a)for(var F in a)a.hasOwnProperty(F)&&(this.options[F]=a[F]);this.setSchema(this.options.schema,this.options.schemaRefs),this._debouncedValidate=d.debounce(this.validate.bind(this),this.DEBOUNCE_INTERVAL)},c.set=function(a,F){if(F&&(console.warn('Second parameter "name" is deprecated. Use setName(name) instead.'),this.options.name=F),a instanceof Function||a===void 0)this.clear();else{this.content.removeChild(this.table);var p={field:this.options.name,value:a},m=new h(this,p);this._setRoot(m),this.validate();var b=!1;this.node.expand(b),this.content.appendChild(this.table)}this.history&&this.history.clear(),this.searchBox&&this.searchBox.clear()},c.get=function(){if(this.focusTarget){var a=h.getNodeFromTarget(this.focusTarget);a&&a.blur()}if(this.node)return this.node.getValue()},c.getText=function(){return JSON.stringify(this.get())},c.setText=function(a){try{this.set(d.parse(a))}catch{var F=d.sanitize(a);this.set(d.parse(F))}},c.setName=function(a){this.options.name=a,this.node&&this.node.updateField(this.options.name)},c.getName=function(){return this.options.name},c.focus=function(){var a=this.content.querySelector("[contenteditable=true]");a?a.focus():this.node.dom.expand?this.node.dom.expand.focus():this.node.dom.menu?this.node.dom.menu.focus():(a=this.frame.querySelector("button"),a&&a.focus())},c.clear=function(){this.node&&(this.node.collapse(),this.tbody.removeChild(this.node.getDom()),delete this.node)},c._setRoot=function(a){this.clear(),this.node=a,this.tbody.appendChild(a.getDom())},c.search=function(a){var F;return this.node?(this.content.removeChild(this.table),F=this.node.search(a),this.content.appendChild(this.table)):F=[],F},c.expandAll=function(){this.node&&(this.content.removeChild(this.table),this.node.expand(),this.content.appendChild(this.table))},c.collapseAll=function(){this.node&&(this.content.removeChild(this.table),this.node.collapse(),this.content.appendChild(this.table))},c._onAction=function(a,F){this.history&&this.history.add(a,F),this._onChange()},c._onChange=function(){if(this._debouncedValidate(),this.options.onChange)try{this.options.onChange()}catch(a){console.error("Error in onChange callback: ",a)}},c.validate=function(){this.errorNodes&&this.errorNodes.forEach(function(b){b.setError(null)});var a=this.node;if(a){var F=a.validate(),p=[];if(this.validateSchema){var m=this.validateSchema(a.getValue());m||(p=this.validateSchema.errors.map(function(b){return d.improveSchemaError(b)}).map(function(C){return{node:a.findNode(C.dataPath),error:C}}).filter(function(C){return C.node!=null}))}this.errorNodes=F.concat(p).reduce(function(C,k){return k.node.findParents().map(function(T){return{node:T,child:k.node,error:{message:T.type==="object"?"Contains invalid properties":"Contains invalid items"}}}).concat(C,[k])},[]).map(function(C){return C.node.setError(C.error,C.child),C.node})}},c.refresh=function(){this.node&&this.node.updateDom({recurse:!0})},c.startAutoScroll=function(a){var F=this,p=this.content,m=d.getAbsoluteTop(p),b=p.clientHeight,C=m+b,k=24,T=50;a<m+k&&p.scrollTop>0?this.autoScrollStep=(m+k-a)/3:a>C-k&&b+p.scrollTop<p.scrollHeight?this.autoScrollStep=(C-k-a)/3:this.autoScrollStep=void 0,this.autoScrollStep?this.autoScrollTimer||(this.autoScrollTimer=setInterval(function(){F.autoScrollStep?p.scrollTop-=F.autoScrollStep:F.stopAutoScroll()},T)):this.stopAutoScroll()},c.stopAutoScroll=function(){this.autoScrollTimer&&(clearTimeout(this.autoScrollTimer),delete this.autoScrollTimer),this.autoScrollStep&&delete this.autoScrollStep},c.setSelection=function(a){a&&("scrollTop"in a&&this.content&&(this.content.scrollTop=a.scrollTop),a.nodes&&this.select(a.nodes),a.range&&d.setSelectionOffset(a.range),a.dom&&a.dom.focus())},c.getSelection=function(){var a=d.getSelectionOffset();return a&&a.container.nodeName!=="DIV"&&(a=null),{dom:this.focusTarget,range:a,nodes:this.multiselection.nodes.slice(0),scrollTop:this.content?this.content.scrollTop:0}},c.scrollTo=function(a,F){var p=this.content;if(p){var m=this;m.animateTimeout&&(clearTimeout(m.animateTimeout),delete m.animateTimeout),m.animateCallback&&(m.animateCallback(!1),delete m.animateCallback);var b=p.clientHeight,C=p.scrollHeight-b,k=Math.min(Math.max(a-b/4,0),C),T=function(){var w=p.scrollTop,A=k-w;Math.abs(A)>3?(p.scrollTop+=A/3,m.animateCallback=F,m.animateTimeout=setTimeout(T,50)):(F&&F(!0),p.scrollTop=k,delete m.animateTimeout,delete m.animateCallback)};T()}else F&&F(!1)},c._createFrame=function(){this.frame=document.createElement("div"),this.frame.className="jsoneditor jsoneditor-mode-"+this.options.mode,this.container.appendChild(this.frame);var a=this;function F(T){a._onEvent&&a._onEvent(T)}this.frame.onclick=function(T){var w=T.target;F(T),w.nodeName=="BUTTON"&&T.preventDefault()},this.frame.oninput=F,this.frame.onchange=F,this.frame.onkeydown=F,this.frame.onkeyup=F,this.frame.oncut=F,this.frame.onpaste=F,this.frame.onmousedown=F,this.frame.onmouseup=F,this.frame.onmouseover=F,this.frame.onmouseout=F,d.addEventListener(this.frame,"focus",F,!0),d.addEventListener(this.frame,"blur",F,!0),this.frame.onfocusin=F,this.frame.onfocusout=F,this.menu=document.createElement("div"),this.menu.className="jsoneditor-menu",this.frame.appendChild(this.menu);var p=document.createElement("button");p.type="button",p.className="jsoneditor-expand-all",p.title="Expand all fields",p.onclick=function(){a.expandAll()},this.menu.appendChild(p);var m=document.createElement("button");if(m.type="button",m.title="Collapse all fields",m.className="jsoneditor-collapse-all",m.onclick=function(){a.collapseAll()},this.menu.appendChild(m),this.history){var b=document.createElement("button");b.type="button",b.className="jsoneditor-undo jsoneditor-separator",b.title="Undo last action (Ctrl+Z)",b.onclick=function(){a._onUndo()},this.menu.appendChild(b),this.dom.undo=b;var C=document.createElement("button");C.type="button",C.className="jsoneditor-redo",C.title="Redo (Ctrl+Shift+Z)",C.onclick=function(){a._onRedo()},this.menu.appendChild(C),this.dom.redo=C,this.history.onChange=function(){b.disabled=!a.history.canUndo(),C.disabled=!a.history.canRedo()},this.history.onChange()}if(this.options&&this.options.modes&&this.options.modes.length){var k=this;this.modeSwitcher=new g(this.menu,this.options.modes,this.options.mode,function(w){k.modeSwitcher.destroy(),k.setMode(w),k.modeSwitcher.focus()})}this.options.search&&(this.searchBox=new f(this,this.menu))},c._onUndo=function(){this.history&&(this.history.undo(),this._onChange())},c._onRedo=function(){this.history&&(this.history.redo(),this._onChange())},c._onEvent=function(a){a.type=="keydown"&&this._onKeyDown(a),a.type=="focus"&&(this.focusTarget=a.target),a.type=="mousedown"&&this._startDragDistance(a),(a.type=="mousemove"||a.type=="mouseup"||a.type=="click")&&this._updateDragDistance(a);var F=h.getNodeFromTarget(a.target);if(F&&F.selected){if(a.type=="click"){if(a.target==F.dom.menu){this.showContextMenu(a.target);return}a.hasMoved||this.deselect()}a.type=="mousedown"&&h.onDragStart(this.multiselection.nodes,a)}else a.type=="mousedown"&&(this.deselect(),F&&a.target==F.dom.drag?h.onDragStart(F,a):(!F||a.target!=F.dom.field&&a.target!=F.dom.value&&a.target!=F.dom.select)&&this._onMultiSelectStart(a));F&&F.onEvent(a)},c._startDragDistance=function(a){this.dragDistanceEvent={initialTarget:a.target,initialPageX:a.pageX,initialPageY:a.pageY,dragDistance:0,hasMoved:!1}},c._updateDragDistance=function(a){this.dragDistanceEvent||this._startDragDistance(a);var F=a.pageX-this.dragDistanceEvent.initialPageX,p=a.pageY-this.dragDistanceEvent.initialPageY;return this.dragDistanceEvent.dragDistance=Math.sqrt(F*F+p*p),this.dragDistanceEvent.hasMoved=this.dragDistanceEvent.hasMoved||this.dragDistanceEvent.dragDistance>10,a.dragDistance=this.dragDistanceEvent.dragDistance,a.hasMoved=this.dragDistanceEvent.hasMoved,a.dragDistance},c._onMultiSelectStart=function(a){var F=h.getNodeFromTarget(a.target);if(!(this.options.mode!=="tree"||this.options.onEditable!==void 0)){this.multiselection={start:F||null,end:null,nodes:[]},this._startDragDistance(a);var p=this;this.mousemove||(this.mousemove=d.addEventListener(window,"mousemove",function(m){p._onMultiSelect(m)})),this.mouseup||(this.mouseup=d.addEventListener(window,"mouseup",function(m){p._onMultiSelectEnd(m)}))}},c._onMultiSelect=function(a){if(a.preventDefault(),this._updateDragDistance(a),!!a.hasMoved){var F=h.getNodeFromTarget(a.target);F&&(this.multiselection.start==null&&(this.multiselection.start=F),this.multiselection.end=F),this.deselect();var p=this.multiselection.start,m=this.multiselection.end||this.multiselection.start;p&&m&&(this.multiselection.nodes=this._findTopLevelNodes(p,m),this.select(this.multiselection.nodes))}},c._onMultiSelectEnd=function(a){this.multiselection.nodes[0]&&this.multiselection.nodes[0].dom.menu.focus(),this.multiselection.start=null,this.multiselection.end=null,this.mousemove&&(d.removeEventListener(window,"mousemove",this.mousemove),delete this.mousemove),this.mouseup&&(d.removeEventListener(window,"mouseup",this.mouseup),delete this.mouseup)},c.deselect=function(a){this.multiselection.nodes.forEach(function(F){F.setSelected(!1)}),this.multiselection.nodes=[],a&&(this.multiselection.start=null,this.multiselection.end=null)},c.select=function(a){if(!Array.isArray(a))return this.select([a]);if(a){this.deselect(),this.multiselection.nodes=a.slice(0);var F=a[0];a.forEach(function(p){p.setSelected(!0,p===F)})}},c._findTopLevelNodes=function(a,F){for(var p=a.getNodePath(),m=F.getNodePath(),b=0;b<p.length&&p[b]===m[b];)b++;var C=p[b-1],k=p[b],T=m[b];if((!k||!T)&&(C.parent?(k=C,T=C,C=C.parent):(k=C.childs[0],T=C.childs[C.childs.length-1])),C&&k&&T){var w=C.childs.indexOf(k),A=C.childs.indexOf(T),M=Math.min(w,A),x=Math.max(w,A);return C.childs.slice(M,x+1)}else return[]},c._onKeyDown=function(a){var F=a.which||a.keyCode,p=a.altKey,m=a.ctrlKey,b=a.metaKey,C=a.shiftKey,k=!1;if(F==9){var T=this;setTimeout(function(){d.selectContentEditable(T.focusTarget)},0)}if(this.searchBox){if(m&&F==70)this.searchBox.dom.search.focus(),this.searchBox.dom.search.select(),k=!0;else if(F==114||m&&F==71){var w=!0;C?this.searchBox.previous(w):this.searchBox.next(w),k=!0}}if(this.history&&(m&&!C&&F==90?(this._onUndo(),k=!0):m&&C&&F==90&&(this._onRedo(),k=!0)),this.options.autocomplete&&!k&&!m&&!p&&!b&&(a.key.length==1||F==8||F==46)){k=!1;var A="";a.target.className.indexOf("jsoneditor-value")>=0&&(A="value"),a.target.className.indexOf("jsoneditor-field")>=0&&(A="field");var M=h.getNodeFromTarget(a.target);setTimeout(function(x,R){if(R.innerText.length>0){var N=this.options.autocomplete.getOptions(R.innerText,x.getPath(),A,x.editor);typeof N.then=="function"?N.then(function(j){j.options?this.autocomplete.show(R,j.startFrom,j.options):this.autocomplete.show(R,0,j)}.bind(this)):N.options?this.autocomplete.show(R,N.startFrom,N.options):this.autocomplete.show(R,0,N)}else this.autocomplete.hideDropDown()}.bind(this,M,a.target),50)}k&&(a.preventDefault(),a.stopPropagation())},c._createTable=function(){var a=document.createElement("div");a.className="jsoneditor-outer",this.contentOuter=a,this.content=document.createElement("div"),this.content.className="jsoneditor-tree",a.appendChild(this.content),this.table=document.createElement("table"),this.table.className="jsoneditor-tree",this.content.appendChild(this.table);var F;this.colgroupContent=document.createElement("colgroup"),this.options.mode==="tree"&&(F=document.createElement("col"),F.width="24px",this.colgroupContent.appendChild(F)),F=document.createElement("col"),F.width="24px",this.colgroupContent.appendChild(F),F=document.createElement("col"),this.colgroupContent.appendChild(F),this.table.appendChild(this.colgroupContent),this.tbody=document.createElement("tbody"),this.table.appendChild(this.tbody),this.frame.appendChild(a)},c.showContextMenu=function(a,F){var p=[],m=this;p.push({text:"Duplicate",title:"Duplicate selected fields (Ctrl+D)",className:"jsoneditor-duplicate",click:function(){h.onDuplicate(m.multiselection.nodes)}}),p.push({text:"Remove",title:"Remove selected fields (Ctrl+Del)",className:"jsoneditor-remove",click:function(){h.onRemove(m.multiselection.nodes)}});var b=new n(p,{close:F});b.show(a,this.content)},u.exports=[{mode:"tree",mixin:c,data:"json"},{mode:"view",mixin:c,data:"json"},{mode:"form",mixin:c,data:"json"}]},function(u,r){function i(){this.locked=!1}i.prototype.highlight=function(s){this.locked||(this.node!=s&&(this.node&&this.node.setHighlight(!1),this.node=s,this.node.setHighlight(!0)),this._cancelUnhighlight())},i.prototype.unhighlight=function(){if(!this.locked){var s=this;this.node&&(this._cancelUnhighlight(),this.unhighlightTimer=setTimeout(function(){s.node.setHighlight(!1),s.node=void 0,s.unhighlightTimer=void 0},0))}},i.prototype._cancelUnhighlight=function(){this.unhighlightTimer&&(clearTimeout(this.unhighlightTimer),this.unhighlightTimer=void 0)},i.prototype.lock=function(){this.locked=!0},i.prototype.unlock=function(){this.locked=!1},u.exports=i},function(u,r,i){i(57);function s(o){this.editor=o,this.history=[],this.index=-1,this.clear(),this.actions={editField:{undo:function(f){f.node.updateField(f.oldValue)},redo:function(f){f.node.updateField(f.newValue)}},editValue:{undo:function(f){f.node.updateValue(f.oldValue)},redo:function(f){f.node.updateValue(f.newValue)}},changeType:{undo:function(f){f.node.changeType(f.oldType)},redo:function(f){f.node.changeType(f.newType)}},appendNodes:{undo:function(f){f.nodes.forEach(function(n){f.parent.removeChild(n)})},redo:function(f){f.nodes.forEach(function(n){f.parent.appendChild(n)})}},insertBeforeNodes:{undo:function(f){f.nodes.forEach(function(n){f.parent.removeChild(n)})},redo:function(f){f.nodes.forEach(function(n){f.parent.insertBefore(n,f.beforeNode)})}},insertAfterNodes:{undo:function(f){f.nodes.forEach(function(n){f.parent.removeChild(n)})},redo:function(f){var n=f.afterNode;f.nodes.forEach(function(h){f.parent.insertAfter(f.node,n),n=h})}},removeNodes:{undo:function(f){var n=f.parent,h=n.childs[f.index]||n.append;f.nodes.forEach(function(g){n.insertBefore(g,h)})},redo:function(f){f.nodes.forEach(function(n){f.parent.removeChild(n)})}},duplicateNodes:{undo:function(f){f.nodes.forEach(function(n){f.parent.removeChild(n)})},redo:function(f){var n=f.afterNode;f.nodes.forEach(function(h){f.parent.insertAfter(h,n),n=h})}},moveNodes:{undo:function(f){f.nodes.forEach(function(n){f.oldBeforeNode.parent.moveBefore(n,f.oldBeforeNode)})},redo:function(f){f.nodes.forEach(function(n){f.newBeforeNode.parent.moveBefore(n,f.newBeforeNode)})}},sort:{undo:function(f){var n=f.node;n.hideChilds(),n.sort=f.oldSort,n.childs=f.oldChilds,n.showChilds()},redo:function(f){var n=f.node;n.hideChilds(),n.sort=f.newSort,n.childs=f.newChilds,n.showChilds()}}}}s.prototype.onChange=function(){},s.prototype.add=function(o,f){this.index++,this.history[this.index]={action:o,params:f,timestamp:new Date},this.index<this.history.length-1&&this.history.splice(this.index+1,this.history.length-this.index-1),this.onChange()},s.prototype.clear=function(){this.history=[],this.index=-1,this.onChange()},s.prototype.canUndo=function(){return this.index>=0},s.prototype.canRedo=function(){return this.index<this.history.length-1},s.prototype.undo=function(){if(this.canUndo()){var o=this.history[this.index];if(o){var f=this.actions[o.action];f&&f.undo?(f.undo(o.params),o.params.oldSelection&&this.editor.setSelection(o.params.oldSelection)):console.error(new Error('unknown action "'+o.action+'"'))}this.index--,this.onChange()}},s.prototype.redo=function(){if(this.canRedo()){this.index++;var o=this.history[this.index];if(o){var f=this.actions[o.action];f&&f.redo?(f.redo(o.params),o.params.newSelection&&this.editor.setSelection(o.params.newSelection)):console.error(new Error('unknown action "'+o.action+'"'))}this.onChange()}},s.prototype.destroy=function(){this.editor=null,this.history=[],this.index=-1},u.exports=s},function(u,r,i){var s=i(58);r.parse=function(h){try{return JSON.parse(h)}catch(g){throw r.validate(h),g}},r.sanitize=function(n){var h=[],g=0,d=n.match(/^\s*(\/\*(.|[\r\n])*?\*\/)?\s*[\da-zA-Z_$]+\s*\(([\s\S]*)\)\s*;?\s*$/);d&&(n=d[3]);var l={"\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","	":"\\t"};function c(){return n.charAt(g)}function a(){return n.charAt(g+1)}function F(){return n.charAt(g-1)}function p(){for(var w=h.length-1;w>=0;){var A=h[w];if(A!==" "&&A!==`
`&&A!=="\r"&&A!=="	")return A;w--}return""}function m(){for(g+=2;g<n.length&&(c()!=="*"||a()!=="/");)g++;g+=2}function b(){for(g+=2;g<n.length&&c()!==`
`;)g++}function C(w){h.push('"'),g++;for(var A=c();g<n.length&&A!==w;)A==='"'&&F()!=="\\"?h.push('\\"'):l.hasOwnProperty(A)?h.push(l[A]):(A==="\\"&&(g++,A=c(),A!=="'"&&h.push("\\")),h.push(A)),g++,A=c();A===w&&(h.push('"'),g++)}function k(){for(var w=["null","true","false"],A="",M=c(),x=/[a-zA-Z_$\d]/;x.test(M);)A+=M,g++,M=c();w.indexOf(A)===-1?h.push('"'+A+'"'):h.push(A)}for(;g<n.length;){var T=c();T==="/"&&a()==="*"?m():T==="/"&&a()==="/"?b():T==="'"||T==='"'?C(T):/[a-zA-Z_$]/.test(T)&&["{",","].indexOf(p())!==-1?k():(h.push(T),g++)}return h.join("")},r.escapeUnicodeChars=function(n){return n.replace(/[\u007F-\uFFFF]/g,function(h){return"\\u"+("0000"+h.charCodeAt(0).toString(16)).slice(-4)})},r.validate=function(h){typeof s<"u"?s.parse(h):JSON.parse(h)},r.extend=function(h,g){for(var d in g)g.hasOwnProperty(d)&&(h[d]=g[d]);return h},r.clear=function(h){for(var g in h)h.hasOwnProperty(g)&&delete h[g];return h},r.type=function(h){return h===null?"null":h===void 0?"undefined":h instanceof Number||typeof h=="number"?"number":h instanceof String||typeof h=="string"?"string":h instanceof Boolean||typeof h=="boolean"?"boolean":h instanceof RegExp||typeof h=="regexp"?"regexp":r.isArray(h)?"array":"object"};var o=/^https?:\/\/\S+$/;r.isUrl=function(h){return(typeof h=="string"||h instanceof String)&&o.test(h)},r.isArray=function(n){return Object.prototype.toString.call(n)==="[object Array]"},r.getAbsoluteLeft=function(h){var g=h.getBoundingClientRect();return g.left+window.pageXOffset||document.scrollLeft||0},r.getAbsoluteTop=function(h){var g=h.getBoundingClientRect();return g.top+window.pageYOffset||document.scrollTop||0},r.addClassName=function(h,g){var d=h.className.split(" ");d.indexOf(g)==-1&&(d.push(g),h.className=d.join(" "))},r.removeClassName=function(h,g){var d=h.className.split(" "),l=d.indexOf(g);l!=-1&&(d.splice(l,1),h.className=d.join(" "))},r.stripFormatting=function(h){for(var g=h.childNodes,d=0,l=g.length;d<l;d++){var c=g[d];c.style&&c.removeAttribute("style");var a=c.attributes;if(a)for(var F=a.length-1;F>=0;F--){var p=a[F];p.specified===!0&&c.removeAttribute(p.name)}r.stripFormatting(c)}},r.setEndOfContentEditable=function(h){var g,d;document.createRange&&(g=document.createRange(),g.selectNodeContents(h),g.collapse(!1),d=window.getSelection(),d.removeAllRanges(),d.addRange(g))},r.selectContentEditable=function(h){if(!(!h||h.nodeName!="DIV")){var g,d;window.getSelection&&document.createRange&&(d=document.createRange(),d.selectNodeContents(h),g=window.getSelection(),g.removeAllRanges(),g.addRange(d))}},r.getSelection=function(){if(window.getSelection){var h=window.getSelection();if(h.getRangeAt&&h.rangeCount)return h.getRangeAt(0)}return null},r.setSelection=function(h){if(h&&window.getSelection){var g=window.getSelection();g.removeAllRanges(),g.addRange(h)}},r.getSelectionOffset=function(){var h=r.getSelection();return h&&"startOffset"in h&&"endOffset"in h&&h.startContainer&&h.startContainer==h.endContainer?{startOffset:h.startOffset,endOffset:h.endOffset,container:h.startContainer.parentNode}:null},r.setSelectionOffset=function(h){if(document.createRange&&window.getSelection){var g=window.getSelection();if(g){var d=document.createRange();h.container.firstChild||h.container.appendChild(document.createTextNode("")),d.setStart(h.container.firstChild,h.startOffset),d.setEnd(h.container.firstChild,h.endOffset),r.setSelection(d)}}},r.getInnerText=function(h,g){var d=g==null;if(d&&(g={text:"",flush:function(){var C=this.text;return this.text="",C},set:function(C){this.text=C}}),h.nodeValue)return g.flush()+h.nodeValue;if(h.hasChildNodes()){for(var l=h.childNodes,c="",a=0,F=l.length;a<F;a++){var p=l[a];if(p.nodeName=="DIV"||p.nodeName=="P"){var m=l[a-1],b=m?m.nodeName:void 0;b&&b!="DIV"&&b!="P"&&b!="BR"&&(c+=`
`,g.flush()),c+=r.getInnerText(p,g),g.set(`
`)}else p.nodeName=="BR"?(c+=g.flush(),g.set(`
`)):c+=r.getInnerText(p,g)}return c}else if(h.nodeName=="P"&&r.getInternetExplorerVersion()!=-1)return g.flush();return""},r.getInternetExplorerVersion=function(){if(f==-1){var h=-1;if(navigator.appName=="Microsoft Internet Explorer"){var g=navigator.userAgent,d=new RegExp("MSIE ([0-9]{1,}[.0-9]{0,})");d.exec(g)!=null&&(h=parseFloat(RegExp.$1))}f=h}return f},r.isFirefox=function(){return navigator.userAgent.indexOf("Firefox")!=-1};var f=-1;r.addEventListener=function(h,g,d,l){if(h.addEventListener)return l===void 0&&(l=!1),g==="mousewheel"&&r.isFirefox()&&(g="DOMMouseScroll"),h.addEventListener(g,d,l),d;if(h.attachEvent){var c=function(){return d.call(h,window.event)};return h.attachEvent("on"+g,c),c}},r.removeEventListener=function(h,g,d,l){h.removeEventListener?(l===void 0&&(l=!1),g==="mousewheel"&&r.isFirefox()&&(g="DOMMouseScroll"),h.removeEventListener(g,d,l)):h.detachEvent&&h.detachEvent("on"+g,d)},r.parsePath=function n(h){var g,d;if(h.length===0)return[];var l=h.match(/^\.(\w+)/);if(l)g=l[1],d=h.substr(g.length+1);else if(h[0]==="["){var c=h.indexOf("]");if(c===-1)throw new SyntaxError("Character ] expected in path");if(c===1)throw new SyntaxError("Index expected after [");var a=h.substring(1,c);a[0]==="'"&&(a='"'+a.substring(1,a.length-1)+'"'),g=a==="*"?a:JSON.parse(a),d=h.substr(c+1)}else throw new SyntaxError("Failed to parse path");return[g].concat(n(d))},r.improveSchemaError=function(n){if(n.keyword==="enum"&&Array.isArray(n.schema)){var h=n.schema;if(h){if(h=h.map(function(d){return JSON.stringify(d)}),h.length>5){var g=["("+(h.length-5)+" more...)"];h=h.slice(0,5),h.push(g)}n.message="should be equal to one of: "+h.join(", ")}}return n.keyword==="additionalProperties"&&(n.message="should NOT have additional property: "+n.params.additionalProperty),n},r.insideRect=function(n,h,g){var d=g!==void 0?g:0;return h.left-d>=n.left&&h.right+d<=n.right&&h.top-d>=n.top&&h.bottom+d<=n.bottom},r.debounce=function(h,g,d){var l;return function(){var c=this,a=arguments,F=function(){l=null,d||h.apply(c,a)},p=d&&!l;clearTimeout(l),l=setTimeout(F,g),p&&h.apply(c,a)}},r.textDiff=function(h,g){for(var d=g.length,l=0,c=h.length,a=g.length;g.charAt(l)===h.charAt(l)&&l<d;)l++;for(;g.charAt(a-1)===h.charAt(c-1)&&a>l&&c>0;)a--,c--;return{start:l,end:a}},typeof Element<"u"&&function(n){n.forEach(function(h){h.hasOwnProperty("remove")||Object.defineProperty(h,"remove",{configurable:!0,enumerable:!0,writable:!0,value:function(){this.parentNode!=null&&this.parentNode.removeChild(this)}})})}([Element.prototype,CharacterData.prototype,DocumentType.prototype]),String.prototype.startsWith||(String.prototype.startsWith=function(n,h){return h=h||0,this.substr(h,n.length)===n})},function(u,r,i){var s=function(){var o={trace:function(){},yy:{},symbols_:{error:2,JSONString:3,STRING:4,JSONNumber:5,NUMBER:6,JSONNullLiteral:7,NULL:8,JSONBooleanLiteral:9,TRUE:10,FALSE:11,JSONText:12,JSONValue:13,EOF:14,JSONObject:15,JSONArray:16,"{":17,"}":18,JSONMemberList:19,JSONMember:20,":":21,",":22,"[":23,"]":24,JSONElementList:25,$accept:0,$end:1},terminals_:{2:"error",4:"STRING",6:"NUMBER",8:"NULL",10:"TRUE",11:"FALSE",14:"EOF",17:"{",18:"}",21:":",22:",",23:"[",24:"]"},productions_:[0,[3,1],[5,1],[7,1],[9,1],[9,1],[12,2],[13,1],[13,1],[13,1],[13,1],[13,1],[13,1],[15,2],[15,3],[20,3],[19,1],[19,3],[16,2],[16,3],[25,1],[25,3]],performAction:function(h,g,d,l,c,a,F){var p=a.length-1;switch(c){case 1:this.$=h.replace(/\\(\\|")/g,"$1").replace(/\\n/g,`
`).replace(/\\r/g,"\r").replace(/\\t/g,"	").replace(/\\v/g,"\v").replace(/\\f/g,"\f").replace(/\\b/g,"\b");break;case 2:this.$=Number(h);break;case 3:this.$=null;break;case 4:this.$=!0;break;case 5:this.$=!1;break;case 6:return this.$=a[p-1];case 13:this.$={};break;case 14:this.$=a[p-1];break;case 15:this.$=[a[p-2],a[p]];break;case 16:this.$={},this.$[a[p][0]]=a[p][1];break;case 17:this.$=a[p-2],a[p-2][a[p][0]]=a[p][1];break;case 18:this.$=[];break;case 19:this.$=a[p-1];break;case 20:this.$=[a[p]];break;case 21:this.$=a[p-2],a[p-2].push(a[p]);break}},table:[{3:5,4:[1,12],5:6,6:[1,13],7:3,8:[1,9],9:4,10:[1,10],11:[1,11],12:1,13:2,15:7,16:8,17:[1,14],23:[1,15]},{1:[3]},{14:[1,16]},{14:[2,7],18:[2,7],22:[2,7],24:[2,7]},{14:[2,8],18:[2,8],22:[2,8],24:[2,8]},{14:[2,9],18:[2,9],22:[2,9],24:[2,9]},{14:[2,10],18:[2,10],22:[2,10],24:[2,10]},{14:[2,11],18:[2,11],22:[2,11],24:[2,11]},{14:[2,12],18:[2,12],22:[2,12],24:[2,12]},{14:[2,3],18:[2,3],22:[2,3],24:[2,3]},{14:[2,4],18:[2,4],22:[2,4],24:[2,4]},{14:[2,5],18:[2,5],22:[2,5],24:[2,5]},{14:[2,1],18:[2,1],21:[2,1],22:[2,1],24:[2,1]},{14:[2,2],18:[2,2],22:[2,2],24:[2,2]},{3:20,4:[1,12],18:[1,17],19:18,20:19},{3:5,4:[1,12],5:6,6:[1,13],7:3,8:[1,9],9:4,10:[1,10],11:[1,11],13:23,15:7,16:8,17:[1,14],23:[1,15],24:[1,21],25:22},{1:[2,6]},{14:[2,13],18:[2,13],22:[2,13],24:[2,13]},{18:[1,24],22:[1,25]},{18:[2,16],22:[2,16]},{21:[1,26]},{14:[2,18],18:[2,18],22:[2,18],24:[2,18]},{22:[1,28],24:[1,27]},{22:[2,20],24:[2,20]},{14:[2,14],18:[2,14],22:[2,14],24:[2,14]},{3:20,4:[1,12],20:29},{3:5,4:[1,12],5:6,6:[1,13],7:3,8:[1,9],9:4,10:[1,10],11:[1,11],13:30,15:7,16:8,17:[1,14],23:[1,15]},{14:[2,19],18:[2,19],22:[2,19],24:[2,19]},{3:5,4:[1,12],5:6,6:[1,13],7:3,8:[1,9],9:4,10:[1,10],11:[1,11],13:31,15:7,16:8,17:[1,14],23:[1,15]},{18:[2,17],22:[2,17]},{18:[2,15],22:[2,15]},{22:[2,21],24:[2,21]}],defaultActions:{16:[2,6]},parseError:function(h,g){throw new Error(h)},parse:function(h){var g=this,d=[0],l=[null],c=[],a=this.table,F="",p=0,m=0,b=0,C=2,k=1;this.lexer.setInput(h),this.lexer.yy=this.yy,this.yy.lexer=this.lexer,typeof this.lexer.yylloc>"u"&&(this.lexer.yylloc={});var T=this.lexer.yylloc;c.push(T),typeof this.yy.parseError=="function"&&(this.parseError=this.yy.parseError);function w(ce){d.length=d.length-2*ce,l.length=l.length-ce,c.length=c.length-ce}function A(){var ce;return ce=g.lexer.lex()||1,typeof ce!="number"&&(ce=g.symbols_[ce]||ce),ce}for(var M,x,R,N,j,B={},q,U,Z,re;;){if(R=d[d.length-1],this.defaultActions[R]?N=this.defaultActions[R]:(M==null&&(M=A()),N=a[R]&&a[R][M]),typeof N>"u"||!N.length||!N[0]){if(!b){re=[];for(q in a[R])this.terminals_[q]&&q>2&&re.push("'"+this.terminals_[q]+"'");var le="";this.lexer.showPosition?le="Parse error on line "+(p+1)+`:
`+this.lexer.showPosition()+`
Expecting `+re.join(", ")+", got '"+this.terminals_[M]+"'":le="Parse error on line "+(p+1)+": Unexpected "+(M==1?"end of input":"'"+(this.terminals_[M]||M)+"'"),this.parseError(le,{text:this.lexer.match,token:this.terminals_[M]||M,line:this.lexer.yylineno,loc:T,expected:re})}if(b==3){if(M==k)throw new Error(le||"Parsing halted.");m=this.lexer.yyleng,F=this.lexer.yytext,p=this.lexer.yylineno,T=this.lexer.yylloc,M=A()}for(;!(C.toString()in a[R]);){if(R==0)throw new Error(le||"Parsing halted.");w(1),R=d[d.length-1]}x=M,M=C,R=d[d.length-1],N=a[R]&&a[R][C],b=3}if(N[0]instanceof Array&&N.length>1)throw new Error("Parse Error: multiple actions possible at state: "+R+", token: "+M);switch(N[0]){case 1:d.push(M),l.push(this.lexer.yytext),c.push(this.lexer.yylloc),d.push(N[1]),M=null,x?(M=x,x=null):(m=this.lexer.yyleng,F=this.lexer.yytext,p=this.lexer.yylineno,T=this.lexer.yylloc,b>0&&b--);break;case 2:if(U=this.productions_[N[1]][1],B.$=l[l.length-U],B._$={first_line:c[c.length-(U||1)].first_line,last_line:c[c.length-1].last_line,first_column:c[c.length-(U||1)].first_column,last_column:c[c.length-1].last_column},j=this.performAction.call(B,F,m,p,this.yy,N[1],l,c),typeof j<"u")return j;U&&(d=d.slice(0,-1*U*2),l=l.slice(0,-1*U),c=c.slice(0,-1*U)),d.push(this.productions_[N[1]][0]),l.push(B.$),c.push(B._$),Z=a[d[d.length-2]][d[d.length-1]],d.push(Z);break;case 3:return!0}}return!0}},f=function(){var n={EOF:1,parseError:function(g,d){if(this.yy.parseError)this.yy.parseError(g,d);else throw new Error(g)},setInput:function(h){return this._input=h,this._more=this._less=this.done=!1,this.yylineno=this.yyleng=0,this.yytext=this.matched=this.match="",this.conditionStack=["INITIAL"],this.yylloc={first_line:1,first_column:0,last_line:1,last_column:0},this},input:function(){var h=this._input[0];this.yytext+=h,this.yyleng++,this.match+=h,this.matched+=h;var g=h.match(/\n/);return g&&this.yylineno++,this._input=this._input.slice(1),h},unput:function(h){return this._input=h+this._input,this},more:function(){return this._more=!0,this},less:function(h){this._input=this.match.slice(h)+this._input},pastInput:function(){var h=this.matched.substr(0,this.matched.length-this.match.length);return(h.length>20?"...":"")+h.substr(-20).replace(/\n/g,"")},upcomingInput:function(){var h=this.match;return h.length<20&&(h+=this._input.substr(0,20-h.length)),(h.substr(0,20)+(h.length>20?"...":"")).replace(/\n/g,"")},showPosition:function(){var h=this.pastInput(),g=new Array(h.length+1).join("-");return h+this.upcomingInput()+`
`+g+"^"},next:function(){if(this.done)return this.EOF;this._input||(this.done=!0);var h,g,d,l,c;this._more||(this.yytext="",this.match="");for(var a=this._currentRules(),F=0;F<a.length&&(d=this._input.match(this.rules[a[F]]),!(d&&(!g||d[0].length>g[0].length)&&(g=d,l=F,!this.options.flex)));F++);if(g)return c=g[0].match(/\n.*/g),c&&(this.yylineno+=c.length),this.yylloc={first_line:this.yylloc.last_line,last_line:this.yylineno+1,first_column:this.yylloc.last_column,last_column:c?c[c.length-1].length-1:this.yylloc.last_column+g[0].length},this.yytext+=g[0],this.match+=g[0],this.yyleng=this.yytext.length,this._more=!1,this._input=this._input.slice(g[0].length),this.matched+=g[0],h=this.performAction.call(this,this.yy,this,a[l],this.conditionStack[this.conditionStack.length-1]),this.done&&this._input&&(this.done=!1),h||void 0;if(this._input==="")return this.EOF;this.parseError("Lexical error on line "+(this.yylineno+1)+`. Unrecognized text.
`+this.showPosition(),{text:"",token:null,line:this.yylineno})},lex:function(){var g=this.next();return typeof g<"u"?g:this.lex()},begin:function(g){this.conditionStack.push(g)},popState:function(){return this.conditionStack.pop()},_currentRules:function(){return this.conditions[this.conditionStack[this.conditionStack.length-1]].rules},topState:function(){return this.conditionStack[this.conditionStack.length-2]},pushState:function(g){this.begin(g)}};return n.options={},n.performAction=function(g,d,l,c){switch(l){case 0:break;case 1:return 6;case 2:return d.yytext=d.yytext.substr(1,d.yyleng-2),4;case 3:return 17;case 4:return 18;case 5:return 23;case 6:return 24;case 7:return 22;case 8:return 21;case 9:return 10;case 10:return 11;case 11:return 8;case 12:return 14;case 13:return"INVALID"}},n.rules=[/^(?:\s+)/,/^(?:(-?([0-9]|[1-9][0-9]+))(\.[0-9]+)?([eE][-+]?[0-9]+)?\b)/,/^(?:"(?:\\[\\"bfnrt/]|\\u[a-fA-F0-9]{4}|[^\\\0-\x09\x0a-\x1f"])*")/,/^(?:\{)/,/^(?:\})/,/^(?:\[)/,/^(?:\])/,/^(?:,)/,/^(?::)/,/^(?:true\b)/,/^(?:false\b)/,/^(?:null\b)/,/^(?:$)/,/^(?:.)/],n.conditions={INITIAL:{rules:[0,1,2,3,4,5,6,7,8,9,10,11,12,13],inclusive:!0}},n}();return o.lexer=f,o}();r.parser=s,r.parse=s.parse.bind(s)},function(u,r){function i(s,o){var f=this;this.editor=s,this.timeout=void 0,this.delay=200,this.lastText=void 0,this.dom={},this.dom.container=o;var n=document.createElement("table");this.dom.table=n,n.className="jsoneditor-search",o.appendChild(n);var h=document.createElement("tbody");this.dom.tbody=h,n.appendChild(h);var g=document.createElement("tr");h.appendChild(g);var d=document.createElement("td");g.appendChild(d);var l=document.createElement("div");this.dom.results=l,l.className="jsoneditor-results",d.appendChild(l),d=document.createElement("td"),g.appendChild(d);var c=document.createElement("div");this.dom.input=c,c.className="jsoneditor-frame",c.title="Search fields and values",d.appendChild(c);var a=document.createElement("table");c.appendChild(a);var F=document.createElement("tbody");a.appendChild(F),g=document.createElement("tr"),F.appendChild(g);var p=document.createElement("button");p.type="button",p.className="jsoneditor-refresh",d=document.createElement("td"),d.appendChild(p),g.appendChild(d);var m=document.createElement("input");this.dom.search=m,m.oninput=function(k){f._onDelayedSearch(k)},m.onchange=function(k){f._onSearch()},m.onkeydown=function(k){f._onKeyDown(k)},m.onkeyup=function(k){f._onKeyUp(k)},p.onclick=function(k){m.select()},d=document.createElement("td"),d.appendChild(m),g.appendChild(d);var b=document.createElement("button");b.type="button",b.title="Next result (Enter)",b.className="jsoneditor-next",b.onclick=function(){f.next()},d=document.createElement("td"),d.appendChild(b),g.appendChild(d);var C=document.createElement("button");C.type="button",C.title="Previous result (Shift+Enter)",C.className="jsoneditor-previous",C.onclick=function(){f.previous()},d=document.createElement("td"),d.appendChild(C),g.appendChild(d)}i.prototype.next=function(s){if(this.results!=null){var o=this.resultIndex!=null?this.resultIndex+1:0;o>this.results.length-1&&(o=0),this._setActiveResult(o,s)}},i.prototype.previous=function(s){if(this.results!=null){var o=this.results.length-1,f=this.resultIndex!=null?this.resultIndex-1:o;f<0&&(f=o),this._setActiveResult(f,s)}},i.prototype._setActiveResult=function(s,o){if(this.activeResult){var f=this.activeResult.node,n=this.activeResult.elem;n=="field"?delete f.searchFieldActive:delete f.searchValueActive,f.updateDom()}if(!this.results||!this.results[s]){this.resultIndex=void 0,this.activeResult=void 0;return}this.resultIndex=s;var h=this.results[this.resultIndex].node,g=this.results[this.resultIndex].elem;g=="field"?h.searchFieldActive=!0:h.searchValueActive=!0,this.activeResult=this.results[this.resultIndex],h.updateDom(),h.scrollTo(function(){o&&h.focus(g)})},i.prototype._clearDelay=function(){this.timeout!=null&&(clearTimeout(this.timeout),delete this.timeout)},i.prototype._onDelayedSearch=function(s){this._clearDelay();var o=this;this.timeout=setTimeout(function(f){o._onSearch()},this.delay)},i.prototype._onSearch=function(s){this._clearDelay();var o=this.dom.search.value,f=o.length>0?o:void 0;if(f!=this.lastText||s)if(this.lastText=f,this.results=this.editor.search(f),this._setActiveResult(void 0),f!=null){var n=this.results.length;switch(n){case 0:this.dom.results.innerHTML="no&nbsp;results";break;case 1:this.dom.results.innerHTML="1&nbsp;result";break;default:this.dom.results.innerHTML=n+"&nbsp;results";break}}else this.dom.results.innerHTML=""},i.prototype._onKeyDown=function(s){var o=s.which;o==27?(this.dom.search.value="",this._onSearch(),s.preventDefault(),s.stopPropagation()):o==13&&(s.ctrlKey?this._onSearch(!0):s.shiftKey?this.previous():this.next(),s.preventDefault(),s.stopPropagation())},i.prototype._onKeyUp=function(s){var o=s.keyCode;o!=27&&o!=13&&this._onDelayedSearch(s)},i.prototype.clear=function(){this.dom.search.value="",this._onSearch()},i.prototype.destroy=function(){this.editor=null,this.dom.container.removeChild(this.dom.table),this.dom=null,this.results=null,this.activeResult=null,this._clearDelay()},u.exports=i},function(u,r,i){var s=i(57);function o(n){return n.getRootNode&&n.getRootNode()||window}function f(n,h){this.dom={};var g=this,d=this.dom;this.anchor=void 0,this.items=n,this.eventListeners={},this.selection=void 0,this.onClose=h?h.close:void 0;var l=document.createElement("div");l.className="jsoneditor-contextmenu-root",d.root=l;var c=document.createElement("div");c.className="jsoneditor-contextmenu",d.menu=c,l.appendChild(c);var a=document.createElement("ul");a.className="jsoneditor-menu",c.appendChild(a),d.list=a,d.items=[];var F=document.createElement("button");F.type="button",d.focusButton=F;var p=document.createElement("li");p.style.overflow="hidden",p.style.height="0",p.appendChild(F),a.appendChild(p);function m(b,C,k){k.forEach(function(T){if(T.type=="separator"){var w=document.createElement("div");w.className="jsoneditor-separator",M=document.createElement("li"),M.appendChild(w),b.appendChild(M)}else{var A={},M=document.createElement("li");b.appendChild(M);var x=document.createElement("button");if(x.type="button",x.className=T.className,A.button=x,T.title&&(x.title=T.title),T.click&&(x.onclick=function(re){re.preventDefault(),g.hide(),T.click()}),M.appendChild(x),T.submenu){var R=document.createElement("div");R.className="jsoneditor-icon",x.appendChild(R);var N=document.createElement("div");N.className="jsoneditor-text"+(T.click?"":" jsoneditor-right-margin"),N.appendChild(document.createTextNode(T.text)),x.appendChild(N);var j;if(T.click){x.className+=" jsoneditor-default";var B=document.createElement("button");B.type="button",A.buttonExpand=B,B.className="jsoneditor-expand",B.innerHTML='<div class="jsoneditor-expand"></div>',M.appendChild(B),T.submenuTitle&&(B.title=T.submenuTitle),j=B}else{var q=document.createElement("div");q.className="jsoneditor-expand",x.appendChild(q),j=x}j.onclick=function(re){re.preventDefault(),g._onExpandItem(A),j.focus()};var U=[];A.subItems=U;var Z=document.createElement("ul");A.ul=Z,Z.className="jsoneditor-menu",Z.style.height="0",M.appendChild(Z),m(Z,U,T.submenu)}else x.innerHTML='<div class="jsoneditor-icon"></div><div class="jsoneditor-text">'+T.text+"</div>";C.push(A)}})}m(a,this.dom.items,n),this.maxHeight=0,n.forEach(function(b){var C=(n.length+(b.submenu?b.submenu.length:0))*24;g.maxHeight=Math.max(g.maxHeight,C)})}f.prototype._getVisibleButtons=function(){var n=[],h=this;return this.dom.items.forEach(function(g){n.push(g.button),g.buttonExpand&&n.push(g.buttonExpand),g.subItems&&g==h.expandedItem&&g.subItems.forEach(function(d){n.push(d.button),d.buttonExpand&&n.push(d.buttonExpand)})}),n},f.visibleMenu=void 0,f.prototype.show=function(n,h){this.hide();var g=!0;if(h){var d=n.getBoundingClientRect(),l=h.getBoundingClientRect();d.bottom+this.maxHeight<l.bottom||d.top-this.maxHeight>l.top&&(g=!1)}if(g){var c=n.offsetHeight;this.dom.menu.style.left="0px",this.dom.menu.style.top=c+"px",this.dom.menu.style.bottom=""}else this.dom.menu.style.left="0px",this.dom.menu.style.top="",this.dom.menu.style.bottom="0px";this.rootNode=o(n);var a=n.parentNode;a.insertBefore(this.dom.root,a.firstChild);var F=this,p=this.dom.list;this.eventListeners.mousedown=s.addEventListener(this.rootNode,"mousedown",function(m){var b=m.target;b!=p&&!F._isChildOf(b,p)&&(F.hide(),m.stopPropagation(),m.preventDefault())}),this.eventListeners.keydown=s.addEventListener(this.rootNode,"keydown",function(m){F._onKeyDown(m)}),this.selection=s.getSelection(),this.anchor=n,setTimeout(function(){F.dom.focusButton.focus()},0),f.visibleMenu&&f.visibleMenu.hide(),f.visibleMenu=this},f.prototype.hide=function(){this.dom.root.parentNode&&(this.dom.root.parentNode.removeChild(this.dom.root),this.onClose&&this.onClose());for(var n in this.eventListeners)if(this.eventListeners.hasOwnProperty(n)){var h=this.eventListeners[n];h&&s.removeEventListener(this.rootNode,n,h),delete this.eventListeners[n]}f.visibleMenu==this&&(f.visibleMenu=void 0)},f.prototype._onExpandItem=function(n){var h=this,g=n==this.expandedItem,d=this.expandedItem;if(d&&(d.ul.style.height="0",d.ul.style.padding="",setTimeout(function(){h.expandedItem!=d&&(d.ul.style.display="",s.removeClassName(d.ul.parentNode,"jsoneditor-selected"))},300),this.expandedItem=void 0),!g){var l=n.ul;l.style.display="block",l.clientHeight,setTimeout(function(){if(h.expandedItem==n){for(var c=0,a=0;a<l.childNodes.length;a++)c+=l.childNodes[a].clientHeight;l.style.height=c+"px",l.style.padding="5px 10px"}},0),s.addClassName(l.parentNode,"jsoneditor-selected"),this.expandedItem=n}},f.prototype._onKeyDown=function(n){var h=n.target,g=n.which,d=!1,l,c,a,F;g==27?(this.selection&&s.setSelection(this.selection),this.anchor&&this.anchor.focus(),this.hide(),d=!0):g==9?n.shiftKey?(l=this._getVisibleButtons(),c=l.indexOf(h),c==0&&(l[l.length-1].focus(),d=!0)):(l=this._getVisibleButtons(),c=l.indexOf(h),c==l.length-1&&(l[0].focus(),d=!0)):g==37?(h.className=="jsoneditor-expand"&&(l=this._getVisibleButtons(),c=l.indexOf(h),a=l[c-1],a&&a.focus()),d=!0):g==38?(l=this._getVisibleButtons(),c=l.indexOf(h),a=l[c-1],a&&a.className=="jsoneditor-expand"&&(a=l[c-2]),a||(a=l[l.length-1]),a&&a.focus(),d=!0):g==39?(l=this._getVisibleButtons(),c=l.indexOf(h),F=l[c+1],F&&F.className=="jsoneditor-expand"&&F.focus(),d=!0):g==40&&(l=this._getVisibleButtons(),c=l.indexOf(h),F=l[c+1],F&&F.className=="jsoneditor-expand"&&(F=l[c+2]),F||(F=l[0]),F&&(F.focus(),d=!0),d=!0),d&&(n.stopPropagation(),n.preventDefault())},f.prototype._isChildOf=function(n,h){for(var g=n.parentNode;g;){if(g==h)return!0;g=g.parentNode}return!1},u.exports=f},function(u,r,i){var s=i(62),o=i(60),f=i(63),n=i(57);function h(d,l){this.editor=d,this.dom={},this.expanded=!1,l&&l instanceof Object?(this.setField(l.field,l.fieldEditable),this.setValue(l.value,l.type)):(this.setField(""),this.setValue(null)),this._debouncedOnChangeValue=n.debounce(this._onChangeValue.bind(this),h.prototype.DEBOUNCE_INTERVAL),this._debouncedOnChangeField=n.debounce(this._onChangeField.bind(this),h.prototype.DEBOUNCE_INTERVAL)}h.prototype.DEBOUNCE_INTERVAL=150,h.prototype._updateEditability=function(){if(this.editable={field:!0,value:!0},this.editor&&(this.editable.field=this.editor.options.mode==="tree",this.editable.value=this.editor.options.mode!=="view",(this.editor.options.mode==="tree"||this.editor.options.mode==="form")&&typeof this.editor.options.onEditable=="function")){var d=this.editor.options.onEditable({field:this.field,value:this.value,path:this.getPath()});typeof d=="boolean"?(this.editable.field=d,this.editable.value=d):(typeof d.field=="boolean"&&(this.editable.field=d.field),typeof d.value=="boolean"&&(this.editable.value=d.value))}},h.prototype.getPath=function(){for(var d=this,l=[];d;){var c=d.parent?d.parent.type!="array"?d.field:d.index:void 0;c!==void 0&&l.unshift(c),d=d.parent}return l},h.prototype.findNode=function(d){for(var l=n.parsePath(d),c=this;c&&l.length>0;){var a=l.shift();if(typeof a=="number"){if(c.type!=="array")throw new Error("Cannot get child node at index "+a+": node is no array");c=c.childs[a]}else{if(c.type!=="object")throw new Error("Cannot get child node "+a+": node is no object");c=c.childs.filter(function(F){return F.field===a})[0]}}return c},h.prototype.findParents=function(){for(var d=[],l=this.parent;l;)d.unshift(l),l=l.parent;return d},h.prototype.setError=function(d,l){this.getDom(),this.error=d;var c=this.dom.tdError;if(d){c||(c=document.createElement("td"),this.dom.tdError=c,this.dom.tdValue.parentNode.appendChild(c));var a=document.createElement("div");a.className="jsoneditor-popover jsoneditor-right",a.appendChild(document.createTextNode(d.message));var F=document.createElement("button");for(F.type="button",F.className="jsoneditor-schema-error",F.appendChild(a),F.onmouseover=F.onfocus=function(){for(var m=["right","above","below","left"],b=0;b<m.length;b++){var C=m[b];a.className="jsoneditor-popover jsoneditor-"+C;var k=this.editor.content.getBoundingClientRect(),T=a.getBoundingClientRect(),w=20,A=n.insideRect(k,T,w);if(A)break}}.bind(this),l&&(F.onclick=function(){l.findParents().forEach(function(m){m.expand(!1)}),l.scrollTo(function(){l.focus()})});c.firstChild;)c.removeChild(c.firstChild);c.appendChild(F)}else c&&(this.dom.tdError.parentNode.removeChild(this.dom.tdError),delete this.dom.tdError)},h.prototype.getIndex=function(){return this.parent?this.parent.childs.indexOf(this):-1},h.prototype.setParent=function(d){this.parent=d},h.prototype.setField=function(d,l){this.field=d,this.previousField=d,this.fieldEditable=l===!0},h.prototype.getField=function(){return this.field===void 0&&this._getDomField(),this.field},h.prototype.setValue=function(d,l){var c,a,F=this.childs;if(F)for(;F.length;)this.removeChild(F[0]);if(this.type=this._getType(d),l&&l!=this.type)if(l=="string"&&this.type=="auto")this.type=l;else throw new Error('Type mismatch: cannot cast value of type "'+this.type+' to the specified type "'+l+'"');if(this.type=="array"){this.childs=[];for(var p=0,m=d.length;p<m;p++)c=d[p],c!==void 0&&!(c instanceof Function)&&(a=new h(this.editor,{value:c}),this.appendChild(a));this.value=""}else if(this.type=="object"){this.childs=[];for(var b in d)d.hasOwnProperty(b)&&(c=d[b],c!==void 0&&!(c instanceof Function)&&(a=new h(this.editor,{field:b,value:c}),this.appendChild(a)));this.value="",this.editor.options.sortObjectKeys===!0&&this.sort("asc")}else this.childs=void 0,this.value=d;this.previousValue=this.value},h.prototype.getValue=function(){if(this.type=="array"){var d=[];return this.childs.forEach(function(c){d.push(c.getValue())}),d}else if(this.type=="object"){var l={};return this.childs.forEach(function(c){l[c.getField()]=c.getValue()}),l}else return this.value===void 0&&this._getDomValue(),this.value},h.prototype.getLevel=function(){return this.parent?this.parent.getLevel()+1:0},h.prototype.getNodePath=function(){var d=this.parent?this.parent.getNodePath():[];return d.push(this),d},h.prototype.clone=function(){var d=new h(this.editor);if(d.type=this.type,d.field=this.field,d.fieldInnerText=this.fieldInnerText,d.fieldEditable=this.fieldEditable,d.value=this.value,d.valueInnerText=this.valueInnerText,d.expanded=this.expanded,this.childs){var l=[];this.childs.forEach(function(c){var a=c.clone();a.setParent(d),l.push(a)}),d.childs=l}else d.childs=void 0;return d},h.prototype.expand=function(d){this.childs&&(this.expanded=!0,this.dom.expand&&(this.dom.expand.className="jsoneditor-expanded"),this.showChilds(),d!==!1&&this.childs.forEach(function(l){l.expand(d)}))},h.prototype.collapse=function(d){this.childs&&(this.hideChilds(),d!==!1&&this.childs.forEach(function(l){l.collapse(d)}),this.dom.expand&&(this.dom.expand.className="jsoneditor-collapsed"),this.expanded=!1)},h.prototype.showChilds=function(){var d=this.childs;if(d&&this.expanded){var l=this.dom.tr,c=l?l.parentNode:void 0;if(c){var a=this.getAppend(),F=l.nextSibling;F?c.insertBefore(a,F):c.appendChild(a),this.childs.forEach(function(p){c.insertBefore(p.getDom(),a),p.showChilds()})}}},h.prototype.hide=function(){var d=this.dom.tr,l=d?d.parentNode:void 0;l&&l.removeChild(d),this.hideChilds()},h.prototype.hideChilds=function(){var d=this.childs;if(d&&this.expanded){var l=this.getAppend();l.parentNode&&l.parentNode.removeChild(l),this.childs.forEach(function(c){c.hide()})}},h.prototype.appendChild=function(d){if(this._hasChilds()){if(d.setParent(this),d.fieldEditable=this.type=="object",this.type=="array"&&(d.index=this.childs.length),this.childs.push(d),this.expanded){var l=d.getDom(),c=this.getAppend(),a=c?c.parentNode:void 0;c&&a&&a.insertBefore(l,c),d.showChilds()}this.updateDom({updateIndexes:!0}),d.updateDom({recurse:!0})}},h.prototype.moveBefore=function(d,l){if(this._hasChilds()){var c=this.dom.tr?this.dom.tr.parentNode:void 0;if(c){var a=document.createElement("tr");a.style.height=c.clientHeight+"px",c.appendChild(a)}d.parent&&d.parent.removeChild(d),l instanceof g?this.appendChild(d):this.insertBefore(d,l),c&&c.removeChild(a)}},h.prototype.moveTo=function(d,l){if(d.parent==this){var c=this.childs.indexOf(d);c<l&&l++}var a=this.childs[l]||this.append;this.moveBefore(d,a)},h.prototype.insertBefore=function(d,l){if(this._hasChilds()){if(l==this.append)d.setParent(this),d.fieldEditable=this.type=="object",this.childs.push(d);else{var c=this.childs.indexOf(l);if(c==-1)throw new Error("Node not found");d.setParent(this),d.fieldEditable=this.type=="object",this.childs.splice(c,0,d)}if(this.expanded){var a=d.getDom(),F=l.getDom(),p=F?F.parentNode:void 0;F&&p&&p.insertBefore(a,F),d.showChilds()}this.updateDom({updateIndexes:!0}),d.updateDom({recurse:!0})}},h.prototype.insertAfter=function(d,l){if(this._hasChilds()){var c=this.childs.indexOf(l),a=this.childs[c+1];a?this.insertBefore(d,a):this.appendChild(d)}},h.prototype.search=function(d){var l=[],c,a=d?d.toLowerCase():void 0;if(delete this.searchField,delete this.searchValue,this.field!=null){var F=String(this.field).toLowerCase();c=F.indexOf(a),c!=-1&&(this.searchField=!0,l.push({node:this,elem:"field"})),this._updateDomField()}if(this._hasChilds()){if(this.childs){var p=[];this.childs.forEach(function(C){p=p.concat(C.search(d))}),l=l.concat(p)}if(a!=null){var m=!1;p.length==0?this.collapse(m):this.expand(m)}}else{if(this.value!=null){var b=String(this.value).toLowerCase();c=b.indexOf(a),c!=-1&&(this.searchValue=!0,l.push({node:this,elem:"value"}))}this._updateDomValue()}return l},h.prototype.scrollTo=function(d){if(!this.dom.tr||!this.dom.tr.parentNode)for(var l=this.parent,c=!1;l;)l.expand(c),l=l.parent;this.dom.tr&&this.dom.tr.parentNode&&this.editor.scrollTo(this.dom.tr.offsetTop,d)},h.focusElement=void 0,h.prototype.focus=function(d){if(h.focusElement=d,this.dom.tr&&this.dom.tr.parentNode){var l=this.dom;switch(d){case"drag":l.drag?l.drag.focus():l.menu.focus();break;case"menu":l.menu.focus();break;case"expand":this._hasChilds()?l.expand.focus():l.field&&this.fieldEditable?(l.field.focus(),n.selectContentEditable(l.field)):l.value&&!this._hasChilds()?(l.value.focus(),n.selectContentEditable(l.value)):l.menu.focus();break;case"field":l.field&&this.fieldEditable?(l.field.focus(),n.selectContentEditable(l.field)):l.value&&!this._hasChilds()?(l.value.focus(),n.selectContentEditable(l.value)):this._hasChilds()?l.expand.focus():l.menu.focus();break;case"value":default:l.select?l.select.focus():l.value&&!this._hasChilds()?(l.value.focus(),n.selectContentEditable(l.value)):l.field&&this.fieldEditable?(l.field.focus(),n.selectContentEditable(l.field)):this._hasChilds()?l.expand.focus():l.menu.focus();break}}},h.select=function(d){setTimeout(function(){n.selectContentEditable(d)},0)},h.prototype.blur=function(){this._getDomValue(!1),this._getDomField(!1)},h.prototype.containsNode=function(d){if(this==d)return!0;var l=this.childs;if(l){for(var c=0,a=l.length;c<a;c++)if(l[c].containsNode(d))return!0}return!1},h.prototype._move=function(d,l){if(d!=l){if(d.containsNode(this))throw new Error("Cannot move a field into a child of itself");d.parent&&d.parent.removeChild(d);var c=d.clone();d.clearDom(),l?this.insertBefore(c,l):this.appendChild(c)}},h.prototype.removeChild=function(d){if(this.childs){var l=this.childs.indexOf(d);if(l!=-1){d.hide(),delete d.searchField,delete d.searchValue;var c=this.childs.splice(l,1)[0];return c.parent=null,this.updateDom({updateIndexes:!0}),c}}},h.prototype._remove=function(d){this.removeChild(d)},h.prototype.changeType=function(d){var l=this.type;if(l!=d){if((d=="string"||d=="auto")&&(l=="string"||l=="auto"))this.type=d;else{var c=this.dom.tr?this.dom.tr.parentNode:void 0,a;this.expanded?a=this.getAppend():a=this.getDom();var F=a&&a.parentNode?a.nextSibling:void 0;this.hide(),this.clearDom(),this.type=d,d=="object"?(this.childs||(this.childs=[]),this.childs.forEach(function(p,m){p.clearDom(),delete p.index,p.fieldEditable=!0,p.field==null&&(p.field="")}),(l=="string"||l=="auto")&&(this.expanded=!0)):d=="array"?(this.childs||(this.childs=[]),this.childs.forEach(function(p,m){p.clearDom(),p.fieldEditable=!1,p.index=m}),(l=="string"||l=="auto")&&(this.expanded=!0)):this.expanded=!1,c&&(F?c.insertBefore(this.getDom(),F):c.appendChild(this.getDom())),this.showChilds()}(d=="auto"||d=="string")&&(d=="string"?this.value=String(this.value):this.value=this._stringCast(String(this.value)),this.focus()),this.updateDom({updateIndexes:!0})}},h.prototype._getDomValue=function(d){if(this.dom.value&&this.type!="array"&&this.type!="object"&&(this.valueInnerText=n.getInnerText(this.dom.value)),this.valueInnerText!=null)try{var l;if(this.type=="string")l=this._unescapeHTML(this.valueInnerText);else{var c=this._unescapeHTML(this.valueInnerText);l=this._stringCast(c)}l!==this.value&&(this.value=l,this._debouncedOnChangeValue())}catch(a){if(this.value=void 0,d!==!0)throw a}},h.prototype._onChangeValue=function(){var d=this.editor.getSelection();if(d.range){var l=n.textDiff(String(this.value),String(this.previousValue));d.range.startOffset=l.start,d.range.endOffset=l.end}var c=this.editor.getSelection();if(c.range){var a=n.textDiff(String(this.previousValue),String(this.value));c.range.startOffset=a.start,c.range.endOffset=a.end}this.editor._onAction("editValue",{node:this,oldValue:this.previousValue,newValue:this.value,oldSelection:d,newSelection:c}),this.previousValue=this.value},h.prototype._onChangeField=function(){var d=this.editor.getSelection();if(d.range){var l=n.textDiff(this.field,this.previousField);d.range.startOffset=l.start,d.range.endOffset=l.end}var c=this.editor.getSelection();if(c.range){var a=n.textDiff(this.previousField,this.field);c.range.startOffset=a.start,c.range.endOffset=a.end}this.editor._onAction("editField",{node:this,oldValue:this.previousField,newValue:this.field,oldSelection:d,newSelection:c}),this.previousField=this.field},h.prototype._updateDomValue=function(){var d=this.dom.value;if(d){var l=["jsoneditor-value"],c=this.value,a=this.type=="auto"?n.type(c):this.type,F=a=="string"&&n.isUrl(c);l.push("jsoneditor-"+a),F&&l.push("jsoneditor-url");var p=String(this.value)==""&&this.type!="array"&&this.type!="object";if(p&&l.push("jsoneditor-empty"),this.searchValueActive&&l.push("jsoneditor-highlight-active"),this.searchValue&&l.push("jsoneditor-highlight"),d.className=l.join(" "),a=="array"||a=="object"){var m=this.childs?this.childs.length:0;d.title=this.type+" containing "+m+" items"}else F&&this.editable.value?d.title="Ctrl+Click or Ctrl+Enter to open url in new window":d.title="";if(a==="boolean"&&this.editable.value?(this.dom.checkbox||(this.dom.checkbox=document.createElement("input"),this.dom.checkbox.type="checkbox",this.dom.tdCheckbox=document.createElement("td"),this.dom.tdCheckbox.className="jsoneditor-tree",this.dom.tdCheckbox.appendChild(this.dom.checkbox),this.dom.tdValue.parentNode.insertBefore(this.dom.tdCheckbox,this.dom.tdValue)),this.dom.checkbox.checked=this.value):this.dom.tdCheckbox&&(this.dom.tdCheckbox.parentNode.removeChild(this.dom.tdCheckbox),delete this.dom.tdCheckbox,delete this.dom.checkbox),this.enum&&this.editable.value){if(!this.dom.select){this.dom.select=document.createElement("select"),this.id=this.field+"_"+new Date().getUTCMilliseconds(),this.dom.select.id=this.id,this.dom.select.name=this.dom.select.id,this.dom.select.option=document.createElement("option"),this.dom.select.option.value="",this.dom.select.option.innerHTML="--",this.dom.select.appendChild(this.dom.select.option);for(var b=0;b<this.enum.length;b++)this.dom.select.option=document.createElement("option"),this.dom.select.option.value=this.enum[b],this.dom.select.option.innerHTML=this.enum[b],this.dom.select.option.value==this.value&&(this.dom.select.option.selected=!0),this.dom.select.appendChild(this.dom.select.option);this.dom.tdSelect=document.createElement("td"),this.dom.tdSelect.className="jsoneditor-tree",this.dom.tdSelect.appendChild(this.dom.select),this.dom.tdValue.parentNode.insertBefore(this.dom.tdSelect,this.dom.tdValue)}this.schema&&!this.schema.hasOwnProperty("oneOf")&&!this.schema.hasOwnProperty("anyOf")&&!this.schema.hasOwnProperty("allOf")?(this.valueFieldHTML=this.dom.tdValue.innerHTML,this.dom.tdValue.style.visibility="hidden",this.dom.tdValue.innerHTML=""):delete this.valueFieldHTML}else this.dom.tdSelect&&(this.dom.tdSelect.parentNode.removeChild(this.dom.tdSelect),delete this.dom.tdSelect,delete this.dom.select,this.dom.tdValue.innerHTML=this.valueFieldHTML,this.dom.tdValue.style.visibility="",delete this.valueFieldHTML);n.stripFormatting(d)}},h.prototype._updateDomField=function(){var d=this.dom.field;if(d){var l=String(this.field)==""&&this.parent.type!="array";l?n.addClassName(d,"jsoneditor-empty"):n.removeClassName(d,"jsoneditor-empty"),this.searchFieldActive?n.addClassName(d,"jsoneditor-highlight-active"):n.removeClassName(d,"jsoneditor-highlight-active"),this.searchField?n.addClassName(d,"jsoneditor-highlight"):n.removeClassName(d,"jsoneditor-highlight"),n.stripFormatting(d)}},h.prototype._getDomField=function(d){if(this.dom.field&&this.fieldEditable&&(this.fieldInnerText=n.getInnerText(this.dom.field)),this.fieldInnerText!=null)try{var l=this._unescapeHTML(this.fieldInnerText);l!==this.field&&(this.field=l,this._debouncedOnChangeField())}catch(c){if(this.field=void 0,d!==!0)throw c}},h.prototype.validate=function(){var d=[];if(this.type==="object"){for(var l={},c=[],a=0;a<this.childs.length;a++){var F=this.childs[a];l.hasOwnProperty(F.field)&&c.push(F.field),l[F.field]=!0}c.length>0&&(d=this.childs.filter(function(m){return c.indexOf(m.field)!==-1}).map(function(m){return{node:m,error:{message:'duplicate key "'+m.field+'"'}}}))}if(this.childs)for(var a=0;a<this.childs.length;a++){var p=this.childs[a].validate();p.length>0&&(d=d.concat(p))}return d},h.prototype.clearDom=function(){this.dom={}},h.prototype.getDom=function(){var d=this.dom;if(d.tr)return d.tr;if(this._updateEditability(),d.tr=document.createElement("tr"),d.tr.node=this,this.editor.options.mode==="tree"){var l=document.createElement("td");if(this.editable.field&&this.parent){var c=document.createElement("button");c.type="button",d.drag=c,c.className="jsoneditor-dragarea",c.title="Drag to move this field (Alt+Shift+Arrows)",l.appendChild(c)}d.tr.appendChild(l);var a=document.createElement("td"),F=document.createElement("button");F.type="button",d.menu=F,F.className="jsoneditor-contextmenu",F.title="Click to open the actions menu (Ctrl+M)",a.appendChild(d.menu),d.tr.appendChild(a)}var p=document.createElement("td");return d.tr.appendChild(p),d.tree=this._createDomTree(),p.appendChild(d.tree),this.updateDom({updateIndexes:!0}),d.tr},h.onDragStart=function(d,l){if(!Array.isArray(d))return h.onDragStart([d],l);if(d.length!==0){var c=d[0],a=d[d.length-1],F=h.getNodeFromTarget(l.target),p=a._nextSibling(),m=c.editor,b=n.getAbsoluteTop(F.dom.tr)-n.getAbsoluteTop(c.dom.tr);m.mousemove||(m.mousemove=n.addEventListener(window,"mousemove",function(C){h.onDrag(d,C)})),m.mouseup||(m.mouseup=n.addEventListener(window,"mouseup",function(C){h.onDragEnd(d,C)})),m.highlighter.lock(),m.drag={oldCursor:document.body.style.cursor,oldSelection:m.getSelection(),oldBeforeNode:p,mouseX:l.pageX,offsetY:b,level:c.getLevel()},document.body.style.cursor="move",l.preventDefault()}},h.onDrag=function(d,l){if(!Array.isArray(d))return h.onDrag([d],l);if(d.length!==0){var c=d[0].editor,a=l.pageY-c.drag.offsetY,F=l.pageX,p,m,b,C,k,T,w,A,M,x,R,N,j,B,q=!1,U=d[0];if(p=U.dom.tr,M=n.getAbsoluteTop(p),N=p.offsetHeight,a<M){m=p;do m=m.previousSibling,w=h.getNodeFromTarget(m),x=m?n.getAbsoluteTop(m):0;while(m&&a<x);w&&!w.parent&&(w=void 0),w||(T=p.parentNode.firstChild,m=T?T.nextSibling:void 0,w=h.getNodeFromTarget(m),w==U&&(w=void 0)),w&&(m=w.dom.tr,x=m?n.getAbsoluteTop(m):0,a>x+N&&(w=void 0)),w&&(d.forEach(function(ge){w.parent.moveBefore(ge,w)}),q=!0)}else{var Z=d[d.length-1];if(k=Z.expanded&&Z.append?Z.append.getDom():Z.dom.tr,C=k?k.nextSibling:void 0,C){R=n.getAbsoluteTop(C),b=C;do A=h.getNodeFromTarget(b),b&&(j=b.nextSibling?n.getAbsoluteTop(b.nextSibling):0,B=b?j-R:0,A.parent.childs.length==d.length&&A.parent.childs[d.length-1]==Z&&(M+=27)),b=b.nextSibling;while(b&&a>M+B);if(A&&A.parent){var re=F-c.drag.mouseX,le=Math.round(re/24/2),ce=c.drag.level+le,de=A.getLevel();for(m=A.dom.tr.previousSibling;de<ce&&m;){w=h.getNodeFromTarget(m);var he=d.some(function(ge){return ge===w||w._isChildOf(ge)});if(!he)if(w instanceof g){var Fe=w.parent.childs;if(Fe.length!=d.length||Fe[d.length-1]!=Z)A=h.getNodeFromTarget(m),de=A.getLevel();else break}else break;m=m.previousSibling}k.nextSibling!=A.dom.tr&&(d.forEach(function(ge){A.parent.moveBefore(ge,A)}),q=!0)}}}q&&(c.drag.mouseX=F,c.drag.level=U.getLevel()),c.startAutoScroll(a),l.preventDefault()}},h.onDragEnd=function(d,l){if(!Array.isArray(d))return h.onDrag([d],l);if(d.length!==0){var c=d[0],a=c.editor,F=c.parent,p=F.childs.indexOf(c),m=F.childs[p+d.length]||F.append;d[0]&&d[0].dom.menu.focus();var b={nodes:d,oldSelection:a.drag.oldSelection,newSelection:a.getSelection(),oldBeforeNode:a.drag.oldBeforeNode,newBeforeNode:m};b.oldBeforeNode!=b.newBeforeNode&&a._onAction("moveNodes",b),document.body.style.cursor=a.drag.oldCursor,a.highlighter.unlock(),d.forEach(function(C){l.target!==C.dom.drag&&l.target!==C.dom.menu&&a.highlighter.unhighlight()}),delete a.drag,a.mousemove&&(n.removeEventListener(window,"mousemove",a.mousemove),delete a.mousemove),a.mouseup&&(n.removeEventListener(window,"mouseup",a.mouseup),delete a.mouseup),a.stopAutoScroll(),l.preventDefault()}},h.prototype._isChildOf=function(d){for(var l=this.parent;l;){if(l==d)return!0;l=l.parent}return!1},h.prototype._createDomField=function(){return document.createElement("div")},h.prototype.setHighlight=function(d){this.dom.tr&&(d?n.addClassName(this.dom.tr,"jsoneditor-highlight"):n.removeClassName(this.dom.tr,"jsoneditor-highlight"),this.append&&this.append.setHighlight(d),this.childs&&this.childs.forEach(function(l){l.setHighlight(d)}))},h.prototype.setSelected=function(d,l){this.selected=d,this.dom.tr&&(d?n.addClassName(this.dom.tr,"jsoneditor-selected"):n.removeClassName(this.dom.tr,"jsoneditor-selected"),l?n.addClassName(this.dom.tr,"jsoneditor-first"):n.removeClassName(this.dom.tr,"jsoneditor-first"),this.append&&this.append.setSelected(d),this.childs&&this.childs.forEach(function(c){c.setSelected(d)}))},h.prototype.updateValue=function(d){this.value=d,this.updateDom()},h.prototype.updateField=function(d){this.field=d,this.updateDom()},h.prototype.updateDom=function(d){var l=this.dom.tree;l&&(l.style.marginLeft=this.getLevel()*24+"px");var c=this.dom.field;if(c){this.fieldEditable?(c.contentEditable=this.editable.field,c.spellcheck=!1,c.className="jsoneditor-field"):c.className="jsoneditor-readonly";var a;this.index!=null?a=this.index:this.field!=null?a=this.field:this._hasChilds()?a=this.type:a="",c.innerHTML=this._escapeHTML(a),this._updateSchema()}var F=this.dom.value;if(F){var p=this.childs?this.childs.length:0;this.type=="array"?(F.innerHTML="["+p+"]",n.addClassName(this.dom.tr,"jsoneditor-expandable")):this.type=="object"?(F.innerHTML="{"+p+"}",n.addClassName(this.dom.tr,"jsoneditor-expandable")):(F.innerHTML=this._escapeHTML(this.value),n.removeClassName(this.dom.tr,"jsoneditor-expandable"))}this._updateDomField(),this._updateDomValue(),d&&d.updateIndexes===!0&&this._updateDomIndexes(),d&&d.recurse===!0&&this.childs&&this.childs.forEach(function(m){m.updateDom(d)}),this.append&&this.append.updateDom()},h.prototype._updateSchema=function(){this.editor&&this.editor.options&&(this.schema=this.editor.options.schema?h._findSchema(this.editor.options.schema,this.getPath()):null,this.schema?this.enum=h._findEnum(this.schema):delete this.enum)},h._findEnum=function(d){if(d.enum)return d.enum;var l=d.oneOf||d.anyOf||d.allOf;if(l){var c=l.filter(function(a){return a.enum});if(c.length>0)return c[0].enum}return null},h._findSchema=function(d,l){var c=d,a=c,F=d.oneOf||d.anyOf||d.allOf;F||(F=[d]);for(var p=0;p<F.length;p++){c=F[p];for(var m=0;m<l.length&&c;m++){var b=l[m];typeof b=="string"&&c.properties?(c=c.properties[b]||null,c&&(a=h._findSchema(c,l.slice(m,l.length)))):typeof b=="number"&&c.items&&(c=c.items,c&&(a=h._findSchema(c,l.slice(m,l.length))))}}return a},h.prototype._updateDomIndexes=function(){var d=this.dom.value,l=this.childs;d&&l&&(this.type=="array"?l.forEach(function(c,a){c.index=a;var F=c.dom.field;F&&(F.innerHTML=a)}):this.type=="object"&&l.forEach(function(c){c.index!=null&&(delete c.index,c.field==null&&(c.field=""))}))},h.prototype._createDomValue=function(){var d;return this.type=="array"?(d=document.createElement("div"),d.innerHTML="[...]"):this.type=="object"?(d=document.createElement("div"),d.innerHTML="{...}"):!this.editable.value&&n.isUrl(this.value)?(d=document.createElement("a"),d.href=this.value,d.target="_blank",d.innerHTML=this._escapeHTML(this.value)):(d=document.createElement("div"),d.contentEditable=this.editable.value,d.spellcheck=!1,d.innerHTML=this._escapeHTML(this.value)),d},h.prototype._createDomExpandButton=function(){var d=document.createElement("button");return d.type="button",this._hasChilds()?(d.className=this.expanded?"jsoneditor-expanded":"jsoneditor-collapsed",d.title=`Click to expand/collapse this field (Ctrl+E). 
Ctrl+Click to expand/collapse including all childs.`):(d.className="jsoneditor-invisible",d.title=""),d},h.prototype._createDomTree=function(){var d=this.dom,l=document.createElement("table"),c=document.createElement("tbody");l.style.borderCollapse="collapse",l.className="jsoneditor-values",l.appendChild(c);var a=document.createElement("tr");c.appendChild(a);var F=document.createElement("td");F.className="jsoneditor-tree",a.appendChild(F),d.expand=this._createDomExpandButton(),F.appendChild(d.expand),d.tdExpand=F;var p=document.createElement("td");p.className="jsoneditor-tree",a.appendChild(p),d.field=this._createDomField(),p.appendChild(d.field),d.tdField=p;var m=document.createElement("td");m.className="jsoneditor-tree",a.appendChild(m),this.type!="object"&&this.type!="array"&&(m.appendChild(document.createTextNode(":")),m.className="jsoneditor-separator"),d.tdSeparator=m;var b=document.createElement("td");return b.className="jsoneditor-tree",a.appendChild(b),d.value=this._createDomValue(),b.appendChild(d.value),d.tdValue=b,l},h.prototype.onEvent=function(d){var l=d.type,c=d.target||d.srcElement,a=this.dom,F=this,p=this._hasChilds();if((c==a.drag||c==a.menu)&&(l=="mouseover"?this.editor.highlighter.highlight(this):l=="mouseout"&&this.editor.highlighter.unhighlight()),l=="click"&&c==a.menu){var m=F.editor.highlighter;m.highlight(F),m.lock(),n.addClassName(a.menu,"jsoneditor-selected"),this.showContextMenu(a.menu,function(){n.removeClassName(a.menu,"jsoneditor-selected"),m.unlock(),m.unhighlight()})}if(l=="click"&&(c==a.expand||(F.editor.options.mode==="view"||F.editor.options.mode==="form")&&c.nodeName==="DIV")&&p){var b=d.ctrlKey;this._onExpand(b)}l=="change"&&c==a.checkbox&&(this.dom.value.innerHTML=!this.value,this._getDomValue()),l=="change"&&c==a.select&&(this.dom.value.innerHTML=a.select.value,this._getDomValue(),this._updateDomValue());var C=a.value;if(c==C)switch(l){case"blur":case"change":this._getDomValue(!0),this._updateDomValue(),this.value&&(C.innerHTML=this._escapeHTML(this.value));break;case"input":this._getDomValue(!0),this._updateDomValue();break;case"keydown":case"mousedown":this.editor.selection=this.editor.getSelection();break;case"click":d.ctrlKey&&this.editable.value&&n.isUrl(this.value)&&(d.preventDefault(),window.open(this.value,"_blank"));break;case"keyup":this._getDomValue(!0),this._updateDomValue();break;case"cut":case"paste":setTimeout(function(){F._getDomValue(!0),F._updateDomValue()},1);break}var k=a.field;if(c==k)switch(l){case"blur":case"change":this._getDomField(!0),this._updateDomField(),this.field&&(k.innerHTML=this._escapeHTML(this.field));break;case"input":this._getDomField(!0),this._updateSchema(),this._updateDomField(),this._updateDomValue();break;case"keydown":case"mousedown":this.editor.selection=this.editor.getSelection();break;case"keyup":this._getDomField(!0),this._updateDomField();break;case"cut":case"paste":setTimeout(function(){F._getDomField(!0),F._updateDomField()},1);break}var T=a.tree;if(c==T.parentNode&&l=="click"&&!d.hasMoved){var w=d.offsetX!=null?d.offsetX<(this.getLevel()+1)*24:d.pageX<n.getAbsoluteLeft(a.tdSeparator);w||p?k&&(n.setEndOfContentEditable(k),k.focus()):C&&!this.enum&&(n.setEndOfContentEditable(C),C.focus())}(c==a.tdExpand&&!p||c==a.tdField||c==a.tdSeparator)&&l=="click"&&!d.hasMoved&&k&&(n.setEndOfContentEditable(k),k.focus()),l=="keydown"&&this.onKeyDown(d)},h.prototype.onKeyDown=function(d){var l=d.which||d.keyCode,c=d.target||d.srcElement,a=d.ctrlKey,F=d.shiftKey,p=d.altKey,m=!1,b,C,k,T,w=this.editor.options.mode==="tree",A,M,x,R,N=this.editor.multiselection.nodes.length>0?this.editor.multiselection.nodes:[this],j=N[0],B=N[N.length-1];if(l==13){if(c==this.dom.value)(!this.editable.value||d.ctrlKey)&&n.isUrl(this.value)&&(window.open(this.value,"_blank"),m=!0);else if(c==this.dom.expand){var q=this._hasChilds();if(q){var U=d.ctrlKey;this._onExpand(U),c.focus(),m=!0}}}else if(l==68)a&&w&&(h.onDuplicate(N),m=!0);else if(l==69)a&&(this._onExpand(F),c.focus(),m=!0);else if(l==77&&w)a&&(this.showContextMenu(c),m=!0);else if(l==46&&w)a&&(h.onRemove(N),m=!0);else if(l==45&&w)a&&!F?(this._onInsertBefore(),m=!0):a&&F&&(this._onInsertAfter(),m=!0);else if(l==35){if(p){var Z=this._lastNode();Z&&Z.focus(h.focusElement||this._getElementName(c)),m=!0}}else if(l==36){if(p){var re=this._firstNode();re&&re.focus(h.focusElement||this._getElementName(c)),m=!0}}else if(l==37){if(p&&!F){var le=this._previousElement(c);le&&this.focus(this._getElementName(le)),m=!0}else if(p&&F&&w){if(B.expanded){var ce=B.getAppend();k=ce?ce.nextSibling:void 0}else{var de=B.getDom();k=de.nextSibling}k&&(C=h.getNodeFromTarget(k),T=k.nextSibling,ge=h.getNodeFromTarget(T),C&&C instanceof g&&B.parent.childs.length!=1&&ge&&ge.parent&&(A=this.editor.getSelection(),M=B._nextSibling(),N.forEach(function(ye){ge.parent.moveBefore(ye,ge)}),this.focus(h.focusElement||this._getElementName(c)),this.editor._onAction("moveNodes",{nodes:N,oldBeforeNode:M,newBeforeNode:ge,oldSelection:A,newSelection:this.editor.getSelection()})))}}else if(l==38)p&&!F?(b=this._previousNode(),b&&(this.editor.deselect(!0),b.focus(h.focusElement||this._getElementName(c))),m=!0):!p&&a&&F&&w?(b=this._previousNode(),b&&(R=this.editor.multiselection,R.start=R.start||this,R.end=b,x=this.editor._findTopLevelNodes(R.start,R.end),this.editor.select(x),b.focus("field")),m=!0):p&&F&&w&&(b=j._previousNode(),b&&b.parent&&(A=this.editor.getSelection(),M=B._nextSibling(),N.forEach(function(ye){b.parent.moveBefore(ye,b)}),this.focus(h.focusElement||this._getElementName(c)),this.editor._onAction("moveNodes",{nodes:N,oldBeforeNode:M,newBeforeNode:b,oldSelection:A,newSelection:this.editor.getSelection()})),m=!0);else if(l==39){if(p&&!F){var he=this._nextElement(c);he&&this.focus(this._getElementName(he)),m=!0}else if(p&&F&&w){de=j.getDom();var Fe=de.previousSibling;Fe&&(b=h.getNodeFromTarget(Fe),b&&b.parent&&b instanceof g&&!b.isVisible()&&(A=this.editor.getSelection(),M=B._nextSibling(),N.forEach(function(ye){b.parent.moveBefore(ye,b)}),this.focus(h.focusElement||this._getElementName(c)),this.editor._onAction("moveNodes",{nodes:N,oldBeforeNode:M,newBeforeNode:b,oldSelection:A,newSelection:this.editor.getSelection()})))}}else if(l==40){if(p&&!F)C=this._nextNode(),C&&(this.editor.deselect(!0),C.focus(h.focusElement||this._getElementName(c))),m=!0;else if(!p&&a&&F&&w)C=this._nextNode(),C&&(R=this.editor.multiselection,R.start=R.start||this,R.end=C,x=this.editor._findTopLevelNodes(R.start,R.end),this.editor.select(x),C.focus("field")),m=!0;else if(p&&F&&w){B.expanded?C=B.append?B.append._nextNode():void 0:C=B._nextNode();var ge=C&&(C._nextNode()||C.parent.append);ge&&ge.parent&&(A=this.editor.getSelection(),M=B._nextSibling(),N.forEach(function(ye){ge.parent.moveBefore(ye,ge)}),this.focus(h.focusElement||this._getElementName(c)),this.editor._onAction("moveNodes",{nodes:N,oldBeforeNode:M,newBeforeNode:ge,oldSelection:A,newSelection:this.editor.getSelection()})),m=!0}}m&&(d.preventDefault(),d.stopPropagation())},h.prototype._onExpand=function(d){if(d){var l=this.dom.tr.parentNode,c=l.parentNode,a=c.scrollTop;c.removeChild(l)}this.expanded?this.collapse(d):this.expand(d),d&&(c.appendChild(l),c.scrollTop=a)},h.onRemove=function(d){if(!Array.isArray(d))return h.onRemove([d]);if(d&&d.length>0){var l=d[0],c=l.parent,a=l.editor,F=l.getIndex();a.highlighter.unhighlight();var p=a.getSelection();h.blurNodes(d);var m=a.getSelection();d.forEach(function(b){b.parent._remove(b)}),a._onAction("removeNodes",{nodes:d.slice(0),parent:c,index:F,oldSelection:p,newSelection:m})}},h.onDuplicate=function(d){if(!Array.isArray(d))return h.onDuplicate([d]);if(d&&d.length>0){var l=d[d.length-1],c=l.parent,a=l.editor;a.deselect(a.multiselection.nodes);var F=a.getSelection(),p=l,m=d.map(function(C){var k=C.clone();return c.insertAfter(k,p),p=k,k});d.length===1?m[0].focus():a.select(m);var b=a.getSelection();a._onAction("duplicateNodes",{afterNode:l,nodes:m,parent:c,oldSelection:F,newSelection:b})}},h.prototype._onInsertBefore=function(d,l,c){var a=this.editor.getSelection(),F=new h(this.editor,{field:d??"",value:l??"",type:c});F.expand(!0),this.parent.insertBefore(F,this),this.editor.highlighter.unhighlight(),F.focus("field");var p=this.editor.getSelection();this.editor._onAction("insertBeforeNodes",{nodes:[F],beforeNode:this,parent:this.parent,oldSelection:a,newSelection:p})},h.prototype._onInsertAfter=function(d,l,c){var a=this.editor.getSelection(),F=new h(this.editor,{field:d??"",value:l??"",type:c});F.expand(!0),this.parent.insertAfter(F,this),this.editor.highlighter.unhighlight(),F.focus("field");var p=this.editor.getSelection();this.editor._onAction("insertAfterNodes",{nodes:[F],afterNode:this,parent:this.parent,oldSelection:a,newSelection:p})},h.prototype._onAppend=function(d,l,c){var a=this.editor.getSelection(),F=new h(this.editor,{field:d??"",value:l??"",type:c});F.expand(!0),this.parent.appendChild(F),this.editor.highlighter.unhighlight(),F.focus("field");var p=this.editor.getSelection();this.editor._onAction("appendNodes",{nodes:[F],parent:this.parent,oldSelection:a,newSelection:p})},h.prototype._onChangeType=function(d){var l=this.type;if(d!=l){var c=this.editor.getSelection();this.changeType(d);var a=this.editor.getSelection();this.editor._onAction("changeType",{node:this,oldType:l,newType:d,oldSelection:c,newSelection:a})}},h.prototype.sort=function(d){if(this._hasChilds()){var l=d=="desc"?-1:1,c=this.type=="array"?"value":"field";this.hideChilds();var a=this.childs,F=this.sortOrder;this.childs=this.childs.concat(),this.childs.sort(function(p,m){return l*s(p[c],m[c])}),this.sortOrder=l==1?"asc":"desc",this.editor._onAction("sort",{node:this,oldChilds:a,oldSort:F,newChilds:this.childs,newSort:this.sortOrder}),this.showChilds()}},h.prototype.getAppend=function(){return this.append||(this.append=new g(this.editor),this.append.setParent(this)),this.append.getDom()},h.getNodeFromTarget=function(d){for(;d;){if(d.node)return d.node;d=d.parentNode}},h.blurNodes=function(d){if(!Array.isArray(d)){h.blurNodes([d]);return}var l=d[0],c=l.parent,a=l.getIndex();c.childs[a+d.length]?c.childs[a+d.length].focus():c.childs[a-1]?c.childs[a-1].focus():c.focus()},h.prototype._nextSibling=function(){var d=this.parent.childs.indexOf(this);return this.parent.childs[d+1]||this.parent.append},h.prototype._previousNode=function(){var d=null,l=this.getDom();if(l&&l.parentNode){var c=l;do c=c.previousSibling,d=h.getNodeFromTarget(c);while(c&&d instanceof g&&!d.isVisible())}return d},h.prototype._nextNode=function(){var d=null,l=this.getDom();if(l&&l.parentNode){var c=l;do c=c.nextSibling,d=h.getNodeFromTarget(c);while(c&&d instanceof g&&!d.isVisible())}return d},h.prototype._firstNode=function(){var d=null,l=this.getDom();if(l&&l.parentNode){var c=l.parentNode.firstChild;d=h.getNodeFromTarget(c)}return d},h.prototype._lastNode=function(){var d=null,l=this.getDom();if(l&&l.parentNode){var c=l.parentNode.lastChild;for(d=h.getNodeFromTarget(c);c&&d instanceof g&&!d.isVisible();)c=c.previousSibling,d=h.getNodeFromTarget(c)}return d},h.prototype._previousElement=function(d){var l=this.dom;switch(d){case l.value:if(this.fieldEditable)return l.field;case l.field:if(this._hasChilds())return l.expand;case l.expand:return l.menu;case l.menu:if(l.drag)return l.drag;default:return null}},h.prototype._nextElement=function(d){var l=this.dom;switch(d){case l.drag:return l.menu;case l.menu:if(this._hasChilds())return l.expand;case l.expand:if(this.fieldEditable)return l.field;case l.field:if(!this._hasChilds())return l.value;default:return null}},h.prototype._getElementName=function(d){var l=this.dom;for(var c in l)if(l.hasOwnProperty(c)&&l[c]==d)return c;return null},h.prototype._hasChilds=function(){return this.type=="array"||this.type=="object"},h.TYPE_TITLES={auto:'Field type "auto". The field type is automatically determined from the value and can be a string, number, boolean, or null.',object:'Field type "object". An object contains an unordered set of key/value pairs.',array:'Field type "array". An array contains an ordered collection of values.',string:'Field type "string". Field type is not determined from the value, but always returned as string.'},h.prototype.addTemplates=function(d,l){var c=this,a=c.editor.options.templates;if(a!=null){a.length&&d.push({type:"separator"});var F=function(m,b){c._onAppend(m,b)},p=function(m,b){c._onInsertBefore(m,b)};a.forEach(function(m){d.push({text:m.text,className:m.className||"jsoneditor-type-object",title:m.title,click:l?F.bind(this,m.field,m.value):p.bind(this,m.field,m.value)})})}},h.prototype.showContextMenu=function(d,l){var c=this,a=h.TYPE_TITLES,F=[];if(this.editable.value&&F.push({text:"Type",title:"Change the type of this field",className:"jsoneditor-type-"+this.type,submenu:[{text:"Auto",className:"jsoneditor-type-auto"+(this.type=="auto"?" jsoneditor-selected":""),title:a.auto,click:function(){c._onChangeType("auto")}},{text:"Array",className:"jsoneditor-type-array"+(this.type=="array"?" jsoneditor-selected":""),title:a.array,click:function(){c._onChangeType("array")}},{text:"Object",className:"jsoneditor-type-object"+(this.type=="object"?" jsoneditor-selected":""),title:a.object,click:function(){c._onChangeType("object")}},{text:"String",className:"jsoneditor-type-string"+(this.type=="string"?" jsoneditor-selected":""),title:a.string,click:function(){c._onChangeType("string")}}]}),this._hasChilds()){var p=this.sortOrder=="asc"?"desc":"asc";F.push({text:"Sort",title:"Sort the childs of this "+this.type,className:"jsoneditor-sort-"+p,click:function(){c.sort(p)},submenu:[{text:"Ascending",className:"jsoneditor-sort-asc",title:"Sort the childs of this "+this.type+" in ascending order",click:function(){c.sort("asc")}},{text:"Descending",className:"jsoneditor-sort-desc",title:"Sort the childs of this "+this.type+" in descending order",click:function(){c.sort("desc")}}]})}if(this.parent&&this.parent._hasChilds()){F.length&&F.push({type:"separator"});var m=c.parent.childs;if(c==m[m.length-1]){var b=[{text:"Auto",className:"jsoneditor-type-auto",title:a.auto,click:function(){c._onAppend("","","auto")}},{text:"Array",className:"jsoneditor-type-array",title:a.array,click:function(){c._onAppend("",[])}},{text:"Object",className:"jsoneditor-type-object",title:a.object,click:function(){c._onAppend("",{})}},{text:"String",className:"jsoneditor-type-string",title:a.string,click:function(){c._onAppend("","","string")}}];c.addTemplates(b,!0),F.push({text:"Append",title:"Append a new field with type 'auto' after this field (Ctrl+Shift+Ins)",submenuTitle:"Select the type of the field to be appended",className:"jsoneditor-append",click:function(){c._onAppend("","","auto")},submenu:b})}var C=[{text:"Auto",className:"jsoneditor-type-auto",title:a.auto,click:function(){c._onInsertBefore("","","auto")}},{text:"Array",className:"jsoneditor-type-array",title:a.array,click:function(){c._onInsertBefore("",[])}},{text:"Object",className:"jsoneditor-type-object",title:a.object,click:function(){c._onInsertBefore("",{})}},{text:"String",className:"jsoneditor-type-string",title:a.string,click:function(){c._onInsertBefore("","","string")}}];c.addTemplates(C,!1),F.push({text:"Insert",title:"Insert a new field with type 'auto' before this field (Ctrl+Ins)",submenuTitle:"Select the type of the field to be inserted",className:"jsoneditor-insert",click:function(){c._onInsertBefore("","","auto")},submenu:C}),this.editable.field&&(F.push({text:"Duplicate",title:"Duplicate this field (Ctrl+D)",className:"jsoneditor-duplicate",click:function(){h.onDuplicate(c)}}),F.push({text:"Remove",title:"Remove this field (Ctrl+Del)",className:"jsoneditor-remove",click:function(){h.onRemove(c)}}))}var k=new o(F,{close:l});k.show(d,this.editor.content)},h.prototype._getType=function(d){return d instanceof Array?"array":d instanceof Object?"object":typeof d=="string"&&typeof this._stringCast(d)!="string"?"string":"auto"},h.prototype._stringCast=function(d){var l=d.toLowerCase(),c=Number(d),a=parseFloat(d);return d==""?"":l=="null"?null:l=="true"?!0:l=="false"?!1:!isNaN(c)&&!isNaN(a)?c:d},h.prototype._escapeHTML=function(d){if(typeof d!="string")return String(d);var l=String(d).replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/  /g," &nbsp;").replace(/^ /,"&nbsp;").replace(/ $/,"&nbsp;"),c=JSON.stringify(l),a=c.substring(1,c.length-1);return this.editor.options.escapeUnicode===!0&&(a=n.escapeUnicodeChars(a)),a},h.prototype._unescapeHTML=function(d){var l='"'+this._escapeJSON(d)+'"',c=n.parse(l);return c.replace(/&lt;/g,"<").replace(/&gt;/g,">").replace(/&nbsp;|\u00A0/g," ").replace(/&amp;/g,"&")},h.prototype._escapeJSON=function(d){for(var l="",c=0;c<d.length;){var a=d.charAt(c);a==`
`?l+="\\n":a=="\\"?(l+=a,c++,a=d.charAt(c),(a===""||'"\\/bfnrtu'.indexOf(a)==-1)&&(l+="\\"),l+=a):a=='"'?l+='\\"':l+=a,c++}return l};var g=f(h);u.exports=h},function(u,r){u.exports=function i(s,o){var f=/(^([+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?)?$|^0x[0-9a-f]+$|\d+)/gi,n=/(^[ ]*|[ ]*$)/g,h=/(^([\w ]+,?[\w ]+)?[\w ]+,?[\w ]+\d+:\d+(:\d+)?[\w ]?|^\d{1,4}[\/\-]\d{1,4}[\/\-]\d{1,4}|^\w+, \w+ \d+, \d{4})/,g=/^0x[0-9a-f]+$/i,d=/^0/,l=function(A){return i.insensitive&&(""+A).toLowerCase()||""+A},c=l(s).replace(n,"")||"",a=l(o).replace(n,"")||"",F=c.replace(f,"\0$1\0").replace(/\0$/,"").replace(/^\0/,"").split("\0"),p=a.replace(f,"\0$1\0").replace(/\0$/,"").replace(/^\0/,"").split("\0"),m=parseInt(c.match(g),16)||F.length!==1&&c.match(h)&&Date.parse(c),b=parseInt(a.match(g),16)||m&&a.match(h)&&Date.parse(a)||null,C,k;if(b){if(m<b)return-1;if(m>b)return 1}for(var T=0,w=Math.max(F.length,p.length);T<w;T++){if(C=!(F[T]||"").match(d)&&parseFloat(F[T])||F[T]||0,k=!(p[T]||"").match(d)&&parseFloat(p[T])||p[T]||0,isNaN(C)!==isNaN(k))return isNaN(C)?1:-1;if(typeof C!=typeof k&&(C+="",k+=""),C<k)return-1;if(C>k)return 1}return 0}},function(u,r,i){var s=i(57),o=i(60);function f(n){function h(g){this.editor=g,this.dom={}}return h.prototype=new n,h.prototype.getDom=function(){var g=this.dom;if(g.tr)return g.tr;this._updateEditability();var d=document.createElement("tr");if(d.node=this,g.tr=d,this.editor.options.mode==="tree"){g.tdDrag=document.createElement("td");var l=document.createElement("td");g.tdMenu=l;var c=document.createElement("button");c.type="button",c.className="jsoneditor-contextmenu",c.title="Click to open the actions menu (Ctrl+M)",g.menu=c,l.appendChild(g.menu)}var a=document.createElement("td"),F=document.createElement("div");return F.innerHTML="(empty)",F.className="jsoneditor-readonly",a.appendChild(F),g.td=a,g.text=F,this.updateDom(),d},h.prototype.updateDom=function(){var g=this.dom,d=g.td;d&&(d.style.paddingLeft=this.getLevel()*24+26+"px");var l=g.text;l&&(l.innerHTML="(empty "+this.parent.type+")");var c=g.tr;this.isVisible()?g.tr.firstChild||(g.tdDrag&&c.appendChild(g.tdDrag),g.tdMenu&&c.appendChild(g.tdMenu),c.appendChild(d)):g.tr.firstChild&&(g.tdDrag&&c.removeChild(g.tdDrag),g.tdMenu&&c.removeChild(g.tdMenu),c.removeChild(d))},h.prototype.isVisible=function(){return this.parent.childs.length==0},h.prototype.showContextMenu=function(g,d){var l=this,c=n.TYPE_TITLES,a=[{text:"Auto",className:"jsoneditor-type-auto",title:c.auto,click:function(){l._onAppend("","","auto")}},{text:"Array",className:"jsoneditor-type-array",title:c.array,click:function(){l._onAppend("",[])}},{text:"Object",className:"jsoneditor-type-object",title:c.object,click:function(){l._onAppend("",{})}},{text:"String",className:"jsoneditor-type-string",title:c.string,click:function(){l._onAppend("","","string")}}];l.addTemplates(a,!0);var F=[{text:"Append",title:"Append a new field with type 'auto' (Ctrl+Shift+Ins)",submenuTitle:"Select the type of the field to be appended",className:"jsoneditor-insert",click:function(){l._onAppend("","","auto")},submenu:a}],p=new o(F,{close:d});p.show(g,this.editor.content)},h.prototype.onEvent=function(g){var d=g.type,l=g.target||g.srcElement,c=this.dom,a=c.menu;if(l==a&&(d=="mouseover"?this.editor.highlighter.highlight(this.parent):d=="mouseout"&&this.editor.highlighter.unhighlight()),d=="click"&&l==c.menu){var F=this.editor.highlighter;F.highlight(this.parent),F.lock(),s.addClassName(c.menu,"jsoneditor-selected"),this.showContextMenu(c.menu,function(){s.removeClassName(c.menu,"jsoneditor-selected"),F.unlock(),F.unhighlight()})}d=="keydown"&&this.onKeyDown(g)},h}u.exports=f},function(u,r,i){var s=i(60);function o(f,n,h,g){for(var d={code:{text:"Code",title:"Switch to code highlighter",click:function(){g("code")}},form:{text:"Form",title:"Switch to form editor",click:function(){g("form")}},text:{text:"Text",title:"Switch to plain text editor",click:function(){g("text")}},tree:{text:"Tree",title:"Switch to tree editor",click:function(){g("tree")}},view:{text:"View",title:"Switch to tree view",click:function(){g("view")}}},l=[],c=0;c<n.length;c++){var a=n[c],F=d[a];if(!F)throw new Error('Unknown mode "'+a+'"');F.className="jsoneditor-type-modes"+(h==a?" jsoneditor-selected":""),l.push(F)}var p=d[h];if(!p)throw new Error('Unknown mode "'+h+'"');var m=p.text,b=document.createElement("button");b.type="button",b.className="jsoneditor-modes jsoneditor-separator",b.innerHTML=m+" &#x25BE;",b.title="Switch editor mode",b.onclick=function(){var k=new s(l);k.show(b)};var C=document.createElement("div");C.className="jsoneditor-modes",C.style.position="relative",C.appendChild(b),f.appendChild(C),this.dom={container:f,box:b,frame:C}}o.prototype.focus=function(){this.dom.box.focus()},o.prototype.destroy=function(){this.dom&&this.dom.frame&&this.dom.frame.parentNode&&this.dom.frame.parentNode.removeChild(this.dom.frame),this.dom=null},u.exports=o},function(u,r){function i(s){s=s||{},s.confirmKeys=s.confirmKeys||[39,35,9];var o="",f="",n=document.createElement("div");n.style.position="relative",n.style.outline="0",n.style.border="0",n.style.margin="0",n.style.padding="0";var h=document.createElement("div");h.className="autocomplete dropdown",h.style.position="absolute",h.style.visibility="hidden";var g,d,l=function(C,k){var T=[],w=0,A=-1,M=function(){this.style.outline="1px solid #ddd"},x=function(){this.style.outline="0"},R=function(){N.hide(),N.onmouseselection(this.__hint,N.rs)},N={rs:k,hide:function(){C.style.visibility="hidden"},refresh:function(j,B){C.style.visibility="hidden",w=0,C.innerHTML="";var q=window.innerHeight||document.documentElement.clientHeight,U=C.parentNode.getBoundingClientRect(),Z=U.top-6,re=q-U.bottom-6;T=[];for(var le=0;le<B.length;le++)if(B[le].indexOf(j)===0){var ce=document.createElement("div");ce.className="item",ce.onmouseover=M,ce.onmouseout=x,ce.onmousedown=R,ce.__hint=B[le],ce.innerHTML=j+"<b>"+B[le].substring(j.length)+"</b>",T.push(ce),C.appendChild(ce)}T.length!==0&&(T.length===1&&j===T[0].__hint||T.length<2||(N.highlight(0),Z>re*3?(C.style.maxHeight=Z+"px",C.style.top="",C.style.bottom="100%"):(C.style.top="100%",C.style.bottom="",C.style.maxHeight=re+"px"),C.style.visibility="visible"))},highlight:function(j){A!=-1&&T[A]&&(T[A].className="item"),T[j].className="item hover",A=j},move:function(j){return C.style.visibility==="hidden"?"":(w+j===-1||w+j===T.length||(w+=j,N.highlight(w)),T[w].__hint)},onmouseselection:function(){}};return N};function c(C){var k,T;document.createRange?(k=document.createRange(),k.selectNodeContents(C),k.collapse(!1),T=window.getSelection(),T.removeAllRanges(),T.addRange(k)):document.selection&&(k=document.body.createTextRange(),k.moveToElementText(C),k.collapse(!1),k.select())}function a(C){return g===void 0&&(g=document.createElement("span"),g.style.visibility="hidden",g.style.position="fixed",g.style.outline="0",g.style.margin="0",g.style.padding="0",g.style.border="0",g.style.left="0",g.style.whiteSpace="pre",g.style.fontSize=o,g.style.fontFamily=f,g.style.fontWeight="normal",document.body.appendChild(g)),g.innerHTML=String(C).replace(/&/g,"&amp;").replace(/"/g,"&quot;").replace(/'/g,"&#39;").replace(/</g,"&lt;").replace(/>/g,"&gt;"),g.getBoundingClientRect().right}var F={onArrowDown:function(){},onArrowUp:function(){},onEnter:function(){},onTab:function(){},startFrom:0,options:[],element:null,elementHint:null,elementStyle:null,wrapper:n,show:function(C,k,T){this.startFrom=k,this.wrapper.remove(),this.elementHint&&(this.elementHint.remove(),this.elementHint=null),o==""&&(o=window.getComputedStyle(C).getPropertyValue("font-size")),f==""&&(f=window.getComputedStyle(C).getPropertyValue("font-family")),C.getBoundingClientRect().right-C.getBoundingClientRect().left,h.style.marginLeft="0",h.style.marginTop=C.getBoundingClientRect().height+"px",this.options=T,this.element!=C&&(this.element=C,this.elementStyle={zIndex:this.element.style.zIndex,position:this.element.style.position,backgroundColor:this.element.style.backgroundColor,borderColor:this.element.style.borderColor}),this.element.style.zIndex=3,this.element.style.position="relative",this.element.style.backgroundColor="transparent",this.element.style.borderColor="transparent",this.elementHint=C.cloneNode(),this.elementHint.className="autocomplete hint",this.elementHint.style.zIndex=2,this.elementHint.style.position="absolute",this.elementHint.onfocus=function(){this.element.focus()}.bind(this),this.element.addEventListener&&(this.element.removeEventListener("keydown",m),this.element.addEventListener("keydown",m,!1),this.element.removeEventListener("blur",b),this.element.addEventListener("blur",b,!1)),n.appendChild(this.elementHint),n.appendChild(h),C.parentElement.appendChild(n),this.repaint(C)},setText:function(C){this.element.innerText=C},getText:function(){return this.element.innerText},hideDropDown:function(){this.wrapper.remove(),this.elementHint&&(this.elementHint.remove(),this.elementHint=null,p.hide(),this.element.style.zIndex=this.elementStyle.zIndex,this.element.style.position=this.elementStyle.position,this.element.style.backgroundColor=this.elementStyle.backgroundColor,this.element.style.borderColor=this.elementStyle.borderColor)},repaint:function(C){var k=C.innerText;k=k.replace(`
`,""),this.startFrom,this.options;var T=this.options.length,w=k.substring(this.startFrom);d=k.substring(0,this.startFrom);for(var A=0;A<T;A++){var M=this.options[A];if(M.indexOf(w)===0){this.elementHint.innerText=d+M;break}}h.style.left=a(d)+"px",p.refresh(w,this.options),this.elementHint.style.width=a(this.elementHint.innerText)+10+"px";var x=h.style.visibility=="hidden";x||(this.elementHint.style.width=a(this.elementHint.innerText)+h.clientWidth+"px")}},p=l(h,F),m=function(C){C=C||window.event;var k=C.keyCode;if(this.elementHint!=null&&k!=33&&k!=34){if(k==27){F.hideDropDown(),F.element.focus(),C.preventDefault(),C.stopPropagation();return}if(s.confirmKeys.indexOf(k)>=0){k==9&&this.elementHint.innerText.length==0&&F.onTab(),this.elementHint.innerText.length>0&&this.element.innerText!=this.elementHint.innerText&&(this.element.innerText=this.elementHint.innerText,F.hideDropDown(),c(this.element),k==9&&(F.element.focus(),C.preventDefault(),C.stopPropagation()));return}if(k==13){if(this.elementHint.innerText.length==0)F.onEnter();else{var T=h.style.visibility=="hidden";if(p.hide(),T){F.hideDropDown(),F.element.focus(),F.onEnter();return}this.element.innerText=this.elementHint.innerText,F.hideDropDown(),c(this.element),C.preventDefault(),C.stopPropagation()}return}if(k==40){var w=p.move(1);w==""&&F.onArrowDown(),this.elementHint.innerText=d+w,C.preventDefault(),C.stopPropagation();return}if(k==38){var w=p.move(-1);w==""&&F.onArrowUp(),this.elementHint.innerText=d+w,C.preventDefault(),C.stopPropagation();return}}}.bind(F),b=function(C){F.hideDropDown()}.bind(F);return p.onmouseselection=function(C,k){k.element.innerText=k.elementHint.innerText=d+C,k.hideDropDown(),window.setTimeout(function(){k.element.focus(),c(k.element)},1)},F}u.exports=i},function(u,r,i){var s=i(67),o=i(64),f=i(57),n={},h=3,g="ace/theme/jsoneditor";n.create=function(d,l){l=l||{},this.options=l,l.indentation?this.indentation=Number(l.indentation):this.indentation=2;var c=l.ace?l.ace:s;if(this.mode=l.mode=="code"?"code":"text",this.mode=="code"&&typeof c>"u"&&(this.mode="text",console.warn("Failed to load Ace editor, falling back to plain text mode. Please use a JSONEditor bundle including Ace, or pass Ace as via the configuration option `ace`.")),this.theme=l.theme||g,this.theme===g&&c)try{i(74)}catch(w){console.error(w)}var a=this;this.container=d,this.dom={},this.aceEditor=void 0,this.textarea=void 0,this.validateSchema=null,this._debouncedValidate=f.debounce(this.validate.bind(this),this.DEBOUNCE_INTERVAL),this.width=d.clientWidth,this.height=d.clientHeight,this.frame=document.createElement("div"),this.frame.className="jsoneditor jsoneditor-mode-"+this.options.mode,this.frame.onclick=function(w){w.preventDefault()},this.frame.onkeydown=function(w){a._onKeyDown(w)},this.menu=document.createElement("div"),this.menu.className="jsoneditor-menu",this.frame.appendChild(this.menu);var F=document.createElement("button");F.type="button",F.className="jsoneditor-format",F.title="Format JSON data, with proper indentation and line feeds (Ctrl+\\)",this.menu.appendChild(F),F.onclick=function(){try{a.format(),a._onChange()}catch(w){a._onError(w)}};var p=document.createElement("button");p.type="button",p.className="jsoneditor-compact",p.title="Compact JSON data, remove all whitespaces (Ctrl+Shift+\\)",this.menu.appendChild(p),p.onclick=function(){try{a.compact(),a._onChange()}catch(w){a._onError(w)}},this.options&&this.options.modes&&this.options.modes.length&&(this.modeSwitcher=new o(this.menu,this.options.modes,this.options.mode,function(A){a.setMode(A),a.modeSwitcher.focus()}));var m={},b=this.options.onEditable&&typeof(this.options.onEditable==="function")&&!this.options.onEditable(m);if(this.content=document.createElement("div"),this.content.className="jsoneditor-outer",this.frame.appendChild(this.content),this.container.appendChild(this.frame),this.mode=="code"){this.editorDom=document.createElement("div"),this.editorDom.style.height="100%",this.editorDom.style.width="100%",this.content.appendChild(this.editorDom);var C=c.edit(this.editorDom);C.$blockScrolling=1/0,C.setTheme(this.theme),C.setOptions({readOnly:b}),C.setShowPrintMargin(!1),C.setFontSize(13),C.getSession().setMode("ace/mode/json"),C.getSession().setTabSize(this.indentation),C.getSession().setUseSoftTabs(!0),C.getSession().setUseWrapMode(!0),C.commands.bindKey("Ctrl-L",null),C.commands.bindKey("Command-L",null),this.aceEditor=C,this.hasOwnProperty("editor")||Object.defineProperty(this,"editor",{get:function(){return console.warn('Property "editor" has been renamed to "aceEditor".'),a.aceEditor},set:function(w){console.warn('Property "editor" has been renamed to "aceEditor".'),a.aceEditor=w}});var k=document.createElement("a");k.appendChild(document.createTextNode("powered by ace")),k.href="http://ace.ajax.org",k.target="_blank",k.className="jsoneditor-poweredBy",k.onclick=function(){window.open(k.href,k.target)},this.menu.appendChild(k),C.on("change",this._onChange.bind(this))}else{var T=document.createElement("textarea");T.className="jsoneditor-text",T.spellcheck=!1,this.content.appendChild(T),this.textarea=T,this.textarea.readOnly=b,this.textarea.oninput===null?this.textarea.oninput=this._onChange.bind(this):this.textarea.onchange=this._onChange.bind(this)}this.setSchema(this.options.schema,this.options.schemaRefs)},n._onChange=function(){if(this._debouncedValidate(),this.options.onChange)try{this.options.onChange()}catch(d){console.error("Error in onChange callback: ",d)}},n._onKeyDown=function(d){var l=d.which||d.keyCode,c=!1;l==220&&d.ctrlKey&&(d.shiftKey?(this.compact(),this._onChange()):(this.format(),this._onChange()),c=!0),c&&(d.preventDefault(),d.stopPropagation())},n.destroy=function(){this.aceEditor&&(this.aceEditor.destroy(),this.aceEditor=null),this.frame&&this.container&&this.frame.parentNode==this.container&&this.container.removeChild(this.frame),this.modeSwitcher&&(this.modeSwitcher.destroy(),this.modeSwitcher=null),this.textarea=null,this._debouncedValidate=null},n.compact=function(){var d=this.get(),l=JSON.stringify(d);this.setText(l)},n.format=function(){var d=this.get(),l=JSON.stringify(d,null,this.indentation);this.setText(l)},n.focus=function(){this.textarea&&this.textarea.focus(),this.aceEditor&&this.aceEditor.focus()},n.resize=function(){if(this.aceEditor){var d=!1;this.aceEditor.resize(d)}},n.set=function(d){this.setText(JSON.stringify(d,null,this.indentation))},n.get=function(){var d=this.getText(),l;try{l=f.parse(d)}catch{d=f.sanitize(d),l=f.parse(d)}return l},n.getText=function(){return this.textarea?this.textarea.value:this.aceEditor?this.aceEditor.getValue():""},n.setText=function(d){var l;if(this.options.escapeUnicode===!0?l=f.escapeUnicodeChars(d):l=d,this.textarea&&(this.textarea.value=l),this.aceEditor){var c=this.options.onChange;this.options.onChange=null,this.aceEditor.setValue(l,-1),this.options.onChange=c}this.validate()},n.validate=function(){this.dom.validationErrors&&(this.dom.validationErrors.parentNode.removeChild(this.dom.validationErrors),this.dom.validationErrors=null,this.content.style.marginBottom="",this.content.style.paddingBottom="");var d=!1,l=[],c;try{c=this.get(),d=!0}catch{}if(d&&this.validateSchema){var a=this.validateSchema(c);a||(l=this.validateSchema.errors.map(function(k){return f.improveSchemaError(k)}))}if(l.length>0){var F=l.length>h;if(F){l=l.slice(0,h);var p=this.validateSchema.errors.length-h;l.push("("+p+" more errors...)")}var m=document.createElement("div");m.innerHTML='<table class="jsoneditor-text-errors"><tbody>'+l.map(function(k){var T;return typeof k=="string"?T='<td colspan="2"><pre>'+k+"</pre></td>":T="<td>"+k.dataPath+"</td><td>"+k.message+"</td>",'<tr><td><button class="jsoneditor-schema-error"></button></td>'+T+"</tr>"}).join("")+"</tbody></table>",this.dom.validationErrors=m,this.frame.appendChild(m);var b=m.clientHeight;this.content.style.marginBottom=-b+"px",this.content.style.paddingBottom=b+"px"}if(this.aceEditor){var C=!1;this.aceEditor.resize(C)}},u.exports=[{mode:"text",mixin:n,data:"text",load:n.format},{mode:"code",mixin:n,data:"text",load:n.format}]},function(u,r,i){var s;if(window.ace)s=window.ace;else try{s=i(68),i(71),i(73)}catch{}u.exports=s},function(u,r,i){(function(){var s="ace",o=function(){return this}();!o&&typeof window<"u"&&(o=window);var f=function(c,a,F){if(typeof c!="string"){f.original?f.original.apply(this,arguments):(console.error("dropping module because define wasn't a string."),console.trace());return}arguments.length==2&&(F=a),f.modules[c]||(f.payloads[c]=F,f.modules[c]=null)};f.modules={},f.payloads={};var n=function(c,a,F){if(typeof a=="string"){var p=d(c,a);if(p!=null)return F&&F(),p}else if(Object.prototype.toString.call(a)==="[object Array]"){for(var m=[],b=0,C=a.length;b<C;++b){var k=d(c,a[b]);if(k==null&&h.original)return;m.push(k)}return F&&F.apply(null,m)||!0}},h=function(c,a){var F=n("",c,a);return F==null&&h.original?h.original.apply(this,arguments):F},g=function(c,a){if(a.indexOf("!")!==-1){var F=a.split("!");return g(c,F[0])+"!"+g(c,F[1])}if(a.charAt(0)=="."){var p=c.split("/").slice(0,-1).join("/");for(a=p+"/"+a;a.indexOf(".")!==-1&&m!=a;){var m=a;a=a.replace(/\/\.\//,"/").replace(/[^\/]+\/\.\.\//,"")}}return a},d=function(c,a){a=g(c,a);var F=f.modules[a];if(!F){if(F=f.payloads[a],typeof F=="function"){var p={},m={id:a,uri:"",exports:p,packaged:!0},b=function(k,T){return n(a,k,T)},C=F(b,p,m);p=C||m.exports,f.modules[a]=p,delete f.payloads[a]}F=f.modules[a]=p||F}return F};function l(c){var a=o;c&&(o[c]||(o[c]={}),a=o[c]),(!a.define||!a.define.packaged)&&(f.original=a.define,a.define=f,a.define.packaged=!0),(!a.acequire||!a.acequire.packaged)&&(h.original=a.acequire,a.acequire=h,a.acequire.packaged=!0)}l(s)})(),ace.define("ace/lib/regexp",["require","exports","module"],function(s,o,f){var n={exec:RegExp.prototype.exec,test:RegExp.prototype.test,match:String.prototype.match,replace:String.prototype.replace,split:String.prototype.split},h=n.exec.call(/()??/,"")[1]===void 0,g=function(){var c=/^/g;return n.test.call(c,""),!c.lastIndex}();if(g&&h)return;RegExp.prototype.exec=function(c){var a=n.exec.apply(this,arguments),F,p;if(typeof c=="string"&&a){if(!h&&a.length>1&&l(a,"")>-1&&(p=RegExp(this.source,n.replace.call(d(this),"g","")),n.replace.call(c.slice(a.index),p,function(){for(var b=1;b<arguments.length-2;b++)arguments[b]===void 0&&(a[b]=void 0)})),this._xregexp&&this._xregexp.captureNames)for(var m=1;m<a.length;m++)F=this._xregexp.captureNames[m-1],F&&(a[F]=a[m]);!g&&this.global&&!a[0].length&&this.lastIndex>a.index&&this.lastIndex--}return a},g||(RegExp.prototype.test=function(c){var a=n.exec.call(this,c);return a&&this.global&&!a[0].length&&this.lastIndex>a.index&&this.lastIndex--,!!a});function d(c){return(c.global?"g":"")+(c.ignoreCase?"i":"")+(c.multiline?"m":"")+(c.extended?"x":"")+(c.sticky?"y":"")}function l(c,a,F){if(Array.prototype.indexOf)return c.indexOf(a,F);for(var p=F||0;p<c.length;p++)if(c[p]===a)return p;return-1}}),ace.define("ace/lib/es5-shim",["require","exports","module"],function(s,o,f){function n(){}Function.prototype.bind||(Function.prototype.bind=function(ue){var Ee=this;if(typeof Ee!="function")throw new TypeError("Function.prototype.bind called on incompatible "+Ee);var ne=l.call(arguments,1),me=function(){if(this instanceof me){var se=Ee.apply(this,ne.concat(l.call(arguments)));return Object(se)===se?se:this}else return Ee.apply(ue,ne.concat(l.call(arguments)))};return Ee.prototype&&(n.prototype=Ee.prototype,me.prototype=new n,n.prototype=null),me});var h=Function.prototype.call,g=Array.prototype,d=Object.prototype,l=g.slice,c=h.bind(d.toString),a=h.bind(d.hasOwnProperty),F,p,m,b,C;if((C=a(d,"__defineGetter__"))&&(F=h.bind(d.__defineGetter__),p=h.bind(d.__defineSetter__),m=h.bind(d.__lookupGetter__),b=h.bind(d.__lookupSetter__)),[1,2].splice(0).length!=2)if(function(){function Y(ne){var me=new Array(ne+2);return me[0]=me[1]=0,me}var ue=[],Ee;if(ue.splice.apply(ue,Y(20)),ue.splice.apply(ue,Y(26)),Ee=ue.length,ue.splice(5,0,"XXX"),Ee+1==ue.length)return!0}()){var k=Array.prototype.splice;Array.prototype.splice=function(Y,ue){return arguments.length?k.apply(this,[Y===void 0?0:Y,ue===void 0?this.length-Y:ue].concat(l.call(arguments,2))):[]}}else Array.prototype.splice=function(Y,ue){var Ee=this.length;Y>0?Y>Ee&&(Y=Ee):Y==null?Y=0:Y<0&&(Y=Math.max(Ee+Y,0)),Y+ue<Ee||(ue=Ee-Y);var ne=this.slice(Y,Y+ue),me=l.call(arguments,2),se=me.length;if(Y===Ee)se&&this.push.apply(this,me);else{var ve=Math.min(ue,Ee-Y),Pe=Y+ve,Ie=Pe+se-ve,z=Ee-Pe,G=Ee-ve;if(Ie<Pe)for(var O=0;O<z;++O)this[Ie+O]=this[Pe+O];else if(Ie>Pe)for(O=z;O--;)this[Ie+O]=this[Pe+O];if(se&&Y===G)this.length=G,this.push.apply(this,me);else for(this.length=G+se,O=0;O<se;++O)this[Y+O]=me[O]}return ne};Array.isArray||(Array.isArray=function(ue){return c(ue)=="[object Array]"});var T=Object("a"),w=T[0]!="a"||!(0 in T);if(Array.prototype.forEach||(Array.prototype.forEach=function(ue){var Ee=ye(this),ne=w&&c(this)=="[object String]"?this.split(""):Ee,me=arguments[1],se=-1,ve=ne.length>>>0;if(c(ue)!="[object Function]")throw new TypeError;for(;++se<ve;)se in ne&&ue.call(me,ne[se],se,Ee)}),Array.prototype.map||(Array.prototype.map=function(ue){var Ee=ye(this),ne=w&&c(this)=="[object String]"?this.split(""):Ee,me=ne.length>>>0,se=Array(me),ve=arguments[1];if(c(ue)!="[object Function]")throw new TypeError(ue+" is not a function");for(var Pe=0;Pe<me;Pe++)Pe in ne&&(se[Pe]=ue.call(ve,ne[Pe],Pe,Ee));return se}),Array.prototype.filter||(Array.prototype.filter=function(ue){var Ee=ye(this),ne=w&&c(this)=="[object String]"?this.split(""):Ee,me=ne.length>>>0,se=[],ve,Pe=arguments[1];if(c(ue)!="[object Function]")throw new TypeError(ue+" is not a function");for(var Ie=0;Ie<me;Ie++)Ie in ne&&(ve=ne[Ie],ue.call(Pe,ve,Ie,Ee)&&se.push(ve));return se}),Array.prototype.every||(Array.prototype.every=function(ue){var Ee=ye(this),ne=w&&c(this)=="[object String]"?this.split(""):Ee,me=ne.length>>>0,se=arguments[1];if(c(ue)!="[object Function]")throw new TypeError(ue+" is not a function");for(var ve=0;ve<me;ve++)if(ve in ne&&!ue.call(se,ne[ve],ve,Ee))return!1;return!0}),Array.prototype.some||(Array.prototype.some=function(ue){var Ee=ye(this),ne=w&&c(this)=="[object String]"?this.split(""):Ee,me=ne.length>>>0,se=arguments[1];if(c(ue)!="[object Function]")throw new TypeError(ue+" is not a function");for(var ve=0;ve<me;ve++)if(ve in ne&&ue.call(se,ne[ve],ve,Ee))return!0;return!1}),Array.prototype.reduce||(Array.prototype.reduce=function(ue){var Ee=ye(this),ne=w&&c(this)=="[object String]"?this.split(""):Ee,me=ne.length>>>0;if(c(ue)!="[object Function]")throw new TypeError(ue+" is not a function");if(!me&&arguments.length==1)throw new TypeError("reduce of empty array with no initial value");var se=0,ve;if(arguments.length>=2)ve=arguments[1];else do{if(se in ne){ve=ne[se++];break}if(++se>=me)throw new TypeError("reduce of empty array with no initial value")}while(!0);for(;se<me;se++)se in ne&&(ve=ue.call(void 0,ve,ne[se],se,Ee));return ve}),Array.prototype.reduceRight||(Array.prototype.reduceRight=function(ue){var Ee=ye(this),ne=w&&c(this)=="[object String]"?this.split(""):Ee,me=ne.length>>>0;if(c(ue)!="[object Function]")throw new TypeError(ue+" is not a function");if(!me&&arguments.length==1)throw new TypeError("reduceRight of empty array with no initial value");var se,ve=me-1;if(arguments.length>=2)se=arguments[1];else do{if(ve in ne){se=ne[ve--];break}if(--ve<0)throw new TypeError("reduceRight of empty array with no initial value")}while(!0);do ve in this&&(se=ue.call(void 0,se,ne[ve],ve,Ee));while(ve--);return se}),(!Array.prototype.indexOf||[0,1].indexOf(1,2)!=-1)&&(Array.prototype.indexOf=function(ue){var Ee=w&&c(this)=="[object String]"?this.split(""):ye(this),ne=Ee.length>>>0;if(!ne)return-1;var me=0;for(arguments.length>1&&(me=ge(arguments[1])),me=me>=0?me:Math.max(0,ne+me);me<ne;me++)if(me in Ee&&Ee[me]===ue)return me;return-1}),(!Array.prototype.lastIndexOf||[0,1].lastIndexOf(0,-3)!=-1)&&(Array.prototype.lastIndexOf=function(ue){var Ee=w&&c(this)=="[object String]"?this.split(""):ye(this),ne=Ee.length>>>0;if(!ne)return-1;var me=ne-1;for(arguments.length>1&&(me=Math.min(me,ge(arguments[1]))),me=me>=0?me:ne-Math.abs(me);me>=0;me--)if(me in Ee&&ue===Ee[me])return me;return-1}),Object.getPrototypeOf||(Object.getPrototypeOf=function(ue){return ue.__proto__||(ue.constructor?ue.constructor.prototype:d)}),!Object.getOwnPropertyDescriptor){var A="Object.getOwnPropertyDescriptor called on a non-object: ";Object.getOwnPropertyDescriptor=function(ue,Ee){if(typeof ue!="object"&&typeof ue!="function"||ue===null)throw new TypeError(A+ue);if(a(ue,Ee)){var ne,me,se;if(ne={enumerable:!0,configurable:!0},C){var ve=ue.__proto__;ue.__proto__=d;var me=m(ue,Ee),se=b(ue,Ee);if(ue.__proto__=ve,me||se)return me&&(ne.get=me),se&&(ne.set=se),ne}return ne.value=ue[Ee],ne}}}if(Object.getOwnPropertyNames||(Object.getOwnPropertyNames=function(ue){return Object.keys(ue)}),!Object.create){var M;Object.prototype.__proto__===null?M=function(){return{__proto__:null}}:M=function(){var Y={};for(var ue in Y)Y[ue]=null;return Y.constructor=Y.hasOwnProperty=Y.propertyIsEnumerable=Y.isPrototypeOf=Y.toLocaleString=Y.toString=Y.valueOf=Y.__proto__=null,Y},Object.create=function(ue,Ee){var ne;if(ue===null)ne=M();else{if(typeof ue!="object")throw new TypeError("typeof prototype["+typeof ue+"] != 'object'");var me=function(){};me.prototype=ue,ne=new me,ne.__proto__=ue}return Ee!==void 0&&Object.defineProperties(ne,Ee),ne}}function x(Y){try{return Object.defineProperty(Y,"sentinel",{}),"sentinel"in Y}catch{}}if(Object.defineProperty){var R=x({}),N=typeof document>"u"||x(document.createElement("div"));if(!R||!N)var j=Object.defineProperty}if(!Object.defineProperty||j){var B="Property description must be an object: ",q="Object.defineProperty called on non-object: ",U="getters & setters can not be defined on this javascript engine";Object.defineProperty=function(ue,Ee,ne){if(typeof ue!="object"&&typeof ue!="function"||ue===null)throw new TypeError(q+ue);if(typeof ne!="object"&&typeof ne!="function"||ne===null)throw new TypeError(B+ne);if(j)try{return j.call(Object,ue,Ee,ne)}catch{}if(a(ne,"value"))if(C&&(m(ue,Ee)||b(ue,Ee))){var me=ue.__proto__;ue.__proto__=d,delete ue[Ee],ue[Ee]=ne.value,ue.__proto__=me}else ue[Ee]=ne.value;else{if(!C)throw new TypeError(U);a(ne,"get")&&F(ue,Ee,ne.get),a(ne,"set")&&p(ue,Ee,ne.set)}return ue}}Object.defineProperties||(Object.defineProperties=function(ue,Ee){for(var ne in Ee)a(Ee,ne)&&Object.defineProperty(ue,ne,Ee[ne]);return ue}),Object.seal||(Object.seal=function(ue){return ue}),Object.freeze||(Object.freeze=function(ue){return ue});try{Object.freeze(function(){})}catch{Object.freeze=function(Ee){return function(me){return typeof me=="function"?me:Ee(me)}}(Object.freeze)}if(Object.preventExtensions||(Object.preventExtensions=function(ue){return ue}),Object.isSealed||(Object.isSealed=function(ue){return!1}),Object.isFrozen||(Object.isFrozen=function(ue){return!1}),Object.isExtensible||(Object.isExtensible=function(ue){if(Object(ue)===ue)throw new TypeError;for(var Ee="";a(ue,Ee);)Ee+="?";ue[Ee]=!0;var ne=a(ue,Ee);return delete ue[Ee],ne}),!Object.keys){var Z=!0,re=["toString","toLocaleString","valueOf","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","constructor"],le=re.length;for(var ce in{toString:null})Z=!1;Object.keys=function(ue){if(typeof ue!="object"&&typeof ue!="function"||ue===null)throw new TypeError("Object.keys called on a non-object");var Ee=[];for(var ne in ue)a(ue,ne)&&Ee.push(ne);if(Z)for(var me=0,se=le;me<se;me++){var ve=re[me];a(ue,ve)&&Ee.push(ve)}return Ee}}Date.now||(Date.now=function(){return new Date().getTime()});var de=`	
\v\f\r   ᠎             　\u2028\u2029\uFEFF`;if(!String.prototype.trim||de.trim()){de="["+de+"]";var he=new RegExp("^"+de+de+"*"),Fe=new RegExp(de+de+"*$");String.prototype.trim=function(){return String(this).replace(he,"").replace(Fe,"")}}function ge(Y){return Y=+Y,Y!==Y?Y=0:Y!==0&&Y!==1/0&&Y!==-(1/0)&&(Y=(Y>0||-1)*Math.floor(Math.abs(Y))),Y}var ye=function(Y){if(Y==null)throw new TypeError("can't convert "+Y+" to object");return Object(Y)}}),ace.define("ace/lib/fixoldbrowsers",["require","exports","module","ace/lib/regexp","ace/lib/es5-shim"],function(s,o,f){s("./regexp"),s("./es5-shim")}),ace.define("ace/lib/dom",["require","exports","module"],function(s,o,f){var n="http://www.w3.org/1999/xhtml";if(o.getDocumentHead=function(h){return h||(h=document),h.head||h.getElementsByTagName("head")[0]||h.documentElement},o.createElement=function(h,g){return document.createElementNS?document.createElementNS(g||n,h):document.createElement(h)},o.hasCssClass=function(h,g){var d=(h.className+"").split(/\s+/g);return d.indexOf(g)!==-1},o.addCssClass=function(h,g){o.hasCssClass(h,g)||(h.className+=" "+g)},o.removeCssClass=function(h,g){for(var d=h.className.split(/\s+/g);;){var l=d.indexOf(g);if(l==-1)break;d.splice(l,1)}h.className=d.join(" ")},o.toggleCssClass=function(h,g){for(var d=h.className.split(/\s+/g),l=!0;;){var c=d.indexOf(g);if(c==-1)break;l=!1,d.splice(c,1)}return l&&d.push(g),h.className=d.join(" "),l},o.setCssClass=function(h,g,d){d?o.addCssClass(h,g):o.removeCssClass(h,g)},o.hasCssString=function(h,g){var d=0,l;if(g=g||document,g.createStyleSheet&&(l=g.styleSheets)){for(;d<l.length;)if(l[d++].owningElement.id===h)return!0}else if(l=g.getElementsByTagName("style")){for(;d<l.length;)if(l[d++].id===h)return!0}return!1},o.importCssString=function(g,d,l){if(l=l||document,d&&o.hasCssString(d,l))return null;var c;d&&(g+=`
/*# sourceURL=ace/css/`+d+" */"),l.createStyleSheet?(c=l.createStyleSheet(),c.cssText=g,d&&(c.owningElement.id=d)):(c=o.createElement("style"),c.appendChild(l.createTextNode(g)),d&&(c.id=d),o.getDocumentHead(l).appendChild(c))},o.importCssStylsheet=function(h,g){if(g.createStyleSheet)g.createStyleSheet(h);else{var d=o.createElement("link");d.rel="stylesheet",d.href=h,o.getDocumentHead(g).appendChild(d)}},o.getInnerWidth=function(h){return parseInt(o.computedStyle(h,"paddingLeft"),10)+parseInt(o.computedStyle(h,"paddingRight"),10)+h.clientWidth},o.getInnerHeight=function(h){return parseInt(o.computedStyle(h,"paddingTop"),10)+parseInt(o.computedStyle(h,"paddingBottom"),10)+h.clientHeight},o.scrollbarWidth=function(h){var g=o.createElement("ace_inner");g.style.width="100%",g.style.minWidth="0px",g.style.height="200px",g.style.display="block";var d=o.createElement("ace_outer"),l=d.style;l.position="absolute",l.left="-10000px",l.overflow="hidden",l.width="200px",l.minWidth="0px",l.height="150px",l.display="block",d.appendChild(g);var c=h.documentElement;c.appendChild(d);var a=g.offsetWidth;l.overflow="scroll";var F=g.offsetWidth;return a==F&&(F=d.clientWidth),c.removeChild(d),a-F},typeof document>"u"){o.importCssString=function(){};return}window.pageYOffset!==void 0?(o.getPageScrollTop=function(){return window.pageYOffset},o.getPageScrollLeft=function(){return window.pageXOffset}):(o.getPageScrollTop=function(){return document.body.scrollTop},o.getPageScrollLeft=function(){return document.body.scrollLeft}),window.getComputedStyle?o.computedStyle=function(h,g){return g?(window.getComputedStyle(h,"")||{})[g]||"":window.getComputedStyle(h,"")||{}}:o.computedStyle=function(h,g){return g?h.currentStyle[g]:h.currentStyle},o.setInnerHtml=function(h,g){var d=h.cloneNode(!1);return d.innerHTML=g,h.parentNode.replaceChild(d,h),d},"textContent"in document.documentElement?(o.setInnerText=function(h,g){h.textContent=g},o.getInnerText=function(h){return h.textContent}):(o.setInnerText=function(h,g){h.innerText=g},o.getInnerText=function(h){return h.innerText}),o.getParentWindow=function(h){return h.defaultView||h.parentWindow}}),ace.define("ace/lib/oop",["require","exports","module"],function(s,o,f){o.inherits=function(n,h){n.super_=h,n.prototype=Object.create(h.prototype,{constructor:{value:n,enumerable:!1,writable:!0,configurable:!0}})},o.mixin=function(n,h){for(var g in h)n[g]=h[g];return n},o.implement=function(n,h){o.mixin(n,h)}}),ace.define("ace/lib/keys",["require","exports","module","ace/lib/fixoldbrowsers","ace/lib/oop"],function(s,o,f){s("./fixoldbrowsers");var n=s("./oop"),h=function(){var g={MODIFIER_KEYS:{16:"Shift",17:"Ctrl",18:"Alt",224:"Meta"},KEY_MODS:{ctrl:1,alt:2,option:2,shift:4,super:8,meta:8,command:8,cmd:8},FUNCTION_KEYS:{8:"Backspace",9:"Tab",13:"Return",19:"Pause",27:"Esc",32:"Space",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"Left",38:"Up",39:"Right",40:"Down",44:"Print",45:"Insert",46:"Delete",96:"Numpad0",97:"Numpad1",98:"Numpad2",99:"Numpad3",100:"Numpad4",101:"Numpad5",102:"Numpad6",103:"Numpad7",104:"Numpad8",105:"Numpad9","-13":"NumpadEnter",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"Numlock",145:"Scrolllock"},PRINTABLE_KEYS:{32:" ",48:"0",49:"1",50:"2",51:"3",52:"4",53:"5",54:"6",55:"7",56:"8",57:"9",59:";",61:"=",65:"a",66:"b",67:"c",68:"d",69:"e",70:"f",71:"g",72:"h",73:"i",74:"j",75:"k",76:"l",77:"m",78:"n",79:"o",80:"p",81:"q",82:"r",83:"s",84:"t",85:"u",86:"v",87:"w",88:"x",89:"y",90:"z",107:"+",109:"-",110:".",186:";",187:"=",188:",",189:"-",190:".",191:"/",192:"`",219:"[",220:"\\",221:"]",222:"'",111:"/",106:"*"}},d,l;for(l in g.FUNCTION_KEYS)d=g.FUNCTION_KEYS[l].toLowerCase(),g[d]=parseInt(l,10);for(l in g.PRINTABLE_KEYS)d=g.PRINTABLE_KEYS[l].toLowerCase(),g[d]=parseInt(l,10);return n.mixin(g,g.MODIFIER_KEYS),n.mixin(g,g.PRINTABLE_KEYS),n.mixin(g,g.FUNCTION_KEYS),g.enter=g.return,g.escape=g.esc,g.del=g.delete,g[173]="-",function(){for(var c=["cmd","ctrl","alt","shift"],a=Math.pow(2,c.length);a--;)g.KEY_MODS[a]=c.filter(function(F){return a&g.KEY_MODS[F]}).join("-")+"-"}(),g.KEY_MODS[0]="",g.KEY_MODS[-1]="input-",g}();n.mixin(o,h),o.keyCodeToString=function(g){var d=h[g];return typeof d!="string"&&(d=String.fromCharCode(g)),d.toLowerCase()}}),ace.define("ace/lib/useragent",["require","exports","module"],function(s,o,f){if(o.OS={LINUX:"LINUX",MAC:"MAC",WINDOWS:"WINDOWS"},o.getOS=function(){return o.isMac?o.OS.MAC:o.isLinux?o.OS.LINUX:o.OS.WINDOWS},typeof navigator=="object"){var n=(navigator.platform.match(/mac|win|linux/i)||["other"])[0].toLowerCase(),h=navigator.userAgent;o.isWin=n=="win",o.isMac=n=="mac",o.isLinux=n=="linux",o.isIE=navigator.appName=="Microsoft Internet Explorer"||navigator.appName.indexOf("MSAppHost")>=0?parseFloat((h.match(/(?:MSIE |Trident\/[0-9]+[\.0-9]+;.*rv:)([0-9]+[\.0-9]+)/)||[])[1]):parseFloat((h.match(/(?:Trident\/[0-9]+[\.0-9]+;.*rv:)([0-9]+[\.0-9]+)/)||[])[1]),o.isOldIE=o.isIE&&o.isIE<9,o.isGecko=o.isMozilla=(window.Controllers||window.controllers)&&window.navigator.product==="Gecko",o.isOldGecko=o.isGecko&&parseInt((h.match(/rv:(\d+)/)||[])[1],10)<4,o.isOpera=window.opera&&Object.prototype.toString.call(window.opera)=="[object Opera]",o.isWebKit=parseFloat(h.split("WebKit/")[1])||void 0,o.isChrome=parseFloat(h.split(" Chrome/")[1])||void 0,o.isAIR=h.indexOf("AdobeAIR")>=0,o.isIPad=h.indexOf("iPad")>=0,o.isTouchPad=h.indexOf("TouchPad")>=0,o.isChromeOS=h.indexOf(" CrOS ")>=0}}),ace.define("ace/lib/event",["require","exports","module","ace/lib/keys","ace/lib/useragent"],function(s,o,f){var n=s("./keys"),h=s("./useragent"),g=null,d=0;o.addListener=function(p,m,b){if(p.addEventListener)return p.addEventListener(m,b,!1);if(p.attachEvent){var C=function(){b.call(p,window.event)};b._wrapper=C,p.attachEvent("on"+m,C)}},o.removeListener=function(p,m,b){if(p.removeEventListener)return p.removeEventListener(m,b,!1);p.detachEvent&&p.detachEvent("on"+m,b._wrapper||b)},o.stopEvent=function(p){return o.stopPropagation(p),o.preventDefault(p),!1},o.stopPropagation=function(p){p.stopPropagation?p.stopPropagation():p.cancelBubble=!0},o.preventDefault=function(p){p.preventDefault?p.preventDefault():p.returnValue=!1},o.getButton=function(p){return p.type=="dblclick"?0:p.type=="contextmenu"||h.isMac&&p.ctrlKey&&!p.altKey&&!p.shiftKey?2:p.preventDefault?p.button:{1:0,2:2,4:1}[p.button]},o.capture=function(p,m,b){function C(k){m&&m(k),b&&b(k),o.removeListener(document,"mousemove",m,!0),o.removeListener(document,"mouseup",C,!0),o.removeListener(document,"dragstart",C,!0)}return o.addListener(document,"mousemove",m,!0),o.addListener(document,"mouseup",C,!0),o.addListener(document,"dragstart",C,!0),C},o.addTouchMoveListener=function(p,m){if("ontouchmove"in p){var b,C;o.addListener(p,"touchstart",function(k){var T=k.changedTouches[0];b=T.clientX,C=T.clientY}),o.addListener(p,"touchmove",function(k){var T=1,w=k.changedTouches[0];k.wheelX=-(w.clientX-b)/T,k.wheelY=-(w.clientY-C)/T,b=w.clientX,C=w.clientY,m(k)})}},o.addMouseWheelListener=function(p,m){"onmousewheel"in p?o.addListener(p,"mousewheel",function(b){var C=8;b.wheelDeltaX!==void 0?(b.wheelX=-b.wheelDeltaX/C,b.wheelY=-b.wheelDeltaY/C):(b.wheelX=0,b.wheelY=-b.wheelDelta/C),m(b)}):"onwheel"in p?o.addListener(p,"wheel",function(b){var C=.35;switch(b.deltaMode){case b.DOM_DELTA_PIXEL:b.wheelX=b.deltaX*C||0,b.wheelY=b.deltaY*C||0;break;case b.DOM_DELTA_LINE:case b.DOM_DELTA_PAGE:b.wheelX=(b.deltaX||0)*5,b.wheelY=(b.deltaY||0)*5;break}m(b)}):o.addListener(p,"DOMMouseScroll",function(b){b.axis&&b.axis==b.HORIZONTAL_AXIS?(b.wheelX=(b.detail||0)*5,b.wheelY=0):(b.wheelX=0,b.wheelY=(b.detail||0)*5),m(b)})},o.addMultiMouseDownListener=function(p,m,b,C){var k=0,T,w,A,M={2:"dblclick",3:"tripleclick",4:"quadclick"};function x(N){if(o.getButton(N)!==0?k=0:N.detail>1?(k++,k>4&&(k=1)):k=1,h.isIE){var j=Math.abs(N.clientX-T)>5||Math.abs(N.clientY-w)>5;(!A||j)&&(k=1),A&&clearTimeout(A),A=setTimeout(function(){A=null},m[k-1]||600),k==1&&(T=N.clientX,w=N.clientY)}if(N._clicks=k,b[C]("mousedown",N),k>4)k=0;else if(k>1)return b[C](M[k],N)}function R(N){k=2,A&&clearTimeout(A),A=setTimeout(function(){A=null},m[k-1]||600),b[C]("mousedown",N),b[C](M[k],N)}Array.isArray(p)||(p=[p]),p.forEach(function(N){o.addListener(N,"mousedown",x),h.isOldIE&&o.addListener(N,"dblclick",R)})};var l=h.isMac&&h.isOpera&&!("KeyboardEvent"in window)?function(p){return 0|(p.metaKey?1:0)|(p.altKey?2:0)|(p.shiftKey?4:0)|(p.ctrlKey?8:0)}:function(p){return 0|(p.ctrlKey?1:0)|(p.altKey?2:0)|(p.shiftKey?4:0)|(p.metaKey?8:0)};o.getModifierString=function(p){return n.KEY_MODS[l(p)]};function c(p,m,b){var C=l(m);if(!h.isMac&&g){if(m.getModifierState&&(m.getModifierState("OS")||m.getModifierState("Win"))&&(C|=8),g.altGr)if((3&C)!=3)g.altGr=0;else return;if(b===18||b===17){var k="location"in m?m.location:m.keyLocation;if(b===17&&k===1)g[b]==1&&(d=m.timeStamp);else if(b===18&&C===3&&k===2){var T=m.timeStamp-d;T<50&&(g.altGr=!0)}}}if(b in n.MODIFIER_KEYS&&(b=-1),C&8&&b>=91&&b<=93&&(b=-1),!C&&b===13){var k="location"in m?m.location:m.keyLocation;if(k===3&&(p(m,C,-b),m.defaultPrevented))return}if(h.isChromeOS&&C&8){if(p(m,C,b),m.defaultPrevented)return;C&=-9}return!C&&!(b in n.FUNCTION_KEYS)&&!(b in n.PRINTABLE_KEYS)?!1:p(m,C,b)}o.addCommandKeyListener=function(p,m){var b=o.addListener;if(h.isOldGecko||h.isOpera&&!("KeyboardEvent"in window)){var C=null;b(p,"keydown",function(T){C=T.keyCode}),b(p,"keypress",function(T){return c(m,T,C)})}else{var k=null;b(p,"keydown",function(T){g[T.keyCode]=(g[T.keyCode]||0)+1;var w=c(m,T,T.keyCode);return k=T.defaultPrevented,w}),b(p,"keypress",function(T){k&&(T.ctrlKey||T.altKey||T.shiftKey||T.metaKey)&&(o.stopEvent(T),k=null)}),b(p,"keyup",function(T){g[T.keyCode]=null}),g||(a(),b(window,"focus",a))}};function a(){g=Object.create(null)}if(typeof window=="object"&&window.postMessage&&!h.isOldIE){var F=1;o.nextTick=function(p,m){m=m||window;var b="zero-timeout-message-"+F;o.addListener(m,"message",function C(k){k.data==b&&(o.stopPropagation(k),o.removeListener(m,"message",C),p())}),m.postMessage(b,"*")}}o.nextFrame=typeof window=="object"&&(window.requestAnimationFrame||window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame||window.msRequestAnimationFrame||window.oRequestAnimationFrame),o.nextFrame?o.nextFrame=o.nextFrame.bind(window):o.nextFrame=function(p){setTimeout(p,17)}}),ace.define("ace/lib/lang",["require","exports","module"],function(s,o,f){o.last=function(g){return g[g.length-1]},o.stringReverse=function(g){return g.split("").reverse().join("")},o.stringRepeat=function(g,d){for(var l="";d>0;)d&1&&(l+=g),(d>>=1)&&(g+=g);return l};var n=/^\s\s*/,h=/\s\s*$/;o.stringTrimLeft=function(g){return g.replace(n,"")},o.stringTrimRight=function(g){return g.replace(h,"")},o.copyObject=function(g){var d={};for(var l in g)d[l]=g[l];return d},o.copyArray=function(g){for(var d=[],l=0,c=g.length;l<c;l++)g[l]&&typeof g[l]=="object"?d[l]=this.copyObject(g[l]):d[l]=g[l];return d},o.deepCopy=function g(d){if(typeof d!="object"||!d)return d;var l;if(Array.isArray(d)){l=[];for(var c=0;c<d.length;c++)l[c]=g(d[c]);return l}if(Object.prototype.toString.call(d)!=="[object Object]")return d;l={};for(var c in d)l[c]=g(d[c]);return l},o.arrayToMap=function(g){for(var d={},l=0;l<g.length;l++)d[g[l]]=1;return d},o.createMap=function(g){var d=Object.create(null);for(var l in g)d[l]=g[l];return d},o.arrayRemove=function(g,d){for(var l=0;l<=g.length;l++)d===g[l]&&g.splice(l,1)},o.escapeRegExp=function(g){return g.replace(/([.*+?^${}()|[\]\/\\])/g,"\\$1")},o.escapeHTML=function(g){return g.replace(/&/g,"&#38;").replace(/"/g,"&#34;").replace(/'/g,"&#39;").replace(/</g,"&#60;")},o.getMatchOffsets=function(g,d){var l=[];return g.replace(d,function(c){l.push({offset:arguments[arguments.length-2],length:c.length})}),l},o.deferredCall=function(g){var d=null,l=function(){d=null,g()},c=function(a){return c.cancel(),d=setTimeout(l,a||0),c};return c.schedule=c,c.call=function(){return this.cancel(),g(),c},c.cancel=function(){return clearTimeout(d),d=null,c},c.isPending=function(){return d},c},o.delayedCall=function(g,d){var l=null,c=function(){l=null,g()},a=function(F){l==null&&(l=setTimeout(c,F||d))};return a.delay=function(F){l&&clearTimeout(l),l=setTimeout(c,F||d)},a.schedule=a,a.call=function(){this.cancel(),g()},a.cancel=function(){l&&clearTimeout(l),l=null},a.isPending=function(){return l},a}}),ace.define("ace/keyboard/textinput",["require","exports","module","ace/lib/event","ace/lib/useragent","ace/lib/dom","ace/lib/lang"],function(s,o,f){var n=s("../lib/event"),h=s("../lib/useragent"),g=s("../lib/dom"),d=s("../lib/lang"),l=h.isChrome<18,c=h.isIE,a=function(F,p){var m=g.createElement("textarea");m.className="ace_text-input",h.isTouchPad&&m.setAttribute("x-palm-disable-auto-cap",!0),m.setAttribute("wrap","off"),m.setAttribute("autocorrect","off"),m.setAttribute("autocapitalize","off"),m.setAttribute("spellcheck",!1),m.style.opacity="0",h.isOldIE&&(m.style.top="-1000px"),F.insertBefore(m,F.firstChild);var b="",C=!1,k=!1,T=!1,w="",A=!0;try{var M=document.activeElement===m}catch{}n.addListener(m,"blur",function(G){p.onBlur(G),M=!1}),n.addListener(m,"focus",function(G){M=!0,p.onFocus(G),N()}),this.focus=function(){if(w)return m.focus();var G=m.style.top;m.style.position="fixed",m.style.top="0px",m.focus(),setTimeout(function(){m.style.position="",m.style.top=="0px"&&(m.style.top=G)},0)},this.blur=function(){m.blur()},this.isFocused=function(){return M};var x=d.delayedCall(function(){M&&N(A)}),R=d.delayedCall(function(){T||(m.value=b,M&&N())});function N(G){if(!T){if(T=!0,ce)O=0,I=G?0:m.value.length-1;else var O=G?2:1,I=2;try{m.setSelectionRange(O,I)}catch{}T=!1}}function j(){T||(m.value=b,h.isWebKit&&R.schedule())}h.isWebKit||p.addEventListener("changeSelection",function(){p.selection.isEmpty()!=A&&(A=!A,x.schedule())}),j(),M&&p.onFocus();var B=function(G){return G.selectionStart===0&&G.selectionEnd===G.value.length};if(!m.setSelectionRange&&m.createTextRange&&(m.setSelectionRange=function(G,O){var I=this.createTextRange();I.collapse(!0),I.moveStart("character",G),I.moveEnd("character",O),I.select()},B=function(G){try{var O=G.ownerDocument.selection.createRange()}catch{}return!O||O.parentElement()!=G?!1:O.text==G.value}),h.isOldIE){var q=!1,U=function(G){if(!q){var O=m.value;if(!(T||!O||O==b)){if(G&&O==b[0])return Z.schedule();he(O),q=!0,j(),q=!1}}},Z=d.delayedCall(U);n.addListener(m,"propertychange",U);var re={13:1,27:1};n.addListener(m,"keyup",function(G){if(T&&(!m.value||re[G.keyCode])&&setTimeout(se,0),(m.value.charCodeAt(0)||0)<129)return Z.call();T?me():ne()}),n.addListener(m,"keydown",function(G){Z.schedule(50)})}var le=function(G){C?C=!1:B(m)?(p.selectAll(),N()):ce&&N(p.selection.isEmpty())},ce=null;this.setInputHandler=function(G){ce=G},this.getInputHandler=function(){return ce};var de=!1,he=function(G){ce&&(G=ce(G),ce=null),k?(N(),G&&p.onPaste(G),k=!1):G==b.charAt(0)?de?p.execCommand("del",{source:"ace"}):p.execCommand("backspace",{source:"ace"}):(G.substring(0,2)==b?G=G.substr(2):G.charAt(0)==b.charAt(0)?G=G.substr(1):G.charAt(G.length-1)==b.charAt(0)&&(G=G.slice(0,-1)),G.charAt(G.length-1)==b.charAt(0)&&(G=G.slice(0,-1)),G&&p.onTextInput(G)),de&&(de=!1)},Fe=function(G){if(!T){var O=m.value;he(O),j()}},ge=function(G,O,I){var v=G.clipboardData||window.clipboardData;if(!(!v||l)){var E=c||I?"Text":"text/plain";try{return O?v.setData(E,O)!==!1:v.getData(E)}catch(L){if(!I)return ge(L,O,!0)}}},ye=function(G,O){var I=p.getCopyText();if(!I)return n.preventDefault(G);ge(G,I)?(O?p.onCut():p.onCopy(),n.preventDefault(G)):(C=!0,m.value=I,m.select(),setTimeout(function(){C=!1,j(),N(),O?p.onCut():p.onCopy()}))},Y=function(G){ye(G,!0)},ue=function(G){ye(G,!1)},Ee=function(G){var O=ge(G);typeof O=="string"?(O&&p.onPaste(O,G),h.isIE&&setTimeout(N),n.preventDefault(G)):(m.value="",k=!0)};n.addCommandKeyListener(m,p.onCommandKey.bind(p)),n.addListener(m,"select",le),n.addListener(m,"input",Fe),n.addListener(m,"cut",Y),n.addListener(m,"copy",ue),n.addListener(m,"paste",Ee),(!("oncut"in m)||!("oncopy"in m)||!("onpaste"in m))&&n.addListener(F,"keydown",function(G){if(!(h.isMac&&!G.metaKey||!G.ctrlKey))switch(G.keyCode){case 67:ue(G);break;case 86:Ee(G);break;case 88:Y(G);break}});var ne=function(G){T||!p.onCompositionStart||p.$readOnly||(T={},T.canUndo=p.session.$undoManager,p.onCompositionStart(),setTimeout(me,0),p.on("mousedown",se),T.canUndo&&!p.selection.isEmpty()&&(p.insert(""),p.session.markUndoGroup(),p.selection.clearSelection()),p.session.markUndoGroup())},me=function(){if(!(!T||!p.onCompositionUpdate||p.$readOnly)){var G=m.value.replace(/\x01/g,"");if(T.lastValue!==G&&(p.onCompositionUpdate(G),T.lastValue&&p.undo(),T.canUndo&&(T.lastValue=G),T.lastValue)){var O=p.selection.getRange();p.insert(T.lastValue),p.session.markUndoGroup(),T.range=p.selection.getRange(),p.selection.setRange(O),p.selection.clearSelection()}}},se=function(G){if(!(!p.onCompositionEnd||p.$readOnly)){var O=T;T=!1;var I=setTimeout(function(){I=null;var v=m.value.replace(/\x01/g,"");T||(v==O.lastValue?j():!O.lastValue&&v&&(j(),he(v)))});ce=function(E){return I&&clearTimeout(I),E=E.replace(/\x01/g,""),E==O.lastValue?"":(O.lastValue&&I&&p.undo(),E)},p.onCompositionEnd(),p.removeListener("mousedown",se),G.type=="compositionend"&&O.range&&p.selection.setRange(O.range),h.isChrome&&h.isChrome>=53&&Fe()}},ve=d.delayedCall(me,50);n.addListener(m,"compositionstart",ne),h.isGecko?n.addListener(m,"text",function(){ve.schedule()}):(n.addListener(m,"keyup",function(){ve.schedule()}),n.addListener(m,"keydown",function(){ve.schedule()})),n.addListener(m,"compositionend",se),this.getElement=function(){return m},this.setReadOnly=function(G){m.readOnly=G},this.onContextMenu=function(G){de=!0,N(p.selection.isEmpty()),p._emit("nativecontextmenu",{target:p,domEvent:G}),this.moveToMouse(G,!0)},this.moveToMouse=function(G,O){if(!(!O&&h.isOldIE)){w||(w=m.style.cssText),m.style.cssText=(O?"z-index:100000;":"")+"height:"+m.style.height+";"+(h.isIE?"opacity:0.1;":"");var I=p.container.getBoundingClientRect(),v=g.computedStyle(p.container),E=I.top+(parseInt(v.borderTopWidth)||0),L=I.left+(parseInt(I.borderLeftWidth)||0),S=I.bottom-E-m.clientHeight-2,P=function(W){m.style.left=W.clientX-L-2+"px",m.style.top=Math.min(W.clientY-E-2,S)+"px"};P(G),G.type=="mousedown"&&(p.renderer.$keepTextAreaAtCursor&&(p.renderer.$keepTextAreaAtCursor=null),clearTimeout(Pe),h.isWin&&!h.isOldIE&&n.capture(p.container,P,Ie))}},this.onContextMenuClose=Ie;var Pe;function Ie(){clearTimeout(Pe),Pe=setTimeout(function(){w&&(m.style.cssText=w,w=""),p.renderer.$keepTextAreaAtCursor==null&&(p.renderer.$keepTextAreaAtCursor=!0,p.renderer.$moveTextAreaToCursor())},h.isOldIE?200:0)}var z=function(G){p.textInput.onContextMenu(G),Ie()};n.addListener(m,"mouseup",z),n.addListener(m,"mousedown",function(G){G.preventDefault(),Ie()}),n.addListener(p.renderer.scroller,"contextmenu",z),n.addListener(m,"contextmenu",z)};o.TextInput=a}),ace.define("ace/mouse/default_handlers",["require","exports","module","ace/lib/dom","ace/lib/event","ace/lib/useragent"],function(s,o,f){s("../lib/dom"),s("../lib/event"),s("../lib/useragent");var n=0;function h(l){l.$clickSelection=null;var c=l.editor;c.setDefaultHandler("mousedown",this.onMouseDown.bind(l)),c.setDefaultHandler("dblclick",this.onDoubleClick.bind(l)),c.setDefaultHandler("tripleclick",this.onTripleClick.bind(l)),c.setDefaultHandler("quadclick",this.onQuadClick.bind(l)),c.setDefaultHandler("mousewheel",this.onMouseWheel.bind(l)),c.setDefaultHandler("touchmove",this.onTouchMove.bind(l));var a=["select","startSelect","selectEnd","selectAllEnd","selectByWordsEnd","selectByLinesEnd","dragWait","dragWaitEnd","focusWait"];a.forEach(function(F){l[F]=this[F]},this),l.selectByLines=this.extendSelectionBy.bind(l,"getLineRange"),l.selectByWords=this.extendSelectionBy.bind(l,"getWordRange")}(function(){this.onMouseDown=function(l){var c=l.inSelection(),a=l.getDocumentPosition();this.mousedownEvent=l;var F=this.editor,p=l.getButton();if(p!==0){var m=F.getSelectionRange(),b=m.isEmpty();F.$blockScrolling++,(b||p==1)&&F.selection.moveToPosition(a),F.$blockScrolling--,p==2&&F.textInput.onContextMenu(l.domEvent);return}if(this.mousedownEvent.time=Date.now(),c&&!F.isFocused()&&(F.focus(),this.$focusTimout&&!this.$clickSelection&&!F.inMultiSelectMode)){this.setState("focusWait"),this.captureMouse(l);return}return this.captureMouse(l),this.startSelect(a,l.domEvent._clicks>1),l.preventDefault()},this.startSelect=function(l,c){l=l||this.editor.renderer.screenToTextCoordinates(this.x,this.y);var a=this.editor;a.$blockScrolling++,this.mousedownEvent.getShiftKey()?a.selection.selectToPosition(l):c||a.selection.moveToPosition(l),c||this.select(),a.renderer.scroller.setCapture&&a.renderer.scroller.setCapture(),a.setStyle("ace_selecting"),this.setState("select"),a.$blockScrolling--},this.select=function(){var l,c=this.editor,a=c.renderer.screenToTextCoordinates(this.x,this.y);if(c.$blockScrolling++,this.$clickSelection){var F=this.$clickSelection.comparePoint(a);if(F==-1)l=this.$clickSelection.end;else if(F==1)l=this.$clickSelection.start;else{var p=d(this.$clickSelection,a);a=p.cursor,l=p.anchor}c.selection.setSelectionAnchor(l.row,l.column)}c.selection.selectToPosition(a),c.$blockScrolling--,c.renderer.scrollCursorIntoView()},this.extendSelectionBy=function(l){var c,a=this.editor,F=a.renderer.screenToTextCoordinates(this.x,this.y),p=a.selection[l](F.row,F.column);if(a.$blockScrolling++,this.$clickSelection){var m=this.$clickSelection.comparePoint(p.start),b=this.$clickSelection.comparePoint(p.end);if(m==-1&&b<=0)c=this.$clickSelection.end,(p.end.row!=F.row||p.end.column!=F.column)&&(F=p.start);else if(b==1&&m>=0)c=this.$clickSelection.start,(p.start.row!=F.row||p.start.column!=F.column)&&(F=p.end);else if(m==-1&&b==1)F=p.end,c=p.start;else{var C=d(this.$clickSelection,F);F=C.cursor,c=C.anchor}a.selection.setSelectionAnchor(c.row,c.column)}a.selection.selectToPosition(F),a.$blockScrolling--,a.renderer.scrollCursorIntoView()},this.selectEnd=this.selectAllEnd=this.selectByWordsEnd=this.selectByLinesEnd=function(){this.$clickSelection=null,this.editor.unsetStyle("ace_selecting"),this.editor.renderer.scroller.releaseCapture&&this.editor.renderer.scroller.releaseCapture()},this.focusWait=function(){var l=g(this.mousedownEvent.x,this.mousedownEvent.y,this.x,this.y),c=Date.now();(l>n||c-this.mousedownEvent.time>this.$focusTimout)&&this.startSelect(this.mousedownEvent.getDocumentPosition())},this.onDoubleClick=function(l){var c=l.getDocumentPosition(),a=this.editor,F=a.session,p=F.getBracketRange(c);p?(p.isEmpty()&&(p.start.column--,p.end.column++),this.setState("select")):(p=a.selection.getWordRange(c.row,c.column),this.setState("selectByWords")),this.$clickSelection=p,this.select()},this.onTripleClick=function(l){var c=l.getDocumentPosition(),a=this.editor;this.setState("selectByLines");var F=a.getSelectionRange();F.isMultiLine()&&F.contains(c.row,c.column)?(this.$clickSelection=a.selection.getLineRange(F.start.row),this.$clickSelection.end=a.selection.getLineRange(F.end.row).end):this.$clickSelection=a.selection.getLineRange(c.row),this.select()},this.onQuadClick=function(l){var c=this.editor;c.selectAll(),this.$clickSelection=c.getSelectionRange(),this.setState("selectAll")},this.onMouseWheel=function(l){if(!l.getAccelKey()){l.getShiftKey()&&l.wheelY&&!l.wheelX&&(l.wheelX=l.wheelY,l.wheelY=0);var c=l.domEvent.timeStamp,a=c-(this.$lastScrollTime||0),F=this.editor,p=F.renderer.isScrollableBy(l.wheelX*l.speed,l.wheelY*l.speed);if(p||a<200)return this.$lastScrollTime=c,F.renderer.scrollBy(l.wheelX*l.speed,l.wheelY*l.speed),l.stop()}},this.onTouchMove=function(l){var c=l.domEvent.timeStamp,a=c-(this.$lastScrollTime||0),F=this.editor,p=F.renderer.isScrollableBy(l.wheelX*l.speed,l.wheelY*l.speed);if(p||a<200)return this.$lastScrollTime=c,F.renderer.scrollBy(l.wheelX*l.speed,l.wheelY*l.speed),l.stop()}}).call(h.prototype),o.DefaultHandlers=h;function g(l,c,a,F){return Math.sqrt(Math.pow(a-l,2)+Math.pow(F-c,2))}function d(l,c){if(l.start.row==l.end.row)var a=2*c.column-l.start.column-l.end.column;else if(l.start.row==l.end.row-1&&!l.start.column&&!l.end.column)var a=c.column-4;else var a=2*c.row-l.start.row-l.end.row;return a<0?{cursor:l.start,anchor:l.end}:{cursor:l.end,anchor:l.start}}}),ace.define("ace/tooltip",["require","exports","module","ace/lib/oop","ace/lib/dom"],function(s,o,f){s("./lib/oop");var n=s("./lib/dom");function h(g){this.isOpen=!1,this.$element=null,this.$parentNode=g}(function(){this.$init=function(){return this.$element=n.createElement("div"),this.$element.className="ace_tooltip",this.$element.style.display="none",this.$parentNode.appendChild(this.$element),this.$element},this.getElement=function(){return this.$element||this.$init()},this.setText=function(g){n.setInnerText(this.getElement(),g)},this.setHtml=function(g){this.getElement().innerHTML=g},this.setPosition=function(g,d){this.getElement().style.left=g+"px",this.getElement().style.top=d+"px"},this.setClassName=function(g){n.addCssClass(this.getElement(),g)},this.show=function(g,d,l){g!=null&&this.setText(g),d!=null&&l!=null&&this.setPosition(d,l),this.isOpen||(this.getElement().style.display="block",this.isOpen=!0)},this.hide=function(){this.isOpen&&(this.getElement().style.display="none",this.isOpen=!1)},this.getHeight=function(){return this.getElement().offsetHeight},this.getWidth=function(){return this.getElement().offsetWidth}}).call(h.prototype),o.Tooltip=h}),ace.define("ace/mouse/default_gutter_handler",["require","exports","module","ace/lib/dom","ace/lib/oop","ace/lib/event","ace/tooltip"],function(s,o,f){var n=s("../lib/dom"),h=s("../lib/oop"),g=s("../lib/event"),d=s("../tooltip").Tooltip;function l(a){var F=a.editor,p=F.renderer.$gutterLayer,m=new c(F.container);a.editor.setDefaultHandler("guttermousedown",function(M){if(!(!F.isFocused()||M.getButton()!=0)){var x=p.getRegion(M);if(x!="foldWidgets"){var R=M.getDocumentPosition().row,N=F.session.selection;if(M.getShiftKey())N.selectTo(R,0);else{if(M.domEvent.detail==2)return F.selectAll(),M.preventDefault();a.$clickSelection=F.selection.getLineRange(R)}return a.setState("selectByLines"),a.captureMouse(M),M.preventDefault()}}});var b,C,k;function T(){var M=C.getDocumentPosition().row,x=p.$annotations[M];if(!x)return w();var R=F.session.getLength();if(M==R){var N=F.renderer.pixelToScreenCoordinates(0,C.y).row,j=C.$pos;if(N>F.session.documentToScreenRow(j.row,j.column))return w()}if(k!=x)if(k=x.text.join("<br/>"),m.setHtml(k),m.show(),F._signal("showGutterTooltip",m),F.on("mousewheel",w),a.$tooltipFollowsMouse)A(C);else{var B=C.domEvent.target,q=B.getBoundingClientRect(),U=m.getElement().style;U.left=q.right+"px",U.top=q.bottom+"px"}}function w(){b&&(b=clearTimeout(b)),k&&(m.hide(),k=null,F._signal("hideGutterTooltip",m),F.removeEventListener("mousewheel",w))}function A(M){m.setPosition(M.x,M.y)}a.editor.setDefaultHandler("guttermousemove",function(M){var x=M.domEvent.target||M.domEvent.srcElement;if(n.hasCssClass(x,"ace_fold-widget"))return w();k&&a.$tooltipFollowsMouse&&A(M),C=M,!b&&(b=setTimeout(function(){b=null,C&&!a.isMousePressed?T():w()},50))}),g.addListener(F.renderer.$gutter,"mouseout",function(M){C=null,!(!k||b)&&(b=setTimeout(function(){b=null,w()},50))}),F.on("changeSession",w)}function c(a){d.call(this,a)}h.inherits(c,d),function(){this.setPosition=function(a,F){var p=window.innerWidth||document.documentElement.clientWidth,m=window.innerHeight||document.documentElement.clientHeight,b=this.getWidth(),C=this.getHeight();a+=15,F+=15,a+b>p&&(a-=a+b-p),F+C>m&&(F-=20+C),d.prototype.setPosition.call(this,a,F)}}.call(c.prototype),o.GutterHandler=l}),ace.define("ace/mouse/mouse_event",["require","exports","module","ace/lib/event","ace/lib/useragent"],function(s,o,f){var n=s("../lib/event"),h=s("../lib/useragent"),g=o.MouseEvent=function(d,l){this.domEvent=d,this.editor=l,this.x=this.clientX=d.clientX,this.y=this.clientY=d.clientY,this.$pos=null,this.$inSelection=null,this.propagationStopped=!1,this.defaultPrevented=!1};(function(){this.stopPropagation=function(){n.stopPropagation(this.domEvent),this.propagationStopped=!0},this.preventDefault=function(){n.preventDefault(this.domEvent),this.defaultPrevented=!0},this.stop=function(){this.stopPropagation(),this.preventDefault()},this.getDocumentPosition=function(){return this.$pos?this.$pos:(this.$pos=this.editor.renderer.screenToTextCoordinates(this.clientX,this.clientY),this.$pos)},this.inSelection=function(){if(this.$inSelection!==null)return this.$inSelection;var d=this.editor,l=d.getSelectionRange();if(l.isEmpty())this.$inSelection=!1;else{var c=this.getDocumentPosition();this.$inSelection=l.contains(c.row,c.column)}return this.$inSelection},this.getButton=function(){return n.getButton(this.domEvent)},this.getShiftKey=function(){return this.domEvent.shiftKey},this.getAccelKey=h.isMac?function(){return this.domEvent.metaKey}:function(){return this.domEvent.ctrlKey}}).call(g.prototype)}),ace.define("ace/mouse/dragdrop_handler",["require","exports","module","ace/lib/dom","ace/lib/event","ace/lib/useragent"],function(s,o,f){var n=s("../lib/dom"),h=s("../lib/event"),g=s("../lib/useragent"),d=200,l=200,c=5;function a(p){var m=p.editor,b=n.createElement("img");b.src="data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==",g.isOpera&&(b.style.cssText="width:1px;height:1px;position:fixed;top:0;left:0;z-index:2147483647;opacity:0;");var C=["dragWait","dragWaitEnd","startDrag","dragReadyEnd","onMouseDrag"];C.forEach(function(ue){p[ue]=this[ue]},this),m.addEventListener("mousedown",this.onMouseDown.bind(p));var k=m.container,T,w,A,M,x,R,N=0,j,B,q,U,Z;this.onDragStart=function(ue){if(this.cancelDrag||!k.draggable){var Ee=this;return setTimeout(function(){Ee.startSelect(),Ee.captureMouse(ue)},0),ue.preventDefault()}x=m.getSelectionRange();var ne=ue.dataTransfer;ne.effectAllowed=m.getReadOnly()?"copy":"copyMove",g.isOpera&&(m.container.appendChild(b),b.scrollTop=0),ne.setDragImage&&ne.setDragImage(b,0,0),g.isOpera&&m.container.removeChild(b),ne.clearData(),ne.setData("Text",m.session.getTextRange()),B=!0,this.setState("drag")},this.onDragEnd=function(ue){if(k.draggable=!1,B=!1,this.setState(null),!m.getReadOnly()){var Ee=ue.dataTransfer.dropEffect;!j&&Ee=="move"&&m.session.remove(m.getSelectionRange()),m.renderer.$cursorLayer.setBlinking(!0)}this.editor.unsetStyle("ace_dragging"),this.editor.renderer.setCursorStyle("")},this.onDragEnter=function(ue){if(!(m.getReadOnly()||!ye(ue.dataTransfer)))return w=ue.clientX,A=ue.clientY,T||de(),N++,ue.dataTransfer.dropEffect=j=Y(ue),h.preventDefault(ue)},this.onDragOver=function(ue){if(!(m.getReadOnly()||!ye(ue.dataTransfer)))return w=ue.clientX,A=ue.clientY,T||(de(),N++),Fe!==null&&(Fe=null),ue.dataTransfer.dropEffect=j=Y(ue),h.preventDefault(ue)},this.onDragLeave=function(ue){if(N--,N<=0&&T)return he(),j=null,h.preventDefault(ue)},this.onDrop=function(ue){if(R){var Ee=ue.dataTransfer;if(B)switch(j){case"move":x.contains(R.row,R.column)?x={start:R,end:R}:x=m.moveText(x,R);break;case"copy":x=m.moveText(x,R,!0);break}else{var ne=Ee.getData("Text");x={start:R,end:m.session.insert(R,ne)},m.focus(),j=null}return he(),h.preventDefault(ue)}},h.addListener(k,"dragstart",this.onDragStart.bind(p)),h.addListener(k,"dragend",this.onDragEnd.bind(p)),h.addListener(k,"dragenter",this.onDragEnter.bind(p)),h.addListener(k,"dragover",this.onDragOver.bind(p)),h.addListener(k,"dragleave",this.onDragLeave.bind(p)),h.addListener(k,"drop",this.onDrop.bind(p));function re(ue,Ee){var ne=Date.now(),me=!Ee||ue.row!=Ee.row,se=!Ee||ue.column!=Ee.column;if(!U||me||se)m.$blockScrolling+=1,m.moveCursorToPosition(ue),m.$blockScrolling-=1,U=ne,Z={x:w,y:A};else{var ve=F(Z.x,Z.y,w,A);ve>c?U=null:ne-U>=l&&(m.renderer.scrollCursorIntoView(),U=null)}}function le(ue,Ee){var ne=Date.now(),me=m.renderer.layerConfig.lineHeight,se=m.renderer.layerConfig.characterWidth,ve=m.renderer.scroller.getBoundingClientRect(),Pe={x:{left:w-ve.left,right:ve.right-w},y:{top:A-ve.top,bottom:ve.bottom-A}},Ie=Math.min(Pe.x.left,Pe.x.right),z=Math.min(Pe.y.top,Pe.y.bottom),G={row:ue.row,column:ue.column};Ie/se<=2&&(G.column+=Pe.x.left<Pe.x.right?-3:2),z/me<=1&&(G.row+=Pe.y.top<Pe.y.bottom?-1:1);var O=ue.row!=G.row,I=ue.column!=G.column,v=!Ee||ue.row!=Ee.row;O||I&&!v?q?ne-q>=d&&m.renderer.scrollCursorIntoView(G):q=ne:q=null}function ce(){var ue=R;R=m.renderer.screenToTextCoordinates(w,A),re(R,ue),le(R,ue)}function de(){x=m.selection.toOrientedRange(),T=m.session.addMarker(x,"ace_selection",m.getSelectionStyle()),m.clearSelection(),m.isFocused()&&m.renderer.$cursorLayer.setBlinking(!1),clearInterval(M),ce(),M=setInterval(ce,20),N=0,h.addListener(document,"mousemove",ge)}function he(){clearInterval(M),m.session.removeMarker(T),T=null,m.$blockScrolling+=1,m.selection.fromOrientedRange(x),m.$blockScrolling-=1,m.isFocused()&&!B&&m.renderer.$cursorLayer.setBlinking(!m.getReadOnly()),x=null,R=null,N=0,q=null,U=null,h.removeListener(document,"mousemove",ge)}var Fe=null;function ge(){Fe==null&&(Fe=setTimeout(function(){Fe!=null&&T&&he()},20))}function ye(ue){var Ee=ue.types;return!Ee||Array.prototype.some.call(Ee,function(ne){return ne=="text/plain"||ne=="Text"})}function Y(ue){var Ee=["copy","copymove","all","uninitialized"],ne=["move","copymove","linkmove","all","uninitialized"],me=g.isMac?ue.altKey:ue.ctrlKey,se="uninitialized";try{se=ue.dataTransfer.effectAllowed.toLowerCase()}catch{}var ve="none";return me&&Ee.indexOf(se)>=0?ve="copy":ne.indexOf(se)>=0?ve="move":Ee.indexOf(se)>=0&&(ve="copy"),ve}}(function(){this.dragWait=function(){var p=Date.now()-this.mousedownEvent.time;p>this.editor.getDragDelay()&&this.startDrag()},this.dragWaitEnd=function(){var p=this.editor.container;p.draggable=!1,this.startSelect(this.mousedownEvent.getDocumentPosition()),this.selectEnd()},this.dragReadyEnd=function(p){this.editor.renderer.$cursorLayer.setBlinking(!this.editor.getReadOnly()),this.editor.unsetStyle("ace_dragging"),this.editor.renderer.setCursorStyle(""),this.dragWaitEnd()},this.startDrag=function(){this.cancelDrag=!1;var p=this.editor,m=p.container;m.draggable=!0,p.renderer.$cursorLayer.setBlinking(!1),p.setStyle("ace_dragging");var b=g.isWin?"default":"move";p.renderer.setCursorStyle(b),this.setState("dragReady")},this.onMouseDrag=function(p){var m=this.editor.container;if(g.isIE&&this.state=="dragReady"){var b=F(this.mousedownEvent.x,this.mousedownEvent.y,this.x,this.y);b>3&&m.dragDrop()}if(this.state==="dragWait"){var b=F(this.mousedownEvent.x,this.mousedownEvent.y,this.x,this.y);b>0&&(m.draggable=!1,this.startSelect(this.mousedownEvent.getDocumentPosition()))}},this.onMouseDown=function(p){if(this.$dragEnabled){this.mousedownEvent=p;var m=this.editor,b=p.inSelection(),C=p.getButton(),k=p.domEvent.detail||1;if(k===1&&C===0&&b){if(p.editor.inMultiSelectMode&&(p.getAccelKey()||p.getShiftKey()))return;this.mousedownEvent.time=Date.now();var T=p.domEvent.target||p.domEvent.srcElement;if("unselectable"in T&&(T.unselectable="on"),m.getDragDelay()){if(g.isWebKit){this.cancelDrag=!0;var w=m.container;w.draggable=!0}this.setState("dragWait")}else this.startDrag();this.captureMouse(p,this.onMouseDrag.bind(this)),p.defaultPrevented=!0}}}}).call(a.prototype);function F(p,m,b,C){return Math.sqrt(Math.pow(b-p,2)+Math.pow(C-m,2))}o.DragdropHandler=a}),ace.define("ace/lib/net",["require","exports","module","ace/lib/dom"],function(s,o,f){var n=s("./dom");o.get=function(h,g){var d=new XMLHttpRequest;d.open("GET",h,!0),d.onreadystatechange=function(){d.readyState===4&&g(d.responseText)},d.send(null)},o.loadScript=function(h,g){var d=n.getDocumentHead(),l=document.createElement("script");l.src=h,d.appendChild(l),l.onload=l.onreadystatechange=function(c,a){(a||!l.readyState||l.readyState=="loaded"||l.readyState=="complete")&&(l=l.onload=l.onreadystatechange=null,a||g())}},o.qualifyURL=function(h){var g=document.createElement("a");return g.href=h,g.href}}),ace.define("ace/lib/event_emitter",["require","exports","module"],function(s,o,f){var n={},h=function(){this.propagationStopped=!0},g=function(){this.defaultPrevented=!0};n._emit=n._dispatchEvent=function(d,l){this._eventRegistry||(this._eventRegistry={}),this._defaultHandlers||(this._defaultHandlers={});var c=this._eventRegistry[d]||[],a=this._defaultHandlers[d];if(!(!c.length&&!a)){(typeof l!="object"||!l)&&(l={}),l.type||(l.type=d),l.stopPropagation||(l.stopPropagation=h),l.preventDefault||(l.preventDefault=g),c=c.slice();for(var F=0;F<c.length&&(c[F](l,this),!l.propagationStopped);F++);if(a&&!l.defaultPrevented)return a(l,this)}},n._signal=function(d,l){var c=(this._eventRegistry||{})[d];if(c){c=c.slice();for(var a=0;a<c.length;a++)c[a](l,this)}},n.once=function(d,l){var c=this;l&&this.addEventListener(d,function a(){c.removeEventListener(d,a),l.apply(null,arguments)})},n.setDefaultHandler=function(d,l){var c=this._defaultHandlers;if(c||(c=this._defaultHandlers={_disabled_:{}}),c[d]){var a=c[d],F=c._disabled_[d];F||(c._disabled_[d]=F=[]),F.push(a);var p=F.indexOf(l);p!=-1&&F.splice(p,1)}c[d]=l},n.removeDefaultHandler=function(d,l){var c=this._defaultHandlers;if(c){var a=c._disabled_[d];if(c[d]==l)c[d],a&&this.setDefaultHandler(d,a.pop());else if(a){var F=a.indexOf(l);F!=-1&&a.splice(F,1)}}},n.on=n.addEventListener=function(d,l,c){this._eventRegistry=this._eventRegistry||{};var a=this._eventRegistry[d];return a||(a=this._eventRegistry[d]=[]),a.indexOf(l)==-1&&a[c?"unshift":"push"](l),l},n.off=n.removeListener=n.removeEventListener=function(d,l){this._eventRegistry=this._eventRegistry||{};var c=this._eventRegistry[d];if(c){var a=c.indexOf(l);a!==-1&&c.splice(a,1)}},n.removeAllListeners=function(d){this._eventRegistry&&(this._eventRegistry[d]=[])},o.EventEmitter=n}),ace.define("ace/lib/app_config",["require","exports","module","ace/lib/oop","ace/lib/event_emitter"],function(s,o,f){"no use strict";var n=s("./oop"),h=s("./event_emitter").EventEmitter,g={setOptions:function(a){Object.keys(a).forEach(function(F){this.setOption(F,a[F])},this)},getOptions:function(a){var F={};return a?Array.isArray(a)||(F=a,a=Object.keys(F)):a=Object.keys(this.$options),a.forEach(function(p){F[p]=this.getOption(p)},this),F},setOption:function(a,F){if(this["$"+a]!==F){var p=this.$options[a];if(!p)return d('misspelled option "'+a+'"');if(p.forwardTo)return this[p.forwardTo]&&this[p.forwardTo].setOption(a,F);p.handlesSet||(this["$"+a]=F),p&&p.set&&p.set.call(this,F)}},getOption:function(a){var F=this.$options[a];return F?F.forwardTo?this[F.forwardTo]&&this[F.forwardTo].getOption(a):F&&F.get?F.get.call(this):this["$"+a]:d('misspelled option "'+a+'"')}};function d(a){typeof console<"u"&&console.warn&&console.warn.apply(console,arguments)}function l(a,F){var p=new Error(a);p.data=F,typeof console=="object"&&console.error&&console.error(p),setTimeout(function(){throw p})}var c=function(){this.$defaultOptions={}};(function(){n.implement(this,h),this.defineOptions=function(a,F,p){return a.$options||(this.$defaultOptions[F]=a.$options={}),Object.keys(p).forEach(function(m){var b=p[m];typeof b=="string"&&(b={forwardTo:b}),b.name||(b.name=m),a.$options[b.name]=b,"initialValue"in b&&(a["$"+b.name]=b.initialValue)}),n.implement(a,g),this},this.resetOptions=function(a){Object.keys(a.$options).forEach(function(F){var p=a.$options[F];"value"in p&&a.setOption(F,p.value)})},this.setDefaultValue=function(a,F,p){var m=this.$defaultOptions[a]||(this.$defaultOptions[a]={});m[F]&&(m.forwardTo?this.setDefaultValue(m.forwardTo,F,p):m[F].value=p)},this.setDefaultValues=function(a,F){Object.keys(F).forEach(function(p){this.setDefaultValue(a,p,F[p])},this)},this.warn=d,this.reportError=l}).call(c.prototype),o.AppConfig=c}),ace.define("ace/config",["require","exports","module","ace/lib/lang","ace/lib/oop","ace/lib/net","ace/lib/app_config"],function(s,o,f){"no use strict";var n=s("./lib/lang");s("./lib/oop");var h=s("./lib/net"),g=s("./lib/app_config").AppConfig;f.exports=o=new g;var d=function(){return this||typeof window<"u"&&window}(),l={packaged:!1,workerPath:null,modePath:null,themePath:null,basePath:"",suffix:".js",$moduleUrls:{}};o.get=function(F){if(!l.hasOwnProperty(F))throw new Error("Unknown config key: "+F);return l[F]},o.set=function(F,p){if(!l.hasOwnProperty(F))throw new Error("Unknown config key: "+F);l[F]=p},o.all=function(){return n.copyObject(l)},o.moduleUrl=function(F,p){if(l.$moduleUrls[F])return l.$moduleUrls[F];var m=F.split("/");p=p||m[m.length-2]||"";var b=p=="snippets"?"/":"-",C=m[m.length-1];if(p=="worker"&&b=="-"){var k=new RegExp("^"+p+"[\\-_]|[\\-_]"+p+"$","g");C=C.replace(k,"")}(!C||C==p)&&m.length>1&&(C=m[m.length-2]);var T=l[p+"Path"];return T==null?T=l.basePath:b=="/"&&(p=b=""),T&&T.slice(-1)!="/"&&(T+="/"),T+p+b+C+this.get("suffix")},o.setModuleUrl=function(F,p){return l.$moduleUrls[F]=p},o.$loading={},o.loadModule=function(F,p){var m,b;Array.isArray(F)&&(b=F[0],F=F[1]);try{m=s(F)}catch{}if(m&&!o.$loading[F])return p&&p(m);if(o.$loading[F]||(o.$loading[F]=[]),o.$loading[F].push(p),!(o.$loading[F].length>1)){var C=function(){s([F],function(k){o._emit("load.module",{name:F,module:k});var T=o.$loading[F];o.$loading[F]=null,T.forEach(function(w){w&&w(k)})})};if(!o.get("packaged"))return C();h.loadScript(o.moduleUrl(F,b),C)}},c(!0);function c(F){if(!(!d||!d.document)){l.packaged=F||s.packaged||f.packaged||d.define&&i(69).packaged;for(var p={},m="",b=document.currentScript||document._currentScript,C=b&&b.ownerDocument||document,k=C.getElementsByTagName("script"),T=0;T<k.length;T++){var w=k[T],A=w.src||w.getAttribute("src");if(A){for(var M=w.attributes,x=0,R=M.length;x<R;x++){var N=M[x];N.name.indexOf("data-ace-")===0&&(p[a(N.name.replace(/^data-ace-/,""))]=N.value)}var j=A.match(/^(.*)\/ace(\-\w+)?\.js(\?|$)/);j&&(m=j[1])}}m&&(p.base=p.base||m,p.packaged=!0),p.basePath=p.base,p.workerPath=p.workerPath||p.base,p.modePath=p.modePath||p.base,p.themePath=p.themePath||p.base,delete p.base;for(var B in p)typeof p[B]<"u"&&o.set(B,p[B])}}o.init=c;function a(F){return F.replace(/-(.)/g,function(p,m){return m.toUpperCase()})}}),ace.define("ace/mouse/mouse_handler",["require","exports","module","ace/lib/event","ace/lib/useragent","ace/mouse/default_handlers","ace/mouse/default_gutter_handler","ace/mouse/mouse_event","ace/mouse/dragdrop_handler","ace/config"],function(s,o,f){var n=s("../lib/event"),h=s("../lib/useragent"),g=s("./default_handlers").DefaultHandlers,d=s("./default_gutter_handler").GutterHandler,l=s("./mouse_event").MouseEvent,c=s("./dragdrop_handler").DragdropHandler,a=s("../config"),F=function(p){var m=this;this.editor=p,new g(this),new d(this),new c(this);var b=function(T){var w=!document.hasFocus||!document.hasFocus()||!p.isFocused()&&document.activeElement==(p.textInput&&p.textInput.getElement());w&&window.focus(),p.focus()},C=p.renderer.getMouseEventTarget();n.addListener(C,"click",this.onMouseEvent.bind(this,"click")),n.addListener(C,"mousemove",this.onMouseMove.bind(this,"mousemove")),n.addMultiMouseDownListener([C,p.renderer.scrollBarV&&p.renderer.scrollBarV.inner,p.renderer.scrollBarH&&p.renderer.scrollBarH.inner,p.textInput&&p.textInput.getElement()].filter(Boolean),[400,300,250],this,"onMouseEvent"),n.addMouseWheelListener(p.container,this.onMouseWheel.bind(this,"mousewheel")),n.addTouchMoveListener(p.container,this.onTouchMove.bind(this,"touchmove"));var k=p.renderer.$gutter;n.addListener(k,"mousedown",this.onMouseEvent.bind(this,"guttermousedown")),n.addListener(k,"click",this.onMouseEvent.bind(this,"gutterclick")),n.addListener(k,"dblclick",this.onMouseEvent.bind(this,"gutterdblclick")),n.addListener(k,"mousemove",this.onMouseEvent.bind(this,"guttermousemove")),n.addListener(C,"mousedown",b),n.addListener(k,"mousedown",b),h.isIE&&p.renderer.scrollBarV&&(n.addListener(p.renderer.scrollBarV.element,"mousedown",b),n.addListener(p.renderer.scrollBarH.element,"mousedown",b)),p.on("mousemove",function(T){if(!(m.state||m.$dragDelay||!m.$dragEnabled)){var w=p.renderer.screenToTextCoordinates(T.x,T.y),A=p.session.selection.getRange(),M=p.renderer;!A.isEmpty()&&A.insideStart(w.row,w.column)?M.setCursorStyle("default"):M.setCursorStyle("")}})};(function(){this.onMouseEvent=function(p,m){this.editor._emit(p,new l(m,this.editor))},this.onMouseMove=function(p,m){var b=this.editor._eventRegistry&&this.editor._eventRegistry.mousemove;!b||!b.length||this.editor._emit(p,new l(m,this.editor))},this.onMouseWheel=function(p,m){var b=new l(m,this.editor);b.speed=this.$scrollSpeed*2,b.wheelX=m.wheelX,b.wheelY=m.wheelY,this.editor._emit(p,b)},this.onTouchMove=function(p,m){var b=new l(m,this.editor);b.speed=1,b.wheelX=m.wheelX,b.wheelY=m.wheelY,this.editor._emit(p,b)},this.setState=function(p){this.state=p},this.captureMouse=function(p,m){this.x=p.x,this.y=p.y,this.isMousePressed=!0;var b=this.editor.renderer;b.$keepTextAreaAtCursor&&(b.$keepTextAreaAtCursor=null);var C=this,k=function(M){if(M){if(h.isWebKit&&!M.which&&C.releaseMouse)return C.releaseMouse();C.x=M.clientX,C.y=M.clientY,m&&m(M),C.mouseEvent=new l(M,C.editor),C.$mouseMoved=!0}},T=function(M){clearInterval(A),w(),C[C.state+"End"]&&C[C.state+"End"](M),C.state="",b.$keepTextAreaAtCursor==null&&(b.$keepTextAreaAtCursor=!0,b.$moveTextAreaToCursor()),C.isMousePressed=!1,C.$onCaptureMouseMove=C.releaseMouse=null,M&&C.onMouseEvent("mouseup",M)},w=function(){C[C.state]&&C[C.state](),C.$mouseMoved=!1};if(h.isOldIE&&p.domEvent.type=="dblclick")return setTimeout(function(){T(p)});C.$onCaptureMouseMove=k,C.releaseMouse=n.capture(this.editor.container,k,T);var A=setInterval(w,20)},this.releaseMouse=null,this.cancelContextMenu=function(){var p=function(m){m&&m.domEvent&&m.domEvent.type!="contextmenu"||(this.editor.off("nativecontextmenu",p),m&&m.domEvent&&n.stopEvent(m.domEvent))}.bind(this);setTimeout(p,10),this.editor.on("nativecontextmenu",p)}}).call(F.prototype),a.defineOptions(F.prototype,"mouseHandler",{scrollSpeed:{initialValue:2},dragDelay:{initialValue:h.isMac?150:0},dragEnabled:{initialValue:!0},focusTimout:{initialValue:0},tooltipFollowsMouse:{initialValue:!0}}),o.MouseHandler=F}),ace.define("ace/mouse/fold_handler",["require","exports","module"],function(s,o,f){function n(h){h.on("click",function(g){var d=g.getDocumentPosition(),l=h.session,c=l.getFoldAt(d.row,d.column,1);c&&(g.getAccelKey()?l.removeFold(c):l.expandFold(c),g.stop())}),h.on("gutterclick",function(g){var d=h.renderer.$gutterLayer.getRegion(g);if(d=="foldWidgets"){var l=g.getDocumentPosition().row,c=h.session;c.foldWidgets&&c.foldWidgets[l]&&h.session.onFoldWidgetClick(l,g),h.isFocused()||h.focus(),g.stop()}}),h.on("gutterdblclick",function(g){var d=h.renderer.$gutterLayer.getRegion(g);if(d=="foldWidgets"){var l=g.getDocumentPosition().row,c=h.session,a=c.getParentFoldRangeData(l,!0),F=a.range||a.firstRange;if(F){l=F.start.row;var p=c.getFoldAt(l,c.getLine(l).length,1);p?c.removeFold(p):(c.addFold("...",F),h.renderer.scrollCursorIntoView({row:F.start.row,column:0}))}g.stop()}})}o.FoldHandler=n}),ace.define("ace/keyboard/keybinding",["require","exports","module","ace/lib/keys","ace/lib/event"],function(s,o,f){var n=s("../lib/keys"),h=s("../lib/event"),g=function(d){this.$editor=d,this.$data={editor:d},this.$handlers=[],this.setDefaultHandler(d.commands)};(function(){this.setDefaultHandler=function(d){this.removeKeyboardHandler(this.$defaultHandler),this.$defaultHandler=d,this.addKeyboardHandler(d,0)},this.setKeyboardHandler=function(d){var l=this.$handlers;if(l[l.length-1]!=d){for(;l[l.length-1]&&l[l.length-1]!=this.$defaultHandler;)this.removeKeyboardHandler(l[l.length-1]);this.addKeyboardHandler(d,1)}},this.addKeyboardHandler=function(d,l){if(d){typeof d=="function"&&!d.handleKeyboard&&(d.handleKeyboard=d);var c=this.$handlers.indexOf(d);c!=-1&&this.$handlers.splice(c,1),l==null?this.$handlers.push(d):this.$handlers.splice(l,0,d),c==-1&&d.attach&&d.attach(this.$editor)}},this.removeKeyboardHandler=function(d){var l=this.$handlers.indexOf(d);return l==-1?!1:(this.$handlers.splice(l,1),d.detach&&d.detach(this.$editor),!0)},this.getKeyboardHandler=function(){return this.$handlers[this.$handlers.length-1]},this.getStatusText=function(){var d=this.$data,l=d.editor;return this.$handlers.map(function(c){return c.getStatusText&&c.getStatusText(l,d)||""}).filter(Boolean).join(" ")},this.$callKeyboardHandlers=function(d,l,c,a){for(var F,p=!1,m=this.$editor.commands,b=this.$handlers.length;b--&&(F=this.$handlers[b].handleKeyboard(this.$data,d,l,c,a),!(!(!F||!F.command)&&(F.command=="null"?p=!0:p=m.exec(F.command,this.$editor,F.args,a),p&&a&&d!=-1&&F.passEvent!=!0&&F.command.passEvent!=!0&&h.stopEvent(a),p))););return!p&&d==-1&&(F={command:"insertstring"},p=m.exec("insertstring",this.$editor,l)),p&&this.$editor._signal&&this.$editor._signal("keyboardActivity",F),p},this.onCommandKey=function(d,l,c){var a=n.keyCodeToString(c);this.$callKeyboardHandlers(l,a,c,d)},this.onTextInput=function(d){this.$callKeyboardHandlers(-1,d)}}).call(g.prototype),o.KeyBinding=g}),ace.define("ace/range",["require","exports","module"],function(s,o,f){var n=function(g,d){return g.row-d.row||g.column-d.column},h=function(g,d,l,c){this.start={row:g,column:d},this.end={row:l,column:c}};(function(){this.isEqual=function(g){return this.start.row===g.start.row&&this.end.row===g.end.row&&this.start.column===g.start.column&&this.end.column===g.end.column},this.toString=function(){return"Range: ["+this.start.row+"/"+this.start.column+"] -> ["+this.end.row+"/"+this.end.column+"]"},this.contains=function(g,d){return this.compare(g,d)==0},this.compareRange=function(g){var d,l=g.end,c=g.start;return d=this.compare(l.row,l.column),d==1?(d=this.compare(c.row,c.column),d==1?2:d==0?1:0):d==-1?-2:(d=this.compare(c.row,c.column),d==-1?-1:d==1?42:0)},this.comparePoint=function(g){return this.compare(g.row,g.column)},this.containsRange=function(g){return this.comparePoint(g.start)==0&&this.comparePoint(g.end)==0},this.intersects=function(g){var d=this.compareRange(g);return d==-1||d==0||d==1},this.isEnd=function(g,d){return this.end.row==g&&this.end.column==d},this.isStart=function(g,d){return this.start.row==g&&this.start.column==d},this.setStart=function(g,d){typeof g=="object"?(this.start.column=g.column,this.start.row=g.row):(this.start.row=g,this.start.column=d)},this.setEnd=function(g,d){typeof g=="object"?(this.end.column=g.column,this.end.row=g.row):(this.end.row=g,this.end.column=d)},this.inside=function(g,d){return this.compare(g,d)==0?!(this.isEnd(g,d)||this.isStart(g,d)):!1},this.insideStart=function(g,d){return this.compare(g,d)==0?!this.isEnd(g,d):!1},this.insideEnd=function(g,d){return this.compare(g,d)==0?!this.isStart(g,d):!1},this.compare=function(g,d){return!this.isMultiLine()&&g===this.start.row?d<this.start.column?-1:d>this.end.column?1:0:g<this.start.row?-1:g>this.end.row?1:this.start.row===g?d>=this.start.column?0:-1:this.end.row===g?d<=this.end.column?0:1:0},this.compareStart=function(g,d){return this.start.row==g&&this.start.column==d?-1:this.compare(g,d)},this.compareEnd=function(g,d){return this.end.row==g&&this.end.column==d?1:this.compare(g,d)},this.compareInside=function(g,d){return this.end.row==g&&this.end.column==d?1:this.start.row==g&&this.start.column==d?-1:this.compare(g,d)},this.clipRows=function(g,d){if(this.end.row>d)var l={row:d+1,column:0};else if(this.end.row<g)var l={row:g,column:0};if(this.start.row>d)var c={row:d+1,column:0};else if(this.start.row<g)var c={row:g,column:0};return h.fromPoints(c||this.start,l||this.end)},this.extend=function(g,d){var l=this.compare(g,d);if(l==0)return this;if(l==-1)var c={row:g,column:d};else var a={row:g,column:d};return h.fromPoints(c||this.start,a||this.end)},this.isEmpty=function(){return this.start.row===this.end.row&&this.start.column===this.end.column},this.isMultiLine=function(){return this.start.row!==this.end.row},this.clone=function(){return h.fromPoints(this.start,this.end)},this.collapseRows=function(){return this.end.column==0?new h(this.start.row,0,Math.max(this.start.row,this.end.row-1),0):new h(this.start.row,0,this.end.row,0)},this.toScreenRange=function(g){var d=g.documentToScreenPosition(this.start),l=g.documentToScreenPosition(this.end);return new h(d.row,d.column,l.row,l.column)},this.moveBy=function(g,d){this.start.row+=g,this.start.column+=d,this.end.row+=g,this.end.column+=d}}).call(h.prototype),h.fromPoints=function(g,d){return new h(g.row,g.column,d.row,d.column)},h.comparePoints=n,h.comparePoints=function(g,d){return g.row-d.row||g.column-d.column},o.Range=h}),ace.define("ace/selection",["require","exports","module","ace/lib/oop","ace/lib/lang","ace/lib/event_emitter","ace/range"],function(s,o,f){var n=s("./lib/oop"),h=s("./lib/lang"),g=s("./lib/event_emitter").EventEmitter,d=s("./range").Range,l=function(c){this.session=c,this.doc=c.getDocument(),this.clearSelection(),this.lead=this.selectionLead=this.doc.createAnchor(0,0),this.anchor=this.selectionAnchor=this.doc.createAnchor(0,0);var a=this;this.lead.on("change",function(F){a._emit("changeCursor"),a.$isEmpty||a._emit("changeSelection"),!a.$keepDesiredColumnOnChange&&F.old.column!=F.value.column&&(a.$desiredColumn=null)}),this.selectionAnchor.on("change",function(){a.$isEmpty||a._emit("changeSelection")})};(function(){n.implement(this,g),this.isEmpty=function(){return this.$isEmpty||this.anchor.row==this.lead.row&&this.anchor.column==this.lead.column},this.isMultiLine=function(){return this.isEmpty()?!1:this.getRange().isMultiLine()},this.getCursor=function(){return this.lead.getPosition()},this.setSelectionAnchor=function(c,a){this.anchor.setPosition(c,a),this.$isEmpty&&(this.$isEmpty=!1,this._emit("changeSelection"))},this.getSelectionAnchor=function(){return this.$isEmpty?this.getSelectionLead():this.anchor.getPosition()},this.getSelectionLead=function(){return this.lead.getPosition()},this.shiftSelection=function(c){if(this.$isEmpty){this.moveCursorTo(this.lead.row,this.lead.column+c);return}var a=this.getSelectionAnchor(),F=this.getSelectionLead(),p=this.isBackwards();(!p||a.column!==0)&&this.setSelectionAnchor(a.row,a.column+c),(p||F.column!==0)&&this.$moveSelection(function(){this.moveCursorTo(F.row,F.column+c)})},this.isBackwards=function(){var c=this.anchor,a=this.lead;return c.row>a.row||c.row==a.row&&c.column>a.column},this.getRange=function(){var c=this.anchor,a=this.lead;return this.isEmpty()?d.fromPoints(a,a):this.isBackwards()?d.fromPoints(a,c):d.fromPoints(c,a)},this.clearSelection=function(){this.$isEmpty||(this.$isEmpty=!0,this._emit("changeSelection"))},this.selectAll=function(){var c=this.doc.getLength()-1;this.setSelectionAnchor(0,0),this.moveCursorTo(c,this.doc.getLine(c).length)},this.setRange=this.setSelectionRange=function(c,a){a?(this.setSelectionAnchor(c.end.row,c.end.column),this.selectTo(c.start.row,c.start.column)):(this.setSelectionAnchor(c.start.row,c.start.column),this.selectTo(c.end.row,c.end.column)),this.getRange().isEmpty()&&(this.$isEmpty=!0),this.$desiredColumn=null},this.$moveSelection=function(c){var a=this.lead;this.$isEmpty&&this.setSelectionAnchor(a.row,a.column),c.call(this)},this.selectTo=function(c,a){this.$moveSelection(function(){this.moveCursorTo(c,a)})},this.selectToPosition=function(c){this.$moveSelection(function(){this.moveCursorToPosition(c)})},this.moveTo=function(c,a){this.clearSelection(),this.moveCursorTo(c,a)},this.moveToPosition=function(c){this.clearSelection(),this.moveCursorToPosition(c)},this.selectUp=function(){this.$moveSelection(this.moveCursorUp)},this.selectDown=function(){this.$moveSelection(this.moveCursorDown)},this.selectRight=function(){this.$moveSelection(this.moveCursorRight)},this.selectLeft=function(){this.$moveSelection(this.moveCursorLeft)},this.selectLineStart=function(){this.$moveSelection(this.moveCursorLineStart)},this.selectLineEnd=function(){this.$moveSelection(this.moveCursorLineEnd)},this.selectFileEnd=function(){this.$moveSelection(this.moveCursorFileEnd)},this.selectFileStart=function(){this.$moveSelection(this.moveCursorFileStart)},this.selectWordRight=function(){this.$moveSelection(this.moveCursorWordRight)},this.selectWordLeft=function(){this.$moveSelection(this.moveCursorWordLeft)},this.getWordRange=function(c,a){if(typeof a>"u"){var F=c||this.lead;c=F.row,a=F.column}return this.session.getWordRange(c,a)},this.selectWord=function(){this.setSelectionRange(this.getWordRange())},this.selectAWord=function(){var c=this.getCursor(),a=this.session.getAWordRange(c.row,c.column);this.setSelectionRange(a)},this.getLineRange=function(c,a){var F=typeof c=="number"?c:this.lead.row,p,m=this.session.getFoldLine(F);return m?(F=m.start.row,p=m.end.row):p=F,a===!0?new d(F,0,p,this.session.getLine(p).length):new d(F,0,p+1,0)},this.selectLine=function(){this.setSelectionRange(this.getLineRange())},this.moveCursorUp=function(){this.moveCursorBy(-1,0)},this.moveCursorDown=function(){this.moveCursorBy(1,0)},this.moveCursorLeft=function(){var c=this.lead.getPosition(),a;if(a=this.session.getFoldAt(c.row,c.column,-1))this.moveCursorTo(a.start.row,a.start.column);else if(c.column===0)c.row>0&&this.moveCursorTo(c.row-1,this.doc.getLine(c.row-1).length);else{var F=this.session.getTabSize();this.session.isTabStop(c)&&this.doc.getLine(c.row).slice(c.column-F,c.column).split(" ").length-1==F?this.moveCursorBy(0,-F):this.moveCursorBy(0,-1)}},this.moveCursorRight=function(){var c=this.lead.getPosition(),a;if(a=this.session.getFoldAt(c.row,c.column,1))this.moveCursorTo(a.end.row,a.end.column);else if(this.lead.column==this.doc.getLine(this.lead.row).length)this.lead.row<this.doc.getLength()-1&&this.moveCursorTo(this.lead.row+1,0);else{var F=this.session.getTabSize(),c=this.lead;this.session.isTabStop(c)&&this.doc.getLine(c.row).slice(c.column,c.column+F).split(" ").length-1==F?this.moveCursorBy(0,F):this.moveCursorBy(0,1)}},this.moveCursorLineStart=function(){var c=this.lead.row,a=this.lead.column,F=this.session.documentToScreenRow(c,a),p=this.session.screenToDocumentPosition(F,0),m=this.session.getDisplayLine(c,null,p.row,p.column),b=m.match(/^\s*/);b[0].length!=a&&!this.session.$useEmacsStyleLineStart&&(p.column+=b[0].length),this.moveCursorToPosition(p)},this.moveCursorLineEnd=function(){var c=this.lead,a=this.session.getDocumentLastRowColumnPosition(c.row,c.column);if(this.lead.column==a.column){var F=this.session.getLine(a.row);if(a.column==F.length){var p=F.search(/\s+$/);p>0&&(a.column=p)}}this.moveCursorTo(a.row,a.column)},this.moveCursorFileEnd=function(){var c=this.doc.getLength()-1,a=this.doc.getLine(c).length;this.moveCursorTo(c,a)},this.moveCursorFileStart=function(){this.moveCursorTo(0,0)},this.moveCursorLongWordRight=function(){var c=this.lead.row,a=this.lead.column,F=this.doc.getLine(c),p=F.substring(a);this.session.nonTokenRe.lastIndex=0,this.session.tokenRe.lastIndex=0;var m=this.session.getFoldAt(c,a,1);if(m){this.moveCursorTo(m.end.row,m.end.column);return}if(this.session.nonTokenRe.exec(p)&&(a+=this.session.nonTokenRe.lastIndex,this.session.nonTokenRe.lastIndex=0,p=F.substring(a)),a>=F.length){this.moveCursorTo(c,F.length),this.moveCursorRight(),c<this.doc.getLength()-1&&this.moveCursorWordRight();return}this.session.tokenRe.exec(p)&&(a+=this.session.tokenRe.lastIndex,this.session.tokenRe.lastIndex=0),this.moveCursorTo(c,a)},this.moveCursorLongWordLeft=function(){var c=this.lead.row,a=this.lead.column,F;if(F=this.session.getFoldAt(c,a,-1)){this.moveCursorTo(F.start.row,F.start.column);return}var p=this.session.getFoldStringAt(c,a,-1);p==null&&(p=this.doc.getLine(c).substring(0,a));var m=h.stringReverse(p);if(this.session.nonTokenRe.lastIndex=0,this.session.tokenRe.lastIndex=0,this.session.nonTokenRe.exec(m)&&(a-=this.session.nonTokenRe.lastIndex,m=m.slice(this.session.nonTokenRe.lastIndex),this.session.nonTokenRe.lastIndex=0),a<=0){this.moveCursorTo(c,0),this.moveCursorLeft(),c>0&&this.moveCursorWordLeft();return}this.session.tokenRe.exec(m)&&(a-=this.session.tokenRe.lastIndex,this.session.tokenRe.lastIndex=0),this.moveCursorTo(c,a)},this.$shortWordEndIndex=function(c){var a=0,F,p=/\s/,m=this.session.tokenRe;if(m.lastIndex=0,this.session.tokenRe.exec(c))a=this.session.tokenRe.lastIndex;else{for(;(F=c[a])&&p.test(F);)a++;if(a<1){for(m.lastIndex=0;(F=c[a])&&!m.test(F);)if(m.lastIndex=0,a++,p.test(F))if(a>2){a--;break}else{for(;(F=c[a])&&p.test(F);)a++;if(a>2)break}}}return m.lastIndex=0,a},this.moveCursorShortWordRight=function(){var c=this.lead.row,a=this.lead.column,F=this.doc.getLine(c),p=F.substring(a),m=this.session.getFoldAt(c,a,1);if(m)return this.moveCursorTo(m.end.row,m.end.column);if(a==F.length){var b=this.doc.getLength();do c++,p=this.doc.getLine(c);while(c<b&&/^\s*$/.test(p));/^\s+/.test(p)||(p=""),a=0}var C=this.$shortWordEndIndex(p);this.moveCursorTo(c,a+C)},this.moveCursorShortWordLeft=function(){var c=this.lead.row,a=this.lead.column,F;if(F=this.session.getFoldAt(c,a,-1))return this.moveCursorTo(F.start.row,F.start.column);var p=this.session.getLine(c).substring(0,a);if(a===0){do c--,p=this.doc.getLine(c);while(c>0&&/^\s*$/.test(p));a=p.length,/\s+$/.test(p)||(p="")}var m=h.stringReverse(p),b=this.$shortWordEndIndex(m);return this.moveCursorTo(c,a-b)},this.moveCursorWordRight=function(){this.session.$selectLongWords?this.moveCursorLongWordRight():this.moveCursorShortWordRight()},this.moveCursorWordLeft=function(){this.session.$selectLongWords?this.moveCursorLongWordLeft():this.moveCursorShortWordLeft()},this.moveCursorBy=function(c,a){var F=this.session.documentToScreenPosition(this.lead.row,this.lead.column);a===0&&(this.$desiredColumn?F.column=this.$desiredColumn:this.$desiredColumn=F.column);var p=this.session.screenToDocumentPosition(F.row+c,F.column);c!==0&&a===0&&p.row===this.lead.row&&p.column===this.lead.column&&this.session.lineWidgets&&this.session.lineWidgets[p.row]&&(p.row>0||c>0)&&p.row++,this.moveCursorTo(p.row,p.column+a,a===0)},this.moveCursorToPosition=function(c){this.moveCursorTo(c.row,c.column)},this.moveCursorTo=function(c,a,F){var p=this.session.getFoldAt(c,a,1);p&&(c=p.start.row,a=p.start.column),this.$keepDesiredColumnOnChange=!0,this.lead.setPosition(c,a),this.$keepDesiredColumnOnChange=!1,F||(this.$desiredColumn=null)},this.moveCursorToScreen=function(c,a,F){var p=this.session.screenToDocumentPosition(c,a);this.moveCursorTo(p.row,p.column,F)},this.detach=function(){this.lead.detach(),this.anchor.detach(),this.session=this.doc=null},this.fromOrientedRange=function(c){this.setSelectionRange(c,c.cursor==c.start),this.$desiredColumn=c.desiredColumn||this.$desiredColumn},this.toOrientedRange=function(c){var a=this.getRange();return c?(c.start.column=a.start.column,c.start.row=a.start.row,c.end.column=a.end.column,c.end.row=a.end.row):c=a,c.cursor=this.isBackwards()?c.start:c.end,c.desiredColumn=this.$desiredColumn,c},this.getRangeOfMovements=function(c){var a=this.getCursor();try{c(this);var F=this.getCursor();return d.fromPoints(a,F)}catch{return d.fromPoints(a,a)}finally{this.moveCursorToPosition(a)}},this.toJSON=function(){if(this.rangeCount)var c=this.ranges.map(function(a){var F=a.clone();return F.isBackwards=a.cursor==a.start,F});else{var c=this.getRange();c.isBackwards=this.isBackwards()}return c},this.fromJSON=function(c){if(c.start==null)if(this.rangeList){this.toSingleRange(c[0]);for(var a=c.length;a--;){var F=d.fromPoints(c[a].start,c[a].end);c[a].isBackwards&&(F.cursor=F.start),this.addRange(F,!0)}return}else c=c[0];this.rangeList&&this.toSingleRange(c),this.setSelectionRange(c,c.isBackwards)},this.isEqual=function(c){if((c.length||this.rangeCount)&&c.length!=this.rangeCount)return!1;if(!c.length||!this.ranges)return this.getRange().isEqual(c);for(var a=this.ranges.length;a--;)if(!this.ranges[a].isEqual(c[a]))return!1;return!0}}).call(l.prototype),o.Selection=l}),ace.define("ace/tokenizer",["require","exports","module","ace/config"],function(s,o,f){var n=s("./config"),h=2e3,g=function(d){this.states=d,this.regExps={},this.matchMappings={};for(var l in this.states){for(var c=this.states[l],a=[],F=0,p=this.matchMappings[l]={defaultToken:"text"},m="g",b=[],C=0;C<c.length;C++){var k=c[C];if(k.defaultToken&&(p.defaultToken=k.defaultToken),k.caseInsensitive&&(m="gi"),k.regex!=null){k.regex instanceof RegExp&&(k.regex=k.regex.toString().slice(1,-1));var T=k.regex,w=new RegExp("(?:("+T+")|(.))").exec("a").length-2;Array.isArray(k.token)?k.token.length==1||w==1?k.token=k.token[0]:w-1!=k.token.length?(this.reportError("number of classes and regexp groups doesn't match",{rule:k,groupCount:w-1}),k.token=k.token[0]):(k.tokenArray=k.token,k.token=null,k.onMatch=this.$arrayTokens):typeof k.token=="function"&&!k.onMatch&&(w>1?k.onMatch=this.$applyToken:k.onMatch=k.token),w>1&&(/\\\d/.test(k.regex)?T=k.regex.replace(/\\([0-9]+)/g,function(A,M){return"\\"+(parseInt(M,10)+F+1)}):(w=1,T=this.removeCapturingGroups(k.regex)),!k.splitRegex&&typeof k.token!="string"&&b.push(k)),p[F]=C,F+=w,a.push(T),k.onMatch||(k.onMatch=null)}}a.length||(p[0]=0,a.push("$")),b.forEach(function(A){A.splitRegex=this.createSplitterRegexp(A.regex,m)},this),this.regExps[l]=new RegExp("("+a.join(")|(")+")|($)",m)}};(function(){this.$setMaxTokenCount=function(d){h=d|0},this.$applyToken=function(d){var l=this.splitRegex.exec(d).slice(1),c=this.token.apply(this,l);if(typeof c=="string")return[{type:c,value:d}];for(var a=[],F=0,p=c.length;F<p;F++)l[F]&&(a[a.length]={type:c[F],value:l[F]});return a},this.$arrayTokens=function(d){if(!d)return[];var l=this.splitRegex.exec(d);if(!l)return"text";for(var c=[],a=this.tokenArray,F=0,p=a.length;F<p;F++)l[F+1]&&(c[c.length]={type:a[F],value:l[F+1]});return c},this.removeCapturingGroups=function(d){var l=d.replace(/\[(?:\\.|[^\]])*?\]|\\.|\(\?[:=!]|(\()/g,function(c,a){return a?"(?:":c});return l},this.createSplitterRegexp=function(d,l){if(d.indexOf("(?=")!=-1){var c=0,a=!1,F={};d.replace(/(\\.)|(\((?:\?[=!])?)|(\))|([\[\]])/g,function(p,m,b,C,k,T){return a?a=k!="]":k?a=!0:C?(c==F.stack&&(F.end=T+1,F.stack=-1),c--):b&&(c++,b.length!=1&&(F.stack=c,F.start=T)),p}),F.end!=null&&/^\)*$/.test(d.substr(F.end))&&(d=d.substring(0,F.start)+d.substr(F.end))}return d.charAt(0)!="^"&&(d="^"+d),d.charAt(d.length-1)!="$"&&(d+="$"),new RegExp(d,(l||"").replace("g",""))},this.getLineTokens=function(d,l){if(l&&typeof l!="string"){var c=l.slice(0);l=c[0],l==="#tmp"&&(c.shift(),l=c.shift())}else var c=[];var a=l||"start",F=this.states[a];F||(a="start",F=this.states[a]);var p=this.matchMappings[a],m=this.regExps[a];m.lastIndex=0;for(var b,C=[],k=0,T=0,w={type:null,value:""};b=m.exec(d);){var A=p.defaultToken,M=null,x=b[0],R=m.lastIndex;if(R-x.length>k){var N=d.substring(k,R-x.length);w.type==A?w.value+=N:(w.type&&C.push(w),w={type:A,value:N})}for(var j=0;j<b.length-2;j++)if(b[j+1]!==void 0){M=F[p[j]],M.onMatch?A=M.onMatch(x,a,c):A=M.token,M.next&&(typeof M.next=="string"?a=M.next:a=M.next(a,c),F=this.states[a],F||(this.reportError("state doesn't exist",a),a="start",F=this.states[a]),p=this.matchMappings[a],k=R,m=this.regExps[a],m.lastIndex=R);break}if(x){if(typeof A=="string")(!M||M.merge!==!1)&&w.type===A?w.value+=x:(w.type&&C.push(w),w={type:A,value:x});else if(A){w.type&&C.push(w),w={type:null,value:""};for(var j=0;j<A.length;j++)C.push(A[j])}}if(k==d.length)break;if(k=R,T++>h){for(T>2*d.length&&this.reportError("infinite loop with in ace tokenizer",{startState:l,line:d});k<d.length;)w.type&&C.push(w),w={value:d.substring(k,k+=2e3),type:"overflow"};a="start",c=[];break}}return w.type&&C.push(w),c.length>1&&c[0]!==a&&c.unshift("#tmp",a),{tokens:C,state:c.length?c:a}},this.reportError=n.reportError}).call(g.prototype),o.Tokenizer=g}),ace.define("ace/mode/text_highlight_rules",["require","exports","module","ace/lib/lang"],function(s,o,f){var n=s("../lib/lang"),h=function(){this.$rules={start:[{token:"empty_line",regex:"^$"},{defaultToken:"text"}]}};(function(){this.addRules=function(l,c){if(!c){for(var a in l)this.$rules[a]=l[a];return}for(var a in l){for(var F=l[a],p=0;p<F.length;p++){var m=F[p];(m.next||m.onMatch)&&(typeof m.next=="string"&&m.next.indexOf(c)!==0&&(m.next=c+m.next),m.nextState&&m.nextState.indexOf(c)!==0&&(m.nextState=c+m.nextState))}this.$rules[c+a]=F}},this.getRules=function(){return this.$rules},this.embedRules=function(l,c,a,F,p){var m=typeof l=="function"?new l().getRules():l;if(F)for(var b=0;b<F.length;b++)F[b]=c+F[b];else{F=[];for(var C in m)F.push(c+C)}if(this.addRules(m,c),a)for(var k=Array.prototype[p?"push":"unshift"],b=0;b<F.length;b++)k.apply(this.$rules[F[b]],n.deepCopy(a));this.$embeds||(this.$embeds=[]),this.$embeds.push(c)},this.getEmbeds=function(){return this.$embeds};var g=function(l,c){return(l!="start"||c.length)&&c.unshift(this.nextState,l),this.nextState},d=function(l,c){return c.shift(),c.shift()||"start"};this.normalizeRules=function(){var l=0,c=this.$rules;function a(F){var p=c[F];p.processed=!0;for(var m=0;m<p.length;m++){var b=p[m],C=null;Array.isArray(b)&&(C=b,b={}),!b.regex&&b.start&&(b.regex=b.start,b.next||(b.next=[]),b.next.push({defaultToken:b.token},{token:b.token+".end",regex:b.end||b.start,next:"pop"}),b.token=b.token+".start",b.push=!0);var k=b.next||b.push;if(k&&Array.isArray(k)){var T=b.stateName;T||(T=b.token,typeof T!="string"&&(T=T[0]||""),c[T]&&(T+=l++)),c[T]=k,b.next=T,a(T)}else k=="pop"&&(b.next=d);if(b.push&&(b.nextState=b.next||b.push,b.next=g,delete b.push),b.rules)for(var w in b.rules)c[w]?c[w].push&&c[w].push.apply(c[w],b.rules[w]):c[w]=b.rules[w];var A=typeof b=="string"?b:typeof b.include=="string"?b.include:"";if(A&&(C=c[A]),C){var M=[m,1].concat(C);b.noEscape&&(M=M.filter(function(x){return!x.next})),p.splice.apply(p,M),m--}b.keywordMap&&(b.token=this.createKeywordMapper(b.keywordMap,b.defaultToken||"text",b.caseInsensitive),delete b.defaultToken)}}Object.keys(c).forEach(a,this)},this.createKeywordMapper=function(l,c,a,F){var p=Object.create(null);return Object.keys(l).forEach(function(m){var b=l[m];a&&(b=b.toLowerCase());for(var C=b.split(F||"|"),k=C.length;k--;)p[C[k]]=m}),Object.getPrototypeOf(p)&&(p.__proto__=null),this.$keywordList=Object.keys(p),l=null,a?function(m){return p[m.toLowerCase()]||c}:function(m){return p[m]||c}},this.getKeywords=function(){return this.$keywords}}).call(h.prototype),o.TextHighlightRules=h}),ace.define("ace/mode/behaviour",["require","exports","module"],function(s,o,f){var n=function(){this.$behaviours={}};(function(){this.add=function(h,g,d){switch(void 0){case this.$behaviours:this.$behaviours={};case this.$behaviours[h]:this.$behaviours[h]={}}this.$behaviours[h][g]=d},this.addBehaviours=function(h){for(var g in h)for(var d in h[g])this.add(g,d,h[g][d])},this.remove=function(h){this.$behaviours&&this.$behaviours[h]&&delete this.$behaviours[h]},this.inherit=function(h,g){if(typeof h=="function")var d=new h().getBehaviours(g);else var d=h.getBehaviours(g);this.addBehaviours(d)},this.getBehaviours=function(h){if(h){for(var g={},d=0;d<h.length;d++)this.$behaviours[h[d]]&&(g[h[d]]=this.$behaviours[h[d]]);return g}else return this.$behaviours}}).call(n.prototype),o.Behaviour=n}),ace.define("ace/token_iterator",["require","exports","module"],function(s,o,f){var n=function(h,g,d){this.$session=h,this.$row=g,this.$rowTokens=h.getTokens(g);var l=h.getTokenAt(g,d);this.$tokenIndex=l?l.index:-1};(function(){this.stepBackward=function(){for(this.$tokenIndex-=1;this.$tokenIndex<0;){if(this.$row-=1,this.$row<0)return this.$row=0,null;this.$rowTokens=this.$session.getTokens(this.$row),this.$tokenIndex=this.$rowTokens.length-1}return this.$rowTokens[this.$tokenIndex]},this.stepForward=function(){this.$tokenIndex+=1;for(var h;this.$tokenIndex>=this.$rowTokens.length;){if(this.$row+=1,h||(h=this.$session.getLength()),this.$row>=h)return this.$row=h-1,null;this.$rowTokens=this.$session.getTokens(this.$row),this.$tokenIndex=0}return this.$rowTokens[this.$tokenIndex]},this.getCurrentToken=function(){return this.$rowTokens[this.$tokenIndex]},this.getCurrentTokenRow=function(){return this.$row},this.getCurrentTokenColumn=function(){var h=this.$rowTokens,g=this.$tokenIndex,d=h[g].start;if(d!==void 0)return d;for(d=0;g>0;)g-=1,d+=h[g].value.length;return d},this.getCurrentTokenPosition=function(){return{row:this.$row,column:this.getCurrentTokenColumn()}}}).call(n.prototype),o.TokenIterator=n}),ace.define("ace/mode/behaviour/cstyle",["require","exports","module","ace/lib/oop","ace/mode/behaviour","ace/token_iterator","ace/lib/lang"],function(s,o,f){var n=s("../../lib/oop"),h=s("../behaviour").Behaviour,g=s("../../token_iterator").TokenIterator,d=s("../../lib/lang"),l=["text","paren.rparen","punctuation.operator"],c=["text","paren.rparen","punctuation.operator","comment"],a,F={},p=function(C){var k=-1;if(C.multiSelect&&(k=C.selection.index,F.rangeCount!=C.multiSelect.rangeCount&&(F={rangeCount:C.multiSelect.rangeCount})),F[k])return a=F[k];a=F[k]={autoInsertedBrackets:0,autoInsertedRow:-1,autoInsertedLineEnd:"",maybeInsertedBrackets:0,maybeInsertedRow:-1,maybeInsertedLineStart:"",maybeInsertedLineEnd:""}},m=function(C,k,T,w){var A=C.end.row-C.start.row;return{text:T+k+w,selection:[0,C.start.column+1,A,C.end.column+(A?0:1)]}},b=function(){this.add("braces","insertion",function(C,k,T,w,A){var M=T.getCursorPosition(),x=w.doc.getLine(M.row);if(A=="{"){p(T);var R=T.getSelectionRange(),N=w.doc.getTextRange(R);if(N!==""&&N!=="{"&&T.getWrapBehavioursEnabled())return m(R,N,"{","}");if(b.isSaneInsertion(T,w))return/[\]\}\)]/.test(x[M.column])||T.inMultiSelectMode?(b.recordAutoInsert(T,w,"}"),{text:"{}",selection:[1,1]}):(b.recordMaybeInsert(T,w,"{"),{text:"{",selection:[1,1]})}else if(A=="}"){p(T);var j=x.substring(M.column,M.column+1);if(j=="}"){var B=w.$findOpeningBracket("}",{column:M.column+1,row:M.row});if(B!==null&&b.isAutoInsertedClosing(M,x,A))return b.popAutoInsertedClosing(),{text:"",selection:[1,1]}}}else if(A==`
`||A==`\r
`){p(T);var q="";b.isMaybeInsertedClosing(M,x)&&(q=d.stringRepeat("}",a.maybeInsertedBrackets),b.clearMaybeInsertedClosing());var j=x.substring(M.column,M.column+1);if(j==="}"){var U=w.findMatchingBracket({row:M.row,column:M.column+1},"}");if(!U)return null;var Z=this.$getIndent(w.getLine(U.row))}else if(q)var Z=this.$getIndent(x);else{b.clearMaybeInsertedClosing();return}var re=Z+w.getTabString();return{text:`
`+re+`
`+Z+q,selection:[1,re.length,1,re.length]}}else b.clearMaybeInsertedClosing()}),this.add("braces","deletion",function(C,k,T,w,A){var M=w.doc.getTextRange(A);if(!A.isMultiLine()&&M=="{"){p(T);var x=w.doc.getLine(A.start.row),R=x.substring(A.end.column,A.end.column+1);if(R=="}")return A.end.column++,A;a.maybeInsertedBrackets--}}),this.add("parens","insertion",function(C,k,T,w,A){if(A=="("){p(T);var M=T.getSelectionRange(),x=w.doc.getTextRange(M);if(x!==""&&T.getWrapBehavioursEnabled())return m(M,x,"(",")");if(b.isSaneInsertion(T,w))return b.recordAutoInsert(T,w,")"),{text:"()",selection:[1,1]}}else if(A==")"){p(T);var R=T.getCursorPosition(),N=w.doc.getLine(R.row),j=N.substring(R.column,R.column+1);if(j==")"){var B=w.$findOpeningBracket(")",{column:R.column+1,row:R.row});if(B!==null&&b.isAutoInsertedClosing(R,N,A))return b.popAutoInsertedClosing(),{text:"",selection:[1,1]}}}}),this.add("parens","deletion",function(C,k,T,w,A){var M=w.doc.getTextRange(A);if(!A.isMultiLine()&&M=="("){p(T);var x=w.doc.getLine(A.start.row),R=x.substring(A.start.column+1,A.start.column+2);if(R==")")return A.end.column++,A}}),this.add("brackets","insertion",function(C,k,T,w,A){if(A=="["){p(T);var M=T.getSelectionRange(),x=w.doc.getTextRange(M);if(x!==""&&T.getWrapBehavioursEnabled())return m(M,x,"[","]");if(b.isSaneInsertion(T,w))return b.recordAutoInsert(T,w,"]"),{text:"[]",selection:[1,1]}}else if(A=="]"){p(T);var R=T.getCursorPosition(),N=w.doc.getLine(R.row),j=N.substring(R.column,R.column+1);if(j=="]"){var B=w.$findOpeningBracket("]",{column:R.column+1,row:R.row});if(B!==null&&b.isAutoInsertedClosing(R,N,A))return b.popAutoInsertedClosing(),{text:"",selection:[1,1]}}}}),this.add("brackets","deletion",function(C,k,T,w,A){var M=w.doc.getTextRange(A);if(!A.isMultiLine()&&M=="["){p(T);var x=w.doc.getLine(A.start.row),R=x.substring(A.start.column+1,A.start.column+2);if(R=="]")return A.end.column++,A}}),this.add("string_dquotes","insertion",function(C,k,T,w,A){if(A=='"'||A=="'"){if(this.lineCommentStart&&this.lineCommentStart.indexOf(A)!=-1)return;p(T);var M=A,x=T.getSelectionRange(),R=w.doc.getTextRange(x);if(R!==""&&R!=="'"&&R!='"'&&T.getWrapBehavioursEnabled())return m(x,R,M,M);if(!R){var N=T.getCursorPosition(),j=w.doc.getLine(N.row),B=j.substring(N.column-1,N.column),q=j.substring(N.column,N.column+1),U=w.getTokenAt(N.row,N.column),Z=w.getTokenAt(N.row,N.column+1);if(B=="\\"&&U&&/escape/.test(U.type))return null;var re=U&&/string|escape/.test(U.type),le=!Z||/string|escape/.test(Z.type),ce;if(q==M)ce=re!==le,ce&&/string\.end/.test(Z.type)&&(ce=!1);else{if(re&&!le||re&&le)return null;var de=w.$mode.tokenRe;de.lastIndex=0;var he=de.test(B);de.lastIndex=0;var Fe=de.test(B);if(he||Fe||q&&!/[\s;,.})\]\\]/.test(q))return null;ce=!0}return{text:ce?M+M:"",selection:[1,1]}}}}),this.add("string_dquotes","deletion",function(C,k,T,w,A){var M=w.doc.getTextRange(A);if(!A.isMultiLine()&&(M=='"'||M=="'")){p(T);var x=w.doc.getLine(A.start.row),R=x.substring(A.start.column+1,A.start.column+2);if(R==M)return A.end.column++,A}})};b.isSaneInsertion=function(C,k){var T=C.getCursorPosition(),w=new g(k,T.row,T.column);if(!this.$matchTokenType(w.getCurrentToken()||"text",l)){var A=new g(k,T.row,T.column+1);if(!this.$matchTokenType(A.getCurrentToken()||"text",l))return!1}return w.stepForward(),w.getCurrentTokenRow()!==T.row||this.$matchTokenType(w.getCurrentToken()||"text",c)},b.$matchTokenType=function(C,k){return k.indexOf(C.type||C)>-1},b.recordAutoInsert=function(C,k,T){var w=C.getCursorPosition(),A=k.doc.getLine(w.row);this.isAutoInsertedClosing(w,A,a.autoInsertedLineEnd[0])||(a.autoInsertedBrackets=0),a.autoInsertedRow=w.row,a.autoInsertedLineEnd=T+A.substr(w.column),a.autoInsertedBrackets++},b.recordMaybeInsert=function(C,k,T){var w=C.getCursorPosition(),A=k.doc.getLine(w.row);this.isMaybeInsertedClosing(w,A)||(a.maybeInsertedBrackets=0),a.maybeInsertedRow=w.row,a.maybeInsertedLineStart=A.substr(0,w.column)+T,a.maybeInsertedLineEnd=A.substr(w.column),a.maybeInsertedBrackets++},b.isAutoInsertedClosing=function(C,k,T){return a.autoInsertedBrackets>0&&C.row===a.autoInsertedRow&&T===a.autoInsertedLineEnd[0]&&k.substr(C.column)===a.autoInsertedLineEnd},b.isMaybeInsertedClosing=function(C,k){return a.maybeInsertedBrackets>0&&C.row===a.maybeInsertedRow&&k.substr(C.column)===a.maybeInsertedLineEnd&&k.substr(0,C.column)==a.maybeInsertedLineStart},b.popAutoInsertedClosing=function(){a.autoInsertedLineEnd=a.autoInsertedLineEnd.substr(1),a.autoInsertedBrackets--},b.clearMaybeInsertedClosing=function(){a&&(a.maybeInsertedBrackets=0,a.maybeInsertedRow=-1)},n.inherits(b,h),o.CstyleBehaviour=b}),ace.define("ace/unicode",["require","exports","module"],function(s,o,f){o.packages={},n({L:"0041-005A0061-007A00AA00B500BA00C0-00D600D8-00F600F8-02C102C6-02D102E0-02E402EC02EE0370-037403760377037A-037D03860388-038A038C038E-03A103A3-03F503F7-0481048A-05250531-055605590561-058705D0-05EA05F0-05F20621-064A066E066F0671-06D306D506E506E606EE06EF06FA-06FC06FF07100712-072F074D-07A507B107CA-07EA07F407F507FA0800-0815081A082408280904-0939093D09500958-0961097109720979-097F0985-098C098F09900993-09A809AA-09B009B209B6-09B909BD09CE09DC09DD09DF-09E109F009F10A05-0A0A0A0F0A100A13-0A280A2A-0A300A320A330A350A360A380A390A59-0A5C0A5E0A72-0A740A85-0A8D0A8F-0A910A93-0AA80AAA-0AB00AB20AB30AB5-0AB90ABD0AD00AE00AE10B05-0B0C0B0F0B100B13-0B280B2A-0B300B320B330B35-0B390B3D0B5C0B5D0B5F-0B610B710B830B85-0B8A0B8E-0B900B92-0B950B990B9A0B9C0B9E0B9F0BA30BA40BA8-0BAA0BAE-0BB90BD00C05-0C0C0C0E-0C100C12-0C280C2A-0C330C35-0C390C3D0C580C590C600C610C85-0C8C0C8E-0C900C92-0CA80CAA-0CB30CB5-0CB90CBD0CDE0CE00CE10D05-0D0C0D0E-0D100D12-0D280D2A-0D390D3D0D600D610D7A-0D7F0D85-0D960D9A-0DB10DB3-0DBB0DBD0DC0-0DC60E01-0E300E320E330E40-0E460E810E820E840E870E880E8A0E8D0E94-0E970E99-0E9F0EA1-0EA30EA50EA70EAA0EAB0EAD-0EB00EB20EB30EBD0EC0-0EC40EC60EDC0EDD0F000F40-0F470F49-0F6C0F88-0F8B1000-102A103F1050-1055105A-105D106110651066106E-10701075-1081108E10A0-10C510D0-10FA10FC1100-1248124A-124D1250-12561258125A-125D1260-1288128A-128D1290-12B012B2-12B512B8-12BE12C012C2-12C512C8-12D612D8-13101312-13151318-135A1380-138F13A0-13F41401-166C166F-167F1681-169A16A0-16EA1700-170C170E-17111720-17311740-17511760-176C176E-17701780-17B317D717DC1820-18771880-18A818AA18B0-18F51900-191C1950-196D1970-19741980-19AB19C1-19C71A00-1A161A20-1A541AA71B05-1B331B45-1B4B1B83-1BA01BAE1BAF1C00-1C231C4D-1C4F1C5A-1C7D1CE9-1CEC1CEE-1CF11D00-1DBF1E00-1F151F18-1F1D1F20-1F451F48-1F4D1F50-1F571F591F5B1F5D1F5F-1F7D1F80-1FB41FB6-1FBC1FBE1FC2-1FC41FC6-1FCC1FD0-1FD31FD6-1FDB1FE0-1FEC1FF2-1FF41FF6-1FFC2071207F2090-209421022107210A-211321152119-211D212421262128212A-212D212F-2139213C-213F2145-2149214E218321842C00-2C2E2C30-2C5E2C60-2CE42CEB-2CEE2D00-2D252D30-2D652D6F2D80-2D962DA0-2DA62DA8-2DAE2DB0-2DB62DB8-2DBE2DC0-2DC62DC8-2DCE2DD0-2DD62DD8-2DDE2E2F300530063031-3035303B303C3041-3096309D-309F30A1-30FA30FC-30FF3105-312D3131-318E31A0-31B731F0-31FF3400-4DB54E00-9FCBA000-A48CA4D0-A4FDA500-A60CA610-A61FA62AA62BA640-A65FA662-A66EA67F-A697A6A0-A6E5A717-A71FA722-A788A78BA78CA7FB-A801A803-A805A807-A80AA80C-A822A840-A873A882-A8B3A8F2-A8F7A8FBA90A-A925A930-A946A960-A97CA984-A9B2A9CFAA00-AA28AA40-AA42AA44-AA4BAA60-AA76AA7AAA80-AAAFAAB1AAB5AAB6AAB9-AABDAAC0AAC2AADB-AADDABC0-ABE2AC00-D7A3D7B0-D7C6D7CB-D7FBF900-FA2DFA30-FA6DFA70-FAD9FB00-FB06FB13-FB17FB1DFB1F-FB28FB2A-FB36FB38-FB3CFB3EFB40FB41FB43FB44FB46-FBB1FBD3-FD3DFD50-FD8FFD92-FDC7FDF0-FDFBFE70-FE74FE76-FEFCFF21-FF3AFF41-FF5AFF66-FFBEFFC2-FFC7FFCA-FFCFFFD2-FFD7FFDA-FFDC",Ll:"0061-007A00AA00B500BA00DF-00F600F8-00FF01010103010501070109010B010D010F01110113011501170119011B011D011F01210123012501270129012B012D012F01310133013501370138013A013C013E014001420144014601480149014B014D014F01510153015501570159015B015D015F01610163016501670169016B016D016F0171017301750177017A017C017E-0180018301850188018C018D019201950199-019B019E01A101A301A501A801AA01AB01AD01B001B401B601B901BA01BD-01BF01C601C901CC01CE01D001D201D401D601D801DA01DC01DD01DF01E101E301E501E701E901EB01ED01EF01F001F301F501F901FB01FD01FF02010203020502070209020B020D020F02110213021502170219021B021D021F02210223022502270229022B022D022F02310233-0239023C023F0240024202470249024B024D024F-02930295-02AF037103730377037B-037D039003AC-03CE03D003D103D5-03D703D903DB03DD03DF03E103E303E503E703E903EB03ED03EF-03F303F503F803FB03FC0430-045F04610463046504670469046B046D046F04710473047504770479047B047D047F0481048B048D048F04910493049504970499049B049D049F04A104A304A504A704A904AB04AD04AF04B104B304B504B704B904BB04BD04BF04C204C404C604C804CA04CC04CE04CF04D104D304D504D704D904DB04DD04DF04E104E304E504E704E904EB04ED04EF04F104F304F504F704F904FB04FD04FF05010503050505070509050B050D050F05110513051505170519051B051D051F0521052305250561-05871D00-1D2B1D62-1D771D79-1D9A1E011E031E051E071E091E0B1E0D1E0F1E111E131E151E171E191E1B1E1D1E1F1E211E231E251E271E291E2B1E2D1E2F1E311E331E351E371E391E3B1E3D1E3F1E411E431E451E471E491E4B1E4D1E4F1E511E531E551E571E591E5B1E5D1E5F1E611E631E651E671E691E6B1E6D1E6F1E711E731E751E771E791E7B1E7D1E7F1E811E831E851E871E891E8B1E8D1E8F1E911E931E95-1E9D1E9F1EA11EA31EA51EA71EA91EAB1EAD1EAF1EB11EB31EB51EB71EB91EBB1EBD1EBF1EC11EC31EC51EC71EC91ECB1ECD1ECF1ED11ED31ED51ED71ED91EDB1EDD1EDF1EE11EE31EE51EE71EE91EEB1EED1EEF1EF11EF31EF51EF71EF91EFB1EFD1EFF-1F071F10-1F151F20-1F271F30-1F371F40-1F451F50-1F571F60-1F671F70-1F7D1F80-1F871F90-1F971FA0-1FA71FB0-1FB41FB61FB71FBE1FC2-1FC41FC61FC71FD0-1FD31FD61FD71FE0-1FE71FF2-1FF41FF61FF7210A210E210F2113212F21342139213C213D2146-2149214E21842C30-2C5E2C612C652C662C682C6A2C6C2C712C732C742C76-2C7C2C812C832C852C872C892C8B2C8D2C8F2C912C932C952C972C992C9B2C9D2C9F2CA12CA32CA52CA72CA92CAB2CAD2CAF2CB12CB32CB52CB72CB92CBB2CBD2CBF2CC12CC32CC52CC72CC92CCB2CCD2CCF2CD12CD32CD52CD72CD92CDB2CDD2CDF2CE12CE32CE42CEC2CEE2D00-2D25A641A643A645A647A649A64BA64DA64FA651A653A655A657A659A65BA65DA65FA663A665A667A669A66BA66DA681A683A685A687A689A68BA68DA68FA691A693A695A697A723A725A727A729A72BA72DA72F-A731A733A735A737A739A73BA73DA73FA741A743A745A747A749A74BA74DA74FA751A753A755A757A759A75BA75DA75FA761A763A765A767A769A76BA76DA76FA771-A778A77AA77CA77FA781A783A785A787A78CFB00-FB06FB13-FB17FF41-FF5A",Lu:"0041-005A00C0-00D600D8-00DE01000102010401060108010A010C010E01100112011401160118011A011C011E01200122012401260128012A012C012E01300132013401360139013B013D013F0141014301450147014A014C014E01500152015401560158015A015C015E01600162016401660168016A016C016E017001720174017601780179017B017D018101820184018601870189-018B018E-0191019301940196-0198019C019D019F01A001A201A401A601A701A901AC01AE01AF01B1-01B301B501B701B801BC01C401C701CA01CD01CF01D101D301D501D701D901DB01DE01E001E201E401E601E801EA01EC01EE01F101F401F6-01F801FA01FC01FE02000202020402060208020A020C020E02100212021402160218021A021C021E02200222022402260228022A022C022E02300232023A023B023D023E02410243-02460248024A024C024E03700372037603860388-038A038C038E038F0391-03A103A3-03AB03CF03D2-03D403D803DA03DC03DE03E003E203E403E603E803EA03EC03EE03F403F703F903FA03FD-042F04600462046404660468046A046C046E04700472047404760478047A047C047E0480048A048C048E04900492049404960498049A049C049E04A004A204A404A604A804AA04AC04AE04B004B204B404B604B804BA04BC04BE04C004C104C304C504C704C904CB04CD04D004D204D404D604D804DA04DC04DE04E004E204E404E604E804EA04EC04EE04F004F204F404F604F804FA04FC04FE05000502050405060508050A050C050E05100512051405160518051A051C051E0520052205240531-055610A0-10C51E001E021E041E061E081E0A1E0C1E0E1E101E121E141E161E181E1A1E1C1E1E1E201E221E241E261E281E2A1E2C1E2E1E301E321E341E361E381E3A1E3C1E3E1E401E421E441E461E481E4A1E4C1E4E1E501E521E541E561E581E5A1E5C1E5E1E601E621E641E661E681E6A1E6C1E6E1E701E721E741E761E781E7A1E7C1E7E1E801E821E841E861E881E8A1E8C1E8E1E901E921E941E9E1EA01EA21EA41EA61EA81EAA1EAC1EAE1EB01EB21EB41EB61EB81EBA1EBC1EBE1EC01EC21EC41EC61EC81ECA1ECC1ECE1ED01ED21ED41ED61ED81EDA1EDC1EDE1EE01EE21EE41EE61EE81EEA1EEC1EEE1EF01EF21EF41EF61EF81EFA1EFC1EFE1F08-1F0F1F18-1F1D1F28-1F2F1F38-1F3F1F48-1F4D1F591F5B1F5D1F5F1F68-1F6F1FB8-1FBB1FC8-1FCB1FD8-1FDB1FE8-1FEC1FF8-1FFB21022107210B-210D2110-211221152119-211D212421262128212A-212D2130-2133213E213F214521832C00-2C2E2C602C62-2C642C672C692C6B2C6D-2C702C722C752C7E-2C802C822C842C862C882C8A2C8C2C8E2C902C922C942C962C982C9A2C9C2C9E2CA02CA22CA42CA62CA82CAA2CAC2CAE2CB02CB22CB42CB62CB82CBA2CBC2CBE2CC02CC22CC42CC62CC82CCA2CCC2CCE2CD02CD22CD42CD62CD82CDA2CDC2CDE2CE02CE22CEB2CEDA640A642A644A646A648A64AA64CA64EA650A652A654A656A658A65AA65CA65EA662A664A666A668A66AA66CA680A682A684A686A688A68AA68CA68EA690A692A694A696A722A724A726A728A72AA72CA72EA732A734A736A738A73AA73CA73EA740A742A744A746A748A74AA74CA74EA750A752A754A756A758A75AA75CA75EA760A762A764A766A768A76AA76CA76EA779A77BA77DA77EA780A782A784A786A78BFF21-FF3A",Lt:"01C501C801CB01F21F88-1F8F1F98-1F9F1FA8-1FAF1FBC1FCC1FFC",Lm:"02B0-02C102C6-02D102E0-02E402EC02EE0374037A0559064006E506E607F407F507FA081A0824082809710E460EC610FC17D718431AA71C78-1C7D1D2C-1D611D781D9B-1DBF2071207F2090-20942C7D2D6F2E2F30053031-3035303B309D309E30FC-30FEA015A4F8-A4FDA60CA67FA717-A71FA770A788A9CFAA70AADDFF70FF9EFF9F",Lo:"01BB01C0-01C3029405D0-05EA05F0-05F20621-063F0641-064A066E066F0671-06D306D506EE06EF06FA-06FC06FF07100712-072F074D-07A507B107CA-07EA0800-08150904-0939093D09500958-096109720979-097F0985-098C098F09900993-09A809AA-09B009B209B6-09B909BD09CE09DC09DD09DF-09E109F009F10A05-0A0A0A0F0A100A13-0A280A2A-0A300A320A330A350A360A380A390A59-0A5C0A5E0A72-0A740A85-0A8D0A8F-0A910A93-0AA80AAA-0AB00AB20AB30AB5-0AB90ABD0AD00AE00AE10B05-0B0C0B0F0B100B13-0B280B2A-0B300B320B330B35-0B390B3D0B5C0B5D0B5F-0B610B710B830B85-0B8A0B8E-0B900B92-0B950B990B9A0B9C0B9E0B9F0BA30BA40BA8-0BAA0BAE-0BB90BD00C05-0C0C0C0E-0C100C12-0C280C2A-0C330C35-0C390C3D0C580C590C600C610C85-0C8C0C8E-0C900C92-0CA80CAA-0CB30CB5-0CB90CBD0CDE0CE00CE10D05-0D0C0D0E-0D100D12-0D280D2A-0D390D3D0D600D610D7A-0D7F0D85-0D960D9A-0DB10DB3-0DBB0DBD0DC0-0DC60E01-0E300E320E330E40-0E450E810E820E840E870E880E8A0E8D0E94-0E970E99-0E9F0EA1-0EA30EA50EA70EAA0EAB0EAD-0EB00EB20EB30EBD0EC0-0EC40EDC0EDD0F000F40-0F470F49-0F6C0F88-0F8B1000-102A103F1050-1055105A-105D106110651066106E-10701075-1081108E10D0-10FA1100-1248124A-124D1250-12561258125A-125D1260-1288128A-128D1290-12B012B2-12B512B8-12BE12C012C2-12C512C8-12D612D8-13101312-13151318-135A1380-138F13A0-13F41401-166C166F-167F1681-169A16A0-16EA1700-170C170E-17111720-17311740-17511760-176C176E-17701780-17B317DC1820-18421844-18771880-18A818AA18B0-18F51900-191C1950-196D1970-19741980-19AB19C1-19C71A00-1A161A20-1A541B05-1B331B45-1B4B1B83-1BA01BAE1BAF1C00-1C231C4D-1C4F1C5A-1C771CE9-1CEC1CEE-1CF12135-21382D30-2D652D80-2D962DA0-2DA62DA8-2DAE2DB0-2DB62DB8-2DBE2DC0-2DC62DC8-2DCE2DD0-2DD62DD8-2DDE3006303C3041-3096309F30A1-30FA30FF3105-312D3131-318E31A0-31B731F0-31FF3400-4DB54E00-9FCBA000-A014A016-A48CA4D0-A4F7A500-A60BA610-A61FA62AA62BA66EA6A0-A6E5A7FB-A801A803-A805A807-A80AA80C-A822A840-A873A882-A8B3A8F2-A8F7A8FBA90A-A925A930-A946A960-A97CA984-A9B2AA00-AA28AA40-AA42AA44-AA4BAA60-AA6FAA71-AA76AA7AAA80-AAAFAAB1AAB5AAB6AAB9-AABDAAC0AAC2AADBAADCABC0-ABE2AC00-D7A3D7B0-D7C6D7CB-D7FBF900-FA2DFA30-FA6DFA70-FAD9FB1DFB1F-FB28FB2A-FB36FB38-FB3CFB3EFB40FB41FB43FB44FB46-FBB1FBD3-FD3DFD50-FD8FFD92-FDC7FDF0-FDFBFE70-FE74FE76-FEFCFF66-FF6FFF71-FF9DFFA0-FFBEFFC2-FFC7FFCA-FFCFFFD2-FFD7FFDA-FFDC",M:"0300-036F0483-04890591-05BD05BF05C105C205C405C505C70610-061A064B-065E067006D6-06DC06DE-06E406E706E806EA-06ED07110730-074A07A6-07B007EB-07F30816-0819081B-08230825-08270829-082D0900-0903093C093E-094E0951-0955096209630981-098309BC09BE-09C409C709C809CB-09CD09D709E209E30A01-0A030A3C0A3E-0A420A470A480A4B-0A4D0A510A700A710A750A81-0A830ABC0ABE-0AC50AC7-0AC90ACB-0ACD0AE20AE30B01-0B030B3C0B3E-0B440B470B480B4B-0B4D0B560B570B620B630B820BBE-0BC20BC6-0BC80BCA-0BCD0BD70C01-0C030C3E-0C440C46-0C480C4A-0C4D0C550C560C620C630C820C830CBC0CBE-0CC40CC6-0CC80CCA-0CCD0CD50CD60CE20CE30D020D030D3E-0D440D46-0D480D4A-0D4D0D570D620D630D820D830DCA0DCF-0DD40DD60DD8-0DDF0DF20DF30E310E34-0E3A0E47-0E4E0EB10EB4-0EB90EBB0EBC0EC8-0ECD0F180F190F350F370F390F3E0F3F0F71-0F840F860F870F90-0F970F99-0FBC0FC6102B-103E1056-1059105E-10601062-10641067-106D1071-10741082-108D108F109A-109D135F1712-17141732-1734175217531772177317B6-17D317DD180B-180D18A91920-192B1930-193B19B0-19C019C819C91A17-1A1B1A55-1A5E1A60-1A7C1A7F1B00-1B041B34-1B441B6B-1B731B80-1B821BA1-1BAA1C24-1C371CD0-1CD21CD4-1CE81CED1CF21DC0-1DE61DFD-1DFF20D0-20F02CEF-2CF12DE0-2DFF302A-302F3099309AA66F-A672A67CA67DA6F0A6F1A802A806A80BA823-A827A880A881A8B4-A8C4A8E0-A8F1A926-A92DA947-A953A980-A983A9B3-A9C0AA29-AA36AA43AA4CAA4DAA7BAAB0AAB2-AAB4AAB7AAB8AABEAABFAAC1ABE3-ABEAABECABEDFB1EFE00-FE0FFE20-FE26",Mn:"0300-036F0483-04870591-05BD05BF05C105C205C405C505C70610-061A064B-065E067006D6-06DC06DF-06E406E706E806EA-06ED07110730-074A07A6-07B007EB-07F30816-0819081B-08230825-08270829-082D0900-0902093C0941-0948094D0951-095509620963098109BC09C1-09C409CD09E209E30A010A020A3C0A410A420A470A480A4B-0A4D0A510A700A710A750A810A820ABC0AC1-0AC50AC70AC80ACD0AE20AE30B010B3C0B3F0B41-0B440B4D0B560B620B630B820BC00BCD0C3E-0C400C46-0C480C4A-0C4D0C550C560C620C630CBC0CBF0CC60CCC0CCD0CE20CE30D41-0D440D4D0D620D630DCA0DD2-0DD40DD60E310E34-0E3A0E47-0E4E0EB10EB4-0EB90EBB0EBC0EC8-0ECD0F180F190F350F370F390F71-0F7E0F80-0F840F860F870F90-0F970F99-0FBC0FC6102D-10301032-10371039103A103D103E10581059105E-10601071-1074108210851086108D109D135F1712-17141732-1734175217531772177317B7-17BD17C617C9-17D317DD180B-180D18A91920-19221927192819321939-193B1A171A181A561A58-1A5E1A601A621A65-1A6C1A73-1A7C1A7F1B00-1B031B341B36-1B3A1B3C1B421B6B-1B731B801B811BA2-1BA51BA81BA91C2C-1C331C361C371CD0-1CD21CD4-1CE01CE2-1CE81CED1DC0-1DE61DFD-1DFF20D0-20DC20E120E5-20F02CEF-2CF12DE0-2DFF302A-302F3099309AA66FA67CA67DA6F0A6F1A802A806A80BA825A826A8C4A8E0-A8F1A926-A92DA947-A951A980-A982A9B3A9B6-A9B9A9BCAA29-AA2EAA31AA32AA35AA36AA43AA4CAAB0AAB2-AAB4AAB7AAB8AABEAABFAAC1ABE5ABE8ABEDFB1EFE00-FE0FFE20-FE26",Mc:"0903093E-09400949-094C094E0982098309BE-09C009C709C809CB09CC09D70A030A3E-0A400A830ABE-0AC00AC90ACB0ACC0B020B030B3E0B400B470B480B4B0B4C0B570BBE0BBF0BC10BC20BC6-0BC80BCA-0BCC0BD70C01-0C030C41-0C440C820C830CBE0CC0-0CC40CC70CC80CCA0CCB0CD50CD60D020D030D3E-0D400D46-0D480D4A-0D4C0D570D820D830DCF-0DD10DD8-0DDF0DF20DF30F3E0F3F0F7F102B102C10311038103B103C105610571062-10641067-106D108310841087-108C108F109A-109C17B617BE-17C517C717C81923-19261929-192B193019311933-193819B0-19C019C819C91A19-1A1B1A551A571A611A631A641A6D-1A721B041B351B3B1B3D-1B411B431B441B821BA11BA61BA71BAA1C24-1C2B1C341C351CE11CF2A823A824A827A880A881A8B4-A8C3A952A953A983A9B4A9B5A9BAA9BBA9BD-A9C0AA2FAA30AA33AA34AA4DAA7BABE3ABE4ABE6ABE7ABE9ABEAABEC",Me:"0488048906DE20DD-20E020E2-20E4A670-A672",N:"0030-003900B200B300B900BC-00BE0660-066906F0-06F907C0-07C90966-096F09E6-09EF09F4-09F90A66-0A6F0AE6-0AEF0B66-0B6F0BE6-0BF20C66-0C6F0C78-0C7E0CE6-0CEF0D66-0D750E50-0E590ED0-0ED90F20-0F331040-10491090-10991369-137C16EE-16F017E0-17E917F0-17F91810-18191946-194F19D0-19DA1A80-1A891A90-1A991B50-1B591BB0-1BB91C40-1C491C50-1C5920702074-20792080-20892150-21822185-21892460-249B24EA-24FF2776-27932CFD30073021-30293038-303A3192-31953220-32293251-325F3280-328932B1-32BFA620-A629A6E6-A6EFA830-A835A8D0-A8D9A900-A909A9D0-A9D9AA50-AA59ABF0-ABF9FF10-FF19",Nd:"0030-00390660-066906F0-06F907C0-07C90966-096F09E6-09EF0A66-0A6F0AE6-0AEF0B66-0B6F0BE6-0BEF0C66-0C6F0CE6-0CEF0D66-0D6F0E50-0E590ED0-0ED90F20-0F291040-10491090-109917E0-17E91810-18191946-194F19D0-19DA1A80-1A891A90-1A991B50-1B591BB0-1BB91C40-1C491C50-1C59A620-A629A8D0-A8D9A900-A909A9D0-A9D9AA50-AA59ABF0-ABF9FF10-FF19",Nl:"16EE-16F02160-21822185-218830073021-30293038-303AA6E6-A6EF",No:"00B200B300B900BC-00BE09F4-09F90BF0-0BF20C78-0C7E0D70-0D750F2A-0F331369-137C17F0-17F920702074-20792080-20892150-215F21892460-249B24EA-24FF2776-27932CFD3192-31953220-32293251-325F3280-328932B1-32BFA830-A835",P:"0021-00230025-002A002C-002F003A003B003F0040005B-005D005F007B007D00A100AB00B700BB00BF037E0387055A-055F0589058A05BE05C005C305C605F305F40609060A060C060D061B061E061F066A-066D06D40700-070D07F7-07F90830-083E0964096509700DF40E4F0E5A0E5B0F04-0F120F3A-0F3D0F850FD0-0FD4104A-104F10FB1361-13681400166D166E169B169C16EB-16ED1735173617D4-17D617D8-17DA1800-180A1944194519DE19DF1A1E1A1F1AA0-1AA61AA8-1AAD1B5A-1B601C3B-1C3F1C7E1C7F1CD32010-20272030-20432045-20512053-205E207D207E208D208E2329232A2768-277527C527C627E6-27EF2983-299829D8-29DB29FC29FD2CF9-2CFC2CFE2CFF2E00-2E2E2E302E313001-30033008-30113014-301F3030303D30A030FBA4FEA4FFA60D-A60FA673A67EA6F2-A6F7A874-A877A8CEA8CFA8F8-A8FAA92EA92FA95FA9C1-A9CDA9DEA9DFAA5C-AA5FAADEAADFABEBFD3EFD3FFE10-FE19FE30-FE52FE54-FE61FE63FE68FE6AFE6BFF01-FF03FF05-FF0AFF0C-FF0FFF1AFF1BFF1FFF20FF3B-FF3DFF3FFF5BFF5DFF5F-FF65",Pd:"002D058A05BE140018062010-20152E172E1A301C303030A0FE31FE32FE58FE63FF0D",Ps:"0028005B007B0F3A0F3C169B201A201E2045207D208D23292768276A276C276E27702772277427C527E627E827EA27EC27EE2983298529872989298B298D298F299129932995299729D829DA29FC2E222E242E262E283008300A300C300E3010301430163018301A301DFD3EFE17FE35FE37FE39FE3BFE3DFE3FFE41FE43FE47FE59FE5BFE5DFF08FF3BFF5BFF5FFF62",Pe:"0029005D007D0F3B0F3D169C2046207E208E232A2769276B276D276F27712773277527C627E727E927EB27ED27EF298429862988298A298C298E2990299229942996299829D929DB29FD2E232E252E272E293009300B300D300F3011301530173019301B301E301FFD3FFE18FE36FE38FE3AFE3CFE3EFE40FE42FE44FE48FE5AFE5CFE5EFF09FF3DFF5DFF60FF63",Pi:"00AB2018201B201C201F20392E022E042E092E0C2E1C2E20",Pf:"00BB2019201D203A2E032E052E0A2E0D2E1D2E21",Pc:"005F203F20402054FE33FE34FE4D-FE4FFF3F",Po:"0021-00230025-0027002A002C002E002F003A003B003F0040005C00A100B700BF037E0387055A-055F058905C005C305C605F305F40609060A060C060D061B061E061F066A-066D06D40700-070D07F7-07F90830-083E0964096509700DF40E4F0E5A0E5B0F04-0F120F850FD0-0FD4104A-104F10FB1361-1368166D166E16EB-16ED1735173617D4-17D617D8-17DA1800-18051807-180A1944194519DE19DF1A1E1A1F1AA0-1AA61AA8-1AAD1B5A-1B601C3B-1C3F1C7E1C7F1CD3201620172020-20272030-2038203B-203E2041-20432047-205120532055-205E2CF9-2CFC2CFE2CFF2E002E012E06-2E082E0B2E0E-2E162E182E192E1B2E1E2E1F2E2A-2E2E2E302E313001-3003303D30FBA4FEA4FFA60D-A60FA673A67EA6F2-A6F7A874-A877A8CEA8CFA8F8-A8FAA92EA92FA95FA9C1-A9CDA9DEA9DFAA5C-AA5FAADEAADFABEBFE10-FE16FE19FE30FE45FE46FE49-FE4CFE50-FE52FE54-FE57FE5F-FE61FE68FE6AFE6BFF01-FF03FF05-FF07FF0AFF0CFF0EFF0FFF1AFF1BFF1FFF20FF3CFF61FF64FF65",S:"0024002B003C-003E005E0060007C007E00A2-00A900AC00AE-00B100B400B600B800D700F702C2-02C502D2-02DF02E5-02EB02ED02EF-02FF03750384038503F604820606-0608060B060E060F06E906FD06FE07F609F209F309FA09FB0AF10B700BF3-0BFA0C7F0CF10CF20D790E3F0F01-0F030F13-0F170F1A-0F1F0F340F360F380FBE-0FC50FC7-0FCC0FCE0FCF0FD5-0FD8109E109F13601390-139917DB194019E0-19FF1B61-1B6A1B74-1B7C1FBD1FBF-1FC11FCD-1FCF1FDD-1FDF1FED-1FEF1FFD1FFE20442052207A-207C208A-208C20A0-20B8210021012103-21062108210921142116-2118211E-2123212521272129212E213A213B2140-2144214A-214D214F2190-2328232B-23E82400-24262440-244A249C-24E92500-26CD26CF-26E126E326E8-26FF2701-27042706-2709270C-27272729-274B274D274F-27522756-275E2761-276727942798-27AF27B1-27BE27C0-27C427C7-27CA27CC27D0-27E527F0-29822999-29D729DC-29FB29FE-2B4C2B50-2B592CE5-2CEA2E80-2E992E9B-2EF32F00-2FD52FF0-2FFB300430123013302030363037303E303F309B309C319031913196-319F31C0-31E33200-321E322A-32503260-327F328A-32B032C0-32FE3300-33FF4DC0-4DFFA490-A4C6A700-A716A720A721A789A78AA828-A82BA836-A839AA77-AA79FB29FDFCFDFDFE62FE64-FE66FE69FF04FF0BFF1C-FF1EFF3EFF40FF5CFF5EFFE0-FFE6FFE8-FFEEFFFCFFFD",Sm:"002B003C-003E007C007E00AC00B100D700F703F60606-060820442052207A-207C208A-208C2140-2144214B2190-2194219A219B21A021A321A621AE21CE21CF21D221D421F4-22FF2308-230B23202321237C239B-23B323DC-23E125B725C125F8-25FF266F27C0-27C427C7-27CA27CC27D0-27E527F0-27FF2900-29822999-29D729DC-29FB29FE-2AFF2B30-2B442B47-2B4CFB29FE62FE64-FE66FF0BFF1C-FF1EFF5CFF5EFFE2FFE9-FFEC",Sc:"002400A2-00A5060B09F209F309FB0AF10BF90E3F17DB20A0-20B8A838FDFCFE69FF04FFE0FFE1FFE5FFE6",Sk:"005E006000A800AF00B400B802C2-02C502D2-02DF02E5-02EB02ED02EF-02FF0375038403851FBD1FBF-1FC11FCD-1FCF1FDD-1FDF1FED-1FEF1FFD1FFE309B309CA700-A716A720A721A789A78AFF3EFF40FFE3",So:"00A600A700A900AE00B000B60482060E060F06E906FD06FE07F609FA0B700BF3-0BF80BFA0C7F0CF10CF20D790F01-0F030F13-0F170F1A-0F1F0F340F360F380FBE-0FC50FC7-0FCC0FCE0FCF0FD5-0FD8109E109F13601390-1399194019E0-19FF1B61-1B6A1B74-1B7C210021012103-21062108210921142116-2118211E-2123212521272129212E213A213B214A214C214D214F2195-2199219C-219F21A121A221A421A521A7-21AD21AF-21CD21D021D121D321D5-21F32300-2307230C-231F2322-2328232B-237B237D-239A23B4-23DB23E2-23E82400-24262440-244A249C-24E92500-25B625B8-25C025C2-25F72600-266E2670-26CD26CF-26E126E326E8-26FF2701-27042706-2709270C-27272729-274B274D274F-27522756-275E2761-276727942798-27AF27B1-27BE2800-28FF2B00-2B2F2B452B462B50-2B592CE5-2CEA2E80-2E992E9B-2EF32F00-2FD52FF0-2FFB300430123013302030363037303E303F319031913196-319F31C0-31E33200-321E322A-32503260-327F328A-32B032C0-32FE3300-33FF4DC0-4DFFA490-A4C6A828-A82BA836A837A839AA77-AA79FDFDFFE4FFE8FFEDFFEEFFFCFFFD",Z:"002000A01680180E2000-200A20282029202F205F3000",Zs:"002000A01680180E2000-200A202F205F3000",Zl:"2028",Zp:"2029",C:"0000-001F007F-009F00AD03780379037F-0383038B038D03A20526-05300557055805600588058B-059005C8-05CF05EB-05EF05F5-0605061C061D0620065F06DD070E070F074B074C07B2-07BF07FB-07FF082E082F083F-08FF093A093B094F095609570973-097809800984098D098E0991099209A909B109B3-09B509BA09BB09C509C609C909CA09CF-09D609D8-09DB09DE09E409E509FC-0A000A040A0B-0A0E0A110A120A290A310A340A370A3A0A3B0A3D0A43-0A460A490A4A0A4E-0A500A52-0A580A5D0A5F-0A650A76-0A800A840A8E0A920AA90AB10AB40ABA0ABB0AC60ACA0ACE0ACF0AD1-0ADF0AE40AE50AF00AF2-0B000B040B0D0B0E0B110B120B290B310B340B3A0B3B0B450B460B490B4A0B4E-0B550B58-0B5B0B5E0B640B650B72-0B810B840B8B-0B8D0B910B96-0B980B9B0B9D0BA0-0BA20BA5-0BA70BAB-0BAD0BBA-0BBD0BC3-0BC50BC90BCE0BCF0BD1-0BD60BD8-0BE50BFB-0C000C040C0D0C110C290C340C3A-0C3C0C450C490C4E-0C540C570C5A-0C5F0C640C650C70-0C770C800C810C840C8D0C910CA90CB40CBA0CBB0CC50CC90CCE-0CD40CD7-0CDD0CDF0CE40CE50CF00CF3-0D010D040D0D0D110D290D3A-0D3C0D450D490D4E-0D560D58-0D5F0D640D650D76-0D780D800D810D840D97-0D990DB20DBC0DBE0DBF0DC7-0DC90DCB-0DCE0DD50DD70DE0-0DF10DF5-0E000E3B-0E3E0E5C-0E800E830E850E860E890E8B0E8C0E8E-0E930E980EA00EA40EA60EA80EA90EAC0EBA0EBE0EBF0EC50EC70ECE0ECF0EDA0EDB0EDE-0EFF0F480F6D-0F700F8C-0F8F0F980FBD0FCD0FD9-0FFF10C6-10CF10FD-10FF1249124E124F12571259125E125F1289128E128F12B112B612B712BF12C112C612C712D7131113161317135B-135E137D-137F139A-139F13F5-13FF169D-169F16F1-16FF170D1715-171F1737-173F1754-175F176D17711774-177F17B417B517DE17DF17EA-17EF17FA-17FF180F181A-181F1878-187F18AB-18AF18F6-18FF191D-191F192C-192F193C-193F1941-1943196E196F1975-197F19AC-19AF19CA-19CF19DB-19DD1A1C1A1D1A5F1A7D1A7E1A8A-1A8F1A9A-1A9F1AAE-1AFF1B4C-1B4F1B7D-1B7F1BAB-1BAD1BBA-1BFF1C38-1C3A1C4A-1C4C1C80-1CCF1CF3-1CFF1DE7-1DFC1F161F171F1E1F1F1F461F471F4E1F4F1F581F5A1F5C1F5E1F7E1F7F1FB51FC51FD41FD51FDC1FF01FF11FF51FFF200B-200F202A-202E2060-206F20722073208F2095-209F20B9-20CF20F1-20FF218A-218F23E9-23FF2427-243F244B-245F26CE26E226E4-26E727002705270A270B2728274C274E2753-2755275F27602795-279727B027BF27CB27CD-27CF2B4D-2B4F2B5A-2BFF2C2F2C5F2CF2-2CF82D26-2D2F2D66-2D6E2D70-2D7F2D97-2D9F2DA72DAF2DB72DBF2DC72DCF2DD72DDF2E32-2E7F2E9A2EF4-2EFF2FD6-2FEF2FFC-2FFF3040309730983100-3104312E-3130318F31B8-31BF31E4-31EF321F32FF4DB6-4DBF9FCC-9FFFA48D-A48FA4C7-A4CFA62C-A63FA660A661A674-A67BA698-A69FA6F8-A6FFA78D-A7FAA82C-A82FA83A-A83FA878-A87FA8C5-A8CDA8DA-A8DFA8FC-A8FFA954-A95EA97D-A97FA9CEA9DA-A9DDA9E0-A9FFAA37-AA3FAA4EAA4FAA5AAA5BAA7C-AA7FAAC3-AADAAAE0-ABBFABEEABEFABFA-ABFFD7A4-D7AFD7C7-D7CAD7FC-F8FFFA2EFA2FFA6EFA6FFADA-FAFFFB07-FB12FB18-FB1CFB37FB3DFB3FFB42FB45FBB2-FBD2FD40-FD4FFD90FD91FDC8-FDEFFDFEFDFFFE1A-FE1FFE27-FE2FFE53FE67FE6C-FE6FFE75FEFD-FF00FFBF-FFC1FFC8FFC9FFD0FFD1FFD8FFD9FFDD-FFDFFFE7FFEF-FFFBFFFEFFFF",Cc:"0000-001F007F-009F",Cf:"00AD0600-060306DD070F17B417B5200B-200F202A-202E2060-2064206A-206FFEFFFFF9-FFFB",Co:"E000-F8FF",Cs:"D800-DFFF",Cn:"03780379037F-0383038B038D03A20526-05300557055805600588058B-059005C8-05CF05EB-05EF05F5-05FF06040605061C061D0620065F070E074B074C07B2-07BF07FB-07FF082E082F083F-08FF093A093B094F095609570973-097809800984098D098E0991099209A909B109B3-09B509BA09BB09C509C609C909CA09CF-09D609D8-09DB09DE09E409E509FC-0A000A040A0B-0A0E0A110A120A290A310A340A370A3A0A3B0A3D0A43-0A460A490A4A0A4E-0A500A52-0A580A5D0A5F-0A650A76-0A800A840A8E0A920AA90AB10AB40ABA0ABB0AC60ACA0ACE0ACF0AD1-0ADF0AE40AE50AF00AF2-0B000B040B0D0B0E0B110B120B290B310B340B3A0B3B0B450B460B490B4A0B4E-0B550B58-0B5B0B5E0B640B650B72-0B810B840B8B-0B8D0B910B96-0B980B9B0B9D0BA0-0BA20BA5-0BA70BAB-0BAD0BBA-0BBD0BC3-0BC50BC90BCE0BCF0BD1-0BD60BD8-0BE50BFB-0C000C040C0D0C110C290C340C3A-0C3C0C450C490C4E-0C540C570C5A-0C5F0C640C650C70-0C770C800C810C840C8D0C910CA90CB40CBA0CBB0CC50CC90CCE-0CD40CD7-0CDD0CDF0CE40CE50CF00CF3-0D010D040D0D0D110D290D3A-0D3C0D450D490D4E-0D560D58-0D5F0D640D650D76-0D780D800D810D840D97-0D990DB20DBC0DBE0DBF0DC7-0DC90DCB-0DCE0DD50DD70DE0-0DF10DF5-0E000E3B-0E3E0E5C-0E800E830E850E860E890E8B0E8C0E8E-0E930E980EA00EA40EA60EA80EA90EAC0EBA0EBE0EBF0EC50EC70ECE0ECF0EDA0EDB0EDE-0EFF0F480F6D-0F700F8C-0F8F0F980FBD0FCD0FD9-0FFF10C6-10CF10FD-10FF1249124E124F12571259125E125F1289128E128F12B112B612B712BF12C112C612C712D7131113161317135B-135E137D-137F139A-139F13F5-13FF169D-169F16F1-16FF170D1715-171F1737-173F1754-175F176D17711774-177F17DE17DF17EA-17EF17FA-17FF180F181A-181F1878-187F18AB-18AF18F6-18FF191D-191F192C-192F193C-193F1941-1943196E196F1975-197F19AC-19AF19CA-19CF19DB-19DD1A1C1A1D1A5F1A7D1A7E1A8A-1A8F1A9A-1A9F1AAE-1AFF1B4C-1B4F1B7D-1B7F1BAB-1BAD1BBA-1BFF1C38-1C3A1C4A-1C4C1C80-1CCF1CF3-1CFF1DE7-1DFC1F161F171F1E1F1F1F461F471F4E1F4F1F581F5A1F5C1F5E1F7E1F7F1FB51FC51FD41FD51FDC1FF01FF11FF51FFF2065-206920722073208F2095-209F20B9-20CF20F1-20FF218A-218F23E9-23FF2427-243F244B-245F26CE26E226E4-26E727002705270A270B2728274C274E2753-2755275F27602795-279727B027BF27CB27CD-27CF2B4D-2B4F2B5A-2BFF2C2F2C5F2CF2-2CF82D26-2D2F2D66-2D6E2D70-2D7F2D97-2D9F2DA72DAF2DB72DBF2DC72DCF2DD72DDF2E32-2E7F2E9A2EF4-2EFF2FD6-2FEF2FFC-2FFF3040309730983100-3104312E-3130318F31B8-31BF31E4-31EF321F32FF4DB6-4DBF9FCC-9FFFA48D-A48FA4C7-A4CFA62C-A63FA660A661A674-A67BA698-A69FA6F8-A6FFA78D-A7FAA82C-A82FA83A-A83FA878-A87FA8C5-A8CDA8DA-A8DFA8FC-A8FFA954-A95EA97D-A97FA9CEA9DA-A9DDA9E0-A9FFAA37-AA3FAA4EAA4FAA5AAA5BAA7C-AA7FAAC3-AADAAAE0-ABBFABEEABEFABFA-ABFFD7A4-D7AFD7C7-D7CAD7FC-D7FFFA2EFA2FFA6EFA6FFADA-FAFFFB07-FB12FB18-FB1CFB37FB3DFB3FFB42FB45FBB2-FBD2FD40-FD4FFD90FD91FDC8-FDEFFDFEFDFFFE1A-FE1FFE27-FE2FFE53FE67FE6C-FE6FFE75FEFDFEFEFF00FFBF-FFC1FFC8FFC9FFD0FFD1FFD8FFD9FFDD-FFDFFFE7FFEF-FFF8FFFEFFFF"});function n(h){var g=/\w{4}/g;for(var d in h)o.packages[d]=h[d].replace(g,"\\u$&")}}),ace.define("ace/mode/text",["require","exports","module","ace/tokenizer","ace/mode/text_highlight_rules","ace/mode/behaviour/cstyle","ace/unicode","ace/lib/lang","ace/token_iterator","ace/range"],function(s,o,f){var n=s("../tokenizer").Tokenizer,h=s("./text_highlight_rules").TextHighlightRules,g=s("./behaviour/cstyle").CstyleBehaviour,d=s("../unicode"),l=s("../lib/lang"),c=s("../token_iterator").TokenIterator,a=s("../range").Range,F=function(){this.HighlightRules=h};(function(){this.$defaultBehaviour=new g,this.tokenRe=new RegExp("^["+d.packages.L+d.packages.Mn+d.packages.Mc+d.packages.Nd+d.packages.Pc+"\\$_]+","g"),this.nonTokenRe=new RegExp("^(?:[^"+d.packages.L+d.packages.Mn+d.packages.Mc+d.packages.Nd+d.packages.Pc+"\\$_]|\\s])+","g"),this.getTokenizer=function(){return this.$tokenizer||(this.$highlightRules=this.$highlightRules||new this.HighlightRules(this.$highlightRuleConfig),this.$tokenizer=new n(this.$highlightRules.getRules())),this.$tokenizer},this.lineCommentStart="",this.blockComment="",this.toggleCommentLines=function(p,m,b,C){var k=m.doc,T=!0,w=!0,A=1/0,M=m.getTabSize(),x=!1;if(this.lineCommentStart){if(Array.isArray(this.lineCommentStart))var j=this.lineCommentStart.map(l.escapeRegExp).join("|"),R=this.lineCommentStart[0];else var j=l.escapeRegExp(this.lineCommentStart),R=this.lineCommentStart;j=new RegExp("^(\\s*)(?:"+j+") ?"),x=m.getUseSoftTabs();var U=function(ye,Y){var ue=ye.match(j);if(ue){var Ee=ue[1].length,ne=ue[0].length;!le(ye,Ee,ne)&&ue[0][ne-1]==" "&&ne--,k.removeInLine(Y,Ee,ne)}},re=R+" ",q=function(ye,Y){(!T||/\S/.test(ye))&&(le(ye,A,A)?k.insertInLine({row:Y,column:A},re):k.insertInLine({row:Y,column:A},R))},Z=function(ye,Y){return j.test(ye)},le=function(ye,Y,ue){for(var Ee=0;Y--&&ye.charAt(Y)==" ";)Ee++;if(Ee%M!=0)return!1;for(var Ee=0;ye.charAt(ue++)==" ";)Ee++;return M>2?Ee%M!=M-1:Ee%M==0}}else{if(!this.blockComment)return!1;var R=this.blockComment.start,N=this.blockComment.end,j=new RegExp("^(\\s*)(?:"+l.escapeRegExp(R)+")"),B=new RegExp("(?:"+l.escapeRegExp(N)+")\\s*$"),q=function(he,Fe){Z(he,Fe)||(!T||/\S/.test(he))&&(k.insertInLine({row:Fe,column:he.length},N),k.insertInLine({row:Fe,column:A},R))},U=function(he,Fe){var ge;(ge=he.match(B))&&k.removeInLine(Fe,he.length-ge[0].length,he.length),(ge=he.match(j))&&k.removeInLine(Fe,ge[1].length,ge[0].length)},Z=function(he,Fe){if(j.test(he))return!0;for(var ge=m.getTokens(Fe),ye=0;ye<ge.length;ye++)if(ge[ye].type==="comment")return!0}}function ce(he){for(var Fe=b;Fe<=C;Fe++)he(k.getLine(Fe),Fe)}var de=1/0;ce(function(he,Fe){var ge=he.search(/\S/);ge!==-1?(ge<A&&(A=ge),w&&!Z(he,Fe)&&(w=!1)):de>he.length&&(de=he.length)}),A==1/0&&(A=de,T=!1,w=!1),x&&A%M!=0&&(A=Math.floor(A/M)*M),ce(w?U:q)},this.toggleBlockComment=function(p,m,b,C){var k=this.blockComment;if(k){!k.start&&k[0]&&(k=k[0]);var T=new c(m,C.row,C.column),w=T.getCurrentToken();m.selection;var A=m.selection.toOrientedRange(),M,x;if(w&&/comment/.test(w.type)){for(var R,N;w&&/comment/.test(w.type);){var j=w.value.indexOf(k.start);if(j!=-1){var B=T.getCurrentTokenRow(),q=T.getCurrentTokenColumn()+j;R=new a(B,q,B,q+k.start.length);break}w=T.stepBackward()}for(var T=new c(m,C.row,C.column),w=T.getCurrentToken();w&&/comment/.test(w.type);){var j=w.value.indexOf(k.end);if(j!=-1){var B=T.getCurrentTokenRow(),q=T.getCurrentTokenColumn()+j;N=new a(B,q,B,q+k.end.length);break}w=T.stepForward()}N&&m.remove(N),R&&(m.remove(R),M=R.start.row,x=-k.start.length)}else x=k.start.length,M=b.start.row,m.insert(b.end,k.end),m.insert(b.start,k.start);A.start.row==M&&(A.start.column+=x),A.end.row==M&&(A.end.column+=x),m.selection.fromOrientedRange(A)}},this.getNextLineIndent=function(p,m,b){return this.$getIndent(m)},this.checkOutdent=function(p,m,b){return!1},this.autoOutdent=function(p,m,b){},this.$getIndent=function(p){return p.match(/^\s*/)[0]},this.createWorker=function(p){return null},this.createModeDelegates=function(p){this.$embeds=[],this.$modes={};for(var m in p)p[m]&&(this.$embeds.push(m),this.$modes[m]=new p[m]);for(var b=["toggleBlockComment","toggleCommentLines","getNextLineIndent","checkOutdent","autoOutdent","transformAction","getCompletions"],m=0;m<b.length;m++)(function(k){var T=b[m],w=k[T];k[b[m]]=function(){return this.$delegator(T,arguments,w)}})(this)},this.$delegator=function(p,m,b){var C=m[0];typeof C!="string"&&(C=C[0]);for(var k=0;k<this.$embeds.length;k++)if(this.$modes[this.$embeds[k]]){var T=C.split(this.$embeds[k]);if(!T[0]&&T[1]){m[0]=T[1];var w=this.$modes[this.$embeds[k]];return w[p].apply(w,m)}}var A=b.apply(this,m);return b?A:void 0},this.transformAction=function(p,m,b,C,k){if(this.$behaviour){var T=this.$behaviour.getBehaviours();for(var w in T)if(T[w][m]){var A=T[w][m].apply(this,arguments);if(A)return A}}},this.getKeywords=function(p){if(!this.completionKeywords){var m=this.$tokenizer.rules,b=[];for(var C in m)for(var k=m[C],T=0,w=k.length;T<w;T++)if(typeof k[T].token=="string")/keyword|support|storage/.test(k[T].token)&&b.push(k[T].regex);else if(typeof k[T].token=="object"){for(var A=0,M=k[T].token.length;A<M;A++)if(/keyword|support|storage/.test(k[T].token[A])){var C=k[T].regex.match(/\(.+?\)/g)[A];b.push(C.substr(1,C.length-2))}}this.completionKeywords=b}return p?b.concat(this.$keywordList||[]):this.$keywordList},this.$createKeywordList=function(){return this.$highlightRules||this.getTokenizer(),this.$keywordList=this.$highlightRules.$keywordList||[]},this.getCompletions=function(p,m,b,C){var k=this.$keywordList||this.$createKeywordList();return k.map(function(T){return{name:T,value:T,score:0,meta:"keyword"}})},this.$id="ace/mode/text"}).call(F.prototype),o.Mode=F}),ace.define("ace/apply_delta",["require","exports","module"],function(s,o,f){o.applyDelta=function(n,h,g){var d=h.start.row,l=h.start.column,c=n[d]||"";switch(h.action){case"insert":var a=h.lines;if(a.length===1)n[d]=c.substring(0,l)+h.lines[0]+c.substring(l);else{var F=[d,1].concat(h.lines);n.splice.apply(n,F),n[d]=c.substring(0,l)+n[d],n[d+h.lines.length-1]+=c.substring(l)}break;case"remove":var p=h.end.column,m=h.end.row;d===m?n[d]=c.substring(0,l)+c.substring(p):n.splice(d,m-d+1,c.substring(0,l)+n[m].substring(p));break}}}),ace.define("ace/anchor",["require","exports","module","ace/lib/oop","ace/lib/event_emitter"],function(s,o,f){var n=s("./lib/oop"),h=s("./lib/event_emitter").EventEmitter,g=o.Anchor=function(d,l,c){this.$onChange=this.onChange.bind(this),this.attach(d),typeof c>"u"?this.setPosition(l.row,l.column):this.setPosition(l,c)};(function(){n.implement(this,h),this.getPosition=function(){return this.$clipPositionToDocument(this.row,this.column)},this.getDocument=function(){return this.document},this.$insertRight=!1,this.onChange=function(c){if(!(c.start.row==c.end.row&&c.start.row!=this.row)&&!(c.start.row>this.row)){var a=l(c,{row:this.row,column:this.column},this.$insertRight);this.setPosition(a.row,a.column,!0)}};function d(c,a,F){var p=F?c.column<=a.column:c.column<a.column;return c.row<a.row||c.row==a.row&&p}function l(c,a,F){var p=c.action=="insert",m=(p?1:-1)*(c.end.row-c.start.row),b=(p?1:-1)*(c.end.column-c.start.column),C=c.start,k=p?C:c.end;return d(a,C,F)?{row:a.row,column:a.column}:d(k,a,!F)?{row:a.row+m,column:a.column+(a.row==k.row?b:0)}:{row:C.row,column:C.column}}this.setPosition=function(c,a,F){var p;if(F?p={row:c,column:a}:p=this.$clipPositionToDocument(c,a),!(this.row==p.row&&this.column==p.column)){var m={row:this.row,column:this.column};this.row=p.row,this.column=p.column,this._signal("change",{old:m,value:p})}},this.detach=function(){this.document.removeEventListener("change",this.$onChange)},this.attach=function(c){this.document=c||this.document,this.document.on("change",this.$onChange)},this.$clipPositionToDocument=function(c,a){var F={};return c>=this.document.getLength()?(F.row=Math.max(0,this.document.getLength()-1),F.column=this.document.getLine(F.row).length):c<0?(F.row=0,F.column=0):(F.row=c,F.column=Math.min(this.document.getLine(F.row).length,Math.max(0,a))),a<0&&(F.column=0),F}}).call(g.prototype)}),ace.define("ace/document",["require","exports","module","ace/lib/oop","ace/apply_delta","ace/lib/event_emitter","ace/range","ace/anchor"],function(s,o,f){var n=s("./lib/oop"),h=s("./apply_delta").applyDelta,g=s("./lib/event_emitter").EventEmitter,d=s("./range").Range,l=s("./anchor").Anchor,c=function(a){this.$lines=[""],a.length===0?this.$lines=[""]:Array.isArray(a)?this.insertMergedLines({row:0,column:0},a):this.insert({row:0,column:0},a)};(function(){n.implement(this,g),this.setValue=function(a){var F=this.getLength()-1;this.remove(new d(0,0,F,this.getLine(F).length)),this.insert({row:0,column:0},a)},this.getValue=function(){return this.getAllLines().join(this.getNewLineCharacter())},this.createAnchor=function(a,F){return new l(this,a,F)},"aaa".split(/a/).length===0?this.$split=function(a){return a.replace(/\r\n|\r/g,`
`).split(`
`)}:this.$split=function(a){return a.split(/\r\n|\r|\n/)},this.$detectNewLine=function(a){var F=a.match(/^.*?(\r\n|\r|\n)/m);this.$autoNewLine=F?F[1]:`
`,this._signal("changeNewLineMode")},this.getNewLineCharacter=function(){switch(this.$newLineMode){case"windows":return`\r
`;case"unix":return`
`;default:return this.$autoNewLine||`
`}},this.$autoNewLine="",this.$newLineMode="auto",this.setNewLineMode=function(a){this.$newLineMode!==a&&(this.$newLineMode=a,this._signal("changeNewLineMode"))},this.getNewLineMode=function(){return this.$newLineMode},this.isNewLine=function(a){return a==`\r
`||a=="\r"||a==`
`},this.getLine=function(a){return this.$lines[a]||""},this.getLines=function(a,F){return this.$lines.slice(a,F+1)},this.getAllLines=function(){return this.getLines(0,this.getLength())},this.getLength=function(){return this.$lines.length},this.getTextRange=function(a){return this.getLinesForRange(a).join(this.getNewLineCharacter())},this.getLinesForRange=function(a){var F;if(a.start.row===a.end.row)F=[this.getLine(a.start.row).substring(a.start.column,a.end.column)];else{F=this.getLines(a.start.row,a.end.row),F[0]=(F[0]||"").substring(a.start.column);var p=F.length-1;a.end.row-a.start.row==p&&(F[p]=F[p].substring(0,a.end.column))}return F},this.insertLines=function(a,F){return console.warn("Use of document.insertLines is deprecated. Use the insertFullLines method instead."),this.insertFullLines(a,F)},this.removeLines=function(a,F){return console.warn("Use of document.removeLines is deprecated. Use the removeFullLines method instead."),this.removeFullLines(a,F)},this.insertNewLine=function(a){return console.warn("Use of document.insertNewLine is deprecated. Use insertMergedLines(position, ['', '']) instead."),this.insertMergedLines(a,["",""])},this.insert=function(a,F){return this.getLength()<=1&&this.$detectNewLine(F),this.insertMergedLines(a,this.$split(F))},this.insertInLine=function(a,F){var p=this.clippedPos(a.row,a.column),m=this.pos(a.row,a.column+F.length);return this.applyDelta({start:p,end:m,action:"insert",lines:[F]},!0),this.clonePos(m)},this.clippedPos=function(a,F){var p=this.getLength();a===void 0?a=p:a<0?a=0:a>=p&&(a=p-1,F=void 0);var m=this.getLine(a);return F==null&&(F=m.length),F=Math.min(Math.max(F,0),m.length),{row:a,column:F}},this.clonePos=function(a){return{row:a.row,column:a.column}},this.pos=function(a,F){return{row:a,column:F}},this.$clipPosition=function(a){var F=this.getLength();return a.row>=F?(a.row=Math.max(0,F-1),a.column=this.getLine(F-1).length):(a.row=Math.max(0,a.row),a.column=Math.min(Math.max(a.column,0),this.getLine(a.row).length)),a},this.insertFullLines=function(a,F){a=Math.min(Math.max(a,0),this.getLength());var p=0;a<this.getLength()?(F=F.concat([""]),p=0):(F=[""].concat(F),a--,p=this.$lines[a].length),this.insertMergedLines({row:a,column:p},F)},this.insertMergedLines=function(a,F){var p=this.clippedPos(a.row,a.column),m={row:p.row+F.length-1,column:(F.length==1?p.column:0)+F[F.length-1].length};return this.applyDelta({start:p,end:m,action:"insert",lines:F}),this.clonePos(m)},this.remove=function(a){var F=this.clippedPos(a.start.row,a.start.column),p=this.clippedPos(a.end.row,a.end.column);return this.applyDelta({start:F,end:p,action:"remove",lines:this.getLinesForRange({start:F,end:p})}),this.clonePos(F)},this.removeInLine=function(a,F,p){var m=this.clippedPos(a,F),b=this.clippedPos(a,p);return this.applyDelta({start:m,end:b,action:"remove",lines:this.getLinesForRange({start:m,end:b})},!0),this.clonePos(m)},this.removeFullLines=function(a,F){a=Math.min(Math.max(0,a),this.getLength()-1),F=Math.min(Math.max(0,F),this.getLength()-1);var p=F==this.getLength()-1&&a>0,m=F<this.getLength()-1,b=p?a-1:a,C=p?this.getLine(b).length:0,k=m?F+1:F,T=m?0:this.getLine(k).length,w=new d(b,C,k,T),A=this.$lines.slice(a,F+1);return this.applyDelta({start:w.start,end:w.end,action:"remove",lines:this.getLinesForRange(w)}),A},this.removeNewLine=function(a){a<this.getLength()-1&&a>=0&&this.applyDelta({start:this.pos(a,this.getLine(a).length),end:this.pos(a+1,0),action:"remove",lines:["",""]})},this.replace=function(a,F){if(a instanceof d||(a=d.fromPoints(a.start,a.end)),F.length===0&&a.isEmpty())return a.start;if(F==this.getTextRange(a))return a.end;this.remove(a);var p;return F?p=this.insert(a.start,F):p=a.start,p},this.applyDeltas=function(a){for(var F=0;F<a.length;F++)this.applyDelta(a[F])},this.revertDeltas=function(a){for(var F=a.length-1;F>=0;F--)this.revertDelta(a[F])},this.applyDelta=function(a,F){var p=a.action=="insert";(p?a.lines.length<=1&&!a.lines[0]:!d.comparePoints(a.start,a.end))||(p&&a.lines.length>2e4&&this.$splitAndapplyLargeDelta(a,2e4),h(this.$lines,a,F),this._signal("change",a))},this.$splitAndapplyLargeDelta=function(a,F){var p=a.lines,m=p.length,b=a.start.row,C=a.start.column,k=0,T=0;do{k=T,T+=F-1;var w=p.slice(k,T);if(T>m){a.lines=w,a.start.row=b+k,a.start.column=C;break}w.push(""),this.applyDelta({start:this.pos(b+k,C),end:this.pos(b+T,C=0),action:a.action,lines:w},!0)}while(!0)},this.revertDelta=function(a){this.applyDelta({start:this.clonePos(a.start),end:this.clonePos(a.end),action:a.action=="insert"?"remove":"insert",lines:a.lines.slice()})},this.indexToPosition=function(a,F){for(var p=this.$lines||this.getAllLines(),m=this.getNewLineCharacter().length,b=F||0,C=p.length;b<C;b++)if(a-=p[b].length+m,a<0)return{row:b,column:a+p[b].length+m};return{row:C-1,column:p[C-1].length}},this.positionToIndex=function(a,F){for(var p=this.$lines||this.getAllLines(),m=this.getNewLineCharacter().length,b=0,C=Math.min(a.row,p.length),k=F||0;k<C;++k)b+=p[k].length+m;return b+a.column}}).call(c.prototype),o.Document=c}),ace.define("ace/background_tokenizer",["require","exports","module","ace/lib/oop","ace/lib/event_emitter"],function(s,o,f){var n=s("./lib/oop"),h=s("./lib/event_emitter").EventEmitter,g=function(d,l){this.running=!1,this.lines=[],this.states=[],this.currentLine=0,this.tokenizer=d;var c=this;this.$worker=function(){if(c.running){for(var a=new Date,F=c.currentLine,p=-1,m=c.doc,b=F;c.lines[F];)F++;var C=m.getLength(),k=0;for(c.running=!1;F<C;){c.$tokenizeRow(F),p=F;do F++;while(c.lines[F]);if(k++,k%5===0&&new Date-a>20){c.running=setTimeout(c.$worker,20);break}}c.currentLine=F,b<=p&&c.fireUpdateEvent(b,p)}}};(function(){n.implement(this,h),this.setTokenizer=function(d){this.tokenizer=d,this.lines=[],this.states=[],this.start(0)},this.setDocument=function(d){this.doc=d,this.lines=[],this.states=[],this.stop()},this.fireUpdateEvent=function(d,l){var c={first:d,last:l};this._signal("update",{data:c})},this.start=function(d){this.currentLine=Math.min(d||0,this.currentLine,this.doc.getLength()),this.lines.splice(this.currentLine,this.lines.length),this.states.splice(this.currentLine,this.states.length),this.stop(),this.running=setTimeout(this.$worker,700)},this.scheduleStart=function(){this.running||(this.running=setTimeout(this.$worker,700))},this.$updateOnChange=function(d){var l=d.start.row,c=d.end.row-l;if(c===0)this.lines[l]=null;else if(d.action=="remove")this.lines.splice(l,c+1,null),this.states.splice(l,c+1,null);else{var a=Array(c+1);a.unshift(l,1),this.lines.splice.apply(this.lines,a),this.states.splice.apply(this.states,a)}this.currentLine=Math.min(l,this.currentLine,this.doc.getLength()),this.stop()},this.stop=function(){this.running&&clearTimeout(this.running),this.running=!1},this.getTokens=function(d){return this.lines[d]||this.$tokenizeRow(d)},this.getState=function(d){return this.currentLine==d&&this.$tokenizeRow(d),this.states[d]||"start"},this.$tokenizeRow=function(d){var l=this.doc.getLine(d),c=this.states[d-1],a=this.tokenizer.getLineTokens(l,c,d);return this.states[d]+""!=a.state+""?(this.states[d]=a.state,this.lines[d+1]=null,this.currentLine>d+1&&(this.currentLine=d+1)):this.currentLine==d&&(this.currentLine=d+1),this.lines[d]=a.tokens}}).call(g.prototype),o.BackgroundTokenizer=g}),ace.define("ace/search_highlight",["require","exports","module","ace/lib/lang","ace/lib/oop","ace/range"],function(s,o,f){var n=s("./lib/lang");s("./lib/oop");var h=s("./range").Range,g=function(d,l,c){this.setRegexp(d),this.clazz=l,this.type=c||"text"};(function(){this.MAX_RANGES=500,this.setRegexp=function(d){this.regExp+""!=d+""&&(this.regExp=d,this.cache=[])},this.update=function(d,l,c,a){if(this.regExp)for(var F=a.firstRow,p=a.lastRow,m=F;m<=p;m++){var b=this.cache[m];b==null&&(b=n.getMatchOffsets(c.getLine(m),this.regExp),b.length>this.MAX_RANGES&&(b=b.slice(0,this.MAX_RANGES)),b=b.map(function(k){return new h(m,k.offset,m,k.offset+k.length)}),this.cache[m]=b.length?b:"");for(var C=b.length;C--;)l.drawSingleLineMarker(d,b[C].toScreenRange(c),this.clazz,a)}}}).call(g.prototype),o.SearchHighlight=g}),ace.define("ace/edit_session/fold_line",["require","exports","module","ace/range"],function(s,o,f){var n=s("../range").Range;function h(g,d){this.foldData=g,Array.isArray(d)?this.folds=d:d=this.folds=[d];var l=d[d.length-1];this.range=new n(d[0].start.row,d[0].start.column,l.end.row,l.end.column),this.start=this.range.start,this.end=this.range.end,this.folds.forEach(function(c){c.setFoldLine(this)},this)}(function(){this.shiftRow=function(g){this.start.row+=g,this.end.row+=g,this.folds.forEach(function(d){d.start.row+=g,d.end.row+=g})},this.addFold=function(g){if(g.sameRow){if(g.start.row<this.startRow||g.endRow>this.endRow)throw new Error("Can't add a fold to this FoldLine as it has no connection");this.folds.push(g),this.folds.sort(function(d,l){return-d.range.compareEnd(l.start.row,l.start.column)}),this.range.compareEnd(g.start.row,g.start.column)>0?(this.end.row=g.end.row,this.end.column=g.end.column):this.range.compareStart(g.end.row,g.end.column)<0&&(this.start.row=g.start.row,this.start.column=g.start.column)}else if(g.start.row==this.end.row)this.folds.push(g),this.end.row=g.end.row,this.end.column=g.end.column;else if(g.end.row==this.start.row)this.folds.unshift(g),this.start.row=g.start.row,this.start.column=g.start.column;else throw new Error("Trying to add fold to FoldRow that doesn't have a matching row");g.foldLine=this},this.containsRow=function(g){return g>=this.start.row&&g<=this.end.row},this.walk=function(g,d,l){var c=0,a=this.folds,F,p,m,b=!0;d==null&&(d=this.end.row,l=this.end.column);for(var C=0;C<a.length;C++){if(F=a[C],p=F.range.compareStart(d,l),p==-1){g(null,d,l,c,b);return}if(m=g(null,F.start.row,F.start.column,c,b),m=!m&&g(F.placeholder,F.start.row,F.start.column,c),m||p===0)return;b=!F.sameRow,c=F.end.column}g(null,d,l,c,b)},this.getNextFoldTo=function(g,d){for(var l,c,a=0;a<this.folds.length;a++){if(l=this.folds[a],c=l.range.compareEnd(g,d),c==-1)return{fold:l,kind:"after"};if(c===0)return{fold:l,kind:"inside"}}return null},this.addRemoveChars=function(g,d,l){var c=this.getNextFoldTo(g,d),a,F;if(c){if(a=c.fold,c.kind=="inside"&&a.start.column!=d&&a.start.row!=g)window.console&&window.console.log(g,d,a);else if(a.start.row==g){F=this.folds;var p=F.indexOf(a);for(p===0&&(this.start.column+=l),p;p<F.length;p++){if(a=F[p],a.start.column+=l,!a.sameRow)return;a.end.column+=l}this.end.column+=l}}},this.split=function(g,d){var l=this.getNextFoldTo(g,d);if(!l||l.kind=="inside")return null;var c=l.fold,a=this.folds,F=this.foldData,p=a.indexOf(c),m=a[p-1];this.end.row=m.end.row,this.end.column=m.end.column,a=a.splice(p,a.length-p);var b=new h(F,a);return F.splice(F.indexOf(this)+1,0,b),b},this.merge=function(g){for(var d=g.folds,l=0;l<d.length;l++)this.addFold(d[l]);var c=this.foldData;c.splice(c.indexOf(g),1)},this.toString=function(){var g=[this.range.toString()+": ["];return this.folds.forEach(function(d){g.push("  "+d.toString())}),g.push("]"),g.join(`
`)},this.idxToPosition=function(g){for(var d=0,l=0;l<this.folds.length;l++){var c=this.folds[l];if(g-=c.start.column-d,g<0)return{row:c.start.row,column:c.start.column+g};if(g-=c.placeholder.length,g<0)return c.start;d=c.end.column}return{row:this.end.row,column:this.end.column+g}}}).call(h.prototype),o.FoldLine=h}),ace.define("ace/range_list",["require","exports","module","ace/range"],function(s,o,f){var n=s("./range").Range,h=n.comparePoints,g=function(){this.ranges=[]};(function(){this.comparePoints=h,this.pointIndex=function(d,l,c){for(var a=this.ranges,F=c||0;F<a.length;F++){var p=a[F],m=h(d,p.end);if(!(m>0)){var b=h(d,p.start);return m===0?l&&b!==0?-F-2:F:b>0||b===0&&!l?F:-F-1}}return-F-1},this.add=function(d){var l=!d.isEmpty(),c=this.pointIndex(d.start,l);c<0&&(c=-c-1);var a=this.pointIndex(d.end,l,c);return a<0?a=-a-1:a++,this.ranges.splice(c,a-c,d)},this.addList=function(d){for(var l=[],c=d.length;c--;)l.push.apply(l,this.add(d[c]));return l},this.substractPoint=function(d){var l=this.pointIndex(d);if(l>=0)return this.ranges.splice(l,1)},this.merge=function(){var d=[],l=this.ranges;l=l.sort(function(m,b){return h(m.start,b.start)});for(var c=l[0],a,F=1;F<l.length;F++){a=c,c=l[F];var p=h(a.end,c.start);p<0||p==0&&!a.isEmpty()&&!c.isEmpty()||(h(a.end,c.end)<0&&(a.end.row=c.end.row,a.end.column=c.end.column),l.splice(F,1),d.push(c),c=a,F--)}return this.ranges=l,d},this.contains=function(d,l){return this.pointIndex({row:d,column:l})>=0},this.containsPoint=function(d){return this.pointIndex(d)>=0},this.rangeAtPoint=function(d){var l=this.pointIndex(d);if(l>=0)return this.ranges[l]},this.clipRows=function(d,l){var c=this.ranges;if(c[0].start.row>l||c[c.length-1].start.row<d)return[];var a=this.pointIndex({row:d,column:0});a<0&&(a=-a-1);var F=this.pointIndex({row:l,column:0},a);F<0&&(F=-F-1);for(var p=[],m=a;m<F;m++)p.push(c[m]);return p},this.removeAll=function(){return this.ranges.splice(0,this.ranges.length)},this.attach=function(d){this.session&&this.detach(),this.session=d,this.onChange=this.$onChange.bind(this),this.session.on("change",this.onChange)},this.detach=function(){this.session&&(this.session.removeListener("change",this.onChange),this.session=null)},this.$onChange=function(d){if(d.action=="insert")var l=d.start,c=d.end;else var c=d.start,l=d.end;for(var a=l.row,F=c.row,p=F-a,m=-l.column+c.column,b=this.ranges,C=0,k=b.length;C<k;C++){var T=b[C];if(!(T.end.row<a)){if(T.start.row>a)break;if(T.start.row==a&&T.start.column>=l.column&&(T.start.column==l.column&&this.$insertRight||(T.start.column+=m,T.start.row+=p)),T.end.row==a&&T.end.column>=l.column){if(T.end.column==l.column&&this.$insertRight)continue;T.end.column==l.column&&m>0&&C<k-1&&T.end.column>T.start.column&&T.end.column==b[C+1].start.column&&(T.end.column-=m),T.end.column+=m,T.end.row+=p}}}if(p!=0&&C<k)for(;C<k;C++){var T=b[C];T.start.row+=p,T.end.row+=p}}}).call(g.prototype),o.RangeList=g}),ace.define("ace/edit_session/fold",["require","exports","module","ace/range","ace/range_list","ace/lib/oop"],function(s,o,f){s("../range").Range;var n=s("../range_list").RangeList,h=s("../lib/oop"),g=o.Fold=function(F,p){this.foldLine=null,this.placeholder=p,this.range=F,this.start=F.start,this.end=F.end,this.sameRow=F.start.row==F.end.row,this.subFolds=this.ranges=[]};h.inherits(g,n),function(){this.toString=function(){return'"'+this.placeholder+'" '+this.range.toString()},this.setFoldLine=function(F){this.foldLine=F,this.subFolds.forEach(function(p){p.setFoldLine(F)})},this.clone=function(){var F=this.range.clone(),p=new g(F,this.placeholder);return this.subFolds.forEach(function(m){p.subFolds.push(m.clone())}),p.collapseChildren=this.collapseChildren,p},this.addSubFold=function(F){if(!this.range.isEqual(F)){if(!this.range.containsRange(F))throw new Error("A fold can't intersect already existing fold"+F.range+this.range);l(F,this.start);for(var C=F.start.row,k=F.start.column,p=0,m=-1;p<this.subFolds.length&&(m=this.subFolds[p].range.compare(C,k),m==1);p++);var b=this.subFolds[p];if(m==0)return b.addSubFold(F);for(var C=F.range.end.row,k=F.range.end.column,T=p,m=-1;T<this.subFolds.length&&(m=this.subFolds[T].range.compare(C,k),m==1);T++);if(this.subFolds[T],m==0)throw new Error("A fold can't intersect already existing fold"+F.range+this.range);return this.subFolds.splice(p,T-p,F),F.setFoldLine(this.foldLine),F}},this.restoreRange=function(F){return a(F,this.start)}}.call(g.prototype);function d(F,p){F.row-=p.row,F.row==0&&(F.column-=p.column)}function l(F,p){d(F.start,p),d(F.end,p)}function c(F,p){F.row==0&&(F.column+=p.column),F.row+=p.row}function a(F,p){c(F.start,p),c(F.end,p)}}),ace.define("ace/edit_session/folding",["require","exports","module","ace/range","ace/edit_session/fold_line","ace/edit_session/fold","ace/token_iterator"],function(s,o,f){var n=s("../range").Range,h=s("./fold_line").FoldLine,g=s("./fold").Fold,d=s("../token_iterator").TokenIterator;function l(){this.getFoldAt=function(c,a,F){var p=this.getFoldLine(c);if(!p)return null;for(var m=p.folds,b=0;b<m.length;b++){var C=m[b];if(C.range.contains(c,a)){if(F==1&&C.range.isEnd(c,a))continue;if(F==-1&&C.range.isStart(c,a))continue;return C}}},this.getFoldsInRange=function(c){var a=c.start,F=c.end,p=this.$foldData,m=[];a.column+=1,F.column-=1;for(var b=0;b<p.length;b++){var C=p[b].range.compareRange(c);if(C!=2){if(C==-2)break;for(var k=p[b].folds,T=0;T<k.length;T++){var w=k[T];if(C=w.range.compareRange(c),C==-2)break;if(C==2)continue;if(C==42)break;m.push(w)}}}return a.column-=1,F.column+=1,m},this.getFoldsInRangeList=function(c){if(Array.isArray(c)){var a=[];c.forEach(function(F){a=a.concat(this.getFoldsInRange(F))},this)}else var a=this.getFoldsInRange(c);return a},this.getAllFolds=function(){for(var c=[],a=this.$foldData,F=0;F<a.length;F++)for(var p=0;p<a[F].folds.length;p++)c.push(a[F].folds[p]);return c},this.getFoldStringAt=function(c,a,F,p){if(p=p||this.getFoldLine(c),!p)return null;for(var m={end:{column:0}},b,C,k=0;k<p.folds.length;k++){C=p.folds[k];var T=C.range.compareEnd(c,a);if(T==-1){b=this.getLine(C.start.row).substring(m.end.column,C.start.column);break}else if(T===0)return null;m=C}return b||(b=this.getLine(C.start.row).substring(m.end.column)),F==-1?b.substring(0,a-m.end.column):F==1?b.substring(a-m.end.column):b},this.getFoldLine=function(c,a){var F=this.$foldData,p=0;for(a&&(p=F.indexOf(a)),p==-1&&(p=0),p;p<F.length;p++){var m=F[p];if(m.start.row<=c&&m.end.row>=c)return m;if(m.end.row>c)return null}return null},this.getNextFoldLine=function(c,a){var F=this.$foldData,p=0;for(a&&(p=F.indexOf(a)),p==-1&&(p=0),p;p<F.length;p++){var m=F[p];if(m.end.row>=c)return m}return null},this.getFoldedRowCount=function(c,a){for(var F=this.$foldData,p=a-c+1,m=0;m<F.length;m++){var b=F[m],C=b.end.row,k=b.start.row;if(C>=a){k<a&&(k>=c?p-=a-k:p=0);break}else C>=c&&(k>=c?p-=C-k:p-=C-c+1)}return p},this.$addFoldLine=function(c){return this.$foldData.push(c),this.$foldData.sort(function(a,F){return a.start.row-F.start.row}),c},this.addFold=function(c,a){var F=this.$foldData,p=!1,m;c instanceof g?m=c:(m=new g(a,c),m.collapseChildren=a.collapseChildren),this.$clipRangeToDocument(m.range);var b=m.start.row,C=m.start.column,k=m.end.row,T=m.end.column;if(!(b<k||b==k&&C<=T-2))throw new Error("The range has to be at least 2 characters width");var w=this.getFoldAt(b,C,1),A=this.getFoldAt(k,T,-1);if(w&&A==w)return w.addSubFold(m);w&&!w.range.isStart(b,C)&&this.removeFold(w),A&&!A.range.isEnd(k,T)&&this.removeFold(A);var M=this.getFoldsInRange(m.range);M.length>0&&(this.removeFolds(M),M.forEach(function(j){m.addSubFold(j)}));for(var x=0;x<F.length;x++){var R=F[x];if(k==R.start.row){R.addFold(m),p=!0;break}else if(b==R.end.row){if(R.addFold(m),p=!0,!m.sameRow){var N=F[x+1];if(N&&N.start.row==k){R.merge(N);break}}break}else if(k<=R.start.row)break}return p||(R=this.$addFoldLine(new h(this.$foldData,m))),this.$useWrapMode?this.$updateWrapData(R.start.row,R.start.row):this.$updateRowLengthCache(R.start.row,R.start.row),this.$modified=!0,this._signal("changeFold",{data:m,action:"add"}),m},this.addFolds=function(c){c.forEach(function(a){this.addFold(a)},this)},this.removeFold=function(c){var a=c.foldLine,F=a.start.row,p=a.end.row,m=this.$foldData,b=a.folds;if(b.length==1)m.splice(m.indexOf(a),1);else if(a.range.isEnd(c.end.row,c.end.column))b.pop(),a.end.row=b[b.length-1].end.row,a.end.column=b[b.length-1].end.column;else if(a.range.isStart(c.start.row,c.start.column))b.shift(),a.start.row=b[0].start.row,a.start.column=b[0].start.column;else if(c.sameRow)b.splice(b.indexOf(c),1);else{var C=a.split(c.start.row,c.start.column);b=C.folds,b.shift(),C.start.row=b[0].start.row,C.start.column=b[0].start.column}this.$updating||(this.$useWrapMode?this.$updateWrapData(F,p):this.$updateRowLengthCache(F,p)),this.$modified=!0,this._signal("changeFold",{data:c,action:"remove"})},this.removeFolds=function(c){for(var a=[],F=0;F<c.length;F++)a.push(c[F]);a.forEach(function(p){this.removeFold(p)},this),this.$modified=!0},this.expandFold=function(c){this.removeFold(c),c.subFolds.forEach(function(a){c.restoreRange(a),this.addFold(a)},this),c.collapseChildren>0&&this.foldAll(c.start.row+1,c.end.row,c.collapseChildren-1),c.subFolds=[]},this.expandFolds=function(c){c.forEach(function(a){this.expandFold(a)},this)},this.unfold=function(c,a){var F,p;if(c==null?(F=new n(0,0,this.getLength(),0),a=!0):typeof c=="number"?F=new n(c,0,c,this.getLine(c).length):"row"in c?F=n.fromPoints(c,c):F=c,p=this.getFoldsInRangeList(F),a)this.removeFolds(p);else for(var m=p;m.length;)this.expandFolds(m),m=this.getFoldsInRangeList(F);if(p.length)return p},this.isRowFolded=function(c,a){return!!this.getFoldLine(c,a)},this.getRowFoldEnd=function(c,a){var F=this.getFoldLine(c,a);return F?F.end.row:c},this.getRowFoldStart=function(c,a){var F=this.getFoldLine(c,a);return F?F.start.row:c},this.getFoldDisplayLine=function(c,a,F,p,m){p==null&&(p=c.start.row),m==null&&(m=0),a==null&&(a=c.end.row),F==null&&(F=this.getLine(a).length);var b=this.doc,C="";return c.walk(function(k,T,w,A){if(!(T<p)){if(T==p){if(w<m)return;A=Math.max(m,A)}k!=null?C+=k:C+=b.getLine(T).substring(A,w)}},a,F),C},this.getDisplayLine=function(c,a,F,p){var m=this.getFoldLine(c);if(m)return this.getFoldDisplayLine(m,c,a,F,p);var b;return b=this.doc.getLine(c),b.substring(p||0,a||b.length)},this.$cloneFoldData=function(){var c=[];return c=this.$foldData.map(function(a){var F=a.folds.map(function(p){return p.clone()});return new h(c,F)}),c},this.toggleFold=function(c){var a=this.selection,F=a.getRange(),p,m;if(F.isEmpty()){var b=F.start;if(p=this.getFoldAt(b.row,b.column),p){this.expandFold(p);return}else(m=this.findMatchingBracket(b))?F.comparePoint(m)==1?F.end=m:(F.start=m,F.start.column++,F.end.column--):(m=this.findMatchingBracket({row:b.row,column:b.column+1}))?(F.comparePoint(m)==1?F.end=m:F.start=m,F.start.column++):F=this.getCommentFoldRange(b.row,b.column)||F}else{var C=this.getFoldsInRange(F);if(c&&C.length){this.expandFolds(C);return}else C.length==1&&(p=C[0])}if(p||(p=this.getFoldAt(F.start.row,F.start.column)),p&&p.range.toString()==F.toString()){this.expandFold(p);return}var k="...";if(!F.isMultiLine()){if(k=this.getTextRange(F),k.length<4)return;k=k.trim().substring(0,2)+".."}this.addFold(k,F)},this.getCommentFoldRange=function(c,a,F){var p=new d(this,c,a),m=p.getCurrentToken();if(m&&/^comment|string/.test(m.type)){var b=new n,C=new RegExp(m.type.replace(/\..*/,"\\."));if(F!=1){do m=p.stepBackward();while(m&&C.test(m.type));p.stepForward()}if(b.start.row=p.getCurrentTokenRow(),b.start.column=p.getCurrentTokenColumn()+2,p=new d(this,c,a),F!=-1){do m=p.stepForward();while(m&&C.test(m.type));m=p.stepBackward()}else m=p.getCurrentToken();return b.end.row=p.getCurrentTokenRow(),b.end.column=p.getCurrentTokenColumn()+m.value.length-2,b}},this.foldAll=function(c,a,F){F==null&&(F=1e5);var p=this.foldWidgets;if(p){a=a||this.getLength(),c=c||0;for(var m=c;m<a;m++)if(p[m]==null&&(p[m]=this.getFoldWidget(m)),p[m]=="start"){var b=this.getFoldWidgetRange(m);if(b&&b.isMultiLine()&&b.end.row<=a&&b.start.row>=c){m=b.end.row;try{var C=this.addFold("...",b);C&&(C.collapseChildren=F)}catch{}}}}},this.$foldStyles={manual:1,markbegin:1,markbeginend:1},this.$foldStyle="markbegin",this.setFoldStyle=function(c){if(!this.$foldStyles[c])throw new Error("invalid fold style: "+c+"["+Object.keys(this.$foldStyles).join(", ")+"]");if(this.$foldStyle!=c){this.$foldStyle=c,c=="manual"&&this.unfold();var a=this.$foldMode;this.$setFolding(null),this.$setFolding(a)}},this.$setFolding=function(c){if(this.$foldMode!=c){if(this.$foldMode=c,this.off("change",this.$updateFoldWidgets),this.off("tokenizerUpdate",this.$tokenizerUpdateFoldWidgets),this._signal("changeAnnotation"),!c||this.$foldStyle=="manual"){this.foldWidgets=null;return}this.foldWidgets=[],this.getFoldWidget=c.getFoldWidget.bind(c,this,this.$foldStyle),this.getFoldWidgetRange=c.getFoldWidgetRange.bind(c,this,this.$foldStyle),this.$updateFoldWidgets=this.updateFoldWidgets.bind(this),this.$tokenizerUpdateFoldWidgets=this.tokenizerUpdateFoldWidgets.bind(this),this.on("change",this.$updateFoldWidgets),this.on("tokenizerUpdate",this.$tokenizerUpdateFoldWidgets)}},this.getParentFoldRangeData=function(c,a){var F=this.foldWidgets;if(!F||a&&F[c])return{};for(var p=c-1,m;p>=0;){var b=F[p];if(b==null&&(b=F[p]=this.getFoldWidget(p)),b=="start"){var C=this.getFoldWidgetRange(p);if(m||(m=C),C&&C.end.row>=c)break}p--}return{range:p!==-1&&C,firstRange:m}},this.onFoldWidgetClick=function(c,a){a=a.domEvent;var F={children:a.shiftKey,all:a.ctrlKey||a.metaKey,siblings:a.altKey},p=this.$toggleFoldWidget(c,F);if(!p){var m=a.target||a.srcElement;m&&/ace_fold-widget/.test(m.className)&&(m.className+=" ace_invalid")}},this.$toggleFoldWidget=function(c,a){if(this.getFoldWidget){var F=this.getFoldWidget(c),p=this.getLine(c),m=F==="end"?-1:1,b=this.getFoldAt(c,m===-1?0:p.length,m);if(b)return a.children||a.all?this.removeFold(b):this.expandFold(b),b;var C=this.getFoldWidgetRange(c,!0);if(C&&!C.isMultiLine()&&(b=this.getFoldAt(C.start.row,C.start.column,1),b&&C.isEqual(b.range)))return this.removeFold(b),b;if(a.siblings){var k=this.getParentFoldRangeData(c);if(k.range)var T=k.range.start.row+1,w=k.range.end.row;this.foldAll(T,w,a.all?1e4:0)}else a.children?(w=C?C.end.row:this.getLength(),this.foldAll(c+1,w,a.all?1e4:0)):C&&(a.all&&(C.collapseChildren=1e4),this.addFold("...",C));return C}},this.toggleFoldWidget=function(c){var a=this.selection.getCursor().row;a=this.getRowFoldStart(a);var F=this.$toggleFoldWidget(a,{});if(!F){var p=this.getParentFoldRangeData(a,!0);if(F=p.range||p.firstRange,F){a=F.start.row;var m=this.getFoldAt(a,this.getLine(a).length,1);m?this.removeFold(m):this.addFold("...",F)}}},this.updateFoldWidgets=function(c){var a=c.start.row,F=c.end.row-a;if(F===0)this.foldWidgets[a]=null;else if(c.action=="remove")this.foldWidgets.splice(a,F+1,null);else{var p=Array(F+1);p.unshift(a,1),this.foldWidgets.splice.apply(this.foldWidgets,p)}},this.tokenizerUpdateFoldWidgets=function(c){var a=c.data;a.first!=a.last&&this.foldWidgets.length>a.first&&this.foldWidgets.splice(a.first,this.foldWidgets.length)}}o.Folding=l}),ace.define("ace/edit_session/bracket_match",["require","exports","module","ace/token_iterator","ace/range"],function(s,o,f){var n=s("../token_iterator").TokenIterator,h=s("../range").Range;function g(){this.findMatchingBracket=function(d,l){if(d.column==0)return null;var c=l||this.getLine(d.row).charAt(d.column-1);if(c=="")return null;var a=c.match(/([\(\[\{])|([\)\]\}])/);return a?a[1]?this.$findClosingBracket(a[1],d):this.$findOpeningBracket(a[2],d):null},this.getBracketRange=function(d){var l=this.getLine(d.row),c=!0,a,F=l.charAt(d.column-1),p=F&&F.match(/([\(\[\{])|([\)\]\}])/);if(p||(F=l.charAt(d.column),d={row:d.row,column:d.column+1},p=F&&F.match(/([\(\[\{])|([\)\]\}])/),c=!1),!p)return null;if(p[1]){var m=this.$findClosingBracket(p[1],d);if(!m)return null;a=h.fromPoints(d,m),c||(a.end.column++,a.start.column--),a.cursor=a.end}else{var m=this.$findOpeningBracket(p[2],d);if(!m)return null;a=h.fromPoints(m,d),c||(a.start.column++,a.end.column--),a.cursor=a.start}return a},this.$brackets={")":"(","(":")","]":"[","[":"]","{":"}","}":"{"},this.$findOpeningBracket=function(d,l,c){var a=this.$brackets[d],F=1,p=new n(this,l.row,l.column),m=p.getCurrentToken();if(m||(m=p.stepForward()),!!m){c||(c=new RegExp("(\\.?"+m.type.replace(".","\\.").replace("rparen",".paren").replace(/\b(?:end)\b/,"(?:start|begin|end)")+")+"));for(var b=l.column-p.getCurrentTokenColumn()-2,C=m.value;;){for(;b>=0;){var k=C.charAt(b);if(k==a){if(F-=1,F==0)return{row:p.getCurrentTokenRow(),column:b+p.getCurrentTokenColumn()}}else k==d&&(F+=1);b-=1}do m=p.stepBackward();while(m&&!c.test(m.type));if(m==null)break;C=m.value,b=C.length-1}return null}},this.$findClosingBracket=function(d,l,c){var a=this.$brackets[d],F=1,p=new n(this,l.row,l.column),m=p.getCurrentToken();if(m||(m=p.stepForward()),!!m){c||(c=new RegExp("(\\.?"+m.type.replace(".","\\.").replace("lparen",".paren").replace(/\b(?:start|begin)\b/,"(?:start|begin|end)")+")+"));for(var b=l.column-p.getCurrentTokenColumn();;){for(var C=m.value,k=C.length;b<k;){var T=C.charAt(b);if(T==a){if(F-=1,F==0)return{row:p.getCurrentTokenRow(),column:b+p.getCurrentTokenColumn()}}else T==d&&(F+=1);b+=1}do m=p.stepForward();while(m&&!c.test(m.type));if(m==null)break;b=0}return null}}}o.BracketMatch=g}),ace.define("ace/edit_session",["require","exports","module","ace/lib/oop","ace/lib/lang","ace/config","ace/lib/event_emitter","ace/selection","ace/mode/text","ace/range","ace/document","ace/background_tokenizer","ace/search_highlight","ace/edit_session/folding","ace/edit_session/bracket_match"],function(s,o,f){var n=s("./lib/oop"),h=s("./lib/lang"),g=s("./config"),d=s("./lib/event_emitter").EventEmitter,l=s("./selection").Selection,c=s("./mode/text").Mode,a=s("./range").Range,F=s("./document").Document,p=s("./background_tokenizer").BackgroundTokenizer,m=s("./search_highlight").SearchHighlight,b=function(C,k){this.$breakpoints=[],this.$decorations=[],this.$frontMarkers={},this.$backMarkers={},this.$markerId=1,this.$undoSelect=!0,this.$foldData=[],this.id="session"+ ++b.$uid,this.$foldData.toString=function(){return this.join(`
`)},this.on("changeFold",this.onChangeFold.bind(this)),this.$onChange=this.onChange.bind(this),(typeof C!="object"||!C.getLine)&&(C=new F(C)),this.setDocument(C),this.selection=new l(this),g.resetOptions(this),this.setMode(k),g._signal("session",this)};(function(){n.implement(this,d),this.setDocument=function(j){this.doc&&this.doc.removeListener("change",this.$onChange),this.doc=j,j.on("change",this.$onChange),this.bgTokenizer&&this.bgTokenizer.setDocument(this.getDocument()),this.resetCaches()},this.getDocument=function(){return this.doc},this.$resetRowCache=function(j){if(!j){this.$docRowCache=[],this.$screenRowCache=[];return}var B=this.$docRowCache.length,q=this.$getRowCacheIndex(this.$docRowCache,j)+1;B>q&&(this.$docRowCache.splice(q,B),this.$screenRowCache.splice(q,B))},this.$getRowCacheIndex=function(j,B){for(var q=0,U=j.length-1;q<=U;){var Z=q+U>>1,re=j[Z];if(B>re)q=Z+1;else if(B<re)U=Z-1;else return Z}return q-1},this.resetCaches=function(){this.$modified=!0,this.$wrapData=[],this.$rowLengthCache=[],this.$resetRowCache(0),this.bgTokenizer&&this.bgTokenizer.start(0)},this.onChangeFold=function(j){var B=j.data;this.$resetRowCache(B.start.row)},this.onChange=function(j){this.$modified=!0,this.$resetRowCache(j.start.row);var B=this.$updateInternalDataOnChange(j);!this.$fromUndo&&this.$undoManager&&!j.ignore&&(this.$deltasDoc.push(j),B&&B.length!=0&&this.$deltasFold.push({action:"removeFolds",folds:B}),this.$informUndoManager.schedule()),this.bgTokenizer&&this.bgTokenizer.$updateOnChange(j),this._signal("change",j)},this.setValue=function(j){this.doc.setValue(j),this.selection.moveTo(0,0),this.$resetRowCache(0),this.$deltas=[],this.$deltasDoc=[],this.$deltasFold=[],this.setUndoManager(this.$undoManager),this.getUndoManager().reset()},this.getValue=this.toString=function(){return this.doc.getValue()},this.getSelection=function(){return this.selection},this.getState=function(j){return this.bgTokenizer.getState(j)},this.getTokens=function(j){return this.bgTokenizer.getTokens(j)},this.getTokenAt=function(j,B){var q=this.bgTokenizer.getTokens(j),U,Z=0;if(B==null)re=q.length-1,Z=this.getLine(j).length;else for(var re=0;re<q.length&&(Z+=q[re].value.length,!(Z>=B));re++);return U=q[re],U?(U.index=re,U.start=Z-U.value.length,U):null},this.setUndoManager=function(j){if(this.$undoManager=j,this.$deltas=[],this.$deltasDoc=[],this.$deltasFold=[],this.$informUndoManager&&this.$informUndoManager.cancel(),j){var B=this;this.$syncInformUndoManager=function(){B.$informUndoManager.cancel(),B.$deltasFold.length&&(B.$deltas.push({group:"fold",deltas:B.$deltasFold}),B.$deltasFold=[]),B.$deltasDoc.length&&(B.$deltas.push({group:"doc",deltas:B.$deltasDoc}),B.$deltasDoc=[]),B.$deltas.length>0&&j.execute({action:"aceupdate",args:[B.$deltas,B],merge:B.mergeUndoDeltas}),B.mergeUndoDeltas=!1,B.$deltas=[]},this.$informUndoManager=h.delayedCall(this.$syncInformUndoManager)}},this.markUndoGroup=function(){this.$syncInformUndoManager&&this.$syncInformUndoManager()},this.$defaultUndoManager={undo:function(){},redo:function(){},reset:function(){}},this.getUndoManager=function(){return this.$undoManager||this.$defaultUndoManager},this.getTabString=function(){return this.getUseSoftTabs()?h.stringRepeat(" ",this.getTabSize()):"	"},this.setUseSoftTabs=function(j){this.setOption("useSoftTabs",j)},this.getUseSoftTabs=function(){return this.$useSoftTabs&&!this.$mode.$indentWithTabs},this.setTabSize=function(j){this.setOption("tabSize",j)},this.getTabSize=function(){return this.$tabSize},this.isTabStop=function(j){return this.$useSoftTabs&&j.column%this.$tabSize===0},this.$overwrite=!1,this.setOverwrite=function(j){this.setOption("overwrite",j)},this.getOverwrite=function(){return this.$overwrite},this.toggleOverwrite=function(){this.setOverwrite(!this.$overwrite)},this.addGutterDecoration=function(j,B){this.$decorations[j]||(this.$decorations[j]=""),this.$decorations[j]+=" "+B,this._signal("changeBreakpoint",{})},this.removeGutterDecoration=function(j,B){this.$decorations[j]=(this.$decorations[j]||"").replace(" "+B,""),this._signal("changeBreakpoint",{})},this.getBreakpoints=function(){return this.$breakpoints},this.setBreakpoints=function(j){this.$breakpoints=[];for(var B=0;B<j.length;B++)this.$breakpoints[j[B]]="ace_breakpoint";this._signal("changeBreakpoint",{})},this.clearBreakpoints=function(){this.$breakpoints=[],this._signal("changeBreakpoint",{})},this.setBreakpoint=function(j,B){B===void 0&&(B="ace_breakpoint"),B?this.$breakpoints[j]=B:delete this.$breakpoints[j],this._signal("changeBreakpoint",{})},this.clearBreakpoint=function(j){delete this.$breakpoints[j],this._signal("changeBreakpoint",{})},this.addMarker=function(j,B,q,U){var Z=this.$markerId++,re={range:j,type:q||"line",renderer:typeof q=="function"?q:null,clazz:B,inFront:!!U,id:Z};return U?(this.$frontMarkers[Z]=re,this._signal("changeFrontMarker")):(this.$backMarkers[Z]=re,this._signal("changeBackMarker")),Z},this.addDynamicMarker=function(j,B){if(j.update){var q=this.$markerId++;return j.id=q,j.inFront=!!B,B?(this.$frontMarkers[q]=j,this._signal("changeFrontMarker")):(this.$backMarkers[q]=j,this._signal("changeBackMarker")),j}},this.removeMarker=function(j){var B=this.$frontMarkers[j]||this.$backMarkers[j];if(B){var q=B.inFront?this.$frontMarkers:this.$backMarkers;B&&(delete q[j],this._signal(B.inFront?"changeFrontMarker":"changeBackMarker"))}},this.getMarkers=function(j){return j?this.$frontMarkers:this.$backMarkers},this.highlight=function(j){if(!this.$searchHighlight){var B=new m(null,"ace_selected-word","text");this.$searchHighlight=this.addDynamicMarker(B)}this.$searchHighlight.setRegexp(j)},this.highlightLines=function(j,B,q,U){typeof B!="number"&&(q=B,B=j),q||(q="ace_step");var Z=new a(j,0,B,1/0);return Z.id=this.addMarker(Z,q,"fullLine",U),Z},this.setAnnotations=function(j){this.$annotations=j,this._signal("changeAnnotation",{})},this.getAnnotations=function(){return this.$annotations||[]},this.clearAnnotations=function(){this.setAnnotations([])},this.$detectNewLine=function(j){var B=j.match(/^.*?(\r?\n)/m);B?this.$autoNewLine=B[1]:this.$autoNewLine=`
`},this.getWordRange=function(j,B){var q=this.getLine(j),U=!1;if(B>0&&(U=!!q.charAt(B-1).match(this.tokenRe)),U||(U=!!q.charAt(B).match(this.tokenRe)),U)var Z=this.tokenRe;else if(/^\s+$/.test(q.slice(B-1,B+1)))var Z=/\s/;else var Z=this.nonTokenRe;var re=B;if(re>0){do re--;while(re>=0&&q.charAt(re).match(Z));re++}for(var le=B;le<q.length&&q.charAt(le).match(Z);)le++;return new a(j,re,j,le)},this.getAWordRange=function(j,B){for(var q=this.getWordRange(j,B),U=this.getLine(q.end.row);U.charAt(q.end.column).match(/[ \t]/);)q.end.column+=1;return q},this.setNewLineMode=function(j){this.doc.setNewLineMode(j)},this.getNewLineMode=function(){return this.doc.getNewLineMode()},this.setUseWorker=function(j){this.setOption("useWorker",j)},this.getUseWorker=function(){return this.$useWorker},this.onReloadTokenizer=function(j){var B=j.data;this.bgTokenizer.start(B.first),this._signal("tokenizerUpdate",j)},this.$modes={},this.$mode=null,this.$modeId=null,this.setMode=function(j,B){if(j&&typeof j=="object"){if(j.getTokenizer)return this.$onChangeMode(j);var q=j,U=q.path}else U=j||"ace/mode/text";if(this.$modes["ace/mode/text"]||(this.$modes["ace/mode/text"]=new c),this.$modes[U]&&!q){this.$onChangeMode(this.$modes[U]),B&&B();return}this.$modeId=U,g.loadModule(["mode",U],function(Z){if(this.$modeId!==U)return B&&B();this.$modes[U]&&!q?this.$onChangeMode(this.$modes[U]):Z&&Z.Mode&&(Z=new Z.Mode(q),q||(this.$modes[U]=Z,Z.$id=U),this.$onChangeMode(Z)),B&&B()}.bind(this)),this.$mode||this.$onChangeMode(this.$modes["ace/mode/text"],!0)},this.$onChangeMode=function(j,B){if(B||(this.$modeId=j.$id),this.$mode!==j){this.$mode=j,this.$stopWorker(),this.$useWorker&&this.$startWorker();var q=j.getTokenizer();if(q.addEventListener!==void 0){var U=this.onReloadTokenizer.bind(this);q.addEventListener("update",U)}if(this.bgTokenizer)this.bgTokenizer.setTokenizer(q);else{this.bgTokenizer=new p(q);var Z=this;this.bgTokenizer.addEventListener("update",function(re){Z._signal("tokenizerUpdate",re)})}this.bgTokenizer.setDocument(this.getDocument()),this.tokenRe=j.tokenRe,this.nonTokenRe=j.nonTokenRe,B||(j.attachToSession&&j.attachToSession(this),this.$options.wrapMethod.set.call(this,this.$wrapMethod),this.$setFolding(j.foldingRules),this.bgTokenizer.start(0),this._emit("changeMode"))}},this.$stopWorker=function(){this.$worker&&(this.$worker.terminate(),this.$worker=null)},this.$startWorker=function(){try{this.$worker=this.$mode.createWorker(this)}catch(j){g.warn("Could not load worker",j),this.$worker=null}},this.getMode=function(){return this.$mode},this.$scrollTop=0,this.setScrollTop=function(j){this.$scrollTop===j||isNaN(j)||(this.$scrollTop=j,this._signal("changeScrollTop",j))},this.getScrollTop=function(){return this.$scrollTop},this.$scrollLeft=0,this.setScrollLeft=function(j){this.$scrollLeft===j||isNaN(j)||(this.$scrollLeft=j,this._signal("changeScrollLeft",j))},this.getScrollLeft=function(){return this.$scrollLeft},this.getScreenWidth=function(){return this.$computeWidth(),this.lineWidgets?Math.max(this.getLineWidgetMaxWidth(),this.screenWidth):this.screenWidth},this.getLineWidgetMaxWidth=function(){if(this.lineWidgetsWidth!=null)return this.lineWidgetsWidth;var j=0;return this.lineWidgets.forEach(function(B){B&&B.screenWidth>j&&(j=B.screenWidth)}),this.lineWidgetWidth=j},this.$computeWidth=function(j){if(this.$modified||j){if(this.$modified=!1,this.$useWrapMode)return this.screenWidth=this.$wrapLimit;for(var B=this.doc.getAllLines(),q=this.$rowLengthCache,U=0,Z=0,re=this.$foldData[Z],le=re?re.start.row:1/0,ce=B.length,de=0;de<ce;de++){if(de>le){if(de=re.end.row+1,de>=ce)break;re=this.$foldData[Z++],le=re?re.start.row:1/0}q[de]==null&&(q[de]=this.$getStringScreenWidth(B[de])[0]),q[de]>U&&(U=q[de])}this.screenWidth=U}},this.getLine=function(j){return this.doc.getLine(j)},this.getLines=function(j,B){return this.doc.getLines(j,B)},this.getLength=function(){return this.doc.getLength()},this.getTextRange=function(j){return this.doc.getTextRange(j||this.selection.getRange())},this.insert=function(j,B){return this.doc.insert(j,B)},this.remove=function(j){return this.doc.remove(j)},this.removeFullLines=function(j,B){return this.doc.removeFullLines(j,B)},this.undoChanges=function(j,B){if(j.length){this.$fromUndo=!0;for(var q=null,U=j.length-1;U!=-1;U--){var Z=j[U];Z.group=="doc"?(this.doc.revertDeltas(Z.deltas),q=this.$getUndoSelection(Z.deltas,!0,q)):Z.deltas.forEach(function(re){this.addFolds(re.folds)},this)}return this.$fromUndo=!1,q&&this.$undoSelect&&!B&&this.selection.setSelectionRange(q),q}},this.redoChanges=function(j,B){if(j.length){this.$fromUndo=!0;for(var q=null,U=0;U<j.length;U++){var Z=j[U];Z.group=="doc"&&(this.doc.applyDeltas(Z.deltas),q=this.$getUndoSelection(Z.deltas,!1,q))}return this.$fromUndo=!1,q&&this.$undoSelect&&!B&&this.selection.setSelectionRange(q),q}},this.setUndoSelect=function(j){this.$undoSelect=j},this.$getUndoSelection=function(j,B,q){function U(he){return B?he.action!=="insert":he.action==="insert"}var Z=j[0],re,le;U(Z)?re=a.fromPoints(Z.start,Z.end):re=a.fromPoints(Z.start,Z.start);for(var ce=1;ce<j.length;ce++)Z=j[ce],U(Z)?(le=Z.start,re.compare(le.row,le.column)==-1&&re.setStart(le),le=Z.end,re.compare(le.row,le.column)==1&&re.setEnd(le)):(le=Z.start,re.compare(le.row,le.column)==-1&&(re=a.fromPoints(Z.start,Z.start)));if(q!=null){a.comparePoints(q.start,re.start)===0&&(q.start.column+=re.end.column-re.start.column,q.end.column+=re.end.column-re.start.column);var de=q.compareRange(re);de==1?re.setStart(q.start):de==-1&&re.setEnd(q.end)}return re},this.replace=function(j,B){return this.doc.replace(j,B)},this.moveText=function(j,B,q){var U=this.getTextRange(j),Z=this.getFoldsInRange(j),re=a.fromPoints(B,B);if(!q){this.remove(j);var le=j.start.row-j.end.row,ce=le?-j.end.column:j.start.column-j.end.column;ce&&(re.start.row==j.end.row&&re.start.column>j.end.column&&(re.start.column+=ce),re.end.row==j.end.row&&re.end.column>j.end.column&&(re.end.column+=ce)),le&&re.start.row>=j.end.row&&(re.start.row+=le,re.end.row+=le)}if(re.end=this.insert(re.start,U),Z.length){var de=j.start,he=re.start,le=he.row-de.row,ce=he.column-de.column;this.addFolds(Z.map(function(ye){return ye=ye.clone(),ye.start.row==de.row&&(ye.start.column+=ce),ye.end.row==de.row&&(ye.end.column+=ce),ye.start.row+=le,ye.end.row+=le,ye}))}return re},this.indentRows=function(j,B,q){q=q.replace(/\t/g,this.getTabString());for(var U=j;U<=B;U++)this.doc.insertInLine({row:U,column:0},q)},this.outdentRows=function(j){for(var B=j.collapseRows(),q=new a(0,0,0,0),U=this.getTabSize(),Z=B.start.row;Z<=B.end.row;++Z){var re=this.getLine(Z);q.start.row=Z,q.end.row=Z;for(var le=0;le<U&&re.charAt(le)==" ";++le);le<U&&re.charAt(le)=="	"?(q.start.column=le,q.end.column=le+1):(q.start.column=0,q.end.column=le),this.remove(q)}},this.$moveLines=function(j,B,q){if(j=this.getRowFoldStart(j),B=this.getRowFoldEnd(B),q<0){var U=this.getRowFoldStart(j+q);if(U<0)return 0;var Z=U-j}else if(q>0){var U=this.getRowFoldEnd(B+q);if(U>this.doc.getLength()-1)return 0;var Z=U-B}else{j=this.$clipRowToDocument(j),B=this.$clipRowToDocument(B);var Z=B-j+1}var re=new a(j,0,B,Number.MAX_VALUE),le=this.getFoldsInRange(re).map(function(de){return de=de.clone(),de.start.row+=Z,de.end.row+=Z,de}),ce=q==0?this.doc.getLines(j,B):this.doc.removeFullLines(j,B);return this.doc.insertFullLines(j+Z,ce),le.length&&this.addFolds(le),Z},this.moveLinesUp=function(j,B){return this.$moveLines(j,B,-1)},this.moveLinesDown=function(j,B){return this.$moveLines(j,B,1)},this.duplicateLines=function(j,B){return this.$moveLines(j,B,0)},this.$clipRowToDocument=function(j){return Math.max(0,Math.min(j,this.doc.getLength()-1))},this.$clipColumnToRow=function(j,B){return B<0?0:Math.min(this.doc.getLine(j).length,B)},this.$clipPositionToDocument=function(j,B){if(B=Math.max(0,B),j<0)j=0,B=0;else{var q=this.doc.getLength();j>=q?(j=q-1,B=this.doc.getLine(q-1).length):B=Math.min(this.doc.getLine(j).length,B)}return{row:j,column:B}},this.$clipRangeToDocument=function(j){j.start.row<0?(j.start.row=0,j.start.column=0):j.start.column=this.$clipColumnToRow(j.start.row,j.start.column);var B=this.doc.getLength()-1;return j.end.row>B?(j.end.row=B,j.end.column=this.doc.getLine(B).length):j.end.column=this.$clipColumnToRow(j.end.row,j.end.column),j},this.$wrapLimit=80,this.$useWrapMode=!1,this.$wrapLimitRange={min:null,max:null},this.setUseWrapMode=function(j){if(j!=this.$useWrapMode){if(this.$useWrapMode=j,this.$modified=!0,this.$resetRowCache(0),j){var B=this.getLength();this.$wrapData=Array(B),this.$updateWrapData(0,B-1)}this._signal("changeWrapMode")}},this.getUseWrapMode=function(){return this.$useWrapMode},this.setWrapLimitRange=function(j,B){(this.$wrapLimitRange.min!==j||this.$wrapLimitRange.max!==B)&&(this.$wrapLimitRange={min:j,max:B},this.$modified=!0,this.$useWrapMode&&this._signal("changeWrapMode"))},this.adjustWrapLimit=function(j,B){var q=this.$wrapLimitRange;q.max<0&&(q={min:B,max:B});var U=this.$constrainWrapLimit(j,q.min,q.max);return U!=this.$wrapLimit&&U>1?(this.$wrapLimit=U,this.$modified=!0,this.$useWrapMode&&(this.$updateWrapData(0,this.getLength()-1),this.$resetRowCache(0),this._signal("changeWrapLimit")),!0):!1},this.$constrainWrapLimit=function(j,B,q){return B&&(j=Math.max(B,j)),q&&(j=Math.min(q,j)),j},this.getWrapLimit=function(){return this.$wrapLimit},this.setWrapLimit=function(j){this.setWrapLimitRange(j,j)},this.getWrapLimitRange=function(){return{min:this.$wrapLimitRange.min,max:this.$wrapLimitRange.max}},this.$updateInternalDataOnChange=function(j){var B=this.$useWrapMode,q=j.action,U=j.start,Z=j.end,re=U.row,le=Z.row,ce=le-re,de=null;if(this.$updating=!0,ce!=0)if(q==="remove"){this[B?"$wrapData":"$rowLengthCache"].splice(re,ce);var he=this.$foldData;de=this.getFoldsInRange(j),this.removeFolds(de);var Fe=this.getFoldLine(Z.row),ge=0;if(Fe){Fe.addRemoveChars(Z.row,Z.column,U.column-Z.column),Fe.shiftRow(-ce);var ye=this.getFoldLine(re);ye&&ye!==Fe&&(ye.merge(Fe),Fe=ye),ge=he.indexOf(Fe)+1}for(ge;ge<he.length;ge++){var Fe=he[ge];Fe.start.row>=Z.row&&Fe.shiftRow(-ce)}le=re}else{var Y=Array(ce);Y.unshift(re,0);var ue=B?this.$wrapData:this.$rowLengthCache;ue.splice.apply(ue,Y);var he=this.$foldData,Fe=this.getFoldLine(re),ge=0;if(Fe){var Ee=Fe.range.compareInside(U.row,U.column);Ee==0?(Fe=Fe.split(U.row,U.column),Fe&&(Fe.shiftRow(ce),Fe.addRemoveChars(le,0,Z.column-U.column))):Ee==-1&&(Fe.addRemoveChars(re,0,Z.column-U.column),Fe.shiftRow(ce)),ge=he.indexOf(Fe)+1}for(ge;ge<he.length;ge++){var Fe=he[ge];Fe.start.row>=re&&Fe.shiftRow(ce)}}else{ce=Math.abs(j.start.column-j.end.column),q==="remove"&&(de=this.getFoldsInRange(j),this.removeFolds(de),ce=-ce);var Fe=this.getFoldLine(re);Fe&&Fe.addRemoveChars(re,U.column,ce)}return B&&this.$wrapData.length!=this.doc.getLength()&&console.error("doc.getLength() and $wrapData.length have to be the same!"),this.$updating=!1,B?this.$updateWrapData(re,le):this.$updateRowLengthCache(re,le),de},this.$updateRowLengthCache=function(j,B,q){this.$rowLengthCache[j]=null,this.$rowLengthCache[B]=null},this.$updateWrapData=function(j,B){var q=this.doc.getAllLines(),U=this.getTabSize(),Z=this.$wrapData,re=this.$wrapLimit,le,ce,de=j;for(B=Math.min(B,q.length-1);de<=B;)ce=this.getFoldLine(de,ce),ce?(le=[],ce.walk(function(he,Fe,ge,ye){var Y;if(he!=null){Y=this.$getDisplayTokens(he,le.length),Y[0]=T;for(var ue=1;ue<Y.length;ue++)Y[ue]=w}else Y=this.$getDisplayTokens(q[Fe].substring(ye,ge),le.length);le=le.concat(Y)}.bind(this),ce.end.row,q[ce.end.row].length+1),Z[ce.start.row]=this.$computeWrapSplits(le,re,U),de=ce.end.row+1):(le=this.$getDisplayTokens(q[de]),Z[de]=this.$computeWrapSplits(le,re,U),de++)};var C=1,k=2,T=3,w=4,A=9,M=10,x=11,R=12;this.$computeWrapSplits=function(j,B,q){if(j.length==0)return[];var U=[],Z=j.length,re=0,le=0,ce=this.$wrapAsCode,de=this.$indentedSoftWrap,he=B<=Math.max(2*q,8)||de===!1?0:Math.floor(B/2);function Fe(){var Ee=0;if(he===0)return Ee;if(de)for(var ne=0;ne<j.length;ne++){var me=j[ne];if(me==M)Ee+=1;else if(me==x)Ee+=q;else{if(me==R)continue;break}}return ce&&de!==!1&&(Ee+=q),Math.min(Ee,he)}function ge(Ee){var ne=j.slice(re,Ee),me=ne.length;ne.join("").replace(/12/g,function(){me-=1}).replace(/2/g,function(){me-=1}),U.length||(ye=Fe(),U.indent=ye),le+=me,U.push(le),re=Ee}for(var ye=0;Z-re>B-ye;){var Y=re+B-ye;if(j[Y-1]>=M&&j[Y]>=M){ge(Y);continue}if(j[Y]==T||j[Y]==w){for(Y;Y!=re-1&&j[Y]!=T;Y--);if(Y>re){ge(Y);continue}for(Y=re+B,Y;Y<j.length&&j[Y]==w;Y++);if(Y==j.length)break;ge(Y);continue}for(var ue=Math.max(Y-(B-(B>>2)),re-1);Y>ue&&j[Y]<T;)Y--;if(ce){for(;Y>ue&&j[Y]<T;)Y--;for(;Y>ue&&j[Y]==A;)Y--}else for(;Y>ue&&j[Y]<M;)Y--;if(Y>ue){ge(++Y);continue}Y=re+B,j[Y]==k&&Y--,ge(Y-ye)}return U},this.$getDisplayTokens=function(j,B){var q=[],U;B=B||0;for(var Z=0;Z<j.length;Z++){var re=j.charCodeAt(Z);if(re==9){U=this.getScreenTabSize(q.length+B),q.push(x);for(var le=1;le<U;le++)q.push(R)}else re==32?q.push(M):re>39&&re<48||re>57&&re<64?q.push(A):re>=4352&&N(re)?q.push(C,k):q.push(C)}return q},this.$getStringScreenWidth=function(j,B,q){if(B==0)return[0,0];B==null&&(B=1/0),q=q||0;var U,Z;for(Z=0;Z<j.length&&(U=j.charCodeAt(Z),U==9?q+=this.getScreenTabSize(q):U>=4352&&N(U)?q+=2:q+=1,!(q>B));Z++);return[q,Z]},this.lineWidgets=null,this.getRowLength=function(j){if(this.lineWidgets)var B=this.lineWidgets[j]&&this.lineWidgets[j].rowCount||0;else B=0;return!this.$useWrapMode||!this.$wrapData[j]?1+B:this.$wrapData[j].length+1+B},this.getRowLineCount=function(j){return!this.$useWrapMode||!this.$wrapData[j]?1:this.$wrapData[j].length+1},this.getRowWrapIndent=function(j){if(this.$useWrapMode){var B=this.screenToDocumentPosition(j,Number.MAX_VALUE),q=this.$wrapData[B.row];return q.length&&q[0]<B.column?q.indent:0}else return 0},this.getScreenLastRowColumn=function(j){var B=this.screenToDocumentPosition(j,Number.MAX_VALUE);return this.documentToScreenColumn(B.row,B.column)},this.getDocumentLastRowColumn=function(j,B){var q=this.documentToScreenRow(j,B);return this.getScreenLastRowColumn(q)},this.getDocumentLastRowColumnPosition=function(j,B){var q=this.documentToScreenRow(j,B);return this.screenToDocumentPosition(q,Number.MAX_VALUE/10)},this.getRowSplitData=function(j){if(this.$useWrapMode)return this.$wrapData[j]},this.getScreenTabSize=function(j){return this.$tabSize-j%this.$tabSize},this.screenToDocumentRow=function(j,B){return this.screenToDocumentPosition(j,B).row},this.screenToDocumentColumn=function(j,B){return this.screenToDocumentPosition(j,B).column},this.screenToDocumentPosition=function(j,B){if(j<0)return{row:0,column:0};var q,U=0,Z=0,re,le=0,ce=0,de=this.$screenRowCache,he=this.$getRowCacheIndex(de,j),Fe=de.length;if(Fe&&he>=0)var le=de[he],U=this.$docRowCache[he],ge=j>de[Fe-1];else var ge=!Fe;for(var ye=this.getLength()-1,Y=this.getNextFoldLine(U),ue=Y?Y.start.row:1/0;le<=j&&(ce=this.getRowLength(U),!(le+ce>j||U>=ye));)le+=ce,U++,U>ue&&(U=Y.end.row+1,Y=this.getNextFoldLine(U,Y),ue=Y?Y.start.row:1/0),ge&&(this.$docRowCache.push(U),this.$screenRowCache.push(le));if(Y&&Y.start.row<=U)q=this.getFoldDisplayLine(Y),U=Y.start.row;else{if(le+ce<=j||U>ye)return{row:ye,column:this.getLine(ye).length};q=this.getLine(U),Y=null}var Ee=0;if(this.$useWrapMode){var ne=this.$wrapData[U];if(ne){var me=Math.floor(j-le);re=ne[me],me>0&&ne.length&&(Ee=ne.indent,Z=ne[me-1]||ne[ne.length-1],q=q.substring(Z))}}return Z+=this.$getStringScreenWidth(q,B-Ee)[1],this.$useWrapMode&&Z>=re&&(Z=re-1),Y?Y.idxToPosition(Z):{row:U,column:Z}},this.documentToScreenPosition=function(j,B){if(typeof B>"u")var q=this.$clipPositionToDocument(j.row,j.column);else q=this.$clipPositionToDocument(j,B);j=q.row,B=q.column;var U=0,Z=null,re=null;re=this.getFoldAt(j,B,1),re&&(j=re.start.row,B=re.start.column);var le,ce=0,de=this.$docRowCache,he=this.$getRowCacheIndex(de,j),Fe=de.length;if(Fe&&he>=0)var ce=de[he],U=this.$screenRowCache[he],ge=j>de[Fe-1];else var ge=!Fe;for(var ye=this.getNextFoldLine(ce),Y=ye?ye.start.row:1/0;ce<j;){if(ce>=Y){if(le=ye.end.row+1,le>j)break;ye=this.getNextFoldLine(le,ye),Y=ye?ye.start.row:1/0}else le=ce+1;U+=this.getRowLength(ce),ce=le,ge&&(this.$docRowCache.push(ce),this.$screenRowCache.push(U))}var ue="";ye&&ce>=Y?(ue=this.getFoldDisplayLine(ye,j,B),Z=ye.start.row):(ue=this.getLine(j).substring(0,B),Z=j);var Ee=0;if(this.$useWrapMode){var ne=this.$wrapData[Z];if(ne){for(var me=0;ue.length>=ne[me];)U++,me++;ue=ue.substring(ne[me-1]||0,ue.length),Ee=me>0?ne.indent:0}}return{row:U,column:Ee+this.$getStringScreenWidth(ue)[0]}},this.documentToScreenColumn=function(j,B){return this.documentToScreenPosition(j,B).column},this.documentToScreenRow=function(j,B){return this.documentToScreenPosition(j,B).row},this.getScreenLength=function(){var j=0,B=null;if(this.$useWrapMode)for(var Z=this.$wrapData.length,re=0,U=0,B=this.$foldData[U++],le=B?B.start.row:1/0;re<Z;){var ce=this.$wrapData[re];j+=ce?ce.length+1:1,re++,re>le&&(re=B.end.row+1,B=this.$foldData[U++],le=B?B.start.row:1/0)}else{j=this.getLength();for(var q=this.$foldData,U=0;U<q.length;U++)B=q[U],j-=B.end.row-B.start.row}return this.lineWidgets&&(j+=this.$getWidgetScreenLength()),j},this.$setFontMetrics=function(j){this.$enableVarChar&&(this.$getStringScreenWidth=function(B,q,U){if(q===0)return[0,0];q||(q=1/0),U=U||0;var Z,re;for(re=0;re<B.length&&(Z=B.charAt(re),Z==="	"?U+=this.getScreenTabSize(U):U+=j.getCharacterWidth(Z),!(U>q));re++);return[U,re]})},this.destroy=function(){this.bgTokenizer&&(this.bgTokenizer.setDocument(null),this.bgTokenizer=null),this.$stopWorker()};function N(j){return j<4352?!1:j>=4352&&j<=4447||j>=4515&&j<=4519||j>=4602&&j<=4607||j>=9001&&j<=9002||j>=11904&&j<=11929||j>=11931&&j<=12019||j>=12032&&j<=12245||j>=12272&&j<=12283||j>=12288&&j<=12350||j>=12353&&j<=12438||j>=12441&&j<=12543||j>=12549&&j<=12589||j>=12593&&j<=12686||j>=12688&&j<=12730||j>=12736&&j<=12771||j>=12784&&j<=12830||j>=12832&&j<=12871||j>=12880&&j<=13054||j>=13056&&j<=19903||j>=19968&&j<=42124||j>=42128&&j<=42182||j>=43360&&j<=43388||j>=44032&&j<=55203||j>=55216&&j<=55238||j>=55243&&j<=55291||j>=63744&&j<=64255||j>=65040&&j<=65049||j>=65072&&j<=65106||j>=65108&&j<=65126||j>=65128&&j<=65131||j>=65281&&j<=65376||j>=65504&&j<=65510}}).call(b.prototype),s("./edit_session/folding").Folding.call(b.prototype),s("./edit_session/bracket_match").BracketMatch.call(b.prototype),g.defineOptions(b.prototype,"session",{wrap:{set:function(C){if(!C||C=="off"?C=!1:C=="free"?C=!0:C=="printMargin"?C=-1:typeof C=="string"&&(C=parseInt(C,10)||!1),this.$wrap!=C)if(this.$wrap=C,!C)this.setUseWrapMode(!1);else{var k=typeof C=="number"?C:null;this.setWrapLimitRange(k,k),this.setUseWrapMode(!0)}},get:function(){return this.getUseWrapMode()?this.$wrap==-1?"printMargin":this.getWrapLimitRange().min?this.$wrap:"free":"off"},handlesSet:!0},wrapMethod:{set:function(C){C=C=="auto"?this.$mode.type!="text":C!="text",C!=this.$wrapAsCode&&(this.$wrapAsCode=C,this.$useWrapMode&&(this.$modified=!0,this.$resetRowCache(0),this.$updateWrapData(0,this.getLength()-1)))},initialValue:"auto"},indentedSoftWrap:{initialValue:!0},firstLineNumber:{set:function(){this._signal("changeBreakpoint")},initialValue:1},useWorker:{set:function(C){this.$useWorker=C,this.$stopWorker(),C&&this.$startWorker()},initialValue:!0},useSoftTabs:{initialValue:!0},tabSize:{set:function(C){isNaN(C)||this.$tabSize===C||(this.$modified=!0,this.$rowLengthCache=[],this.$tabSize=C,this._signal("changeTabSize"))},initialValue:4,handlesSet:!0},overwrite:{set:function(C){this._signal("changeOverwrite")},initialValue:!1},newLineMode:{set:function(C){this.doc.setNewLineMode(C)},get:function(){return this.doc.getNewLineMode()},handlesSet:!0},mode:{set:function(C){this.setMode(C)},get:function(){return this.$modeId}}}),o.EditSession=b}),ace.define("ace/search",["require","exports","module","ace/lib/lang","ace/lib/oop","ace/range"],function(s,o,f){var n=s("./lib/lang"),h=s("./lib/oop"),g=s("./range").Range,d=function(){this.$options={}};(function(){this.set=function(c){return h.mixin(this.$options,c),this},this.getOptions=function(){return n.copyObject(this.$options)},this.setOptions=function(c){this.$options=c},this.find=function(c){var a=this.$options,F=this.$matchIterator(c,a);if(!F)return!1;var p=null;return F.forEach(function(m,b,C){if(m.start)p=m;else{var k=m.offset+(C||0);if(p=new g(b,k,b,k+m.length),!m.length&&a.start&&a.start.start&&a.skipCurrent!=!1&&p.isEqual(a.start))return p=null,!1}return!0}),p},this.findAll=function(c){var a=this.$options;if(!a.needle)return[];this.$assembleRegExp(a);var F=a.range,p=F?c.getLines(F.start.row,F.end.row):c.doc.getAllLines(),m=[],b=a.re;if(a.$isMultiLine){var C=b.length,k=p.length-C,T;e:for(var w=b.offset||0;w<=k;w++){for(var A=0;A<C;A++)if(p[w+A].search(b[A])==-1)continue e;var M=p[w],x=p[w+C-1],R=M.length-M.match(b[0])[0].length,N=x.match(b[C-1])[0].length;T&&T.end.row===w&&T.end.column>R||(m.push(T=new g(w,R,w+C-1,N)),C>2&&(w=w+C-2))}}else for(var j=0;j<p.length;j++)for(var B=n.getMatchOffsets(p[j],b),A=0;A<B.length;A++){var q=B[A];m.push(new g(j,q.offset,j,q.offset+q.length))}if(F){for(var U=F.start.column,Z=F.start.column,j=0,A=m.length-1;j<A&&m[j].start.column<U&&m[j].start.row==F.start.row;)j++;for(;j<A&&m[A].end.column>Z&&m[A].end.row==F.end.row;)A--;for(m=m.slice(j,A+1),j=0,A=m.length;j<A;j++)m[j].start.row+=F.start.row,m[j].end.row+=F.start.row}return m},this.replace=function(c,a){var F=this.$options,p=this.$assembleRegExp(F);if(F.$isMultiLine)return a;if(p){var m=p.exec(c);if(!m||m[0].length!=c.length)return null;if(a=c.replace(p,a),F.preserveCase){a=a.split("");for(var b=Math.min(c.length,c.length);b--;){var C=c[b];C&&C.toLowerCase()!=C?a[b]=a[b].toUpperCase():a[b]=a[b].toLowerCase()}a=a.join("")}return a}},this.$matchIterator=function(c,a){var F=this.$assembleRegExp(a);if(!F)return!1;var p;if(a.$isMultiLine)var m=F.length,b=function(k,T,w){var A=k.search(F[0]);if(A!=-1){for(var M=1;M<m;M++)if(k=c.getLine(T+M),k.search(F[M])==-1)return;var x=k.match(F[m-1])[0].length,R=new g(T,A,T+m-1,x);if(F.offset==1?(R.start.row--,R.start.column=Number.MAX_VALUE):w&&(R.start.column+=w),p(R))return!0}};else if(a.backwards)var b=function(T,w,A){for(var M=n.getMatchOffsets(T,F),x=M.length-1;x>=0;x--)if(p(M[x],w,A))return!0};else var b=function(T,w,A){for(var M=n.getMatchOffsets(T,F),x=0;x<M.length;x++)if(p(M[x],w,A))return!0};var C=this.$lineIterator(c,a);return{forEach:function(k){p=k,C.forEach(b)}}},this.$assembleRegExp=function(c,a){if(c.needle instanceof RegExp)return c.re=c.needle;var F=c.needle;if(!c.needle)return c.re=!1;c.regExp||(F=n.escapeRegExp(F)),c.wholeWord&&(F=l(F,c));var p=c.caseSensitive?"gm":"gmi";if(c.$isMultiLine=!a&&/[\n\r]/.test(F),c.$isMultiLine)return c.re=this.$assembleMultilineRegExp(F,p);try{var m=new RegExp(F,p)}catch{m=!1}return c.re=m},this.$assembleMultilineRegExp=function(c,a){for(var F=c.replace(/\r\n|\r|\n/g,`$
^`).split(`
`),p=[],m=0;m<F.length;m++)try{p.push(new RegExp(F[m],a))}catch{return!1}return F[0]==""?(p.shift(),p.offset=1):p.offset=0,p},this.$lineIterator=function(c,a){var F=a.backwards==!0,p=a.skipCurrent!=!1,m=a.range,b=a.start;b||(b=m?m[F?"end":"start"]:c.selection.getRange()),b.start&&(b=b[p!=F?"end":"start"]);var C=m?m.start.row:0,k=m?m.end.row:c.getLength()-1,T=F?function(w){var A=b.row,M=c.getLine(A).substring(0,b.column);if(!w(M,A)){for(A--;A>=C;A--)if(w(c.getLine(A),A))return;if(a.wrap!=!1){for(A=k,C=b.row;A>=C;A--)if(w(c.getLine(A),A))return}}}:function(w){var A=b.row,M=c.getLine(A).substr(b.column);if(!w(M,A,b.column)){for(A=A+1;A<=k;A++)if(w(c.getLine(A),A))return;if(a.wrap!=!1){for(A=C,k=b.row;A<=k;A++)if(w(c.getLine(A),A))return}}};return{forEach:T}}}).call(d.prototype);function l(c,a){function F(p){return/\w/.test(p)||a.regExp?"\\b":""}return F(c[0])+c+F(c[c.length-1])}o.Search=d}),ace.define("ace/keyboard/hash_handler",["require","exports","module","ace/lib/keys","ace/lib/useragent"],function(s,o,f){var n=s("../lib/keys"),h=s("../lib/useragent"),g=n.KEY_MODS;function d(c,a){this.platform=a||(h.isMac?"mac":"win"),this.commands={},this.commandKeyBinding={},this.addCommands(c),this.$singleCommand=!0}function l(c,a){d.call(this,c,a),this.$singleCommand=!1}l.prototype=d.prototype,function(){this.addCommand=function(a){this.commands[a.name]&&this.removeCommand(a),this.commands[a.name]=a,a.bindKey&&this._buildKeyHash(a)},this.removeCommand=function(a,F){var p=a&&(typeof a=="string"?a:a.name);a=this.commands[p],F||delete this.commands[p];var m=this.commandKeyBinding;for(var b in m){var C=m[b];if(C==a)delete m[b];else if(Array.isArray(C)){var k=C.indexOf(a);k!=-1&&(C.splice(k,1),C.length==1&&(m[b]=C[0]))}}},this.bindKey=function(a,F,p){if(typeof a=="object"&&a&&(p==null&&(p=a.position),a=a[this.platform]),!!a){if(typeof F=="function")return this.addCommand({exec:F,bindKey:a,name:F.name||a});a.split("|").forEach(function(m){var b="";if(m.indexOf(" ")!=-1){var C=m.split(/\s+/);m=C.pop(),C.forEach(function(w){var A=this.parseKeys(w),M=g[A.hashId]+A.key;b+=(b?" ":"")+M,this._addCommandToBinding(b,"chainKeys")},this),b+=" "}var k=this.parseKeys(m),T=g[k.hashId]+k.key;this._addCommandToBinding(b+T,F,p)},this)}};function c(a){return typeof a=="object"&&a.bindKey&&a.bindKey.position||0}this._addCommandToBinding=function(a,F,p){var m=this.commandKeyBinding,b;if(!F)delete m[a];else if(!m[a]||this.$singleCommand)m[a]=F;else{Array.isArray(m[a])?(b=m[a].indexOf(F))!=-1&&m[a].splice(b,1):m[a]=[m[a]],typeof p!="number"&&(p||F.isDefault?p=-100:p=c(F));var C=m[a];for(b=0;b<C.length;b++){var k=C[b],T=c(k);if(T>p)break}C.splice(b,0,F)}},this.addCommands=function(a){a&&Object.keys(a).forEach(function(F){var p=a[F];if(p){if(typeof p=="string")return this.bindKey(p,F);typeof p=="function"&&(p={exec:p}),typeof p=="object"&&(p.name||(p.name=F),this.addCommand(p))}},this)},this.removeCommands=function(a){Object.keys(a).forEach(function(F){this.removeCommand(a[F])},this)},this.bindKeys=function(a){Object.keys(a).forEach(function(F){this.bindKey(F,a[F])},this)},this._buildKeyHash=function(a){this.bindKey(a.bindKey,a)},this.parseKeys=function(a){var F=a.toLowerCase().split(/[\-\+]([\-\+])?/).filter(function(T){return T}),p=F.pop(),m=n[p];if(n.FUNCTION_KEYS[m])p=n.FUNCTION_KEYS[m].toLowerCase();else if(F.length){if(F.length==1&&F[0]=="shift")return{key:p.toUpperCase(),hashId:-1}}else return{key:p,hashId:-1};for(var b=0,C=F.length;C--;){var k=n.KEY_MODS[F[C]];if(k==null)return typeof console<"u"&&console.error("invalid modifier "+F[C]+" in "+a),!1;b|=k}return{key:p,hashId:b}},this.findKeyCommand=function(F,p){var m=g[F]+p;return this.commandKeyBinding[m]},this.handleKeyboard=function(a,F,p,m){if(!(m<0)){var b=g[F]+p,C=this.commandKeyBinding[b];return a.$keyChain&&(a.$keyChain+=" "+b,C=this.commandKeyBinding[a.$keyChain]||C),C&&(C=="chainKeys"||C[C.length-1]=="chainKeys")?(a.$keyChain=a.$keyChain||b,{command:"null"}):(a.$keyChain&&((!F||F==4)&&p.length==1?a.$keyChain=a.$keyChain.slice(0,-b.length-1):(F==-1||m>0)&&(a.$keyChain="")),{command:C})}},this.getStatusText=function(a,F){return F.$keyChain||""}}.call(d.prototype),o.HashHandler=d,o.MultiHashHandler=l}),ace.define("ace/commands/command_manager",["require","exports","module","ace/lib/oop","ace/keyboard/hash_handler","ace/lib/event_emitter"],function(s,o,f){var n=s("../lib/oop"),h=s("../keyboard/hash_handler").MultiHashHandler,g=s("../lib/event_emitter").EventEmitter,d=function(l,c){h.call(this,c,l),this.byName=this.commands,this.setDefaultHandler("exec",function(a){return a.command.exec(a.editor,a.args||{})})};n.inherits(d,h),function(){n.implement(this,g),this.exec=function(l,c,a){if(Array.isArray(l)){for(var F=l.length;F--;)if(this.exec(l[F],c,a))return!0;return!1}if(typeof l=="string"&&(l=this.commands[l]),!l||c&&c.$readOnly&&!l.readOnly)return!1;var p={editor:c,command:l,args:a};return p.returnValue=this._emit("exec",p),this._signal("afterExec",p),p.returnValue!==!1},this.toggleRecording=function(l){if(!this.$inReplay)return l&&l._emit("changeStatus"),this.recording?(this.macro.pop(),this.removeEventListener("exec",this.$addCommandToMacro),this.macro.length||(this.macro=this.oldMacro),this.recording=!1):(this.$addCommandToMacro||(this.$addCommandToMacro=function(c){this.macro.push([c.command,c.args])}.bind(this)),this.oldMacro=this.macro,this.macro=[],this.on("exec",this.$addCommandToMacro),this.recording=!0)},this.replay=function(l){if(!(this.$inReplay||!this.macro)){if(this.recording)return this.toggleRecording(l);try{this.$inReplay=!0,this.macro.forEach(function(c){typeof c=="string"?this.exec(c,l):this.exec(c[0],l,c[1])},this)}finally{this.$inReplay=!1}}},this.trimMacro=function(l){return l.map(function(c){return typeof c[0]!="string"&&(c[0]=c[0].name),c[1]||(c=c[0]),c})}}.call(d.prototype),o.CommandManager=d}),ace.define("ace/commands/default_commands",["require","exports","module","ace/lib/lang","ace/config","ace/range"],function(s,o,f){var n=s("../lib/lang"),h=s("../config"),g=s("../range").Range;function d(l,c){return{win:l,mac:c}}o.commands=[{name:"showSettingsMenu",bindKey:d("Ctrl-,","Command-,"),exec:function(l){h.loadModule("ace/ext/settings_menu",function(c){c.init(l),l.showSettingsMenu()})},readOnly:!0},{name:"goToNextError",bindKey:d("Alt-E","F4"),exec:function(l){h.loadModule("ace/ext/error_marker",function(c){c.showErrorMarker(l,1)})},scrollIntoView:"animate",readOnly:!0},{name:"goToPreviousError",bindKey:d("Alt-Shift-E","Shift-F4"),exec:function(l){h.loadModule("ace/ext/error_marker",function(c){c.showErrorMarker(l,-1)})},scrollIntoView:"animate",readOnly:!0},{name:"selectall",bindKey:d("Ctrl-A","Command-A"),exec:function(l){l.selectAll()},readOnly:!0},{name:"centerselection",bindKey:d(null,"Ctrl-L"),exec:function(l){l.centerSelection()},readOnly:!0},{name:"gotoline",bindKey:d("Ctrl-L","Command-L"),exec:function(l){var c=parseInt(prompt("Enter line number:"),10);isNaN(c)||l.gotoLine(c)},readOnly:!0},{name:"fold",bindKey:d("Alt-L|Ctrl-F1","Command-Alt-L|Command-F1"),exec:function(l){l.session.toggleFold(!1)},multiSelectAction:"forEach",scrollIntoView:"center",readOnly:!0},{name:"unfold",bindKey:d("Alt-Shift-L|Ctrl-Shift-F1","Command-Alt-Shift-L|Command-Shift-F1"),exec:function(l){l.session.toggleFold(!0)},multiSelectAction:"forEach",scrollIntoView:"center",readOnly:!0},{name:"toggleFoldWidget",bindKey:d("F2","F2"),exec:function(l){l.session.toggleFoldWidget()},multiSelectAction:"forEach",scrollIntoView:"center",readOnly:!0},{name:"toggleParentFoldWidget",bindKey:d("Alt-F2","Alt-F2"),exec:function(l){l.session.toggleFoldWidget(!0)},multiSelectAction:"forEach",scrollIntoView:"center",readOnly:!0},{name:"foldall",bindKey:d(null,"Ctrl-Command-Option-0"),exec:function(l){l.session.foldAll()},scrollIntoView:"center",readOnly:!0},{name:"foldOther",bindKey:d("Alt-0","Command-Option-0"),exec:function(l){l.session.foldAll(),l.session.unfold(l.selection.getAllRanges())},scrollIntoView:"center",readOnly:!0},{name:"unfoldall",bindKey:d("Alt-Shift-0","Command-Option-Shift-0"),exec:function(l){l.session.unfold()},scrollIntoView:"center",readOnly:!0},{name:"findnext",bindKey:d("Ctrl-K","Command-G"),exec:function(l){l.findNext()},multiSelectAction:"forEach",scrollIntoView:"center",readOnly:!0},{name:"findprevious",bindKey:d("Ctrl-Shift-K","Command-Shift-G"),exec:function(l){l.findPrevious()},multiSelectAction:"forEach",scrollIntoView:"center",readOnly:!0},{name:"selectOrFindNext",bindKey:d("Alt-K","Ctrl-G"),exec:function(l){l.selection.isEmpty()?l.selection.selectWord():l.findNext()},readOnly:!0},{name:"selectOrFindPrevious",bindKey:d("Alt-Shift-K","Ctrl-Shift-G"),exec:function(l){l.selection.isEmpty()?l.selection.selectWord():l.findPrevious()},readOnly:!0},{name:"find",bindKey:d("Ctrl-F","Command-F"),exec:function(l){h.loadModule("ace/ext/searchbox",function(c){c.Search(l)})},readOnly:!0},{name:"overwrite",bindKey:"Insert",exec:function(l){l.toggleOverwrite()},readOnly:!0},{name:"selecttostart",bindKey:d("Ctrl-Shift-Home","Command-Shift-Home|Command-Shift-Up"),exec:function(l){l.getSelection().selectFileStart()},multiSelectAction:"forEach",readOnly:!0,scrollIntoView:"animate",aceCommandGroup:"fileJump"},{name:"gotostart",bindKey:d("Ctrl-Home","Command-Home|Command-Up"),exec:function(l){l.navigateFileStart()},multiSelectAction:"forEach",readOnly:!0,scrollIntoView:"animate",aceCommandGroup:"fileJump"},{name:"selectup",bindKey:d("Shift-Up","Shift-Up|Ctrl-Shift-P"),exec:function(l){l.getSelection().selectUp()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"golineup",bindKey:d("Up","Up|Ctrl-P"),exec:function(l,c){l.navigateUp(c.times)},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"selecttoend",bindKey:d("Ctrl-Shift-End","Command-Shift-End|Command-Shift-Down"),exec:function(l){l.getSelection().selectFileEnd()},multiSelectAction:"forEach",readOnly:!0,scrollIntoView:"animate",aceCommandGroup:"fileJump"},{name:"gotoend",bindKey:d("Ctrl-End","Command-End|Command-Down"),exec:function(l){l.navigateFileEnd()},multiSelectAction:"forEach",readOnly:!0,scrollIntoView:"animate",aceCommandGroup:"fileJump"},{name:"selectdown",bindKey:d("Shift-Down","Shift-Down|Ctrl-Shift-N"),exec:function(l){l.getSelection().selectDown()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"golinedown",bindKey:d("Down","Down|Ctrl-N"),exec:function(l,c){l.navigateDown(c.times)},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"selectwordleft",bindKey:d("Ctrl-Shift-Left","Option-Shift-Left"),exec:function(l){l.getSelection().selectWordLeft()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"gotowordleft",bindKey:d("Ctrl-Left","Option-Left"),exec:function(l){l.navigateWordLeft()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"selecttolinestart",bindKey:d("Alt-Shift-Left","Command-Shift-Left|Ctrl-Shift-A"),exec:function(l){l.getSelection().selectLineStart()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"gotolinestart",bindKey:d("Alt-Left|Home","Command-Left|Home|Ctrl-A"),exec:function(l){l.navigateLineStart()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"selectleft",bindKey:d("Shift-Left","Shift-Left|Ctrl-Shift-B"),exec:function(l){l.getSelection().selectLeft()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"gotoleft",bindKey:d("Left","Left|Ctrl-B"),exec:function(l,c){l.navigateLeft(c.times)},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"selectwordright",bindKey:d("Ctrl-Shift-Right","Option-Shift-Right"),exec:function(l){l.getSelection().selectWordRight()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"gotowordright",bindKey:d("Ctrl-Right","Option-Right"),exec:function(l){l.navigateWordRight()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"selecttolineend",bindKey:d("Alt-Shift-Right","Command-Shift-Right|Shift-End|Ctrl-Shift-E"),exec:function(l){l.getSelection().selectLineEnd()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"gotolineend",bindKey:d("Alt-Right|End","Command-Right|End|Ctrl-E"),exec:function(l){l.navigateLineEnd()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"selectright",bindKey:d("Shift-Right","Shift-Right"),exec:function(l){l.getSelection().selectRight()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"gotoright",bindKey:d("Right","Right|Ctrl-F"),exec:function(l,c){l.navigateRight(c.times)},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"selectpagedown",bindKey:"Shift-PageDown",exec:function(l){l.selectPageDown()},readOnly:!0},{name:"pagedown",bindKey:d(null,"Option-PageDown"),exec:function(l){l.scrollPageDown()},readOnly:!0},{name:"gotopagedown",bindKey:d("PageDown","PageDown|Ctrl-V"),exec:function(l){l.gotoPageDown()},readOnly:!0},{name:"selectpageup",bindKey:"Shift-PageUp",exec:function(l){l.selectPageUp()},readOnly:!0},{name:"pageup",bindKey:d(null,"Option-PageUp"),exec:function(l){l.scrollPageUp()},readOnly:!0},{name:"gotopageup",bindKey:"PageUp",exec:function(l){l.gotoPageUp()},readOnly:!0},{name:"scrollup",bindKey:d("Ctrl-Up",null),exec:function(l){l.renderer.scrollBy(0,-2*l.renderer.layerConfig.lineHeight)},readOnly:!0},{name:"scrolldown",bindKey:d("Ctrl-Down",null),exec:function(l){l.renderer.scrollBy(0,2*l.renderer.layerConfig.lineHeight)},readOnly:!0},{name:"selectlinestart",bindKey:"Shift-Home",exec:function(l){l.getSelection().selectLineStart()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"selectlineend",bindKey:"Shift-End",exec:function(l){l.getSelection().selectLineEnd()},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"togglerecording",bindKey:d("Ctrl-Alt-E","Command-Option-E"),exec:function(l){l.commands.toggleRecording(l)},readOnly:!0},{name:"replaymacro",bindKey:d("Ctrl-Shift-E","Command-Shift-E"),exec:function(l){l.commands.replay(l)},readOnly:!0},{name:"jumptomatching",bindKey:d("Ctrl-P","Ctrl-P"),exec:function(l){l.jumpToMatching()},multiSelectAction:"forEach",scrollIntoView:"animate",readOnly:!0},{name:"selecttomatching",bindKey:d("Ctrl-Shift-P","Ctrl-Shift-P"),exec:function(l){l.jumpToMatching(!0)},multiSelectAction:"forEach",scrollIntoView:"animate",readOnly:!0},{name:"expandToMatching",bindKey:d("Ctrl-Shift-M","Ctrl-Shift-M"),exec:function(l){l.jumpToMatching(!0,!0)},multiSelectAction:"forEach",scrollIntoView:"animate",readOnly:!0},{name:"passKeysToBrowser",bindKey:d(null,null),exec:function(){},passEvent:!0,readOnly:!0},{name:"copy",exec:function(l){},readOnly:!0},{name:"cut",exec:function(l){var c=l.getSelectionRange();l._emit("cut",c),l.selection.isEmpty()||(l.session.remove(c),l.clearSelection())},scrollIntoView:"cursor",multiSelectAction:"forEach"},{name:"paste",exec:function(l,c){l.$handlePaste(c)},scrollIntoView:"cursor"},{name:"removeline",bindKey:d("Ctrl-D","Command-D"),exec:function(l){l.removeLines()},scrollIntoView:"cursor",multiSelectAction:"forEachLine"},{name:"duplicateSelection",bindKey:d("Ctrl-Shift-D","Command-Shift-D"),exec:function(l){l.duplicateSelection()},scrollIntoView:"cursor",multiSelectAction:"forEach"},{name:"sortlines",bindKey:d("Ctrl-Alt-S","Command-Alt-S"),exec:function(l){l.sortLines()},scrollIntoView:"selection",multiSelectAction:"forEachLine"},{name:"togglecomment",bindKey:d("Ctrl-/","Command-/"),exec:function(l){l.toggleCommentLines()},multiSelectAction:"forEachLine",scrollIntoView:"selectionPart"},{name:"toggleBlockComment",bindKey:d("Ctrl-Shift-/","Command-Shift-/"),exec:function(l){l.toggleBlockComment()},multiSelectAction:"forEach",scrollIntoView:"selectionPart"},{name:"modifyNumberUp",bindKey:d("Ctrl-Shift-Up","Alt-Shift-Up"),exec:function(l){l.modifyNumber(1)},scrollIntoView:"cursor",multiSelectAction:"forEach"},{name:"modifyNumberDown",bindKey:d("Ctrl-Shift-Down","Alt-Shift-Down"),exec:function(l){l.modifyNumber(-1)},scrollIntoView:"cursor",multiSelectAction:"forEach"},{name:"replace",bindKey:d("Ctrl-H","Command-Option-F"),exec:function(l){h.loadModule("ace/ext/searchbox",function(c){c.Search(l,!0)})}},{name:"undo",bindKey:d("Ctrl-Z","Command-Z"),exec:function(l){l.undo()}},{name:"redo",bindKey:d("Ctrl-Shift-Z|Ctrl-Y","Command-Shift-Z|Command-Y"),exec:function(l){l.redo()}},{name:"copylinesup",bindKey:d("Alt-Shift-Up","Command-Option-Up"),exec:function(l){l.copyLinesUp()},scrollIntoView:"cursor"},{name:"movelinesup",bindKey:d("Alt-Up","Option-Up"),exec:function(l){l.moveLinesUp()},scrollIntoView:"cursor"},{name:"copylinesdown",bindKey:d("Alt-Shift-Down","Command-Option-Down"),exec:function(l){l.copyLinesDown()},scrollIntoView:"cursor"},{name:"movelinesdown",bindKey:d("Alt-Down","Option-Down"),exec:function(l){l.moveLinesDown()},scrollIntoView:"cursor"},{name:"del",bindKey:d("Delete","Delete|Ctrl-D|Shift-Delete"),exec:function(l){l.remove("right")},multiSelectAction:"forEach",scrollIntoView:"cursor"},{name:"backspace",bindKey:d("Shift-Backspace|Backspace","Ctrl-Backspace|Shift-Backspace|Backspace|Ctrl-H"),exec:function(l){l.remove("left")},multiSelectAction:"forEach",scrollIntoView:"cursor"},{name:"cut_or_delete",bindKey:d("Shift-Delete",null),exec:function(l){if(l.selection.isEmpty())l.remove("left");else return!1},multiSelectAction:"forEach",scrollIntoView:"cursor"},{name:"removetolinestart",bindKey:d("Alt-Backspace","Command-Backspace"),exec:function(l){l.removeToLineStart()},multiSelectAction:"forEach",scrollIntoView:"cursor"},{name:"removetolineend",bindKey:d("Alt-Delete","Ctrl-K"),exec:function(l){l.removeToLineEnd()},multiSelectAction:"forEach",scrollIntoView:"cursor"},{name:"removewordleft",bindKey:d("Ctrl-Backspace","Alt-Backspace|Ctrl-Alt-Backspace"),exec:function(l){l.removeWordLeft()},multiSelectAction:"forEach",scrollIntoView:"cursor"},{name:"removewordright",bindKey:d("Ctrl-Delete","Alt-Delete"),exec:function(l){l.removeWordRight()},multiSelectAction:"forEach",scrollIntoView:"cursor"},{name:"outdent",bindKey:d("Shift-Tab","Shift-Tab"),exec:function(l){l.blockOutdent()},multiSelectAction:"forEach",scrollIntoView:"selectionPart"},{name:"indent",bindKey:d("Tab","Tab"),exec:function(l){l.indent()},multiSelectAction:"forEach",scrollIntoView:"selectionPart"},{name:"blockoutdent",bindKey:d("Ctrl-[","Ctrl-["),exec:function(l){l.blockOutdent()},multiSelectAction:"forEachLine",scrollIntoView:"selectionPart"},{name:"blockindent",bindKey:d("Ctrl-]","Ctrl-]"),exec:function(l){l.blockIndent()},multiSelectAction:"forEachLine",scrollIntoView:"selectionPart"},{name:"insertstring",exec:function(l,c){l.insert(c)},multiSelectAction:"forEach",scrollIntoView:"cursor"},{name:"inserttext",exec:function(l,c){l.insert(n.stringRepeat(c.text||"",c.times||1))},multiSelectAction:"forEach",scrollIntoView:"cursor"},{name:"splitline",bindKey:d(null,"Ctrl-O"),exec:function(l){l.splitLine()},multiSelectAction:"forEach",scrollIntoView:"cursor"},{name:"transposeletters",bindKey:d("Ctrl-T","Ctrl-T"),exec:function(l){l.transposeLetters()},multiSelectAction:function(l){l.transposeSelections(1)},scrollIntoView:"cursor"},{name:"touppercase",bindKey:d("Ctrl-U","Ctrl-U"),exec:function(l){l.toUpperCase()},multiSelectAction:"forEach",scrollIntoView:"cursor"},{name:"tolowercase",bindKey:d("Ctrl-Shift-U","Ctrl-Shift-U"),exec:function(l){l.toLowerCase()},multiSelectAction:"forEach",scrollIntoView:"cursor"},{name:"expandtoline",bindKey:d("Ctrl-Shift-L","Command-Shift-L"),exec:function(l){var c=l.selection.getRange();c.start.column=c.end.column=0,c.end.row++,l.selection.setRange(c,!1)},multiSelectAction:"forEach",scrollIntoView:"cursor",readOnly:!0},{name:"joinlines",bindKey:d(null,null),exec:function(l){for(var c=l.selection.isBackwards(),a=c?l.selection.getSelectionLead():l.selection.getSelectionAnchor(),F=c?l.selection.getSelectionAnchor():l.selection.getSelectionLead(),p=l.session.doc.getLine(a.row).length,m=l.session.doc.getTextRange(l.selection.getRange()),b=m.replace(/\n\s*/," ").length,C=l.session.doc.getLine(a.row),k=a.row+1;k<=F.row+1;k++){var T=n.stringTrimLeft(n.stringTrimRight(l.session.doc.getLine(k)));T.length!==0&&(T=" "+T),C+=T}F.row+1<l.session.doc.getLength()-1&&(C+=l.session.doc.getNewLineCharacter()),l.clearSelection(),l.session.doc.replace(new g(a.row,0,F.row+2,0),C),b>0?(l.selection.moveCursorTo(a.row,a.column),l.selection.selectTo(a.row,a.column+b)):(p=l.session.doc.getLine(a.row).length>p?p+1:p,l.selection.moveCursorTo(a.row,p))},multiSelectAction:"forEach",readOnly:!0},{name:"invertSelection",bindKey:d(null,null),exec:function(l){var c=l.session.doc.getLength()-1,a=l.session.doc.getLine(c).length,F=l.selection.rangeList.ranges,p=[];F.length<1&&(F=[l.selection.getRange()]);for(var m=0;m<F.length;m++)m==F.length-1&&(F[m].end.row===c&&F[m].end.column===a||p.push(new g(F[m].end.row,F[m].end.column,c,a))),m===0?F[m].start.row===0&&F[m].start.column===0||p.push(new g(0,0,F[m].start.row,F[m].start.column)):p.push(new g(F[m-1].end.row,F[m-1].end.column,F[m].start.row,F[m].start.column));l.exitMultiSelectMode(),l.clearSelection();for(var m=0;m<p.length;m++)l.selection.addRange(p[m],!1)},readOnly:!0,scrollIntoView:"none"}]}),ace.define("ace/editor",["require","exports","module","ace/lib/fixoldbrowsers","ace/lib/oop","ace/lib/dom","ace/lib/lang","ace/lib/useragent","ace/keyboard/textinput","ace/mouse/mouse_handler","ace/mouse/fold_handler","ace/keyboard/keybinding","ace/edit_session","ace/search","ace/range","ace/lib/event_emitter","ace/commands/command_manager","ace/commands/default_commands","ace/config","ace/token_iterator"],function(s,o,f){s("./lib/fixoldbrowsers");var n=s("./lib/oop"),h=s("./lib/dom"),g=s("./lib/lang"),d=s("./lib/useragent"),l=s("./keyboard/textinput").TextInput,c=s("./mouse/mouse_handler").MouseHandler,a=s("./mouse/fold_handler").FoldHandler,F=s("./keyboard/keybinding").KeyBinding,p=s("./edit_session").EditSession,m=s("./search").Search,b=s("./range").Range,C=s("./lib/event_emitter").EventEmitter,k=s("./commands/command_manager").CommandManager,T=s("./commands/default_commands").commands,w=s("./config"),A=s("./token_iterator").TokenIterator,M=function(x,R){var N=x.getContainerElement();this.container=N,this.renderer=x,this.commands=new k(d.isMac?"mac":"win",T),this.textInput=new l(x.getTextAreaContainer(),this),this.renderer.textarea=this.textInput.getElement(),this.keyBinding=new F(this),this.$mouseHandler=new c(this),new a(this),this.$blockScrolling=0,this.$search=new m().set({wrap:!0}),this.$historyTracker=this.$historyTracker.bind(this),this.commands.on("exec",this.$historyTracker),this.$initOperationListeners(),this._$emitInputEvent=g.delayedCall(function(){this._signal("input",{}),this.session&&this.session.bgTokenizer&&this.session.bgTokenizer.scheduleStart()}.bind(this)),this.on("change",function(j,B){B._$emitInputEvent.schedule(31)}),this.setSession(R||new p("")),w.resetOptions(this),w._signal("editor",this)};(function(){n.implement(this,C),this.$initOperationListeners=function(){this.selections=[],this.commands.on("exec",this.startOperation.bind(this),!0),this.commands.on("afterExec",this.endOperation.bind(this),!0),this.$opResetTimer=g.delayedCall(this.endOperation.bind(this)),this.on("change",function(){this.curOp||this.startOperation(),this.curOp.docChanged=!0}.bind(this),!0),this.on("changeSelection",function(){this.curOp||this.startOperation(),this.curOp.selectionChanged=!0}.bind(this),!0)},this.curOp=null,this.prevOp={},this.startOperation=function(x){if(this.curOp){if(!x||this.curOp.command)return;this.prevOp=this.curOp}x||(this.previousCommand=null,x={}),this.$opResetTimer.schedule(),this.curOp={command:x.command||{},args:x.args,scrollTop:this.renderer.scrollTop},this.curOp.command.name&&this.curOp.command.scrollIntoView!==void 0&&this.$blockScrolling++},this.endOperation=function(x){if(this.curOp){if(x&&x.returnValue===!1)return this.curOp=null;this._signal("beforeEndOperation");var R=this.curOp.command;R.name&&this.$blockScrolling>0&&this.$blockScrolling--;var N=R&&R.scrollIntoView;if(N){switch(N){case"center-animate":N="animate";case"center":this.renderer.scrollCursorIntoView(null,.5);break;case"animate":case"cursor":this.renderer.scrollCursorIntoView();break;case"selectionPart":var j=this.selection.getRange(),B=this.renderer.layerConfig;(j.start.row>=B.lastRow||j.end.row<=B.firstRow)&&this.renderer.scrollSelectionIntoView(this.selection.anchor,this.selection.lead);break}N=="animate"&&this.renderer.animateScrolling(this.curOp.scrollTop)}this.prevOp=this.curOp,this.curOp=null}},this.$mergeableCommands=["backspace","del","insertstring"],this.$historyTracker=function(x){if(this.$mergeUndoDeltas){var R=this.prevOp,N=this.$mergeableCommands,j=R.command&&x.command.name==R.command.name;if(x.command.name=="insertstring"){var B=x.args;this.mergeNextCommand===void 0&&(this.mergeNextCommand=!0),j=j&&this.mergeNextCommand&&(!/\s/.test(B)||/\s/.test(R.args)),this.mergeNextCommand=!0}else j=j&&N.indexOf(x.command.name)!==-1;this.$mergeUndoDeltas!="always"&&Date.now()-this.sequenceStartTime>2e3&&(j=!1),j?this.session.mergeUndoDeltas=!0:N.indexOf(x.command.name)!==-1&&(this.sequenceStartTime=Date.now())}},this.setKeyboardHandler=function(x,R){if(x&&typeof x=="string"){this.$keybindingId=x;var N=this;w.loadModule(["keybinding",x],function(j){N.$keybindingId==x&&N.keyBinding.setKeyboardHandler(j&&j.handler),R&&R()})}else this.$keybindingId=null,this.keyBinding.setKeyboardHandler(x),R&&R()},this.getKeyboardHandler=function(){return this.keyBinding.getKeyboardHandler()},this.setSession=function(x){if(this.session!=x){this.curOp&&this.endOperation(),this.curOp={};var R=this.session;if(R){this.session.off("change",this.$onDocumentChange),this.session.off("changeMode",this.$onChangeMode),this.session.off("tokenizerUpdate",this.$onTokenizerUpdate),this.session.off("changeTabSize",this.$onChangeTabSize),this.session.off("changeWrapLimit",this.$onChangeWrapLimit),this.session.off("changeWrapMode",this.$onChangeWrapMode),this.session.off("changeFold",this.$onChangeFold),this.session.off("changeFrontMarker",this.$onChangeFrontMarker),this.session.off("changeBackMarker",this.$onChangeBackMarker),this.session.off("changeBreakpoint",this.$onChangeBreakpoint),this.session.off("changeAnnotation",this.$onChangeAnnotation),this.session.off("changeOverwrite",this.$onCursorChange),this.session.off("changeScrollTop",this.$onScrollTopChange),this.session.off("changeScrollLeft",this.$onScrollLeftChange);var N=this.session.getSelection();N.off("changeCursor",this.$onCursorChange),N.off("changeSelection",this.$onSelectionChange)}this.session=x,x?(this.$onDocumentChange=this.onDocumentChange.bind(this),x.on("change",this.$onDocumentChange),this.renderer.setSession(x),this.$onChangeMode=this.onChangeMode.bind(this),x.on("changeMode",this.$onChangeMode),this.$onTokenizerUpdate=this.onTokenizerUpdate.bind(this),x.on("tokenizerUpdate",this.$onTokenizerUpdate),this.$onChangeTabSize=this.renderer.onChangeTabSize.bind(this.renderer),x.on("changeTabSize",this.$onChangeTabSize),this.$onChangeWrapLimit=this.onChangeWrapLimit.bind(this),x.on("changeWrapLimit",this.$onChangeWrapLimit),this.$onChangeWrapMode=this.onChangeWrapMode.bind(this),x.on("changeWrapMode",this.$onChangeWrapMode),this.$onChangeFold=this.onChangeFold.bind(this),x.on("changeFold",this.$onChangeFold),this.$onChangeFrontMarker=this.onChangeFrontMarker.bind(this),this.session.on("changeFrontMarker",this.$onChangeFrontMarker),this.$onChangeBackMarker=this.onChangeBackMarker.bind(this),this.session.on("changeBackMarker",this.$onChangeBackMarker),this.$onChangeBreakpoint=this.onChangeBreakpoint.bind(this),this.session.on("changeBreakpoint",this.$onChangeBreakpoint),this.$onChangeAnnotation=this.onChangeAnnotation.bind(this),this.session.on("changeAnnotation",this.$onChangeAnnotation),this.$onCursorChange=this.onCursorChange.bind(this),this.session.on("changeOverwrite",this.$onCursorChange),this.$onScrollTopChange=this.onScrollTopChange.bind(this),this.session.on("changeScrollTop",this.$onScrollTopChange),this.$onScrollLeftChange=this.onScrollLeftChange.bind(this),this.session.on("changeScrollLeft",this.$onScrollLeftChange),this.selection=x.getSelection(),this.selection.on("changeCursor",this.$onCursorChange),this.$onSelectionChange=this.onSelectionChange.bind(this),this.selection.on("changeSelection",this.$onSelectionChange),this.onChangeMode(),this.$blockScrolling+=1,this.onCursorChange(),this.$blockScrolling-=1,this.onScrollTopChange(),this.onScrollLeftChange(),this.onSelectionChange(),this.onChangeFrontMarker(),this.onChangeBackMarker(),this.onChangeBreakpoint(),this.onChangeAnnotation(),this.session.getUseWrapMode()&&this.renderer.adjustWrapLimit(),this.renderer.updateFull()):(this.selection=null,this.renderer.setSession(x)),this._signal("changeSession",{session:x,oldSession:R}),this.curOp=null,R&&R._signal("changeEditor",{oldEditor:this}),x&&x._signal("changeEditor",{editor:this})}},this.getSession=function(){return this.session},this.setValue=function(x,R){return this.session.doc.setValue(x),R?R==1?this.navigateFileEnd():R==-1&&this.navigateFileStart():this.selectAll(),x},this.getValue=function(){return this.session.getValue()},this.getSelection=function(){return this.selection},this.resize=function(x){this.renderer.onResize(x)},this.setTheme=function(x,R){this.renderer.setTheme(x,R)},this.getTheme=function(){return this.renderer.getTheme()},this.setStyle=function(x){this.renderer.setStyle(x)},this.unsetStyle=function(x){this.renderer.unsetStyle(x)},this.getFontSize=function(){return this.getOption("fontSize")||h.computedStyle(this.container,"fontSize")},this.setFontSize=function(x){this.setOption("fontSize",x)},this.$highlightBrackets=function(){if(this.session.$bracketHighlight&&(this.session.removeMarker(this.session.$bracketHighlight),this.session.$bracketHighlight=null),!this.$highlightPending){var x=this;this.$highlightPending=!0,setTimeout(function(){x.$highlightPending=!1;var R=x.session;if(!(!R||!R.bgTokenizer)){var N=R.findMatchingBracket(x.getCursorPosition());if(N)var j=new b(N.row,N.column,N.row,N.column+1);else if(R.$mode.getMatching)var j=R.$mode.getMatching(x.session);j&&(R.$bracketHighlight=R.addMarker(j,"ace_bracket","text"))}},50)}},this.$highlightTags=function(){if(!this.$highlightTagPending){var x=this;this.$highlightTagPending=!0,setTimeout(function(){x.$highlightTagPending=!1;var R=x.session;if(!(!R||!R.bgTokenizer)){var N=x.getCursorPosition(),j=new A(x.session,N.row,N.column),B=j.getCurrentToken();if(!B||!/\b(?:tag-open|tag-name)/.test(B.type)){R.removeMarker(R.$tagHighlight),R.$tagHighlight=null;return}if(!(B.type.indexOf("tag-open")!=-1&&(B=j.stepForward(),!B))){var q=B.value,U=0,Z=j.stepBackward();if(Z.value=="<")do Z=B,B=j.stepForward(),B&&B.value===q&&B.type.indexOf("tag-name")!==-1&&(Z.value==="<"?U++:Z.value==="</"&&U--);while(B&&U>=0);else{do B=Z,Z=j.stepBackward(),B&&B.value===q&&B.type.indexOf("tag-name")!==-1&&(Z.value==="<"?U++:Z.value==="</"&&U--);while(Z&&U<=0);j.stepForward()}if(!B){R.removeMarker(R.$tagHighlight),R.$tagHighlight=null;return}var re=j.getCurrentTokenRow(),le=j.getCurrentTokenColumn(),ce=new b(re,le,re,le+B.value.length),de=R.$backMarkers[R.$tagHighlight];R.$tagHighlight&&de!=null&&ce.compareRange(de.range)!==0&&(R.removeMarker(R.$tagHighlight),R.$tagHighlight=null),ce&&!R.$tagHighlight&&(R.$tagHighlight=R.addMarker(ce,"ace_bracket","text"))}}},50)}},this.focus=function(){var x=this;setTimeout(function(){x.textInput.focus()}),this.textInput.focus()},this.isFocused=function(){return this.textInput.isFocused()},this.blur=function(){this.textInput.blur()},this.onFocus=function(x){this.$isFocused||(this.$isFocused=!0,this.renderer.showCursor(),this.renderer.visualizeFocus(),this._emit("focus",x))},this.onBlur=function(x){this.$isFocused&&(this.$isFocused=!1,this.renderer.hideCursor(),this.renderer.visualizeBlur(),this._emit("blur",x))},this.$cursorChange=function(){this.renderer.updateCursor()},this.onDocumentChange=function(x){var R=this.session.$useWrapMode,N=x.start.row==x.end.row?x.end.row:1/0;this.renderer.updateLines(x.start.row,N,R),this._signal("change",x),this.$cursorChange(),this.$updateHighlightActiveLine()},this.onTokenizerUpdate=function(x){var R=x.data;this.renderer.updateLines(R.first,R.last)},this.onScrollTopChange=function(){this.renderer.scrollToY(this.session.getScrollTop())},this.onScrollLeftChange=function(){this.renderer.scrollToX(this.session.getScrollLeft())},this.onCursorChange=function(){this.$cursorChange(),this.$blockScrolling||(w.warn("Automatically scrolling cursor into view after selection change","this will be disabled in the next version","set editor.$blockScrolling = Infinity to disable this message"),this.renderer.scrollCursorIntoView()),this.$highlightBrackets(),this.$highlightTags(),this.$updateHighlightActiveLine(),this._signal("changeSelection")},this.$updateHighlightActiveLine=function(){var x=this.getSession(),R;if(this.$highlightActiveLine&&((this.$selectionStyle!="line"||!this.selection.isMultiLine())&&(R=this.getCursorPosition()),this.renderer.$maxLines&&this.session.getLength()===1&&!(this.renderer.$minLines>1)&&(R=!1)),x.$highlightLineMarker&&!R)x.removeMarker(x.$highlightLineMarker.id),x.$highlightLineMarker=null;else if(!x.$highlightLineMarker&&R){var N=new b(R.row,R.column,R.row,1/0);N.id=x.addMarker(N,"ace_active-line","screenLine"),x.$highlightLineMarker=N}else R&&(x.$highlightLineMarker.start.row=R.row,x.$highlightLineMarker.end.row=R.row,x.$highlightLineMarker.start.column=R.column,x._signal("changeBackMarker"))},this.onSelectionChange=function(x){var R=this.session;if(R.$selectionMarker&&R.removeMarker(R.$selectionMarker),R.$selectionMarker=null,this.selection.isEmpty())this.$updateHighlightActiveLine();else{var N=this.selection.getRange(),j=this.getSelectionStyle();R.$selectionMarker=R.addMarker(N,"ace_selection",j)}var B=this.$highlightSelectedWord&&this.$getSelectionHighLightRegexp();this.session.highlight(B),this._signal("changeSelection")},this.$getSelectionHighLightRegexp=function(){var x=this.session,R=this.getSelectionRange();if(!(R.isEmpty()||R.isMultiLine())){var N=R.start.column-1,j=R.end.column+1,B=x.getLine(R.start.row),q=B.length,U=B.substring(Math.max(N,0),Math.min(j,q));if(!(N>=0&&/^[\w\d]/.test(U)||j<=q&&/[\w\d]$/.test(U))&&(U=B.substring(R.start.column,R.end.column),!!/^[\w\d]+$/.test(U))){var Z=this.$search.$assembleRegExp({wholeWord:!0,caseSensitive:!0,needle:U});return Z}}},this.onChangeFrontMarker=function(){this.renderer.updateFrontMarkers()},this.onChangeBackMarker=function(){this.renderer.updateBackMarkers()},this.onChangeBreakpoint=function(){this.renderer.updateBreakpoints()},this.onChangeAnnotation=function(){this.renderer.setAnnotations(this.session.getAnnotations())},this.onChangeMode=function(x){this.renderer.updateText(),this._emit("changeMode",x)},this.onChangeWrapLimit=function(){this.renderer.updateFull()},this.onChangeWrapMode=function(){this.renderer.onResize(!0)},this.onChangeFold=function(){this.$updateHighlightActiveLine(),this.renderer.updateFull()},this.getSelectedText=function(){return this.session.getTextRange(this.getSelectionRange())},this.getCopyText=function(){var x=this.getSelectedText();return this._signal("copy",x),x},this.onCopy=function(){this.commands.exec("copy",this)},this.onCut=function(){this.commands.exec("cut",this)},this.onPaste=function(x,R){var N={text:x,event:R};this.commands.exec("paste",this,N)},this.$handlePaste=function(x){typeof x=="string"&&(x={text:x}),this._signal("paste",x);var R=x.text;if(!this.inMultiSelectMode||this.inVirtualSelectionMode)this.insert(R);else{var N=R.split(/\r\n|\r|\n/),j=this.selection.rangeList.ranges;if(N.length>j.length||N.length<2||!N[1])return this.commands.exec("insertstring",this,R);for(var B=j.length;B--;){var q=j[B];q.isEmpty()||this.session.remove(q),this.session.insert(q.start,N[B])}}},this.execCommand=function(x,R){return this.commands.exec(x,this,R)},this.insert=function(x,R){var N=this.session,j=N.getMode(),B=this.getCursorPosition();if(this.getBehavioursEnabled()&&!R){var q=j.transformAction(N.getState(B.row),"insertion",this,N,x);q&&(x!==q.text&&(this.session.mergeUndoDeltas=!1,this.$mergeNextCommand=!1),x=q.text)}if(x=="	"&&(x=this.session.getTabString()),this.selection.isEmpty()){if(this.session.getOverwrite()){var U=new b.fromPoints(B,B);U.end.column+=x.length,this.session.remove(U)}}else{var U=this.getSelectionRange();B=this.session.remove(U),this.clearSelection()}if(x==`
`||x==`\r
`){var ce=N.getLine(B.row);if(B.column>ce.search(/\S|$/)){var Z=ce.substr(B.column).search(/\S|$/);N.doc.removeInLine(B.row,B.column,B.column+Z)}}this.clearSelection();var re=B.column,le=N.getState(B.row),ce=N.getLine(B.row),de=j.checkOutdent(le,ce,x);if(N.insert(B,x),q&&q.selection&&(q.selection.length==2?this.selection.setSelectionRange(new b(B.row,re+q.selection[0],B.row,re+q.selection[1])):this.selection.setSelectionRange(new b(B.row+q.selection[0],q.selection[1],B.row+q.selection[2],q.selection[3]))),N.getDocument().isNewLine(x)){var he=j.getNextLineIndent(le,ce.slice(0,B.column),N.getTabString());N.insert({row:B.row+1,column:0},he)}de&&j.autoOutdent(le,N,B.row)},this.onTextInput=function(x){this.keyBinding.onTextInput(x)},this.onCommandKey=function(x,R,N){this.keyBinding.onCommandKey(x,R,N)},this.setOverwrite=function(x){this.session.setOverwrite(x)},this.getOverwrite=function(){return this.session.getOverwrite()},this.toggleOverwrite=function(){this.session.toggleOverwrite()},this.setScrollSpeed=function(x){this.setOption("scrollSpeed",x)},this.getScrollSpeed=function(){return this.getOption("scrollSpeed")},this.setDragDelay=function(x){this.setOption("dragDelay",x)},this.getDragDelay=function(){return this.getOption("dragDelay")},this.setSelectionStyle=function(x){this.setOption("selectionStyle",x)},this.getSelectionStyle=function(){return this.getOption("selectionStyle")},this.setHighlightActiveLine=function(x){this.setOption("highlightActiveLine",x)},this.getHighlightActiveLine=function(){return this.getOption("highlightActiveLine")},this.setHighlightGutterLine=function(x){this.setOption("highlightGutterLine",x)},this.getHighlightGutterLine=function(){return this.getOption("highlightGutterLine")},this.setHighlightSelectedWord=function(x){this.setOption("highlightSelectedWord",x)},this.getHighlightSelectedWord=function(){return this.$highlightSelectedWord},this.setAnimatedScroll=function(x){this.renderer.setAnimatedScroll(x)},this.getAnimatedScroll=function(){return this.renderer.getAnimatedScroll()},this.setShowInvisibles=function(x){this.renderer.setShowInvisibles(x)},this.getShowInvisibles=function(){return this.renderer.getShowInvisibles()},this.setDisplayIndentGuides=function(x){this.renderer.setDisplayIndentGuides(x)},this.getDisplayIndentGuides=function(){return this.renderer.getDisplayIndentGuides()},this.setShowPrintMargin=function(x){this.renderer.setShowPrintMargin(x)},this.getShowPrintMargin=function(){return this.renderer.getShowPrintMargin()},this.setPrintMarginColumn=function(x){this.renderer.setPrintMarginColumn(x)},this.getPrintMarginColumn=function(){return this.renderer.getPrintMarginColumn()},this.setReadOnly=function(x){this.setOption("readOnly",x)},this.getReadOnly=function(){return this.getOption("readOnly")},this.setBehavioursEnabled=function(x){this.setOption("behavioursEnabled",x)},this.getBehavioursEnabled=function(){return this.getOption("behavioursEnabled")},this.setWrapBehavioursEnabled=function(x){this.setOption("wrapBehavioursEnabled",x)},this.getWrapBehavioursEnabled=function(){return this.getOption("wrapBehavioursEnabled")},this.setShowFoldWidgets=function(x){this.setOption("showFoldWidgets",x)},this.getShowFoldWidgets=function(){return this.getOption("showFoldWidgets")},this.setFadeFoldWidgets=function(x){this.setOption("fadeFoldWidgets",x)},this.getFadeFoldWidgets=function(){return this.getOption("fadeFoldWidgets")},this.remove=function(x){this.selection.isEmpty()&&(x=="left"?this.selection.selectLeft():this.selection.selectRight());var R=this.getSelectionRange();if(this.getBehavioursEnabled()){var N=this.session,j=N.getState(R.start.row),B=N.getMode().transformAction(j,"deletion",this,N,R);if(R.end.column===0){var q=N.getTextRange(R);if(q[q.length-1]==`
`){var U=N.getLine(R.end.row);/^\s+$/.test(U)&&(R.end.column=U.length)}}B&&(R=B)}this.session.remove(R),this.clearSelection()},this.removeWordRight=function(){this.selection.isEmpty()&&this.selection.selectWordRight(),this.session.remove(this.getSelectionRange()),this.clearSelection()},this.removeWordLeft=function(){this.selection.isEmpty()&&this.selection.selectWordLeft(),this.session.remove(this.getSelectionRange()),this.clearSelection()},this.removeToLineStart=function(){this.selection.isEmpty()&&this.selection.selectLineStart(),this.session.remove(this.getSelectionRange()),this.clearSelection()},this.removeToLineEnd=function(){this.selection.isEmpty()&&this.selection.selectLineEnd();var x=this.getSelectionRange();x.start.column==x.end.column&&x.start.row==x.end.row&&(x.end.column=0,x.end.row++),this.session.remove(x),this.clearSelection()},this.splitLine=function(){this.selection.isEmpty()||(this.session.remove(this.getSelectionRange()),this.clearSelection());var x=this.getCursorPosition();this.insert(`
`),this.moveCursorToPosition(x)},this.transposeLetters=function(){if(this.selection.isEmpty()){var x=this.getCursorPosition(),R=x.column;if(R!==0){var N=this.session.getLine(x.row),j,B;R<N.length?(j=N.charAt(R)+N.charAt(R-1),B=new b(x.row,R-1,x.row,R+1)):(j=N.charAt(R-1)+N.charAt(R-2),B=new b(x.row,R-2,x.row,R)),this.session.replace(B,j)}}},this.toLowerCase=function(){var x=this.getSelectionRange();this.selection.isEmpty()&&this.selection.selectWord();var R=this.getSelectionRange(),N=this.session.getTextRange(R);this.session.replace(R,N.toLowerCase()),this.selection.setSelectionRange(x)},this.toUpperCase=function(){var x=this.getSelectionRange();this.selection.isEmpty()&&this.selection.selectWord();var R=this.getSelectionRange(),N=this.session.getTextRange(R);this.session.replace(R,N.toUpperCase()),this.selection.setSelectionRange(x)},this.indent=function(){var x=this.session,R=this.getSelectionRange();if(R.start.row<R.end.row){var N=this.$getSelectedRows();x.indentRows(N.first,N.last,"	");return}else if(R.start.column<R.end.column){var j=x.getTextRange(R);if(!/^\s+$/.test(j)){var N=this.$getSelectedRows();x.indentRows(N.first,N.last,"	");return}}var B=x.getLine(R.start.row),q=R.start,U=x.getTabSize(),Z=x.documentToScreenColumn(q.row,q.column);if(this.session.getUseSoftTabs())var re=U-Z%U,le=g.stringRepeat(" ",re);else{for(var re=Z%U;B[R.start.column-1]==" "&&re;)R.start.column--,re--;this.selection.setSelectionRange(R),le="	"}return this.insert(le)},this.blockIndent=function(){var x=this.$getSelectedRows();this.session.indentRows(x.first,x.last,"	")},this.blockOutdent=function(){var x=this.session.getSelection();this.session.outdentRows(x.getRange())},this.sortLines=function(){var x=this.$getSelectedRows(),R=this.session,N=[];for(B=x.first;B<=x.last;B++)N.push(R.getLine(B));N.sort(function(U,Z){return U.toLowerCase()<Z.toLowerCase()?-1:U.toLowerCase()>Z.toLowerCase()?1:0});for(var j=new b(0,0,0,0),B=x.first;B<=x.last;B++){var q=R.getLine(B);j.start.row=B,j.end.row=B,j.end.column=q.length,R.replace(j,N[B-x.first])}},this.toggleCommentLines=function(){var x=this.session.getState(this.getCursorPosition().row),R=this.$getSelectedRows();this.session.getMode().toggleCommentLines(x,this.session,R.first,R.last)},this.toggleBlockComment=function(){var x=this.getCursorPosition(),R=this.session.getState(x.row),N=this.getSelectionRange();this.session.getMode().toggleBlockComment(R,this.session,N,x)},this.getNumberAt=function(x,R){var N=/[\-]?[0-9]+(?:\.[0-9]+)?/g;N.lastIndex=0;for(var j=this.session.getLine(x);N.lastIndex<R;){var B=N.exec(j);if(B.index<=R&&B.index+B[0].length>=R){var q={value:B[0],start:B.index,end:B.index+B[0].length};return q}}return null},this.modifyNumber=function(x){var R=this.selection.getCursor().row,N=this.selection.getCursor().column,j=new b(R,N-1,R,N),B=this.session.getTextRange(j);if(!isNaN(parseFloat(B))&&isFinite(B)){var q=this.getNumberAt(R,N);if(q){var U=q.value.indexOf(".")>=0?q.start+q.value.indexOf(".")+1:q.end,Z=q.start+q.value.length-U,re=parseFloat(q.value);re*=Math.pow(10,Z),U!==q.end&&N<U?x*=Math.pow(10,q.end-N-1):x*=Math.pow(10,q.end-N),re+=x,re/=Math.pow(10,Z);var le=re.toFixed(Z),ce=new b(R,q.start,R,q.end);this.session.replace(ce,le),this.moveCursorTo(R,Math.max(q.start+1,N+le.length-q.value.length))}}},this.removeLines=function(){var x=this.$getSelectedRows();this.session.removeFullLines(x.first,x.last),this.clearSelection()},this.duplicateSelection=function(){var x=this.selection,R=this.session,N=x.getRange(),j=x.isBackwards();if(N.isEmpty()){var B=N.start.row;R.duplicateLines(B,B)}else{var q=j?N.start:N.end,U=R.insert(q,R.getTextRange(N),!1);N.start=q,N.end=U,x.setSelectionRange(N,j)}},this.moveLinesDown=function(){this.$moveLines(1,!1)},this.moveLinesUp=function(){this.$moveLines(-1,!1)},this.moveText=function(x,R,N){return this.session.moveText(x,R,N)},this.copyLinesUp=function(){this.$moveLines(-1,!0)},this.copyLinesDown=function(){this.$moveLines(1,!0)},this.$moveLines=function(x,R){var N,j,B=this.selection;if(!B.inMultiSelectMode||this.inVirtualSelectionMode){var q=B.toOrientedRange();N=this.$getSelectedRows(q),j=this.session.$moveLines(N.first,N.last,R?0:x),R&&x==-1&&(j=0),q.moveBy(j,0),B.fromOrientedRange(q)}else{var U=B.rangeList.ranges;B.rangeList.detach(this.session),this.inVirtualSelectionMode=!0;for(var Z=0,re=0,le=U.length,ce=0;ce<le;ce++){var de=ce;U[ce].moveBy(Z,0),N=this.$getSelectedRows(U[ce]);for(var he=N.first,Fe=N.last;++ce<le;){re&&U[ce].moveBy(re,0);var ge=this.$getSelectedRows(U[ce]);if(R&&ge.first!=Fe)break;if(!R&&ge.first>Fe+1)break;Fe=ge.last}for(ce--,Z=this.session.$moveLines(he,Fe,R?0:x),R&&x==-1&&(de=ce+1);de<=ce;)U[de].moveBy(Z,0),de++;R||(Z=0),re+=Z}B.fromOrientedRange(B.ranges[0]),B.rangeList.attach(this.session),this.inVirtualSelectionMode=!1}},this.$getSelectedRows=function(x){return x=(x||this.getSelectionRange()).collapseRows(),{first:this.session.getRowFoldStart(x.start.row),last:this.session.getRowFoldEnd(x.end.row)}},this.onCompositionStart=function(x){this.renderer.showComposition(this.getCursorPosition())},this.onCompositionUpdate=function(x){this.renderer.setCompositionText(x)},this.onCompositionEnd=function(){this.renderer.hideComposition()},this.getFirstVisibleRow=function(){return this.renderer.getFirstVisibleRow()},this.getLastVisibleRow=function(){return this.renderer.getLastVisibleRow()},this.isRowVisible=function(x){return x>=this.getFirstVisibleRow()&&x<=this.getLastVisibleRow()},this.isRowFullyVisible=function(x){return x>=this.renderer.getFirstFullyVisibleRow()&&x<=this.renderer.getLastFullyVisibleRow()},this.$getVisibleRowCount=function(){return this.renderer.getScrollBottomRow()-this.renderer.getScrollTopRow()+1},this.$moveByPage=function(x,R){var N=this.renderer,j=this.renderer.layerConfig,B=x*Math.floor(j.height/j.lineHeight);this.$blockScrolling++,R===!0?this.selection.$moveSelection(function(){this.moveCursorBy(B,0)}):R===!1&&(this.selection.moveCursorBy(B,0),this.selection.clearSelection()),this.$blockScrolling--;var q=N.scrollTop;N.scrollBy(0,B*j.lineHeight),R!=null&&N.scrollCursorIntoView(null,.5),N.animateScrolling(q)},this.selectPageDown=function(){this.$moveByPage(1,!0)},this.selectPageUp=function(){this.$moveByPage(-1,!0)},this.gotoPageDown=function(){this.$moveByPage(1,!1)},this.gotoPageUp=function(){this.$moveByPage(-1,!1)},this.scrollPageDown=function(){this.$moveByPage(1)},this.scrollPageUp=function(){this.$moveByPage(-1)},this.scrollToRow=function(x){this.renderer.scrollToRow(x)},this.scrollToLine=function(x,R,N,j){this.renderer.scrollToLine(x,R,N,j)},this.centerSelection=function(){var x=this.getSelectionRange(),R={row:Math.floor(x.start.row+(x.end.row-x.start.row)/2),column:Math.floor(x.start.column+(x.end.column-x.start.column)/2)};this.renderer.alignCursor(R,.5)},this.getCursorPosition=function(){return this.selection.getCursor()},this.getCursorPositionScreen=function(){return this.session.documentToScreenPosition(this.getCursorPosition())},this.getSelectionRange=function(){return this.selection.getRange()},this.selectAll=function(){this.$blockScrolling+=1,this.selection.selectAll(),this.$blockScrolling-=1},this.clearSelection=function(){this.selection.clearSelection()},this.moveCursorTo=function(x,R){this.selection.moveCursorTo(x,R)},this.moveCursorToPosition=function(x){this.selection.moveCursorToPosition(x)},this.jumpToMatching=function(x,R){var N=this.getCursorPosition(),j=new A(this.session,N.row,N.column),B=j.getCurrentToken(),q=B||j.stepForward();if(q){var U,Z=!1,re={},le=N.column-q.start,ce,de={")":"(","(":"(","]":"[","[":"[","{":"{","}":"{"};do{if(q.value.match(/[{}()\[\]]/g)){for(;le<q.value.length&&!Z;le++)if(de[q.value[le]])switch(ce=de[q.value[le]]+"."+q.type.replace("rparen","lparen"),isNaN(re[ce])&&(re[ce]=0),q.value[le]){case"(":case"[":case"{":re[ce]++;break;case")":case"]":case"}":re[ce]--,re[ce]===-1&&(U="bracket",Z=!0);break}}else q&&q.type.indexOf("tag-name")!==-1&&(isNaN(re[q.value])&&(re[q.value]=0),B.value==="<"?re[q.value]++:B.value==="</"&&re[q.value]--,re[q.value]===-1&&(U="tag",Z=!0));Z||(B=q,q=j.stepForward(),le=0)}while(q&&!Z);if(U){var he,Fe;if(U==="bracket")he=this.session.getBracketRange(N),he||(he=new b(j.getCurrentTokenRow(),j.getCurrentTokenColumn()+le-1,j.getCurrentTokenRow(),j.getCurrentTokenColumn()+le-1),Fe=he.start,(R||Fe.row===N.row&&Math.abs(Fe.column-N.column)<2)&&(he=this.session.getBracketRange(Fe)));else if(U==="tag"){if(q&&q.type.indexOf("tag-name")!==-1)var ge=q.value;else return;if(he=new b(j.getCurrentTokenRow(),j.getCurrentTokenColumn()-2,j.getCurrentTokenRow(),j.getCurrentTokenColumn()-2),he.compare(N.row,N.column)===0){Z=!1;do q=B,B=j.stepBackward(),B&&(B.type.indexOf("tag-close")!==-1&&he.setEnd(j.getCurrentTokenRow(),j.getCurrentTokenColumn()+1),q.value===ge&&q.type.indexOf("tag-name")!==-1&&(B.value==="<"?re[ge]++:B.value==="</"&&re[ge]--,re[ge]===0&&(Z=!0)));while(B&&!Z)}q&&q.type.indexOf("tag-name")&&(Fe=he.start,Fe.row==N.row&&Math.abs(Fe.column-N.column)<2&&(Fe=he.end))}Fe=he&&he.cursor||Fe,Fe&&(x?he&&R?this.selection.setRange(he):he&&he.isEqual(this.getSelectionRange())?this.clearSelection():this.selection.selectTo(Fe.row,Fe.column):this.selection.moveTo(Fe.row,Fe.column))}}},this.gotoLine=function(x,R,N){this.selection.clearSelection(),this.session.unfold({row:x-1,column:R||0}),this.$blockScrolling+=1,this.exitMultiSelectMode&&this.exitMultiSelectMode(),this.moveCursorTo(x-1,R||0),this.$blockScrolling-=1,this.isRowFullyVisible(x-1)||this.scrollToLine(x-1,!0,N)},this.navigateTo=function(x,R){this.selection.moveTo(x,R)},this.navigateUp=function(x){if(this.selection.isMultiLine()&&!this.selection.isBackwards()){var R=this.selection.anchor.getPosition();return this.moveCursorToPosition(R)}this.selection.clearSelection(),this.selection.moveCursorBy(-x||-1,0)},this.navigateDown=function(x){if(this.selection.isMultiLine()&&this.selection.isBackwards()){var R=this.selection.anchor.getPosition();return this.moveCursorToPosition(R)}this.selection.clearSelection(),this.selection.moveCursorBy(x||1,0)},this.navigateLeft=function(x){if(this.selection.isEmpty())for(x=x||1;x--;)this.selection.moveCursorLeft();else{var R=this.getSelectionRange().start;this.moveCursorToPosition(R)}this.clearSelection()},this.navigateRight=function(x){if(this.selection.isEmpty())for(x=x||1;x--;)this.selection.moveCursorRight();else{var R=this.getSelectionRange().end;this.moveCursorToPosition(R)}this.clearSelection()},this.navigateLineStart=function(){this.selection.moveCursorLineStart(),this.clearSelection()},this.navigateLineEnd=function(){this.selection.moveCursorLineEnd(),this.clearSelection()},this.navigateFileEnd=function(){this.selection.moveCursorFileEnd(),this.clearSelection()},this.navigateFileStart=function(){this.selection.moveCursorFileStart(),this.clearSelection()},this.navigateWordRight=function(){this.selection.moveCursorWordRight(),this.clearSelection()},this.navigateWordLeft=function(){this.selection.moveCursorWordLeft(),this.clearSelection()},this.replace=function(x,R){R&&this.$search.set(R);var N=this.$search.find(this.session),j=0;return N&&(this.$tryReplace(N,x)&&(j=1),N!==null&&(this.selection.setSelectionRange(N),this.renderer.scrollSelectionIntoView(N.start,N.end))),j},this.replaceAll=function(x,R){R&&this.$search.set(R);var N=this.$search.findAll(this.session),j=0;if(!N.length)return j;this.$blockScrolling+=1;var B=this.getSelectionRange();this.selection.moveTo(0,0);for(var q=N.length-1;q>=0;--q)this.$tryReplace(N[q],x)&&j++;return this.selection.setSelectionRange(B),this.$blockScrolling-=1,j},this.$tryReplace=function(x,R){var N=this.session.getTextRange(x);return R=this.$search.replace(N,R),R!==null?(x.end=this.session.replace(x,R),x):null},this.getLastSearchOptions=function(){return this.$search.getOptions()},this.find=function(x,R,N){R||(R={}),typeof x=="string"||x instanceof RegExp?R.needle=x:typeof x=="object"&&n.mixin(R,x);var j=this.selection.getRange();R.needle==null&&(x=this.session.getTextRange(j)||this.$search.$options.needle,x||(j=this.session.getWordRange(j.start.row,j.start.column),x=this.session.getTextRange(j)),this.$search.set({needle:x})),this.$search.set(R),R.start||this.$search.set({start:j});var B=this.$search.find(this.session);if(R.preventScroll)return B;if(B)return this.revealRange(B,N),B;R.backwards?j.start=j.end:j.end=j.start,this.selection.setRange(j)},this.findNext=function(x,R){this.find({skipCurrent:!0,backwards:!1},x,R)},this.findPrevious=function(x,R){this.find(x,{skipCurrent:!0,backwards:!0},R)},this.revealRange=function(x,R){this.$blockScrolling+=1,this.session.unfold(x),this.selection.setSelectionRange(x),this.$blockScrolling-=1;var N=this.renderer.scrollTop;this.renderer.scrollSelectionIntoView(x.start,x.end,.5),R!==!1&&this.renderer.animateScrolling(N)},this.undo=function(){this.$blockScrolling++,this.session.getUndoManager().undo(),this.$blockScrolling--,this.renderer.scrollCursorIntoView(null,.5)},this.redo=function(){this.$blockScrolling++,this.session.getUndoManager().redo(),this.$blockScrolling--,this.renderer.scrollCursorIntoView(null,.5)},this.destroy=function(){this.renderer.destroy(),this._signal("destroy",this),this.session&&this.session.destroy()},this.setAutoScrollEditorIntoView=function(x){if(x){var R,N=this,j=!1;this.$scrollAnchor||(this.$scrollAnchor=document.createElement("div"));var B=this.$scrollAnchor;B.style.cssText="position:absolute",this.container.insertBefore(B,this.container.firstChild);var q=this.on("changeSelection",function(){j=!0}),U=this.renderer.on("beforeRender",function(){j&&(R=N.renderer.container.getBoundingClientRect())}),Z=this.renderer.on("afterRender",function(){if(j&&R&&(N.isFocused()||N.searchBox&&N.searchBox.isFocused())){var re=N.renderer,le=re.$cursorLayer.$pixelPos,ce=re.layerConfig,de=le.top-ce.offset;le.top>=0&&de+R.top<0?j=!0:le.top<ce.height&&le.top+R.top+ce.lineHeight>window.innerHeight?j=!1:j=null,j!=null&&(B.style.top=de+"px",B.style.left=le.left+"px",B.style.height=ce.lineHeight+"px",B.scrollIntoView(j)),j=R=null}});this.setAutoScrollEditorIntoView=function(re){re||(delete this.setAutoScrollEditorIntoView,this.off("changeSelection",q),this.renderer.off("afterRender",Z),this.renderer.off("beforeRender",U))}}},this.$resetCursorStyle=function(){var x=this.$cursorStyle||"ace",R=this.renderer.$cursorLayer;R&&(R.setSmoothBlinking(/smooth/.test(x)),R.isBlinking=!this.$readOnly&&x!="wide",h.setCssClass(R.element,"ace_slim-cursors",/slim/.test(x)))}}).call(M.prototype),w.defineOptions(M.prototype,"editor",{selectionStyle:{set:function(x){this.onSelectionChange(),this._signal("changeSelectionStyle",{data:x})},initialValue:"line"},highlightActiveLine:{set:function(){this.$updateHighlightActiveLine()},initialValue:!0},highlightSelectedWord:{set:function(x){this.$onSelectionChange()},initialValue:!0},readOnly:{set:function(x){this.$resetCursorStyle()},initialValue:!1},cursorStyle:{set:function(x){this.$resetCursorStyle()},values:["ace","slim","smooth","wide"],initialValue:"ace"},mergeUndoDeltas:{values:[!1,!0,"always"],initialValue:!0},behavioursEnabled:{initialValue:!0},wrapBehavioursEnabled:{initialValue:!0},autoScrollEditorIntoView:{set:function(x){this.setAutoScrollEditorIntoView(x)}},keyboardHandler:{set:function(x){this.setKeyboardHandler(x)},get:function(){return this.keybindingId},handlesSet:!0},hScrollBarAlwaysVisible:"renderer",vScrollBarAlwaysVisible:"renderer",highlightGutterLine:"renderer",animatedScroll:"renderer",showInvisibles:"renderer",showPrintMargin:"renderer",printMarginColumn:"renderer",printMargin:"renderer",fadeFoldWidgets:"renderer",showFoldWidgets:"renderer",showLineNumbers:"renderer",showGutter:"renderer",displayIndentGuides:"renderer",fontSize:"renderer",fontFamily:"renderer",maxLines:"renderer",minLines:"renderer",scrollPastEnd:"renderer",fixedWidthGutter:"renderer",theme:"renderer",scrollSpeed:"$mouseHandler",dragDelay:"$mouseHandler",dragEnabled:"$mouseHandler",focusTimout:"$mouseHandler",tooltipFollowsMouse:"$mouseHandler",firstLineNumber:"session",overwrite:"session",newLineMode:"session",useWorker:"session",useSoftTabs:"session",tabSize:"session",wrap:"session",indentedSoftWrap:"session",foldStyle:"session",mode:"session"}),o.Editor=M}),ace.define("ace/undomanager",["require","exports","module"],function(s,o,f){var n=function(){this.reset()};(function(){this.execute=function(l){var c=l.args[0];this.$doc=l.args[1],l.merge&&this.hasUndo()&&(this.dirtyCounter--,c=this.$undoStack.pop().concat(c)),this.$undoStack.push(c),this.$redoStack=[],this.dirtyCounter<0&&(this.dirtyCounter=NaN),this.dirtyCounter++},this.undo=function(l){var c=this.$undoStack.pop(),a=null;return c&&(a=this.$doc.undoChanges(c,l),this.$redoStack.push(c),this.dirtyCounter--),a},this.redo=function(l){var c=this.$redoStack.pop(),a=null;return c&&(a=this.$doc.redoChanges(this.$deserializeDeltas(c),l),this.$undoStack.push(c),this.dirtyCounter++),a},this.reset=function(){this.$undoStack=[],this.$redoStack=[],this.dirtyCounter=0},this.hasUndo=function(){return this.$undoStack.length>0},this.hasRedo=function(){return this.$redoStack.length>0},this.markClean=function(){this.dirtyCounter=0},this.isClean=function(){return this.dirtyCounter===0},this.$serializeDeltas=function(l){return d(l,h)},this.$deserializeDeltas=function(l){return d(l,g)};function h(l){return{action:l.action,start:l.start,end:l.end,lines:l.lines.length==1?null:l.lines,text:l.lines.length==1?l.lines[0]:null}}function g(l){return{action:l.action,start:l.start,end:l.end,lines:l.lines||[l.text]}}function d(l,c){for(var a=new Array(l.length),F=0;F<l.length;F++){for(var p=l[F],m={group:p.group,deltas:new Array(p.length)},b=0;b<p.deltas.length;b++){var C=p.deltas[b];m.deltas[b]=c(C)}a[F]=m}return a}}).call(n.prototype),o.UndoManager=n}),ace.define("ace/layer/gutter",["require","exports","module","ace/lib/dom","ace/lib/oop","ace/lib/lang","ace/lib/event_emitter"],function(s,o,f){var n=s("../lib/dom"),h=s("../lib/oop"),g=s("../lib/lang"),d=s("../lib/event_emitter").EventEmitter,l=function(c){this.element=n.createElement("div"),this.element.className="ace_layer ace_gutter-layer",c.appendChild(this.element),this.setShowFoldWidgets(this.$showFoldWidgets),this.gutterWidth=0,this.$annotations=[],this.$updateAnnotations=this.$updateAnnotations.bind(this),this.$cells=[]};(function(){h.implement(this,d),this.setSession=function(c){this.session&&this.session.removeEventListener("change",this.$updateAnnotations),this.session=c,c&&c.on("change",this.$updateAnnotations)},this.addGutterDecoration=function(c,a){window.console&&console.warn&&console.warn("deprecated use session.addGutterDecoration"),this.session.addGutterDecoration(c,a)},this.removeGutterDecoration=function(c,a){window.console&&console.warn&&console.warn("deprecated use session.removeGutterDecoration"),this.session.removeGutterDecoration(c,a)},this.setAnnotations=function(c){this.$annotations=[];for(var a=0;a<c.length;a++){var F=c[a],p=F.row,m=this.$annotations[p];m||(m=this.$annotations[p]={text:[]});var b=F.text;b=b?g.escapeHTML(b):F.html||"",m.text.indexOf(b)===-1&&m.text.push(b);var C=F.type;C=="error"?m.className=" ace_error":C=="warning"&&m.className!=" ace_error"?m.className=" ace_warning":C=="info"&&!m.className&&(m.className=" ace_info")}},this.$updateAnnotations=function(c){if(this.$annotations.length){var a=c.start.row,F=c.end.row-a;if(F!==0)if(c.action=="remove")this.$annotations.splice(a,F+1,null);else{var p=new Array(F+1);p.unshift(a,1),this.$annotations.splice.apply(this.$annotations,p)}}},this.update=function(c){for(var a=this.session,F=c.firstRow,p=Math.min(c.lastRow+c.gutterOffset,a.getLength()-1),m=a.getNextFoldLine(F),b=m?m.start.row:1/0,C=this.$showFoldWidgets&&a.foldWidgets,k=a.$breakpoints,T=a.$decorations,w=a.$firstLineNumber,A=0,M=a.gutterRenderer||this.$renderer,x=null,R=-1,N=F;;){if(N>b&&(N=m.end.row+1,m=a.getNextFoldLine(N,m),b=m?m.start.row:1/0),N>p){for(;this.$cells.length>R+1;)x=this.$cells.pop(),this.element.removeChild(x.element);break}x=this.$cells[++R],x||(x={element:null,textNode:null,foldWidget:null},x.element=n.createElement("div"),x.textNode=document.createTextNode(""),x.element.appendChild(x.textNode),this.element.appendChild(x.element),this.$cells[R]=x);var j="ace_gutter-cell ";k[N]&&(j+=k[N]),T[N]&&(j+=T[N]),this.$annotations[N]&&(j+=this.$annotations[N].className),x.element.className!=j&&(x.element.className=j);var B=a.getRowLength(N)*c.lineHeight+"px";if(B!=x.element.style.height&&(x.element.style.height=B),C){var q=C[N];q==null&&(q=C[N]=a.getFoldWidget(N))}if(q){x.foldWidget||(x.foldWidget=n.createElement("span"),x.element.appendChild(x.foldWidget));var j="ace_fold-widget ace_"+q;q=="start"&&N==b&&N<m.end.row?j+=" ace_closed":j+=" ace_open",x.foldWidget.className!=j&&(x.foldWidget.className=j);var B=c.lineHeight+"px";x.foldWidget.style.height!=B&&(x.foldWidget.style.height=B)}else x.foldWidget&&(x.element.removeChild(x.foldWidget),x.foldWidget=null);var U=A=M?M.getText(a,N):N+w;U!=x.textNode.data&&(x.textNode.data=U),N++}this.element.style.height=c.minHeight+"px",(this.$fixedWidth||a.$useWrapMode)&&(A=a.getLength()+w);var Z=M?M.getWidth(a,A,c):A.toString().length*c.characterWidth,re=this.$padding||this.$computePadding();Z+=re.left+re.right,Z!==this.gutterWidth&&!isNaN(Z)&&(this.gutterWidth=Z,this.element.style.width=Math.ceil(this.gutterWidth)+"px",this._emit("changeGutterWidth",Z))},this.$fixedWidth=!1,this.$showLineNumbers=!0,this.$renderer="",this.setShowLineNumbers=function(c){this.$renderer=!c&&{getWidth:function(){return""},getText:function(){return""}}},this.getShowLineNumbers=function(){return this.$showLineNumbers},this.$showFoldWidgets=!0,this.setShowFoldWidgets=function(c){c?n.addCssClass(this.element,"ace_folding-enabled"):n.removeCssClass(this.element,"ace_folding-enabled"),this.$showFoldWidgets=c,this.$padding=null},this.getShowFoldWidgets=function(){return this.$showFoldWidgets},this.$computePadding=function(){if(!this.element.firstChild)return{left:0,right:0};var c=n.computedStyle(this.element.firstChild);return this.$padding={},this.$padding.left=parseInt(c.paddingLeft)+1||0,this.$padding.right=parseInt(c.paddingRight)||0,this.$padding},this.getRegion=function(c){var a=this.$padding||this.$computePadding(),F=this.element.getBoundingClientRect();if(c.x<a.left+F.left)return"markers";if(this.$showFoldWidgets&&c.x>F.right-a.right)return"foldWidgets"}}).call(l.prototype),o.Gutter=l}),ace.define("ace/layer/marker",["require","exports","module","ace/range","ace/lib/dom"],function(s,o,f){var n=s("../range").Range,h=s("../lib/dom"),g=function(d){this.element=h.createElement("div"),this.element.className="ace_layer ace_marker-layer",d.appendChild(this.element)};(function(){this.$padding=0,this.setPadding=function(l){this.$padding=l},this.setSession=function(l){this.session=l},this.setMarkers=function(l){this.markers=l},this.update=function(c){var c=c||this.config;if(c){this.config=c;var a=[];for(var F in this.markers){var p=this.markers[F];if(!p.range){p.update(a,this,this.session,c);continue}var m=p.range.clipRows(c.firstRow,c.lastRow);if(!m.isEmpty())if(m=m.toScreenRange(this.session),p.renderer){var b=this.$getTop(m.start.row,c),C=this.$padding+m.start.column*c.characterWidth;p.renderer(a,m,C,b,c)}else p.type=="fullLine"?this.drawFullLineMarker(a,m,p.clazz,c):p.type=="screenLine"?this.drawScreenLineMarker(a,m,p.clazz,c):m.isMultiLine()?p.type=="text"?this.drawTextMarker(a,m,p.clazz,c):this.drawMultiLineMarker(a,m,p.clazz,c):this.drawSingleLineMarker(a,m,p.clazz+" ace_start ace_br15",c)}this.element.innerHTML=a.join("")}},this.$getTop=function(l,c){return(l-c.firstRowScreen)*c.lineHeight};function d(l,c,a,F){return(l?1:0)|(c?2:0)|(a?4:0)|(F?8:0)}this.drawTextMarker=function(l,c,a,F,p){for(var m=this.session,b=c.start.row,C=c.end.row,k=b,T=0,w=0,A=m.getScreenLastRowColumn(k),M=new n(k,c.start.column,k,w);k<=C;k++)M.start.row=M.end.row=k,M.start.column=k==b?c.start.column:m.getRowWrapIndent(k),M.end.column=A,T=w,w=A,A=k+1<C?m.getScreenLastRowColumn(k+1):k==C?0:c.end.column,this.drawSingleLineMarker(l,M,a+(k==b?" ace_start":"")+" ace_br"+d(k==b||k==b+1&&c.start.column,T<w,w>A,k==C),F,k==C?0:1,p)},this.drawMultiLineMarker=function(l,c,a,F,p){var m=this.$padding,b=F.lineHeight,C=this.$getTop(c.start.row,F),k=m+c.start.column*F.characterWidth;p=p||"",l.push("<div class='",a," ace_br1 ace_start' style='","height:",b,"px;","right:0;","top:",C,"px;","left:",k,"px;",p,"'></div>"),C=this.$getTop(c.end.row,F);var T=c.end.column*F.characterWidth;if(l.push("<div class='",a," ace_br12' style='","height:",b,"px;","width:",T,"px;","top:",C,"px;","left:",m,"px;",p,"'></div>"),b=(c.end.row-c.start.row-1)*F.lineHeight,!(b<=0)){C=this.$getTop(c.start.row+1,F);var w=(c.start.column?1:0)|(c.end.column?0:8);l.push("<div class='",a,w?" ace_br"+w:"","' style='","height:",b,"px;","right:0;","top:",C,"px;","left:",m,"px;",p,"'></div>")}},this.drawSingleLineMarker=function(l,c,a,F,p,m){var b=F.lineHeight,C=(c.end.column+(p||0)-c.start.column)*F.characterWidth,k=this.$getTop(c.start.row,F),T=this.$padding+c.start.column*F.characterWidth;l.push("<div class='",a,"' style='","height:",b,"px;","width:",C,"px;","top:",k,"px;","left:",T,"px;",m||"","'></div>")},this.drawFullLineMarker=function(l,c,a,F,p){var m=this.$getTop(c.start.row,F),b=F.lineHeight;c.start.row!=c.end.row&&(b+=this.$getTop(c.end.row,F)-m),l.push("<div class='",a,"' style='","height:",b,"px;","top:",m,"px;","left:0;right:0;",p||"","'></div>")},this.drawScreenLineMarker=function(l,c,a,F,p){var m=this.$getTop(c.start.row,F),b=F.lineHeight;l.push("<div class='",a,"' style='","height:",b,"px;","top:",m,"px;","left:0;right:0;",p||"","'></div>")}}).call(g.prototype),o.Marker=g}),ace.define("ace/layer/text",["require","exports","module","ace/lib/oop","ace/lib/dom","ace/lib/lang","ace/lib/useragent","ace/lib/event_emitter"],function(s,o,f){var n=s("../lib/oop"),h=s("../lib/dom"),g=s("../lib/lang");s("../lib/useragent");var d=s("../lib/event_emitter").EventEmitter,l=function(c){this.element=h.createElement("div"),this.element.className="ace_layer ace_text-layer",c.appendChild(this.element),this.$updateEolChar=this.$updateEolChar.bind(this)};(function(){n.implement(this,d),this.EOF_CHAR="¶",this.EOL_CHAR_LF="¬",this.EOL_CHAR_CRLF="¤",this.EOL_CHAR=this.EOL_CHAR_LF,this.TAB_CHAR="—",this.SPACE_CHAR="·",this.$padding=0,this.$updateEolChar=function(){var c=this.session.doc.getNewLineCharacter()==`
`?this.EOL_CHAR_LF:this.EOL_CHAR_CRLF;if(this.EOL_CHAR!=c)return this.EOL_CHAR=c,!0},this.setPadding=function(c){this.$padding=c,this.element.style.padding="0 "+c+"px"},this.getLineHeight=function(){return this.$fontMetrics.$characterSize.height||0},this.getCharacterWidth=function(){return this.$fontMetrics.$characterSize.width||0},this.$setFontMetrics=function(c){this.$fontMetrics=c,this.$fontMetrics.on("changeCharacterSize",function(a){this._signal("changeCharacterSize",a)}.bind(this)),this.$pollSizeChanges()},this.checkForSizeChanges=function(){this.$fontMetrics.checkForSizeChanges()},this.$pollSizeChanges=function(){return this.$pollSizeChangesTimer=this.$fontMetrics.$pollSizeChanges()},this.setSession=function(c){this.session=c,c&&this.$computeTabString()},this.showInvisibles=!1,this.setShowInvisibles=function(c){return this.showInvisibles==c?!1:(this.showInvisibles=c,this.$computeTabString(),!0)},this.displayIndentGuides=!0,this.setDisplayIndentGuides=function(c){return this.displayIndentGuides==c?!1:(this.displayIndentGuides=c,this.$computeTabString(),!0)},this.$tabStrings=[],this.onChangeTabSize=this.$computeTabString=function(){var c=this.session.getTabSize();this.tabSize=c;for(var a=this.$tabStrings=[0],F=1;F<c+1;F++)this.showInvisibles?a.push("<span class='ace_invisible ace_invisible_tab'>"+g.stringRepeat(this.TAB_CHAR,F)+"</span>"):a.push(g.stringRepeat(" ",F));if(this.displayIndentGuides){this.$indentGuideRe=/\s\S| \t|\t |\s$/;var p="ace_indent-guide",m="",b="";if(this.showInvisibles){p+=" ace_invisible",m=" ace_invisible_space",b=" ace_invisible_tab";var C=g.stringRepeat(this.SPACE_CHAR,this.tabSize),k=g.stringRepeat(this.TAB_CHAR,this.tabSize)}else var C=g.stringRepeat(" ",this.tabSize),k=C;this.$tabStrings[" "]="<span class='"+p+m+"'>"+C+"</span>",this.$tabStrings["	"]="<span class='"+p+b+"'>"+k+"</span>"}},this.updateLines=function(c,a,F){(this.config.lastRow!=c.lastRow||this.config.firstRow!=c.firstRow)&&this.scrollLines(c),this.config=c;for(var p=Math.max(a,c.firstRow),m=Math.min(F,c.lastRow),b=this.element.childNodes,C=0,k=c.firstRow;k<p;k++){var T=this.session.getFoldLine(k);if(T)if(T.containsRow(p)){p=T.start.row;break}else k=T.end.row;C++}for(var k=p,T=this.session.getNextFoldLine(k),w=T?T.start.row:1/0;k>w&&(k=T.end.row+1,T=this.session.getNextFoldLine(k,T),w=T?T.start.row:1/0),!(k>m);){var A=b[C++];if(A){var M=[];this.$renderLine(M,k,!this.$useLineGroups(),k==w?T:!1),A.style.height=c.lineHeight*this.session.getRowLength(k)+"px",A.innerHTML=M.join("")}k++}},this.scrollLines=function(c){var a=this.config;if(this.config=c,!a||a.lastRow<c.firstRow)return this.update(c);if(c.lastRow<a.firstRow)return this.update(c);var F=this.element;if(a.firstRow<c.firstRow)for(var p=this.session.getFoldedRowCount(a.firstRow,c.firstRow-1);p>0;p--)F.removeChild(F.firstChild);if(a.lastRow>c.lastRow)for(var p=this.session.getFoldedRowCount(c.lastRow+1,a.lastRow);p>0;p--)F.removeChild(F.lastChild);if(c.firstRow<a.firstRow){var m=this.$renderLinesFragment(c,c.firstRow,a.firstRow-1);F.firstChild?F.insertBefore(m,F.firstChild):F.appendChild(m)}if(c.lastRow>a.lastRow){var m=this.$renderLinesFragment(c,a.lastRow+1,c.lastRow);F.appendChild(m)}},this.$renderLinesFragment=function(c,a,F){for(var p=this.element.ownerDocument.createDocumentFragment(),m=a,b=this.session.getNextFoldLine(m),C=b?b.start.row:1/0;m>C&&(m=b.end.row+1,b=this.session.getNextFoldLine(m,b),C=b?b.start.row:1/0),!(m>F);){var k=h.createElement("div"),T=[];if(this.$renderLine(T,m,!1,m==C?b:!1),k.innerHTML=T.join(""),this.$useLineGroups())k.className="ace_line_group",p.appendChild(k),k.style.height=c.lineHeight*this.session.getRowLength(m)+"px";else for(;k.firstChild;)p.appendChild(k.firstChild);m++}return p},this.update=function(c){this.config=c;for(var a=[],F=c.firstRow,p=c.lastRow,m=F,b=this.session.getNextFoldLine(m),C=b?b.start.row:1/0;m>C&&(m=b.end.row+1,b=this.session.getNextFoldLine(m,b),C=b?b.start.row:1/0),!(m>p);)this.$useLineGroups()&&a.push("<div class='ace_line_group' style='height:",c.lineHeight*this.session.getRowLength(m),"px'>"),this.$renderLine(a,m,!1,m==C?b:!1),this.$useLineGroups()&&a.push("</div>"),m++;this.element.innerHTML=a.join("")},this.$textToken={text:!0,rparen:!0,lparen:!0},this.$renderToken=function(c,a,F,p){var m=this,b=/\t|&|<|>|( +)|([\x00-\x1f\x80-\xa0\xad\u1680\u180E\u2000-\u200f\u2028\u2029\u202F\u205F\u3000\uFEFF\uFFF9-\uFFFC])|[\u1100-\u115F\u11A3-\u11A7\u11FA-\u11FF\u2329-\u232A\u2E80-\u2E99\u2E9B-\u2EF3\u2F00-\u2FD5\u2FF0-\u2FFB\u3000-\u303E\u3041-\u3096\u3099-\u30FF\u3105-\u312D\u3131-\u318E\u3190-\u31BA\u31C0-\u31E3\u31F0-\u321E\u3220-\u3247\u3250-\u32FE\u3300-\u4DBF\u4E00-\uA48C\uA490-\uA4C6\uA960-\uA97C\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFAFF\uFE10-\uFE19\uFE30-\uFE52\uFE54-\uFE66\uFE68-\uFE6B\uFF01-\uFF60\uFFE0-\uFFE6]/g,C=function(A,M,x,R,N){if(M)return m.showInvisibles?"<span class='ace_invisible ace_invisible_space'>"+g.stringRepeat(m.SPACE_CHAR,A.length)+"</span>":A;if(A=="&")return"&#38;";if(A=="<")return"&#60;";if(A==">")return"&#62;";if(A=="	"){var j=m.session.getScreenTabSize(a+R);return a+=j-1,m.$tabStrings[j]}else if(A=="　"){var B=m.showInvisibles?"ace_cjk ace_invisible ace_invisible_space":"ace_cjk",q=m.showInvisibles?m.SPACE_CHAR:"";return a+=1,"<span class='"+B+"' style='width:"+m.config.characterWidth*2+"px'>"+q+"</span>"}else return x?"<span class='ace_invisible ace_invisible_space ace_invalid'>"+m.SPACE_CHAR+"</span>":(a+=1,"<span class='ace_cjk' style='width:"+m.config.characterWidth*2+"px'>"+A+"</span>")},k=p.replace(b,C);if(this.$textToken[F.type])c.push(k);else{var T="ace_"+F.type.replace(/\./g," ace_"),w="";F.type=="fold"&&(w=" style='width:"+F.value.length*this.config.characterWidth+"px;' "),c.push("<span class='",T,"'",w,">",k,"</span>")}return a+p.length},this.renderIndentGuide=function(c,a,F){var p=a.search(this.$indentGuideRe);return p<=0||p>=F?a:a[0]==" "?(p-=p%this.tabSize,c.push(g.stringRepeat(this.$tabStrings[" "],p/this.tabSize)),a.substr(p)):a[0]=="	"?(c.push(g.stringRepeat(this.$tabStrings["	"],p)),a.substr(p)):a},this.$renderWrappedLine=function(c,a,F,p){for(var m=0,b=0,C=F[0],k=0,T=0;T<a.length;T++){var w=a[T],A=w.value;if(T==0&&this.displayIndentGuides){if(m=A.length,A=this.renderIndentGuide(c,A,C),!A)continue;m-=A.length}if(m+A.length<C)k=this.$renderToken(c,k,w,A),m+=A.length;else{for(;m+A.length>=C;)k=this.$renderToken(c,k,w,A.substring(0,C-m)),A=A.substring(C-m),m=C,p||c.push("</div>","<div class='ace_line' style='height:",this.config.lineHeight,"px'>"),c.push(g.stringRepeat(" ",F.indent)),b++,k=0,C=F[b]||Number.MAX_VALUE;A.length!=0&&(m+=A.length,k=this.$renderToken(c,k,w,A))}}},this.$renderSimpleLine=function(c,a){var F=0,p=a[0],m=p.value;this.displayIndentGuides&&(m=this.renderIndentGuide(c,m)),m&&(F=this.$renderToken(c,F,p,m));for(var b=1;b<a.length;b++)p=a[b],m=p.value,F=this.$renderToken(c,F,p,m)},this.$renderLine=function(c,a,F,p){if(!p&&p!=!1&&(p=this.session.getFoldLine(a)),p)var m=this.$getFoldLineTokens(a,p);else var m=this.session.getTokens(a);if(F||c.push("<div class='ace_line' style='height:",this.config.lineHeight*(this.$useLineGroups()?1:this.session.getRowLength(a)),"px'>"),m.length){var b=this.session.getRowSplitData(a);b&&b.length?this.$renderWrappedLine(c,m,b,F):this.$renderSimpleLine(c,m)}this.showInvisibles&&(p&&(a=p.end.row),c.push("<span class='ace_invisible ace_invisible_eol'>",a==this.session.getLength()-1?this.EOF_CHAR:this.EOL_CHAR,"</span>")),F||c.push("</div>")},this.$getFoldLineTokens=function(c,a){var F=this.session,p=[];function m(C,k,T){for(var w=0,A=0;A+C[w].value.length<k;)if(A+=C[w].value.length,w++,w==C.length)return;if(A!=k){var M=C[w].value.substring(k-A);M.length>T-k&&(M=M.substring(0,T-k)),p.push({type:C[w].type,value:M}),A=k+M.length,w+=1}for(;A<T&&w<C.length;){var M=C[w].value;M.length+A>T?p.push({type:C[w].type,value:M.substring(0,T-A)}):p.push(C[w]),A+=M.length,w+=1}}var b=F.getTokens(c);return a.walk(function(C,k,T,w,A){C!=null?p.push({type:"fold",value:C}):(A&&(b=F.getTokens(k)),b.length&&m(b,w,T))},a.end.row,this.session.getLine(a.end.row).length),p},this.$useLineGroups=function(){return this.session.getUseWrapMode()},this.destroy=function(){clearInterval(this.$pollSizeChangesTimer),this.$measureNode&&this.$measureNode.parentNode.removeChild(this.$measureNode),delete this.$measureNode}}).call(l.prototype),o.Text=l}),ace.define("ace/layer/cursor",["require","exports","module","ace/lib/dom"],function(s,o,f){var n=s("../lib/dom"),h,g=function(d){this.element=n.createElement("div"),this.element.className="ace_layer ace_cursor-layer",d.appendChild(this.element),h===void 0&&(h=!("opacity"in this.element.style)),this.isVisible=!1,this.isBlinking=!0,this.blinkInterval=1e3,this.smoothBlinking=!1,this.cursors=[],this.cursor=this.addCursor(),n.addCssClass(this.element,"ace_hidden-cursors"),this.$updateCursors=(h?this.$updateVisibility:this.$updateOpacity).bind(this)};(function(){this.$updateVisibility=function(d){for(var l=this.cursors,c=l.length;c--;)l[c].style.visibility=d?"":"hidden"},this.$updateOpacity=function(d){for(var l=this.cursors,c=l.length;c--;)l[c].style.opacity=d?"":"0"},this.$padding=0,this.setPadding=function(d){this.$padding=d},this.setSession=function(d){this.session=d},this.setBlinking=function(d){d!=this.isBlinking&&(this.isBlinking=d,this.restartTimer())},this.setBlinkInterval=function(d){d!=this.blinkInterval&&(this.blinkInterval=d,this.restartTimer())},this.setSmoothBlinking=function(d){d!=this.smoothBlinking&&!h&&(this.smoothBlinking=d,n.setCssClass(this.element,"ace_smooth-blinking",d),this.$updateCursors(!0),this.$updateCursors=this.$updateOpacity.bind(this),this.restartTimer())},this.addCursor=function(){var d=n.createElement("div");return d.className="ace_cursor",this.element.appendChild(d),this.cursors.push(d),d},this.removeCursor=function(){if(this.cursors.length>1){var d=this.cursors.pop();return d.parentNode.removeChild(d),d}},this.hideCursor=function(){this.isVisible=!1,n.addCssClass(this.element,"ace_hidden-cursors"),this.restartTimer()},this.showCursor=function(){this.isVisible=!0,n.removeCssClass(this.element,"ace_hidden-cursors"),this.restartTimer()},this.restartTimer=function(){var d=this.$updateCursors;if(clearInterval(this.intervalId),clearTimeout(this.timeoutId),this.smoothBlinking&&n.removeCssClass(this.element,"ace_smooth-blinking"),d(!0),!(!this.isBlinking||!this.blinkInterval||!this.isVisible)){this.smoothBlinking&&setTimeout(function(){n.addCssClass(this.element,"ace_smooth-blinking")}.bind(this));var l=function(){this.timeoutId=setTimeout(function(){d(!1)},.6*this.blinkInterval)}.bind(this);this.intervalId=setInterval(function(){d(!0),l()},this.blinkInterval),l()}},this.getPixelPosition=function(d,l){if(!this.config||!this.session)return{left:0,top:0};d||(d=this.session.selection.getCursor());var c=this.session.documentToScreenPosition(d),a=this.$padding+c.column*this.config.characterWidth,F=(c.row-(l?this.config.firstRowScreen:0))*this.config.lineHeight;return{left:a,top:F}},this.update=function(d){this.config=d;var l=this.session.$selectionMarkers,c=0,a=0;(l===void 0||l.length===0)&&(l=[{cursor:null}]);for(var c=0,F=l.length;c<F;c++){var p=this.getPixelPosition(l[c].cursor,!0);if(!((p.top>d.height+d.offset||p.top<0)&&c>1)){var m=(this.cursors[a++]||this.addCursor()).style;this.drawCursor?this.drawCursor(m,p,d,l[c],this.session):(m.left=p.left+"px",m.top=p.top+"px",m.width=d.characterWidth+"px",m.height=d.lineHeight+"px")}}for(;this.cursors.length>a;)this.removeCursor();var b=this.session.getOverwrite();this.$setOverwrite(b),this.$pixelPos=p,this.restartTimer()},this.drawCursor=null,this.$setOverwrite=function(d){d!=this.overwrite&&(this.overwrite=d,d?n.addCssClass(this.element,"ace_overwrite-cursors"):n.removeCssClass(this.element,"ace_overwrite-cursors"))},this.destroy=function(){clearInterval(this.intervalId),clearTimeout(this.timeoutId)}}).call(g.prototype),o.Cursor=g}),ace.define("ace/scrollbar",["require","exports","module","ace/lib/oop","ace/lib/dom","ace/lib/event","ace/lib/event_emitter"],function(s,o,f){var n=s("./lib/oop"),h=s("./lib/dom"),g=s("./lib/event"),d=s("./lib/event_emitter").EventEmitter,l=32768,c=function(p){this.element=h.createElement("div"),this.element.className="ace_scrollbar ace_scrollbar"+this.classSuffix,this.inner=h.createElement("div"),this.inner.className="ace_scrollbar-inner",this.element.appendChild(this.inner),p.appendChild(this.element),this.setVisible(!1),this.skipEvent=!1,g.addListener(this.element,"scroll",this.onScroll.bind(this)),g.addListener(this.element,"mousedown",g.preventDefault)};(function(){n.implement(this,d),this.setVisible=function(p){this.element.style.display=p?"":"none",this.isVisible=p,this.coeff=1}}).call(c.prototype);var a=function(p,m){c.call(this,p),this.scrollTop=0,this.scrollHeight=0,m.$scrollbarWidth=this.width=h.scrollbarWidth(p.ownerDocument),this.inner.style.width=this.element.style.width=(this.width||15)+5+"px"};n.inherits(a,c),function(){this.classSuffix="-v",this.onScroll=function(){if(!this.skipEvent){if(this.scrollTop=this.element.scrollTop,this.coeff!=1){var p=this.element.clientHeight/this.scrollHeight;this.scrollTop=this.scrollTop*(1-p)/(this.coeff-p)}this._emit("scroll",{data:this.scrollTop})}this.skipEvent=!1},this.getWidth=function(){return this.isVisible?this.width:0},this.setHeight=function(p){this.element.style.height=p+"px"},this.setInnerHeight=this.setScrollHeight=function(p){this.scrollHeight=p,p>l?(this.coeff=l/p,p=l):this.coeff!=1&&(this.coeff=1),this.inner.style.height=p+"px"},this.setScrollTop=function(p){this.scrollTop!=p&&(this.skipEvent=!0,this.scrollTop=p,this.element.scrollTop=p*this.coeff)}}.call(a.prototype);var F=function(p,m){c.call(this,p),this.scrollLeft=0,this.height=m.$scrollbarWidth,this.inner.style.height=this.element.style.height=(this.height||15)+5+"px"};n.inherits(F,c),function(){this.classSuffix="-h",this.onScroll=function(){this.skipEvent||(this.scrollLeft=this.element.scrollLeft,this._emit("scroll",{data:this.scrollLeft})),this.skipEvent=!1},this.getHeight=function(){return this.isVisible?this.height:0},this.setWidth=function(p){this.element.style.width=p+"px"},this.setInnerWidth=function(p){this.inner.style.width=p+"px"},this.setScrollWidth=function(p){this.inner.style.width=p+"px"},this.setScrollLeft=function(p){this.scrollLeft!=p&&(this.skipEvent=!0,this.scrollLeft=this.element.scrollLeft=p)}}.call(F.prototype),o.ScrollBar=a,o.ScrollBarV=a,o.ScrollBarH=F,o.VScrollBar=a,o.HScrollBar=F}),ace.define("ace/renderloop",["require","exports","module","ace/lib/event"],function(s,o,f){var n=s("./lib/event"),h=function(g,d){this.onRender=g,this.pending=!1,this.changes=0,this.window=d||window};(function(){this.schedule=function(g){if(this.changes=this.changes|g,!this.pending&&this.changes){this.pending=!0;var d=this;n.nextFrame(function(){d.pending=!1;for(var l;l=d.changes;)d.changes=0,d.onRender(l)},this.window)}}}).call(h.prototype),o.RenderLoop=h}),ace.define("ace/layer/font_metrics",["require","exports","module","ace/lib/oop","ace/lib/dom","ace/lib/lang","ace/lib/useragent","ace/lib/event_emitter"],function(s,o,f){var n=s("../lib/oop"),h=s("../lib/dom"),g=s("../lib/lang"),d=s("../lib/useragent"),l=s("../lib/event_emitter").EventEmitter,c=0,a=o.FontMetrics=function(F){this.el=h.createElement("div"),this.$setMeasureNodeStyles(this.el.style,!0),this.$main=h.createElement("div"),this.$setMeasureNodeStyles(this.$main.style),this.$measureNode=h.createElement("div"),this.$setMeasureNodeStyles(this.$measureNode.style),this.el.appendChild(this.$main),this.el.appendChild(this.$measureNode),F.appendChild(this.el),c||this.$testFractionalRect(),this.$measureNode.innerHTML=g.stringRepeat("X",c),this.$characterSize={width:0,height:0},this.checkForSizeChanges()};(function(){n.implement(this,l),this.$characterSize={width:0,height:0},this.$testFractionalRect=function(){var F=h.createElement("div");this.$setMeasureNodeStyles(F.style),F.style.width="0.2px",document.documentElement.appendChild(F);var p=F.getBoundingClientRect().width;p>0&&p<1?c=50:c=100,F.parentNode.removeChild(F)},this.$setMeasureNodeStyles=function(F,p){F.width=F.height="auto",F.left=F.top="0px",F.visibility="hidden",F.position="absolute",F.whiteSpace="pre",d.isIE<8?F["font-family"]="inherit":F.font="inherit",F.overflow=p?"hidden":"visible"},this.checkForSizeChanges=function(){var F=this.$measureSizes();if(F&&(this.$characterSize.width!==F.width||this.$characterSize.height!==F.height)){this.$measureNode.style.fontWeight="bold";var p=this.$measureSizes();this.$measureNode.style.fontWeight="",this.$characterSize=F,this.charSizes=Object.create(null),this.allowBoldFonts=p&&p.width===F.width&&p.height===F.height,this._emit("changeCharacterSize",{data:F})}},this.$pollSizeChanges=function(){if(this.$pollSizeChangesTimer)return this.$pollSizeChangesTimer;var F=this;return this.$pollSizeChangesTimer=setInterval(function(){F.checkForSizeChanges()},500)},this.setPolling=function(F){F?this.$pollSizeChanges():this.$pollSizeChangesTimer&&(clearInterval(this.$pollSizeChangesTimer),this.$pollSizeChangesTimer=0)},this.$measureSizes=function(){if(c===50){var F=null;try{F=this.$measureNode.getBoundingClientRect()}catch{F={width:0,height:0}}var p={height:F.height,width:F.width/c}}else var p={height:this.$measureNode.clientHeight,width:this.$measureNode.clientWidth/c};return p.width===0||p.height===0?null:p},this.$measureCharWidth=function(F){this.$main.innerHTML=g.stringRepeat(F,c);var p=this.$main.getBoundingClientRect();return p.width/c},this.getCharacterWidth=function(F){var p=this.charSizes[F];return p===void 0&&(p=this.charSizes[F]=this.$measureCharWidth(F)/this.$characterSize.width),p},this.destroy=function(){clearInterval(this.$pollSizeChangesTimer),this.el&&this.el.parentNode&&this.el.parentNode.removeChild(this.el)}}).call(a.prototype)}),ace.define("ace/virtual_renderer",["require","exports","module","ace/lib/oop","ace/lib/dom","ace/config","ace/lib/useragent","ace/layer/gutter","ace/layer/marker","ace/layer/text","ace/layer/cursor","ace/scrollbar","ace/scrollbar","ace/renderloop","ace/layer/font_metrics","ace/lib/event_emitter"],function(s,o,f){var n=s("./lib/oop"),h=s("./lib/dom"),g=s("./config"),d=s("./lib/useragent"),l=s("./layer/gutter").Gutter,c=s("./layer/marker").Marker,a=s("./layer/text").Text,F=s("./layer/cursor").Cursor,p=s("./scrollbar").HScrollBar,m=s("./scrollbar").VScrollBar,b=s("./renderloop").RenderLoop,C=s("./layer/font_metrics").FontMetrics,k=s("./lib/event_emitter").EventEmitter,T=`.ace_editor {		position: relative;		overflow: hidden;		font: 12px/normal 'Monaco', 'Menlo', 'Ubuntu Mono', 'Consolas', 'source-code-pro', monospace;		direction: ltr;		text-align: left;		}		.ace_scroller {		position: absolute;		overflow: hidden;		top: 0;		bottom: 0;		background-color: inherit;		-ms-user-select: none;		-moz-user-select: none;		-webkit-user-select: none;		user-select: none;		cursor: text;		}		.ace_content {		position: absolute;		-moz-box-sizing: border-box;		-webkit-box-sizing: border-box;		box-sizing: border-box;		min-width: 100%;		}		.ace_dragging .ace_scroller:before{		position: absolute;		top: 0;		left: 0;		right: 0;		bottom: 0;		content: '';		background: rgba(250, 250, 250, 0.01);		z-index: 1000;		}		.ace_dragging.ace_dark .ace_scroller:before{		background: rgba(0, 0, 0, 0.01);		}		.ace_selecting, .ace_selecting * {		cursor: text !important;		}		.ace_gutter {		position: absolute;		overflow : hidden;		width: auto;		top: 0;		bottom: 0;		left: 0;		cursor: default;		z-index: 4;		-ms-user-select: none;		-moz-user-select: none;		-webkit-user-select: none;		user-select: none;		}		.ace_gutter-active-line {		position: absolute;		left: 0;		right: 0;		}		.ace_scroller.ace_scroll-left {		box-shadow: 17px 0 16px -16px rgba(0, 0, 0, 0.4) inset;		}		.ace_gutter-cell {		padding-left: 19px;		padding-right: 6px;		background-repeat: no-repeat;		}		.ace_gutter-cell.ace_error {		background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAMAAAAoLQ9TAAABOFBMVEX/////////QRswFAb/Ui4wFAYwFAYwFAaWGAfDRymzOSH/PxswFAb/SiUwFAYwFAbUPRvjQiDllog5HhHdRybsTi3/Tyv9Tir+Syj/UC3////XurebMBIwFAb/RSHbPx/gUzfdwL3kzMivKBAwFAbbvbnhPx66NhowFAYwFAaZJg8wFAaxKBDZurf/RB6mMxb/SCMwFAYwFAbxQB3+RB4wFAb/Qhy4Oh+4QifbNRcwFAYwFAYwFAb/QRzdNhgwFAYwFAbav7v/Uy7oaE68MBK5LxLewr/r2NXewLswFAaxJw4wFAbkPRy2PyYwFAaxKhLm1tMwFAazPiQwFAaUGAb/QBrfOx3bvrv/VC/maE4wFAbRPBq6MRO8Qynew8Dp2tjfwb0wFAbx6eju5+by6uns4uH9/f36+vr/GkHjAAAAYnRSTlMAGt+64rnWu/bo8eAA4InH3+DwoN7j4eLi4xP99Nfg4+b+/u9B/eDs1MD1mO7+4PHg2MXa347g7vDizMLN4eG+Pv7i5evs/v79yu7S3/DV7/498Yv24eH+4ufQ3Ozu/v7+y13sRqwAAADLSURBVHjaZc/XDsFgGIBhtDrshlitmk2IrbHFqL2pvXf/+78DPokj7+Fz9qpU/9UXJIlhmPaTaQ6QPaz0mm+5gwkgovcV6GZzd5JtCQwgsxoHOvJO15kleRLAnMgHFIESUEPmawB9ngmelTtipwwfASilxOLyiV5UVUyVAfbG0cCPHig+GBkzAENHS0AstVF6bacZIOzgLmxsHbt2OecNgJC83JERmePUYq8ARGkJx6XtFsdddBQgZE2nPR6CICZhawjA4Fb/chv+399kfR+MMMDGOQAAAABJRU5ErkJggg==");		background-repeat: no-repeat;		background-position: 2px center;		}		.ace_gutter-cell.ace_warning {		background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAMAAAAoLQ9TAAAAmVBMVEX///8AAAD///8AAAAAAABPSzb/5sAAAAB/blH/73z/ulkAAAAAAAD85pkAAAAAAAACAgP/vGz/rkDerGbGrV7/pkQICAf////e0IsAAAD/oED/qTvhrnUAAAD/yHD/njcAAADuv2r/nz//oTj/p064oGf/zHAAAAA9Nir/tFIAAAD/tlTiuWf/tkIAAACynXEAAAAAAAAtIRW7zBpBAAAAM3RSTlMAABR1m7RXO8Ln31Z36zT+neXe5OzooRDfn+TZ4p3h2hTf4t3k3ucyrN1K5+Xaks52Sfs9CXgrAAAAjklEQVR42o3PbQ+CIBQFYEwboPhSYgoYunIqqLn6/z8uYdH8Vmdnu9vz4WwXgN/xTPRD2+sgOcZjsge/whXZgUaYYvT8QnuJaUrjrHUQreGczuEafQCO/SJTufTbroWsPgsllVhq3wJEk2jUSzX3CUEDJC84707djRc5MTAQxoLgupWRwW6UB5fS++NV8AbOZgnsC7BpEAAAAABJRU5ErkJggg==");		background-position: 2px center;		}		.ace_gutter-cell.ace_info {		background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAAAAAA6mKC9AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAAJ0Uk5TAAB2k804AAAAPklEQVQY02NgIB68QuO3tiLznjAwpKTgNyDbMegwisCHZUETUZV0ZqOquBpXj2rtnpSJT1AEnnRmL2OgGgAAIKkRQap2htgAAAAASUVORK5CYII=");		background-position: 2px center;		}		.ace_dark .ace_gutter-cell.ace_info {		background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQBAMAAADt3eJSAAAAJFBMVEUAAAChoaGAgIAqKiq+vr6tra1ZWVmUlJSbm5s8PDxubm56enrdgzg3AAAAAXRSTlMAQObYZgAAAClJREFUeNpjYMAPdsMYHegyJZFQBlsUlMFVCWUYKkAZMxZAGdxlDMQBAG+TBP4B6RyJAAAAAElFTkSuQmCC");		}		.ace_scrollbar {		position: absolute;		right: 0;		bottom: 0;		z-index: 6;		}		.ace_scrollbar-inner {		position: absolute;		cursor: text;		left: 0;		top: 0;		}		.ace_scrollbar-v{		overflow-x: hidden;		overflow-y: scroll;		top: 0;		}		.ace_scrollbar-h {		overflow-x: scroll;		overflow-y: hidden;		left: 0;		}		.ace_print-margin {		position: absolute;		height: 100%;		}		.ace_text-input {		position: absolute;		z-index: 0;		width: 0.5em;		height: 1em;		opacity: 0;		background: transparent;		-moz-appearance: none;		appearance: none;		border: none;		resize: none;		outline: none;		overflow: hidden;		font: inherit;		padding: 0 1px;		margin: 0 -1px;		text-indent: -1em;		-ms-user-select: text;		-moz-user-select: text;		-webkit-user-select: text;		user-select: text;		white-space: pre!important;		}		.ace_text-input.ace_composition {		background: inherit;		color: inherit;		z-index: 1000;		opacity: 1;		text-indent: 0;		}		.ace_layer {		z-index: 1;		position: absolute;		overflow: hidden;		word-wrap: normal;		white-space: pre;		height: 100%;		width: 100%;		-moz-box-sizing: border-box;		-webkit-box-sizing: border-box;		box-sizing: border-box;		pointer-events: none;		}		.ace_gutter-layer {		position: relative;		width: auto;		text-align: right;		pointer-events: auto;		}		.ace_text-layer {		font: inherit !important;		}		.ace_cjk {		display: inline-block;		text-align: center;		}		.ace_cursor-layer {		z-index: 4;		}		.ace_cursor {		z-index: 4;		position: absolute;		-moz-box-sizing: border-box;		-webkit-box-sizing: border-box;		box-sizing: border-box;		border-left: 2px solid;		transform: translatez(0);		}		.ace_slim-cursors .ace_cursor {		border-left-width: 1px;		}		.ace_overwrite-cursors .ace_cursor {		border-left-width: 0;		border-bottom: 1px solid;		}		.ace_hidden-cursors .ace_cursor {		opacity: 0.2;		}		.ace_smooth-blinking .ace_cursor {		-webkit-transition: opacity 0.18s;		transition: opacity 0.18s;		}		.ace_editor.ace_multiselect .ace_cursor {		border-left-width: 1px;		}		.ace_marker-layer .ace_step, .ace_marker-layer .ace_stack {		position: absolute;		z-index: 3;		}		.ace_marker-layer .ace_selection {		position: absolute;		z-index: 5;		}		.ace_marker-layer .ace_bracket {		position: absolute;		z-index: 6;		}		.ace_marker-layer .ace_active-line {		position: absolute;		z-index: 2;		}		.ace_marker-layer .ace_selected-word {		position: absolute;		z-index: 4;		-moz-box-sizing: border-box;		-webkit-box-sizing: border-box;		box-sizing: border-box;		}		.ace_line .ace_fold {		-moz-box-sizing: border-box;		-webkit-box-sizing: border-box;		box-sizing: border-box;		display: inline-block;		height: 11px;		margin-top: -2px;		vertical-align: middle;		background-image:		url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABEAAAAJCAYAAADU6McMAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAJpJREFUeNpi/P//PwOlgAXGYGRklAVSokD8GmjwY1wasKljQpYACtpCFeADcHVQfQyMQAwzwAZI3wJKvCLkfKBaMSClBlR7BOQikCFGQEErIH0VqkabiGCAqwUadAzZJRxQr/0gwiXIal8zQQPnNVTgJ1TdawL0T5gBIP1MUJNhBv2HKoQHHjqNrA4WO4zY0glyNKLT2KIfIMAAQsdgGiXvgnYAAAAASUVORK5CYII="),		url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAA3CAYAAADNNiA5AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAACJJREFUeNpi+P//fxgTAwPDBxDxD078RSX+YeEyDFMCIMAAI3INmXiwf2YAAAAASUVORK5CYII=");		background-repeat: no-repeat, repeat-x;		background-position: center center, top left;		color: transparent;		border: 1px solid black;		border-radius: 2px;		cursor: pointer;		pointer-events: auto;		}		.ace_dark .ace_fold {		}		.ace_fold:hover{		background-image:		url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABEAAAAJCAYAAADU6McMAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAJpJREFUeNpi/P//PwOlgAXGYGRklAVSokD8GmjwY1wasKljQpYACtpCFeADcHVQfQyMQAwzwAZI3wJKvCLkfKBaMSClBlR7BOQikCFGQEErIH0VqkabiGCAqwUadAzZJRxQr/0gwiXIal8zQQPnNVTgJ1TdawL0T5gBIP1MUJNhBv2HKoQHHjqNrA4WO4zY0glyNKLT2KIfIMAAQsdgGiXvgnYAAAAASUVORK5CYII="),		url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAA3CAYAAADNNiA5AAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAACBJREFUeNpi+P//fz4TAwPDZxDxD5X4i5fLMEwJgAADAEPVDbjNw87ZAAAAAElFTkSuQmCC");		}		.ace_tooltip {		background-color: #FFF;		background-image: -webkit-linear-gradient(top, transparent, rgba(0, 0, 0, 0.1));		background-image: linear-gradient(to bottom, transparent, rgba(0, 0, 0, 0.1));		border: 1px solid gray;		border-radius: 1px;		box-shadow: 0 1px 2px rgba(0, 0, 0, 0.3);		color: black;		max-width: 100%;		padding: 3px 4px;		position: fixed;		z-index: 999999;		-moz-box-sizing: border-box;		-webkit-box-sizing: border-box;		box-sizing: border-box;		cursor: default;		white-space: pre;		word-wrap: break-word;		line-height: normal;		font-style: normal;		font-weight: normal;		letter-spacing: normal;		pointer-events: none;		}		.ace_folding-enabled > .ace_gutter-cell {		padding-right: 13px;		}		.ace_fold-widget {		-moz-box-sizing: border-box;		-webkit-box-sizing: border-box;		box-sizing: border-box;		margin: 0 -12px 0 1px;		display: none;		width: 11px;		vertical-align: top;		background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAFCAYAAACNbyblAAAANElEQVR42mWKsQ0AMAzC8ixLlrzQjzmBiEjp0A6WwBCSPgKAXoLkqSot7nN3yMwR7pZ32NzpKkVoDBUxKAAAAABJRU5ErkJggg==");		background-repeat: no-repeat;		background-position: center;		border-radius: 3px;		border: 1px solid transparent;		cursor: pointer;		}		.ace_folding-enabled .ace_fold-widget {		display: inline-block;   		}		.ace_fold-widget.ace_end {		background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAFCAYAAACNbyblAAAANElEQVR42m3HwQkAMAhD0YzsRchFKI7sAikeWkrxwScEB0nh5e7KTPWimZki4tYfVbX+MNl4pyZXejUO1QAAAABJRU5ErkJggg==");		}		.ace_fold-widget.ace_closed {		background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAMAAAAGCAYAAAAG5SQMAAAAOUlEQVR42jXKwQkAMAgDwKwqKD4EwQ26sSOkVWjgIIHAzPiCgaqiqnJHZnKICBERHN194O5b9vbLuAVRL+l0YWnZAAAAAElFTkSuQmCCXA==");		}		.ace_fold-widget:hover {		border: 1px solid rgba(0, 0, 0, 0.3);		background-color: rgba(255, 255, 255, 0.2);		box-shadow: 0 1px 1px rgba(255, 255, 255, 0.7);		}		.ace_fold-widget:active {		border: 1px solid rgba(0, 0, 0, 0.4);		background-color: rgba(0, 0, 0, 0.05);		box-shadow: 0 1px 1px rgba(255, 255, 255, 0.8);		}		.ace_dark .ace_fold-widget {		background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAFCAYAAACNbyblAAAAHklEQVQIW2P4//8/AzoGEQ7oGCaLLAhWiSwB146BAQCSTPYocqT0AAAAAElFTkSuQmCC");		}		.ace_dark .ace_fold-widget.ace_end {		background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUAAAAFCAYAAACNbyblAAAAH0lEQVQIW2P4//8/AxQ7wNjIAjDMgC4AxjCVKBirIAAF0kz2rlhxpAAAAABJRU5ErkJggg==");		}		.ace_dark .ace_fold-widget.ace_closed {		background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAMAAAAFCAYAAACAcVaiAAAAHElEQVQIW2P4//+/AxAzgDADlOOAznHAKgPWAwARji8UIDTfQQAAAABJRU5ErkJggg==");		}		.ace_dark .ace_fold-widget:hover {		box-shadow: 0 1px 1px rgba(255, 255, 255, 0.2);		background-color: rgba(255, 255, 255, 0.1);		}		.ace_dark .ace_fold-widget:active {		box-shadow: 0 1px 1px rgba(255, 255, 255, 0.2);		}		.ace_fold-widget.ace_invalid {		background-color: #FFB4B4;		border-color: #DE5555;		}		.ace_fade-fold-widgets .ace_fold-widget {		-webkit-transition: opacity 0.4s ease 0.05s;		transition: opacity 0.4s ease 0.05s;		opacity: 0;		}		.ace_fade-fold-widgets:hover .ace_fold-widget {		-webkit-transition: opacity 0.05s ease 0.05s;		transition: opacity 0.05s ease 0.05s;		opacity:1;		}		.ace_underline {		text-decoration: underline;		}		.ace_bold {		font-weight: bold;		}		.ace_nobold .ace_bold {		font-weight: normal;		}		.ace_italic {		font-style: italic;		}		.ace_error-marker {		background-color: rgba(255, 0, 0,0.2);		position: absolute;		z-index: 9;		}		.ace_highlight-marker {		background-color: rgba(255, 255, 0,0.2);		position: absolute;		z-index: 8;		}		.ace_br1 {border-top-left-radius    : 3px;}		.ace_br2 {border-top-right-radius   : 3px;}		.ace_br3 {border-top-left-radius    : 3px; border-top-right-radius:    3px;}		.ace_br4 {border-bottom-right-radius: 3px;}		.ace_br5 {border-top-left-radius    : 3px; border-bottom-right-radius: 3px;}		.ace_br6 {border-top-right-radius   : 3px; border-bottom-right-radius: 3px;}		.ace_br7 {border-top-left-radius    : 3px; border-top-right-radius:    3px; border-bottom-right-radius: 3px;}		.ace_br8 {border-bottom-left-radius : 3px;}		.ace_br9 {border-top-left-radius    : 3px; border-bottom-left-radius:  3px;}		.ace_br10{border-top-right-radius   : 3px; border-bottom-left-radius:  3px;}		.ace_br11{border-top-left-radius    : 3px; border-top-right-radius:    3px; border-bottom-left-radius:  3px;}		.ace_br12{border-bottom-right-radius: 3px; border-bottom-left-radius:  3px;}		.ace_br13{border-top-left-radius    : 3px; border-bottom-right-radius: 3px; border-bottom-left-radius:  3px;}		.ace_br14{border-top-right-radius   : 3px; border-bottom-right-radius: 3px; border-bottom-left-radius:  3px;}		.ace_br15{border-top-left-radius    : 3px; border-top-right-radius:    3px; border-bottom-right-radius: 3px; border-bottom-left-radius: 3px;}		`;h.importCssString(T,"ace_editor.css");var w=function(A,M){var x=this;this.container=A||h.createElement("div"),this.$keepTextAreaAtCursor=!d.isOldIE,h.addCssClass(this.container,"ace_editor"),this.setTheme(M),this.$gutter=h.createElement("div"),this.$gutter.className="ace_gutter",this.container.appendChild(this.$gutter),this.scroller=h.createElement("div"),this.scroller.className="ace_scroller",this.container.appendChild(this.scroller),this.content=h.createElement("div"),this.content.className="ace_content",this.scroller.appendChild(this.content),this.$gutterLayer=new l(this.$gutter),this.$gutterLayer.on("changeGutterWidth",this.onGutterResize.bind(this)),this.$markerBack=new c(this.content);var R=this.$textLayer=new a(this.content);this.canvas=R.element,this.$markerFront=new c(this.content),this.$cursorLayer=new F(this.content),this.$horizScroll=!1,this.$vScroll=!1,this.scrollBar=this.scrollBarV=new m(this.container,this),this.scrollBarH=new p(this.container,this),this.scrollBarV.addEventListener("scroll",function(N){x.$scrollAnimation||x.session.setScrollTop(N.data-x.scrollMargin.top)}),this.scrollBarH.addEventListener("scroll",function(N){x.$scrollAnimation||x.session.setScrollLeft(N.data-x.scrollMargin.left)}),this.scrollTop=0,this.scrollLeft=0,this.cursorPos={row:0,column:0},this.$fontMetrics=new C(this.container),this.$textLayer.$setFontMetrics(this.$fontMetrics),this.$textLayer.addEventListener("changeCharacterSize",function(N){x.updateCharacterSize(),x.onResize(!0,x.gutterWidth,x.$size.width,x.$size.height),x._signal("changeCharacterSize",N)}),this.$size={width:0,height:0,scrollerHeight:0,scrollerWidth:0,$dirty:!0},this.layerConfig={width:1,padding:0,firstRow:0,firstRowScreen:0,lastRow:0,lineHeight:0,characterWidth:0,minHeight:1,maxHeight:1,offset:0,height:1,gutterOffset:1},this.scrollMargin={left:0,right:0,top:0,bottom:0,v:0,h:0},this.$loop=new b(this.$renderChanges.bind(this),this.container.ownerDocument.defaultView),this.$loop.schedule(this.CHANGE_FULL),this.updateCharacterSize(),this.setPadding(4),g.resetOptions(this),g._emit("renderer",this)};(function(){this.CHANGE_CURSOR=1,this.CHANGE_MARKER=2,this.CHANGE_GUTTER=4,this.CHANGE_SCROLL=8,this.CHANGE_LINES=16,this.CHANGE_TEXT=32,this.CHANGE_SIZE=64,this.CHANGE_MARKER_BACK=128,this.CHANGE_MARKER_FRONT=256,this.CHANGE_FULL=512,this.CHANGE_H_SCROLL=1024,n.implement(this,k),this.updateCharacterSize=function(){this.$textLayer.allowBoldFonts!=this.$allowBoldFonts&&(this.$allowBoldFonts=this.$textLayer.allowBoldFonts,this.setStyle("ace_nobold",!this.$allowBoldFonts)),this.layerConfig.characterWidth=this.characterWidth=this.$textLayer.getCharacterWidth(),this.layerConfig.lineHeight=this.lineHeight=this.$textLayer.getLineHeight(),this.$updatePrintMargin()},this.setSession=function(A){this.session&&this.session.doc.off("changeNewLineMode",this.onChangeNewLineMode),this.session=A,A&&this.scrollMargin.top&&A.getScrollTop()<=0&&A.setScrollTop(-this.scrollMargin.top),this.$cursorLayer.setSession(A),this.$markerBack.setSession(A),this.$markerFront.setSession(A),this.$gutterLayer.setSession(A),this.$textLayer.setSession(A),A&&(this.$loop.schedule(this.CHANGE_FULL),this.session.$setFontMetrics(this.$fontMetrics),this.scrollBarV.scrollLeft=this.scrollBarV.scrollTop=null,this.onChangeNewLineMode=this.onChangeNewLineMode.bind(this),this.onChangeNewLineMode(),this.session.doc.on("changeNewLineMode",this.onChangeNewLineMode))},this.updateLines=function(A,M,x){if(M===void 0&&(M=1/0),this.$changedLines?(this.$changedLines.firstRow>A&&(this.$changedLines.firstRow=A),this.$changedLines.lastRow<M&&(this.$changedLines.lastRow=M)):this.$changedLines={firstRow:A,lastRow:M},this.$changedLines.lastRow<this.layerConfig.firstRow)if(x)this.$changedLines.lastRow=this.layerConfig.lastRow;else return;this.$changedLines.firstRow>this.layerConfig.lastRow||this.$loop.schedule(this.CHANGE_LINES)},this.onChangeNewLineMode=function(){this.$loop.schedule(this.CHANGE_TEXT),this.$textLayer.$updateEolChar()},this.onChangeTabSize=function(){this.$loop.schedule(this.CHANGE_TEXT|this.CHANGE_MARKER),this.$textLayer.onChangeTabSize()},this.updateText=function(){this.$loop.schedule(this.CHANGE_TEXT)},this.updateFull=function(A){A?this.$renderChanges(this.CHANGE_FULL,!0):this.$loop.schedule(this.CHANGE_FULL)},this.updateFontSize=function(){this.$textLayer.checkForSizeChanges()},this.$changes=0,this.$updateSizeAsync=function(){this.$loop.pending?this.$size.$dirty=!0:this.onResize()},this.onResize=function(A,M,x,R){if(!(this.resizing>2)){this.resizing>0?this.resizing++:this.resizing=A?1:0;var N=this.container;R||(R=N.clientHeight||N.scrollHeight),x||(x=N.clientWidth||N.scrollWidth);var j=this.$updateCachedSize(A,M,x,R);if(!this.$size.scrollerHeight||!x&&!R)return this.resizing=0;A&&(this.$gutterLayer.$padding=null),A?this.$renderChanges(j|this.$changes,!0):this.$loop.schedule(j|this.$changes),this.resizing&&(this.resizing=0),this.scrollBarV.scrollLeft=this.scrollBarV.scrollTop=null}},this.$updateCachedSize=function(A,M,x,R){R-=this.$extraHeight||0;var N=0,j=this.$size,B={width:j.width,height:j.height,scrollerHeight:j.scrollerHeight,scrollerWidth:j.scrollerWidth};return R&&(A||j.height!=R)&&(j.height=R,N|=this.CHANGE_SIZE,j.scrollerHeight=j.height,this.$horizScroll&&(j.scrollerHeight-=this.scrollBarH.getHeight()),this.scrollBarV.element.style.bottom=this.scrollBarH.getHeight()+"px",N=N|this.CHANGE_SCROLL),x&&(A||j.width!=x)&&(N|=this.CHANGE_SIZE,j.width=x,M==null&&(M=this.$showGutter?this.$gutter.offsetWidth:0),this.gutterWidth=M,this.scrollBarH.element.style.left=this.scroller.style.left=M+"px",j.scrollerWidth=Math.max(0,x-M-this.scrollBarV.getWidth()),this.scrollBarH.element.style.right=this.scroller.style.right=this.scrollBarV.getWidth()+"px",this.scroller.style.bottom=this.scrollBarH.getHeight()+"px",(this.session&&this.session.getUseWrapMode()&&this.adjustWrapLimit()||A)&&(N|=this.CHANGE_FULL)),j.$dirty=!x||!R,N&&this._signal("resize",B),N},this.onGutterResize=function(){var A=this.$showGutter?this.$gutter.offsetWidth:0;A!=this.gutterWidth&&(this.$changes|=this.$updateCachedSize(!0,A,this.$size.width,this.$size.height)),this.session.getUseWrapMode()&&this.adjustWrapLimit()?this.$loop.schedule(this.CHANGE_FULL):this.$size.$dirty?this.$loop.schedule(this.CHANGE_FULL):(this.$computeLayerConfig(),this.$loop.schedule(this.CHANGE_MARKER))},this.adjustWrapLimit=function(){var A=this.$size.scrollerWidth-this.$padding*2,M=Math.floor(A/this.characterWidth);return this.session.adjustWrapLimit(M,this.$showPrintMargin&&this.$printMarginColumn)},this.setAnimatedScroll=function(A){this.setOption("animatedScroll",A)},this.getAnimatedScroll=function(){return this.$animatedScroll},this.setShowInvisibles=function(A){this.setOption("showInvisibles",A)},this.getShowInvisibles=function(){return this.getOption("showInvisibles")},this.getDisplayIndentGuides=function(){return this.getOption("displayIndentGuides")},this.setDisplayIndentGuides=function(A){this.setOption("displayIndentGuides",A)},this.setShowPrintMargin=function(A){this.setOption("showPrintMargin",A)},this.getShowPrintMargin=function(){return this.getOption("showPrintMargin")},this.setPrintMarginColumn=function(A){this.setOption("printMarginColumn",A)},this.getPrintMarginColumn=function(){return this.getOption("printMarginColumn")},this.getShowGutter=function(){return this.getOption("showGutter")},this.setShowGutter=function(A){return this.setOption("showGutter",A)},this.getFadeFoldWidgets=function(){return this.getOption("fadeFoldWidgets")},this.setFadeFoldWidgets=function(A){this.setOption("fadeFoldWidgets",A)},this.setHighlightGutterLine=function(A){this.setOption("highlightGutterLine",A)},this.getHighlightGutterLine=function(){return this.getOption("highlightGutterLine")},this.$updateGutterLineHighlight=function(){var A=this.$cursorLayer.$pixelPos,M=this.layerConfig.lineHeight;if(this.session.getUseWrapMode()){var x=this.session.selection.getCursor();x.column=0,A=this.$cursorLayer.getPixelPosition(x,!0),M*=this.session.getRowLength(x.row)}this.$gutterLineHighlight.style.top=A.top-this.layerConfig.offset+"px",this.$gutterLineHighlight.style.height=M+"px"},this.$updatePrintMargin=function(){if(!(!this.$showPrintMargin&&!this.$printMarginEl)){if(!this.$printMarginEl){var A=h.createElement("div");A.className="ace_layer ace_print-margin-layer",this.$printMarginEl=h.createElement("div"),this.$printMarginEl.className="ace_print-margin",A.appendChild(this.$printMarginEl),this.content.insertBefore(A,this.content.firstChild)}var M=this.$printMarginEl.style;M.left=this.characterWidth*this.$printMarginColumn+this.$padding+"px",M.visibility=this.$showPrintMargin?"visible":"hidden",this.session&&this.session.$wrap==-1&&this.adjustWrapLimit()}},this.getContainerElement=function(){return this.container},this.getMouseEventTarget=function(){return this.scroller},this.getTextAreaContainer=function(){return this.container},this.$moveTextAreaToCursor=function(){if(this.$keepTextAreaAtCursor){var A=this.layerConfig,M=this.$cursorLayer.$pixelPos.top,x=this.$cursorLayer.$pixelPos.left;M-=A.offset;var R=this.textarea.style,N=this.lineHeight;if(M<0||M>A.height-N){R.top=R.left="0";return}var j=this.characterWidth;if(this.$composition){var B=this.textarea.value.replace(/^\x01+/,"");j*=this.session.$getStringScreenWidth(B)[0]+2,N+=2}x-=this.scrollLeft,x>this.$size.scrollerWidth-j&&(x=this.$size.scrollerWidth-j),x+=this.gutterWidth,R.height=N+"px",R.width=j+"px",R.left=Math.min(x,this.$size.scrollerWidth-j)+"px",R.top=Math.min(M,this.$size.height-N)+"px"}},this.getFirstVisibleRow=function(){return this.layerConfig.firstRow},this.getFirstFullyVisibleRow=function(){return this.layerConfig.firstRow+(this.layerConfig.offset===0?0:1)},this.getLastFullyVisibleRow=function(){var A=this.layerConfig,M=A.lastRow,x=this.session.documentToScreenRow(M,0)*A.lineHeight;return x-this.session.getScrollTop()>A.height-A.lineHeight?M-1:M},this.getLastVisibleRow=function(){return this.layerConfig.lastRow},this.$padding=null,this.setPadding=function(A){this.$padding=A,this.$textLayer.setPadding(A),this.$cursorLayer.setPadding(A),this.$markerFront.setPadding(A),this.$markerBack.setPadding(A),this.$loop.schedule(this.CHANGE_FULL),this.$updatePrintMargin()},this.setScrollMargin=function(A,M,x,R){var N=this.scrollMargin;N.top=A|0,N.bottom=M|0,N.right=R|0,N.left=x|0,N.v=N.top+N.bottom,N.h=N.left+N.right,N.top&&this.scrollTop<=0&&this.session&&this.session.setScrollTop(-N.top),this.updateFull()},this.getHScrollBarAlwaysVisible=function(){return this.$hScrollBarAlwaysVisible},this.setHScrollBarAlwaysVisible=function(A){this.setOption("hScrollBarAlwaysVisible",A)},this.getVScrollBarAlwaysVisible=function(){return this.$vScrollBarAlwaysVisible},this.setVScrollBarAlwaysVisible=function(A){this.setOption("vScrollBarAlwaysVisible",A)},this.$updateScrollBarV=function(){var A=this.layerConfig.maxHeight,M=this.$size.scrollerHeight;!this.$maxLines&&this.$scrollPastEnd&&(A-=(M-this.lineHeight)*this.$scrollPastEnd,this.scrollTop>A-M&&(A=this.scrollTop+M,this.scrollBarV.scrollTop=null)),this.scrollBarV.setScrollHeight(A+this.scrollMargin.v),this.scrollBarV.setScrollTop(this.scrollTop+this.scrollMargin.top)},this.$updateScrollBarH=function(){this.scrollBarH.setScrollWidth(this.layerConfig.width+2*this.$padding+this.scrollMargin.h),this.scrollBarH.setScrollLeft(this.scrollLeft+this.scrollMargin.left)},this.$frozen=!1,this.freeze=function(){this.$frozen=!0},this.unfreeze=function(){this.$frozen=!1},this.$renderChanges=function(A,M){if(this.$changes&&(A|=this.$changes,this.$changes=0),!this.session||!this.container.offsetWidth||this.$frozen||!A&&!M){this.$changes|=A;return}if(this.$size.$dirty)return this.$changes|=A,this.onResize(!0);this.lineHeight||this.$textLayer.checkForSizeChanges(),this._signal("beforeRender");var x=this.layerConfig;if(A&this.CHANGE_FULL||A&this.CHANGE_SIZE||A&this.CHANGE_TEXT||A&this.CHANGE_LINES||A&this.CHANGE_SCROLL||A&this.CHANGE_H_SCROLL){if(A|=this.$computeLayerConfig(),x.firstRow!=this.layerConfig.firstRow&&x.firstRowScreen==this.layerConfig.firstRowScreen){var R=this.scrollTop+(x.firstRow-this.layerConfig.firstRow)*this.lineHeight;R>0&&(this.scrollTop=R,A=A|this.CHANGE_SCROLL,A|=this.$computeLayerConfig())}x=this.layerConfig,this.$updateScrollBarV(),A&this.CHANGE_H_SCROLL&&this.$updateScrollBarH(),this.$gutterLayer.element.style.marginTop=-x.offset+"px",this.content.style.marginTop=-x.offset+"px",this.content.style.width=x.width+2*this.$padding+"px",this.content.style.height=x.minHeight+"px"}if(A&this.CHANGE_H_SCROLL&&(this.content.style.marginLeft=-this.scrollLeft+"px",this.scroller.className=this.scrollLeft<=0?"ace_scroller":"ace_scroller ace_scroll-left"),A&this.CHANGE_FULL){this.$textLayer.update(x),this.$showGutter&&this.$gutterLayer.update(x),this.$markerBack.update(x),this.$markerFront.update(x),this.$cursorLayer.update(x),this.$moveTextAreaToCursor(),this.$highlightGutterLine&&this.$updateGutterLineHighlight(),this._signal("afterRender");return}if(A&this.CHANGE_SCROLL){A&this.CHANGE_TEXT||A&this.CHANGE_LINES?this.$textLayer.update(x):this.$textLayer.scrollLines(x),this.$showGutter&&this.$gutterLayer.update(x),this.$markerBack.update(x),this.$markerFront.update(x),this.$cursorLayer.update(x),this.$highlightGutterLine&&this.$updateGutterLineHighlight(),this.$moveTextAreaToCursor(),this._signal("afterRender");return}A&this.CHANGE_TEXT?(this.$textLayer.update(x),this.$showGutter&&this.$gutterLayer.update(x)):A&this.CHANGE_LINES?(this.$updateLines()||A&this.CHANGE_GUTTER&&this.$showGutter)&&this.$gutterLayer.update(x):(A&this.CHANGE_TEXT||A&this.CHANGE_GUTTER)&&this.$showGutter&&this.$gutterLayer.update(x),A&this.CHANGE_CURSOR&&(this.$cursorLayer.update(x),this.$moveTextAreaToCursor(),this.$highlightGutterLine&&this.$updateGutterLineHighlight()),A&(this.CHANGE_MARKER|this.CHANGE_MARKER_FRONT)&&this.$markerFront.update(x),A&(this.CHANGE_MARKER|this.CHANGE_MARKER_BACK)&&this.$markerBack.update(x),this._signal("afterRender")},this.$autosize=function(){var A=this.session.getScreenLength()*this.lineHeight,M=this.$maxLines*this.lineHeight,x=Math.min(M,Math.max((this.$minLines||1)*this.lineHeight,A))+this.scrollMargin.v+(this.$extraHeight||0);this.$horizScroll&&(x+=this.scrollBarH.getHeight()),this.$maxPixelHeight&&x>this.$maxPixelHeight&&(x=this.$maxPixelHeight);var R=A>M;if(x!=this.desiredHeight||this.$size.height!=this.desiredHeight||R!=this.$vScroll){R!=this.$vScroll&&(this.$vScroll=R,this.scrollBarV.setVisible(R));var N=this.container.clientWidth;this.container.style.height=x+"px",this.$updateCachedSize(!0,this.$gutterWidth,N,x),this.desiredHeight=x,this._signal("autosize")}},this.$computeLayerConfig=function(){var A=this.session,M=this.$size,x=M.height<=2*this.lineHeight,R=this.session.getScreenLength(),N=R*this.lineHeight,j=this.$getLongestLine(),B=!x&&(this.$hScrollBarAlwaysVisible||M.scrollerWidth-j-2*this.$padding<0),q=this.$horizScroll!==B;q&&(this.$horizScroll=B,this.scrollBarH.setVisible(B));var U=this.$vScroll;this.$maxLines&&this.lineHeight>1&&this.$autosize();var Z=this.scrollTop%this.lineHeight,re=M.scrollerHeight+this.lineHeight,le=!this.$maxLines&&this.$scrollPastEnd?(M.scrollerHeight-this.lineHeight)*this.$scrollPastEnd:0;N+=le;var ce=this.scrollMargin;this.session.setScrollTop(Math.max(-ce.top,Math.min(this.scrollTop,N-M.scrollerHeight+ce.bottom))),this.session.setScrollLeft(Math.max(-ce.left,Math.min(this.scrollLeft,j+2*this.$padding-M.scrollerWidth+ce.right)));var de=!x&&(this.$vScrollBarAlwaysVisible||M.scrollerHeight-N+le<0||this.scrollTop>ce.top),he=U!==de;he&&(this.$vScroll=de,this.scrollBarV.setVisible(de));var Fe=Math.ceil(re/this.lineHeight)-1,ge=Math.max(0,Math.round((this.scrollTop-Z)/this.lineHeight)),ye=ge+Fe,Y,ue,Ee=this.lineHeight;ge=A.screenToDocumentRow(ge,0);var ne=A.getFoldLine(ge);ne&&(ge=ne.start.row),Y=A.documentToScreenRow(ge,0),ue=A.getRowLength(ge)*Ee,ye=Math.min(A.screenToDocumentRow(ye,0),A.getLength()-1),re=M.scrollerHeight+A.getRowLength(ye)*Ee+ue,Z=this.scrollTop-Y*Ee;var me=0;return this.layerConfig.width!=j&&(me=this.CHANGE_H_SCROLL),(q||he)&&(me=this.$updateCachedSize(!0,this.gutterWidth,M.width,M.height),this._signal("scrollbarVisibilityChanged"),he&&(j=this.$getLongestLine())),this.layerConfig={width:j,padding:this.$padding,firstRow:ge,firstRowScreen:Y,lastRow:ye,lineHeight:Ee,characterWidth:this.characterWidth,minHeight:re,maxHeight:N,offset:Z,gutterOffset:Ee?Math.max(0,Math.ceil((Z+M.height-M.scrollerHeight)/Ee)):0,height:this.$size.scrollerHeight},me},this.$updateLines=function(){var A=this.$changedLines.firstRow,M=this.$changedLines.lastRow;this.$changedLines=null;var x=this.layerConfig;if(!(A>x.lastRow+1)&&!(M<x.firstRow)){if(M===1/0){this.$showGutter&&this.$gutterLayer.update(x),this.$textLayer.update(x);return}return this.$textLayer.updateLines(x,A,M),!0}},this.$getLongestLine=function(){var A=this.session.getScreenWidth();return this.showInvisibles&&!this.session.$useWrapMode&&(A+=1),Math.max(this.$size.scrollerWidth-2*this.$padding,Math.round(A*this.characterWidth))},this.updateFrontMarkers=function(){this.$markerFront.setMarkers(this.session.getMarkers(!0)),this.$loop.schedule(this.CHANGE_MARKER_FRONT)},this.updateBackMarkers=function(){this.$markerBack.setMarkers(this.session.getMarkers()),this.$loop.schedule(this.CHANGE_MARKER_BACK)},this.addGutterDecoration=function(A,M){this.$gutterLayer.addGutterDecoration(A,M)},this.removeGutterDecoration=function(A,M){this.$gutterLayer.removeGutterDecoration(A,M)},this.updateBreakpoints=function(A){this.$loop.schedule(this.CHANGE_GUTTER)},this.setAnnotations=function(A){this.$gutterLayer.setAnnotations(A),this.$loop.schedule(this.CHANGE_GUTTER)},this.updateCursor=function(){this.$loop.schedule(this.CHANGE_CURSOR)},this.hideCursor=function(){this.$cursorLayer.hideCursor()},this.showCursor=function(){this.$cursorLayer.showCursor()},this.scrollSelectionIntoView=function(A,M,x){this.scrollCursorIntoView(A,x),this.scrollCursorIntoView(M,x)},this.scrollCursorIntoView=function(A,M,x){if(this.$size.scrollerHeight!==0){var R=this.$cursorLayer.getPixelPosition(A),N=R.left,j=R.top,B=x&&x.top||0,q=x&&x.bottom||0,U=this.$scrollAnimation?this.session.getScrollTop():this.scrollTop;U+B>j?(M&&U+B>j+this.lineHeight&&(j-=M*this.$size.scrollerHeight),j===0&&(j=-this.scrollMargin.top),this.session.setScrollTop(j)):U+this.$size.scrollerHeight-q<j+this.lineHeight&&(M&&U+this.$size.scrollerHeight-q<j-this.lineHeight&&(j+=M*this.$size.scrollerHeight),this.session.setScrollTop(j+this.lineHeight-this.$size.scrollerHeight));var Z=this.scrollLeft;Z>N?(N<this.$padding+2*this.layerConfig.characterWidth&&(N=-this.scrollMargin.left),this.session.setScrollLeft(N)):Z+this.$size.scrollerWidth<N+this.characterWidth?this.session.setScrollLeft(Math.round(N+this.characterWidth-this.$size.scrollerWidth)):Z<=this.$padding&&N-Z<this.characterWidth&&this.session.setScrollLeft(0)}},this.getScrollTop=function(){return this.session.getScrollTop()},this.getScrollLeft=function(){return this.session.getScrollLeft()},this.getScrollTopRow=function(){return this.scrollTop/this.lineHeight},this.getScrollBottomRow=function(){return Math.max(0,Math.floor((this.scrollTop+this.$size.scrollerHeight)/this.lineHeight)-1)},this.scrollToRow=function(A){this.session.setScrollTop(A*this.lineHeight)},this.alignCursor=function(A,M){typeof A=="number"&&(A={row:A,column:0});var x=this.$cursorLayer.getPixelPosition(A),R=this.$size.scrollerHeight-this.lineHeight,N=x.top-R*(M||0);return this.session.setScrollTop(N),N},this.STEPS=8,this.$calcSteps=function(A,M){var x=0,R=this.STEPS,N=[],j=function(B,q,U){return U*(Math.pow(B-1,3)+1)+q};for(x=0;x<R;++x)N.push(j(x/this.STEPS,A,M-A));return N},this.scrollToLine=function(A,M,x,R){var N=this.$cursorLayer.getPixelPosition({row:A,column:0}),j=N.top;M&&(j-=this.$size.scrollerHeight/2);var B=this.scrollTop;this.session.setScrollTop(j),x!==!1&&this.animateScrolling(B,R)},this.animateScrolling=function(A,M){var x=this.scrollTop;if(this.$animatedScroll){var R=this;if(A!=x){if(this.$scrollAnimation){var N=this.$scrollAnimation.steps;if(N.length&&(A=N[0],A==x))return}var j=R.$calcSteps(A,x);this.$scrollAnimation={from:A,to:x,steps:j},clearInterval(this.$timer),R.session.setScrollTop(j.shift()),R.session.$scrollTop=x,this.$timer=setInterval(function(){j.length?(R.session.setScrollTop(j.shift()),R.session.$scrollTop=x):x!=null?(R.session.$scrollTop=-1,R.session.setScrollTop(x),x=null):(R.$timer=clearInterval(R.$timer),R.$scrollAnimation=null,M&&M())},10)}}},this.scrollToY=function(A){this.scrollTop!==A&&(this.$loop.schedule(this.CHANGE_SCROLL),this.scrollTop=A)},this.scrollToX=function(A){this.scrollLeft!==A&&(this.scrollLeft=A),this.$loop.schedule(this.CHANGE_H_SCROLL)},this.scrollTo=function(A,M){this.session.setScrollTop(M),this.session.setScrollLeft(M)},this.scrollBy=function(A,M){M&&this.session.setScrollTop(this.session.getScrollTop()+M),A&&this.session.setScrollLeft(this.session.getScrollLeft()+A)},this.isScrollableBy=function(A,M){if(M<0&&this.session.getScrollTop()>=1-this.scrollMargin.top||M>0&&this.session.getScrollTop()+this.$size.scrollerHeight-this.layerConfig.maxHeight<-1+this.scrollMargin.bottom||A<0&&this.session.getScrollLeft()>=1-this.scrollMargin.left||A>0&&this.session.getScrollLeft()+this.$size.scrollerWidth-this.layerConfig.width<-1+this.scrollMargin.right)return!0},this.pixelToScreenCoordinates=function(A,M){var x=this.scroller.getBoundingClientRect(),R=(A+this.scrollLeft-x.left-this.$padding)/this.characterWidth,N=Math.floor((M+this.scrollTop-x.top)/this.lineHeight),j=Math.round(R);return{row:N,column:j,side:R-j>0?1:-1}},this.screenToTextCoordinates=function(A,M){var x=this.scroller.getBoundingClientRect(),R=Math.round((A+this.scrollLeft-x.left-this.$padding)/this.characterWidth),N=(M+this.scrollTop-x.top)/this.lineHeight;return this.session.screenToDocumentPosition(N,Math.max(R,0))},this.textToScreenCoordinates=function(A,M){var x=this.scroller.getBoundingClientRect(),R=this.session.documentToScreenPosition(A,M),N=this.$padding+Math.round(R.column*this.characterWidth),j=R.row*this.lineHeight;return{pageX:x.left+N-this.scrollLeft,pageY:x.top+j-this.scrollTop}},this.visualizeFocus=function(){h.addCssClass(this.container,"ace_focus")},this.visualizeBlur=function(){h.removeCssClass(this.container,"ace_focus")},this.showComposition=function(A){this.$composition||(this.$composition={keepTextAreaAtCursor:this.$keepTextAreaAtCursor,cssText:this.textarea.style.cssText}),this.$keepTextAreaAtCursor=!0,h.addCssClass(this.textarea,"ace_composition"),this.textarea.style.cssText="",this.$moveTextAreaToCursor()},this.setCompositionText=function(A){this.$moveTextAreaToCursor()},this.hideComposition=function(){this.$composition&&(h.removeCssClass(this.textarea,"ace_composition"),this.$keepTextAreaAtCursor=this.$composition.keepTextAreaAtCursor,this.textarea.style.cssText=this.$composition.cssText,this.$composition=null)},this.setTheme=function(A,M){var x=this;if(this.$themeId=A,x._dispatchEvent("themeChange",{theme:A}),!A||typeof A=="string"){var R=A||this.$options.theme.initialValue;g.loadModule(["theme",R],N)}else N(A);function N(j){if(x.$themeId!=A)return M&&M();if(!j||!j.cssClass)throw new Error("couldn't load module "+A+" or it didn't call define");h.importCssString(j.cssText,j.cssClass,x.container.ownerDocument),x.theme&&h.removeCssClass(x.container,x.theme.cssClass);var B="padding"in j?j.padding:"padding"in(x.theme||{})?4:x.$padding;x.$padding&&B!=x.$padding&&x.setPadding(B),x.$theme=j.cssClass,x.theme=j,h.addCssClass(x.container,j.cssClass),h.setCssClass(x.container,"ace_dark",j.isDark),x.$size&&(x.$size.width=0,x.$updateSizeAsync()),x._dispatchEvent("themeLoaded",{theme:j}),M&&M()}},this.getTheme=function(){return this.$themeId},this.setStyle=function(A,M){h.setCssClass(this.container,A,M!==!1)},this.unsetStyle=function(A){h.removeCssClass(this.container,A)},this.setCursorStyle=function(A){this.scroller.style.cursor!=A&&(this.scroller.style.cursor=A)},this.setMouseCursor=function(A){this.scroller.style.cursor=A},this.destroy=function(){this.$textLayer.destroy(),this.$cursorLayer.destroy()}}).call(w.prototype),g.defineOptions(w.prototype,"renderer",{animatedScroll:{initialValue:!1},showInvisibles:{set:function(A){this.$textLayer.setShowInvisibles(A)&&this.$loop.schedule(this.CHANGE_TEXT)},initialValue:!1},showPrintMargin:{set:function(){this.$updatePrintMargin()},initialValue:!0},printMarginColumn:{set:function(){this.$updatePrintMargin()},initialValue:80},printMargin:{set:function(A){typeof A=="number"&&(this.$printMarginColumn=A),this.$showPrintMargin=!!A,this.$updatePrintMargin()},get:function(){return this.$showPrintMargin&&this.$printMarginColumn}},showGutter:{set:function(A){this.$gutter.style.display=A?"block":"none",this.$loop.schedule(this.CHANGE_FULL),this.onGutterResize()},initialValue:!0},fadeFoldWidgets:{set:function(A){h.setCssClass(this.$gutter,"ace_fade-fold-widgets",A)},initialValue:!1},showFoldWidgets:{set:function(A){this.$gutterLayer.setShowFoldWidgets(A)},initialValue:!0},showLineNumbers:{set:function(A){this.$gutterLayer.setShowLineNumbers(A),this.$loop.schedule(this.CHANGE_GUTTER)},initialValue:!0},displayIndentGuides:{set:function(A){this.$textLayer.setDisplayIndentGuides(A)&&this.$loop.schedule(this.CHANGE_TEXT)},initialValue:!0},highlightGutterLine:{set:function(A){if(!this.$gutterLineHighlight){this.$gutterLineHighlight=h.createElement("div"),this.$gutterLineHighlight.className="ace_gutter-active-line",this.$gutter.appendChild(this.$gutterLineHighlight);return}this.$gutterLineHighlight.style.display=A?"":"none",this.$cursorLayer.$pixelPos&&this.$updateGutterLineHighlight()},initialValue:!1,value:!0},hScrollBarAlwaysVisible:{set:function(A){(!this.$hScrollBarAlwaysVisible||!this.$horizScroll)&&this.$loop.schedule(this.CHANGE_SCROLL)},initialValue:!1},vScrollBarAlwaysVisible:{set:function(A){(!this.$vScrollBarAlwaysVisible||!this.$vScroll)&&this.$loop.schedule(this.CHANGE_SCROLL)},initialValue:!1},fontSize:{set:function(A){typeof A=="number"&&(A=A+"px"),this.container.style.fontSize=A,this.updateFontSize()},initialValue:12},fontFamily:{set:function(A){this.container.style.fontFamily=A,this.updateFontSize()}},maxLines:{set:function(A){this.updateFull()}},minLines:{set:function(A){this.updateFull()}},maxPixelHeight:{set:function(A){this.updateFull()},initialValue:0},scrollPastEnd:{set:function(A){A=+A||0,this.$scrollPastEnd!=A&&(this.$scrollPastEnd=A,this.$loop.schedule(this.CHANGE_SCROLL))},initialValue:0,handlesSet:!0},fixedWidthGutter:{set:function(A){this.$gutterLayer.$fixedWidth=!!A,this.$loop.schedule(this.CHANGE_GUTTER)}},theme:{set:function(A){this.setTheme(A)},get:function(){return this.$themeId||this.theme},initialValue:"./theme/textmate",handlesSet:!0}}),o.VirtualRenderer=w}),ace.define("ace/worker/worker_client",["require","exports","module","ace/lib/oop","ace/lib/net","ace/lib/event_emitter","ace/config"],function(s,o,f){var n=s("../lib/oop"),h=s("../lib/net"),g=s("../lib/event_emitter").EventEmitter,d=s("../config"),l=function(a,F,p,m){if(this.$sendDeltaQueue=this.$sendDeltaQueue.bind(this),this.changeListener=this.changeListener.bind(this),this.onMessage=this.onMessage.bind(this),s.nameToUrl&&!s.toUrl&&(s.toUrl=s.nameToUrl),d.get("packaged")||!s.toUrl)m=m||d.moduleUrl(F.id,"worker");else{var b=this.$normalizePath;m=m||b(s.toUrl("ace/worker/worker.js",null,"_"));var C={};a.forEach(function(R){C[R]=b(s.toUrl(R,null,"_").replace(/(\.js)?(\?.*)?$/,""))})}try{var k=F.src,T=i(70),w=new T([k],{type:"application/javascript"}),A=(window.URL||window.webkitURL).createObjectURL(w);this.$worker=new Worker(A)}catch(R){if(R instanceof window.DOMException){var w=this.$workerBlob(m),M=window.URL||window.webkitURL,x=M.createObjectURL(w);this.$worker=new Worker(x),M.revokeObjectURL(x)}else throw R}this.$worker.postMessage({init:!0,tlns:C,module:F.id,classname:p}),this.callbackId=1,this.callbacks={},this.$worker.onmessage=this.onMessage};(function(){n.implement(this,g),this.onMessage=function(a){var F=a.data;switch(F.type){case"event":this._signal(F.name,{data:F.data});break;case"call":var p=this.callbacks[F.id];p&&(p(F.data),delete this.callbacks[F.id]);break;case"error":this.reportError(F.data);break;case"log":window.console&&console.log&&console.log.apply(console,F.data);break}},this.reportError=function(a){window.console&&console.error&&console.error(a)},this.$normalizePath=function(a){return h.qualifyURL(a)},this.terminate=function(){this._signal("terminate",{}),this.deltaQueue=null,this.$worker.terminate(),this.$worker=null,this.$doc&&this.$doc.off("change",this.changeListener),this.$doc=null},this.send=function(a,F){this.$worker.postMessage({command:a,args:F})},this.call=function(a,F,p){if(p){var m=this.callbackId++;this.callbacks[m]=p,F.push(m)}this.send(a,F)},this.emit=function(a,F){try{this.$worker.postMessage({event:a,data:{data:F.data}})}catch(p){console.error(p.stack)}},this.attachToDocument=function(a){this.$doc&&this.terminate(),this.$doc=a,this.call("setValue",[a.getValue()]),a.on("change",this.changeListener)},this.changeListener=function(a){this.deltaQueue||(this.deltaQueue=[],setTimeout(this.$sendDeltaQueue,0)),a.action=="insert"?this.deltaQueue.push(a.start,a.lines):this.deltaQueue.push(a.start,a.end)},this.$sendDeltaQueue=function(){var a=this.deltaQueue;a&&(this.deltaQueue=null,a.length>50&&a.length>this.$doc.getLength()>>1?this.call("setValue",[this.$doc.getValue()]):this.emit("change",{data:a}))},this.$workerBlob=function(a){var F="importScripts('"+h.qualifyURL(a)+"');";try{return new Blob([F],{type:"application/javascript"})}catch{var p=window.BlobBuilder||window.WebKitBlobBuilder||window.MozBlobBuilder,m=new p;return m.append(F),m.getBlob("application/javascript")}}}).call(l.prototype);var c=function(a,F,p){this.$sendDeltaQueue=this.$sendDeltaQueue.bind(this),this.changeListener=this.changeListener.bind(this),this.callbackId=1,this.callbacks={},this.messageBuffer=[];var m=null,b=!1,C=Object.create(g),k=this;this.$worker={},this.$worker.terminate=function(){},this.$worker.postMessage=function(w){k.messageBuffer.push(w),m&&(b?setTimeout(T):T())},this.setEmitSync=function(w){b=w};var T=function(){var w=k.messageBuffer.shift();w.command?m[w.command].apply(m,w.args):w.event&&C._signal(w.event,w.data)};C.postMessage=function(w){k.onMessage({data:w})},C.callback=function(w,A){this.postMessage({type:"call",id:A,data:w})},C.emit=function(w,A){this.postMessage({type:"event",name:w,data:A})},d.loadModule(["worker",F],function(w){for(m=new w[p](C);k.messageBuffer.length;)T()})};c.prototype=l.prototype,o.UIWorkerClient=c,o.WorkerClient=l}),ace.define("ace/placeholder",["require","exports","module","ace/range","ace/lib/event_emitter","ace/lib/oop"],function(s,o,f){var n=s("./range").Range,h=s("./lib/event_emitter").EventEmitter,g=s("./lib/oop"),d=function(l,c,a,F,p,m){var b=this;this.length=c,this.session=l,this.doc=l.getDocument(),this.mainClass=p,this.othersClass=m,this.$onUpdate=this.onUpdate.bind(this),this.doc.on("change",this.$onUpdate),this.$others=F,this.$onCursorChange=function(){setTimeout(function(){b.onCursorChange()})},this.$pos=a;var C=l.getUndoManager().$undoStack||l.getUndoManager().$undostack||{length:-1};this.$undoStackDepth=C.length,this.setup(),l.selection.on("changeCursor",this.$onCursorChange)};(function(){g.implement(this,h),this.setup=function(){var l=this,c=this.doc,a=this.session;this.selectionBefore=a.selection.toJSON(),a.selection.inMultiSelectMode&&a.selection.toSingleRange(),this.pos=c.createAnchor(this.$pos.row,this.$pos.column);var F=this.pos;F.$insertRight=!0,F.detach(),F.markerId=a.addMarker(new n(F.row,F.column,F.row,F.column+this.length),this.mainClass,null,!1),this.others=[],this.$others.forEach(function(p){var m=c.createAnchor(p.row,p.column);m.$insertRight=!0,m.detach(),l.others.push(m)}),a.setUndoSelect(!1)},this.showOtherMarkers=function(){if(!this.othersActive){var l=this.session,c=this;this.othersActive=!0,this.others.forEach(function(a){a.markerId=l.addMarker(new n(a.row,a.column,a.row,a.column+c.length),c.othersClass,null,!1)})}},this.hideOtherMarkers=function(){if(this.othersActive){this.othersActive=!1;for(var l=0;l<this.others.length;l++)this.session.removeMarker(this.others[l].markerId)}},this.onUpdate=function(l){if(this.$updating)return this.updateAnchors(l);var c=l;if(c.start.row===c.end.row&&c.start.row===this.pos.row){this.$updating=!0;var a=l.action==="insert"?c.end.column-c.start.column:c.start.column-c.end.column,F=c.start.column>=this.pos.column&&c.start.column<=this.pos.column+this.length+1,p=c.start.column-this.pos.column;if(this.updateAnchors(l),F&&(this.length+=a),F&&!this.session.$fromUndo){if(l.action==="insert")for(var m=this.others.length-1;m>=0;m--){var b=this.others[m],C={row:b.row,column:b.column+p};this.doc.insertMergedLines(C,l.lines)}else if(l.action==="remove")for(var m=this.others.length-1;m>=0;m--){var b=this.others[m],C={row:b.row,column:b.column+p};this.doc.remove(new n(C.row,C.column,C.row,C.column-a))}}this.$updating=!1,this.updateMarkers()}},this.updateAnchors=function(l){this.pos.onChange(l);for(var c=this.others.length;c--;)this.others[c].onChange(l);this.updateMarkers()},this.updateMarkers=function(){if(!this.$updating){var l=this,c=this.session,a=function(p,m){c.removeMarker(p.markerId),p.markerId=c.addMarker(new n(p.row,p.column,p.row,p.column+l.length),m,null,!1)};a(this.pos,this.mainClass);for(var F=this.others.length;F--;)a(this.others[F],this.othersClass)}},this.onCursorChange=function(l){if(!(this.$updating||!this.session)){var c=this.session.selection.getCursor();c.row===this.pos.row&&c.column>=this.pos.column&&c.column<=this.pos.column+this.length?(this.showOtherMarkers(),this._emit("cursorEnter",l)):(this.hideOtherMarkers(),this._emit("cursorLeave",l))}},this.detach=function(){this.session.removeMarker(this.pos&&this.pos.markerId),this.hideOtherMarkers(),this.doc.removeEventListener("change",this.$onUpdate),this.session.selection.removeEventListener("changeCursor",this.$onCursorChange),this.session.setUndoSelect(!0),this.session=null},this.cancel=function(){if(this.$undoStackDepth!==-1){for(var l=this.session.getUndoManager(),c=(l.$undoStack||l.$undostack).length-this.$undoStackDepth,a=0;a<c;a++)l.undo(!0);this.selectionBefore&&this.session.selection.fromJSON(this.selectionBefore)}}}).call(d.prototype),o.PlaceHolder=d}),ace.define("ace/mouse/multi_select_handler",["require","exports","module","ace/lib/event","ace/lib/useragent"],function(s,o,f){var n=s("../lib/event"),h=s("../lib/useragent");function g(l,c){return l.row==c.row&&l.column==c.column}function d(l){var c=l.domEvent,a=c.altKey,F=c.shiftKey,p=c.ctrlKey,m=l.getAccelKey(),b=l.getButton();if(p&&h.isMac&&(b=c.button),l.editor.inMultiSelectMode&&b==2){l.editor.textInput.onContextMenu(l.domEvent);return}if(!p&&!a&&!m){b===0&&l.editor.inMultiSelectMode&&l.editor.exitMultiSelectMode();return}if(b===0){var C=l.editor,k=C.selection,T=C.inMultiSelectMode,w=l.getDocumentPosition(),A=k.getCursor(),M=l.inSelection()||k.isEmpty()&&g(w,A),x=l.x,R=l.y,N=function(ye){x=ye.clientX,R=ye.clientY},j=C.session,B=C.renderer.pixelToScreenCoordinates(x,R),q=B,U;if(C.$mouseHandler.$enableJumpToDef)p&&a||m&&a?U=F?"block":"add":a&&C.$blockSelectEnabled&&(U="block");else if(m&&!a){if(U="add",!T&&F)return}else a&&C.$blockSelectEnabled&&(U="block");if(U&&h.isMac&&c.ctrlKey&&C.$mouseHandler.cancelContextMenu(),U=="add"){if(!T&&M)return;if(!T){var Z=k.toOrientedRange();C.addSelectionMarker(Z)}var re=k.rangeList.rangeAtPoint(w);C.$blockScrolling++,C.inVirtualSelectionMode=!0,F&&(re=null,Z=k.ranges[0]||Z,C.removeSelectionMarker(Z)),C.once("mouseup",function(){var ye=k.toOrientedRange();re&&ye.isEmpty()&&g(re.cursor,ye.cursor)?k.substractPoint(ye.cursor):(F?k.substractPoint(Z.cursor):Z&&(C.removeSelectionMarker(Z),k.addRange(Z)),k.addRange(ye)),C.$blockScrolling--,C.inVirtualSelectionMode=!1})}else if(U=="block"){l.stop(),C.inVirtualSelectionMode=!0;var le,ce=[],de=function(){var ye=C.renderer.pixelToScreenCoordinates(x,R),Y=j.screenToDocumentPosition(ye.row,ye.column);g(q,ye)&&g(Y,k.lead)||(q=ye,C.$blockScrolling++,C.selection.moveToPosition(Y),C.renderer.scrollCursorIntoView(),C.removeSelectionMarkers(ce),ce=k.rectangularRangeBlock(q,B),C.$mouseHandler.$clickSelection&&ce.length==1&&ce[0].isEmpty()&&(ce[0]=C.$mouseHandler.$clickSelection.clone()),ce.forEach(C.addSelectionMarker,C),C.updateSelectionMarkers(),C.$blockScrolling--)};C.$blockScrolling++,T&&!m?k.toSingleRange():!T&&m&&(le=k.toOrientedRange(),C.addSelectionMarker(le)),F?B=j.documentToScreenPosition(k.lead):k.moveToPosition(w),C.$blockScrolling--,q={row:-1,column:-1};var he=function(ye){clearInterval(ge),C.removeSelectionMarkers(ce),ce.length||(ce=[k.toOrientedRange()]),C.$blockScrolling++,le&&(C.removeSelectionMarker(le),k.toSingleRange(le));for(var Y=0;Y<ce.length;Y++)k.addRange(ce[Y]);C.inVirtualSelectionMode=!1,C.$mouseHandler.$clickSelection=null,C.$blockScrolling--},Fe=de;n.capture(C.container,N,he);var ge=setInterval(function(){Fe()},20);return l.preventDefault()}}}o.onMouseDown=d}),ace.define("ace/commands/multi_select_commands",["require","exports","module","ace/keyboard/hash_handler"],function(s,o,f){o.defaultCommands=[{name:"addCursorAbove",exec:function(h){h.selectMoreLines(-1)},bindKey:{win:"Ctrl-Alt-Up",mac:"Ctrl-Alt-Up"},scrollIntoView:"cursor",readOnly:!0},{name:"addCursorBelow",exec:function(h){h.selectMoreLines(1)},bindKey:{win:"Ctrl-Alt-Down",mac:"Ctrl-Alt-Down"},scrollIntoView:"cursor",readOnly:!0},{name:"addCursorAboveSkipCurrent",exec:function(h){h.selectMoreLines(-1,!0)},bindKey:{win:"Ctrl-Alt-Shift-Up",mac:"Ctrl-Alt-Shift-Up"},scrollIntoView:"cursor",readOnly:!0},{name:"addCursorBelowSkipCurrent",exec:function(h){h.selectMoreLines(1,!0)},bindKey:{win:"Ctrl-Alt-Shift-Down",mac:"Ctrl-Alt-Shift-Down"},scrollIntoView:"cursor",readOnly:!0},{name:"selectMoreBefore",exec:function(h){h.selectMore(-1)},bindKey:{win:"Ctrl-Alt-Left",mac:"Ctrl-Alt-Left"},scrollIntoView:"cursor",readOnly:!0},{name:"selectMoreAfter",exec:function(h){h.selectMore(1)},bindKey:{win:"Ctrl-Alt-Right",mac:"Ctrl-Alt-Right"},scrollIntoView:"cursor",readOnly:!0},{name:"selectNextBefore",exec:function(h){h.selectMore(-1,!0)},bindKey:{win:"Ctrl-Alt-Shift-Left",mac:"Ctrl-Alt-Shift-Left"},scrollIntoView:"cursor",readOnly:!0},{name:"selectNextAfter",exec:function(h){h.selectMore(1,!0)},bindKey:{win:"Ctrl-Alt-Shift-Right",mac:"Ctrl-Alt-Shift-Right"},scrollIntoView:"cursor",readOnly:!0},{name:"splitIntoLines",exec:function(h){h.multiSelect.splitIntoLines()},bindKey:{win:"Ctrl-Alt-L",mac:"Ctrl-Alt-L"},readOnly:!0},{name:"alignCursors",exec:function(h){h.alignCursors()},bindKey:{win:"Ctrl-Alt-A",mac:"Ctrl-Alt-A"},scrollIntoView:"cursor"},{name:"findAll",exec:function(h){h.findAll()},bindKey:{win:"Ctrl-Alt-K",mac:"Ctrl-Alt-G"},scrollIntoView:"cursor",readOnly:!0}],o.multiSelectCommands=[{name:"singleSelection",bindKey:"esc",exec:function(h){h.exitMultiSelectMode()},scrollIntoView:"cursor",readOnly:!0,isAvailable:function(h){return h&&h.inMultiSelectMode}}];var n=s("../keyboard/hash_handler").HashHandler;o.keyboardHandler=new n(o.multiSelectCommands)}),ace.define("ace/multi_select",["require","exports","module","ace/range_list","ace/range","ace/selection","ace/mouse/multi_select_handler","ace/lib/event","ace/lib/lang","ace/commands/multi_select_commands","ace/search","ace/edit_session","ace/editor","ace/config"],function(s,o,f){var n=s("./range_list").RangeList,h=s("./range").Range,g=s("./selection").Selection,d=s("./mouse/multi_select_handler").onMouseDown,l=s("./lib/event"),c=s("./lib/lang"),a=s("./commands/multi_select_commands");o.commands=a.defaultCommands.concat(a.multiSelectCommands);var F=s("./search").Search,p=new F;function m(A,M,x){return p.$options.wrap=!0,p.$options.needle=M,p.$options.backwards=x==-1,p.find(A)}var b=s("./edit_session").EditSession;(function(){this.getSelectionMarkers=function(){return this.$selectionMarkers}}).call(b.prototype),function(){this.ranges=null,this.rangeList=null,this.addRange=function(A,M){if(A){if(!this.inMultiSelectMode&&this.rangeCount===0){var x=this.toOrientedRange();if(this.rangeList.add(x),this.rangeList.add(A),this.rangeList.ranges.length!=2)return this.rangeList.removeAll(),M||this.fromOrientedRange(A);this.rangeList.removeAll(),this.rangeList.add(x),this.$onAddRange(x)}A.cursor||(A.cursor=A.end);var R=this.rangeList.add(A);return this.$onAddRange(A),R.length&&this.$onRemoveRange(R),this.rangeCount>1&&!this.inMultiSelectMode&&(this._signal("multiSelect"),this.inMultiSelectMode=!0,this.session.$undoSelect=!1,this.rangeList.attach(this.session)),M||this.fromOrientedRange(A)}},this.toSingleRange=function(A){A=A||this.ranges[0];var M=this.rangeList.removeAll();M.length&&this.$onRemoveRange(M),A&&this.fromOrientedRange(A)},this.substractPoint=function(A){var M=this.rangeList.substractPoint(A);if(M)return this.$onRemoveRange(M),M[0]},this.mergeOverlappingRanges=function(){var A=this.rangeList.merge();A.length?this.$onRemoveRange(A):this.ranges[0]&&this.fromOrientedRange(this.ranges[0])},this.$onAddRange=function(A){this.rangeCount=this.rangeList.ranges.length,this.ranges.unshift(A),this._signal("addRange",{range:A})},this.$onRemoveRange=function(A){if(this.rangeCount=this.rangeList.ranges.length,this.rangeCount==1&&this.inMultiSelectMode){var M=this.rangeList.ranges.pop();A.push(M),this.rangeCount=0}for(var x=A.length;x--;){var R=this.ranges.indexOf(A[x]);this.ranges.splice(R,1)}this._signal("removeRange",{ranges:A}),this.rangeCount===0&&this.inMultiSelectMode&&(this.inMultiSelectMode=!1,this._signal("singleSelect"),this.session.$undoSelect=!0,this.rangeList.detach(this.session)),M=M||this.ranges[0],M&&!M.isEqual(this.getRange())&&this.fromOrientedRange(M)},this.$initRangeList=function(){this.rangeList||(this.rangeList=new n,this.ranges=[],this.rangeCount=0)},this.getAllRanges=function(){return this.rangeCount?this.rangeList.ranges.concat():[this.getRange()]},this.splitIntoLines=function(){if(this.rangeCount>1){var A=this.rangeList.ranges,M=A[A.length-1],x=h.fromPoints(A[0].start,M.end);this.toSingleRange(),this.setSelectionRange(x,M.cursor==M.start)}else{var x=this.getRange(),R=this.isBackwards(),N=x.start.row,j=x.end.row;if(N==j){if(R)var B=x.end,q=x.start;else var B=x.start,q=x.end;this.addRange(h.fromPoints(q,q)),this.addRange(h.fromPoints(B,B));return}var U=[],Z=this.getLineRange(N,!0);Z.start.column=x.start.column,U.push(Z);for(var re=N+1;re<j;re++)U.push(this.getLineRange(re,!0));Z=this.getLineRange(j,!0),Z.end.column=x.end.column,U.push(Z),U.forEach(this.addRange,this)}},this.toggleBlockSelection=function(){if(this.rangeCount>1){var A=this.rangeList.ranges,M=A[A.length-1],x=h.fromPoints(A[0].start,M.end);this.toSingleRange(),this.setSelectionRange(x,M.cursor==M.start)}else{var R=this.session.documentToScreenPosition(this.selectionLead),N=this.session.documentToScreenPosition(this.selectionAnchor),j=this.rectangularRangeBlock(R,N);j.forEach(this.addRange,this)}},this.rectangularRangeBlock=function(A,M,x){var R=[],N=A.column<M.column;if(N)var j=A.column,B=M.column;else var j=M.column,B=A.column;var q=A.row<M.row;if(q)var U=A.row,Z=M.row;else var U=M.row,Z=A.row;j<0&&(j=0),U<0&&(U=0),U==Z&&(x=!0);for(var re=U;re<=Z;re++){var le=h.fromPoints(this.session.screenToDocumentPosition(re,j),this.session.screenToDocumentPosition(re,B));if(le.isEmpty()){if(ce&&k(le.end,ce))break;var ce=le.end}le.cursor=N?le.start:le.end,R.push(le)}if(q&&R.reverse(),!x){for(var de=R.length-1;R[de].isEmpty()&&de>0;)de--;if(de>0)for(var he=0;R[he].isEmpty();)he++;for(var Fe=de;Fe>=he;Fe--)R[Fe].isEmpty()&&R.splice(Fe,1)}return R}}.call(g.prototype);var C=s("./editor").Editor;(function(){this.updateSelectionMarkers=function(){this.renderer.updateCursor(),this.renderer.updateBackMarkers()},this.addSelectionMarker=function(A){A.cursor||(A.cursor=A.end);var M=this.getSelectionStyle();return A.marker=this.session.addMarker(A,"ace_selection",M),this.session.$selectionMarkers.push(A),this.session.selectionMarkerCount=this.session.$selectionMarkers.length,A},this.removeSelectionMarker=function(A){if(A.marker){this.session.removeMarker(A.marker);var M=this.session.$selectionMarkers.indexOf(A);M!=-1&&this.session.$selectionMarkers.splice(M,1),this.session.selectionMarkerCount=this.session.$selectionMarkers.length}},this.removeSelectionMarkers=function(A){for(var M=this.session.$selectionMarkers,x=A.length;x--;){var R=A[x];if(R.marker){this.session.removeMarker(R.marker);var N=M.indexOf(R);N!=-1&&M.splice(N,1)}}this.session.selectionMarkerCount=M.length},this.$onAddRange=function(A){this.addSelectionMarker(A.range),this.renderer.updateCursor(),this.renderer.updateBackMarkers()},this.$onRemoveRange=function(A){this.removeSelectionMarkers(A.ranges),this.renderer.updateCursor(),this.renderer.updateBackMarkers()},this.$onMultiSelect=function(A){this.inMultiSelectMode||(this.inMultiSelectMode=!0,this.setStyle("ace_multiselect"),this.keyBinding.addKeyboardHandler(a.keyboardHandler),this.commands.setDefaultHandler("exec",this.$onMultiSelectExec),this.renderer.updateCursor(),this.renderer.updateBackMarkers())},this.$onSingleSelect=function(A){this.session.multiSelect.inVirtualMode||(this.inMultiSelectMode=!1,this.unsetStyle("ace_multiselect"),this.keyBinding.removeKeyboardHandler(a.keyboardHandler),this.commands.removeDefaultHandler("exec",this.$onMultiSelectExec),this.renderer.updateCursor(),this.renderer.updateBackMarkers(),this._emit("changeSelection"))},this.$onMultiSelectExec=function(A){var M=A.command,x=A.editor;if(x.multiSelect){if(M.multiSelectAction)M.multiSelectAction=="forEach"?R=x.forEachSelection(M,A.args):M.multiSelectAction=="forEachLine"?R=x.forEachSelection(M,A.args,!0):M.multiSelectAction=="single"?(x.exitMultiSelectMode(),R=M.exec(x,A.args||{})):R=M.multiSelectAction(x,A.args||{});else{var R=M.exec(x,A.args||{});x.multiSelect.addRange(x.multiSelect.toOrientedRange()),x.multiSelect.mergeOverlappingRanges()}return R}},this.forEachSelection=function(A,M,x){if(!this.inVirtualSelectionMode){var R=x&&x.keepOrder,N=x==!0||x&&x.$byLines,j=this.session,B=this.selection,q=B.rangeList,U=(R?B:q).ranges,Z;if(!U.length)return A.exec?A.exec(this,M||{}):A(this,M||{});var re=B._eventRegistry;B._eventRegistry={};var le=new g(j);this.inVirtualSelectionMode=!0;for(var ce=U.length;ce--;){if(N)for(;ce>0&&U[ce].start.row==U[ce-1].end.row;)ce--;le.fromOrientedRange(U[ce]),le.index=ce,this.selection=j.selection=le;var de=A.exec?A.exec(this,M||{}):A(this,M||{});!Z&&de!==void 0&&(Z=de),le.toOrientedRange(U[ce])}le.detach(),this.selection=j.selection=B,this.inVirtualSelectionMode=!1,B._eventRegistry=re,B.mergeOverlappingRanges();var he=this.renderer.$scrollAnimation;return this.onCursorChange(),this.onSelectionChange(),he&&he.from==he.to&&this.renderer.animateScrolling(he.from),Z}},this.exitMultiSelectMode=function(){!this.inMultiSelectMode||this.inVirtualSelectionMode||this.multiSelect.toSingleRange()},this.getSelectedText=function(){var A="";if(this.inMultiSelectMode&&!this.inVirtualSelectionMode){for(var M=this.multiSelect.rangeList.ranges,x=[],R=0;R<M.length;R++)x.push(this.session.getTextRange(M[R]));var N=this.session.getDocument().getNewLineCharacter();A=x.join(N),A.length==(x.length-1)*N.length&&(A="")}else this.selection.isEmpty()||(A=this.session.getTextRange(this.getSelectionRange()));return A},this.$checkMultiselectChange=function(A,M){if(this.inMultiSelectMode&&!this.inVirtualSelectionMode){var x=this.multiSelect.ranges[0];if(this.multiSelect.isEmpty()&&M==this.multiSelect.anchor)return;var R=M==this.multiSelect.anchor?x.cursor==x.start?x.end:x.start:x.cursor;(R.row!=M.row||this.session.$clipPositionToDocument(R.row,R.column).column!=M.column)&&this.multiSelect.toSingleRange(this.multiSelect.toOrientedRange())}},this.findAll=function(A,M,x){if(M=M||{},M.needle=A||M.needle,M.needle==null){var R=this.selection.isEmpty()?this.selection.getWordRange():this.selection.getRange();M.needle=this.session.getTextRange(R)}this.$search.set(M);var N=this.$search.findAll(this.session);if(!N.length)return 0;this.$blockScrolling+=1;var j=this.multiSelect;x||j.toSingleRange(N[0]);for(var B=N.length;B--;)j.addRange(N[B],!0);return R&&j.rangeList.rangeAtPoint(R.start)&&j.addRange(R,!0),this.$blockScrolling-=1,N.length},this.selectMoreLines=function(A,M){var x=this.selection.toOrientedRange(),R=x.cursor==x.end,N=this.session.documentToScreenPosition(x.cursor);this.selection.$desiredColumn&&(N.column=this.selection.$desiredColumn);var j=this.session.screenToDocumentPosition(N.row+A,N.column);if(x.isEmpty())var q=j;else var B=this.session.documentToScreenPosition(R?x.end:x.start),q=this.session.screenToDocumentPosition(B.row+A,B.column);if(R){var U=h.fromPoints(j,q);U.cursor=U.start}else{var U=h.fromPoints(q,j);U.cursor=U.end}if(U.desiredColumn=N.column,!this.selection.inMultiSelectMode)this.selection.addRange(x);else if(M)var Z=x.cursor;this.selection.addRange(U),Z&&this.selection.substractPoint(Z)},this.transposeSelections=function(A){for(var M=this.session,x=M.multiSelect,R=x.ranges,N=R.length;N--;){var j=R[N];if(j.isEmpty()){var B=M.getWordRange(j.start.row,j.start.column);j.start.row=B.start.row,j.start.column=B.start.column,j.end.row=B.end.row,j.end.column=B.end.column}}x.mergeOverlappingRanges();for(var q=[],N=R.length;N--;){var j=R[N];q.unshift(M.getTextRange(j))}A<0?q.unshift(q.pop()):q.push(q.shift());for(var N=R.length;N--;){var j=R[N],B=j.clone();M.replace(j,q[N]),j.start.row=B.start.row,j.start.column=B.start.column}},this.selectMore=function(A,M,x){var R=this.session,N=R.multiSelect,j=N.toOrientedRange();if(!(j.isEmpty()&&(j=R.getWordRange(j.start.row,j.start.column),j.cursor=A==-1?j.start:j.end,this.multiSelect.addRange(j),x))){var B=R.getTextRange(j),q=m(R,B,A);q&&(q.cursor=A==-1?q.start:q.end,this.$blockScrolling+=1,this.session.unfold(q),this.multiSelect.addRange(q),this.$blockScrolling-=1,this.renderer.scrollCursorIntoView(null,.5)),M&&this.multiSelect.substractPoint(j.cursor)}},this.alignCursors=function(){var A=this.session,M=A.multiSelect,x=M.ranges,R=-1,N=x.filter(function(Fe){if(Fe.cursor.row==R)return!0;R=Fe.cursor.row});if(!x.length||N.length==x.length-1){var j=this.selection.getRange(),B=j.start.row,q=j.end.row,U=B==q;if(U){var Z=this.session.getLength(),re;do re=this.session.getLine(q);while(/[=:]/.test(re)&&++q<Z);do re=this.session.getLine(B);while(/[=:]/.test(re)&&--B>0);B<0&&(B=0),q>=Z&&(q=Z-1)}var le=this.session.removeFullLines(B,q);le=this.$reAlignText(le,U),this.session.insert({row:B,column:0},le.join(`
`)+`
`),U||(j.start.column=0,j.end.column=le[le.length-1].length),this.selection.setRange(j)}else{N.forEach(function(Fe){M.substractPoint(Fe.cursor)});var ce=0,de=1/0,he=x.map(function(Fe){var ge=Fe.cursor,ye=A.getLine(ge.row),Y=ye.substr(ge.column).search(/\S/g);return Y==-1&&(Y=0),ge.column>ce&&(ce=ge.column),Y<de&&(de=Y),Y});x.forEach(function(Fe,ge){var ye=Fe.cursor,Y=ce-ye.column,ue=he[ge]-de;Y>ue?A.insert(ye,c.stringRepeat(" ",Y-ue)):A.remove(new h(ye.row,ye.column,ye.row,ye.column-Y+ue)),Fe.start.column=Fe.end.column=ce,Fe.start.row=Fe.end.row=ye.row,Fe.cursor=Fe.end}),M.fromOrientedRange(x[0]),this.renderer.updateCursor(),this.renderer.updateBackMarkers()}},this.$reAlignText=function(A,M){var x=!0,R=!0,N,j,B;return A.map(function(le){var ce=le.match(/(\s*)(.*?)(\s*)([=:].*)/);return ce?N==null?(N=ce[1].length,j=ce[2].length,B=ce[3].length,ce):(N+j+B!=ce[1].length+ce[2].length+ce[3].length&&(R=!1),N!=ce[1].length&&(x=!1),N>ce[1].length&&(N=ce[1].length),j<ce[2].length&&(j=ce[2].length),B>ce[3].length&&(B=ce[3].length),ce):[le]}).map(M?U:x?R?Z:U:re);function q(le){return c.stringRepeat(" ",le)}function U(le){return le[2]?q(N)+le[2]+q(j-le[2].length+B)+le[4].replace(/^([=:])\s+/,"$1 "):le[0]}function Z(le){return le[2]?q(N+j-le[2].length)+le[2]+q(B)+le[4].replace(/^([=:])\s+/,"$1 "):le[0]}function re(le){return le[2]?q(N)+le[2]+q(B)+le[4].replace(/^([=:])\s+/,"$1 "):le[0]}}}).call(C.prototype);function k(A,M){return A.row==M.row&&A.column==M.column}o.onSessionChange=function(A){var M=A.session;M&&!M.multiSelect&&(M.$selectionMarkers=[],M.selection.$initRangeList(),M.multiSelect=M.selection),this.multiSelect=M&&M.multiSelect;var x=A.oldSession;x&&(x.multiSelect.off("addRange",this.$onAddRange),x.multiSelect.off("removeRange",this.$onRemoveRange),x.multiSelect.off("multiSelect",this.$onMultiSelect),x.multiSelect.off("singleSelect",this.$onSingleSelect),x.multiSelect.lead.off("change",this.$checkMultiselectChange),x.multiSelect.anchor.off("change",this.$checkMultiselectChange)),M&&(M.multiSelect.on("addRange",this.$onAddRange),M.multiSelect.on("removeRange",this.$onRemoveRange),M.multiSelect.on("multiSelect",this.$onMultiSelect),M.multiSelect.on("singleSelect",this.$onSingleSelect),M.multiSelect.lead.on("change",this.$checkMultiselectChange),M.multiSelect.anchor.on("change",this.$checkMultiselectChange)),M&&this.inMultiSelectMode!=M.selection.inMultiSelectMode&&(M.selection.inMultiSelectMode?this.$onMultiSelect():this.$onSingleSelect())};function T(A){A.$multiselectOnSessionChange||(A.$onAddRange=A.$onAddRange.bind(A),A.$onRemoveRange=A.$onRemoveRange.bind(A),A.$onMultiSelect=A.$onMultiSelect.bind(A),A.$onSingleSelect=A.$onSingleSelect.bind(A),A.$multiselectOnSessionChange=o.onSessionChange.bind(A),A.$checkMultiselectChange=A.$checkMultiselectChange.bind(A),A.$multiselectOnSessionChange(A),A.on("changeSession",A.$multiselectOnSessionChange),A.on("mousedown",d),A.commands.addCommands(a.defaultCommands),w(A))}function w(A){var M=A.textInput.getElement(),x=!1;l.addListener(M,"keydown",function(N){var j=N.keyCode==18&&!(N.ctrlKey||N.shiftKey||N.metaKey);A.$blockSelectEnabled&&j?x||(A.renderer.setMouseCursor("crosshair"),x=!0):x&&R()}),l.addListener(M,"keyup",R),l.addListener(M,"blur",R);function R(N){x&&(A.renderer.setMouseCursor(""),x=!1)}}o.MultiSelect=T,s("./config").defineOptions(C.prototype,"editor",{enableMultiselect:{set:function(A){T(this),A?(this.on("changeSession",this.$multiselectOnSessionChange),this.on("mousedown",d)):(this.off("changeSession",this.$multiselectOnSessionChange),this.off("mousedown",d))},value:!0},enableBlockSelect:{set:function(A){this.$blockSelectEnabled=A},value:!0}})}),ace.define("ace/mode/folding/fold_mode",["require","exports","module","ace/range"],function(s,o,f){var n=s("../../range").Range,h=o.FoldMode=function(){};(function(){this.foldingStartMarker=null,this.foldingStopMarker=null,this.getFoldWidget=function(g,d,l){var c=g.getLine(l);return this.foldingStartMarker.test(c)?"start":d=="markbeginend"&&this.foldingStopMarker&&this.foldingStopMarker.test(c)?"end":""},this.getFoldWidgetRange=function(g,d,l){return null},this.indentationBlock=function(g,d,l){var c=/\S/,a=g.getLine(d),F=a.search(c);if(F!=-1){for(var p=l||a.length,m=g.getLength(),b=d,C=d;++d<m;){var k=g.getLine(d).search(c);if(k!=-1){if(k<=F)break;C=d}}if(C>b){var T=g.getLine(C).length;return new n(b,p,C,T)}}},this.openingBracketBlock=function(g,d,l,c,a){var F={row:l,column:c+1},p=g.$findClosingBracket(d,F,a);if(p){var m=g.foldWidgets[p.row];return m==null&&(m=g.getFoldWidget(p.row)),m=="start"&&p.row>F.row&&(p.row--,p.column=g.getLine(p.row).length),n.fromPoints(F,p)}},this.closingBracketBlock=function(g,d,l,c,a){var F={row:l,column:c},p=g.$findOpeningBracket(d,F);if(p)return p.column++,F.column--,n.fromPoints(p,F)}}).call(h.prototype)}),ace.define("ace/theme/textmate",["require","exports","module","ace/lib/dom"],function(s,o,f){o.isDark=!1,o.cssClass="ace-tm",o.cssText='.ace-tm .ace_gutter {		background: #f0f0f0;		color: #333;		}		.ace-tm .ace_print-margin {		width: 1px;		background: #e8e8e8;		}		.ace-tm .ace_fold {		background-color: #6B72E6;		}		.ace-tm {		background-color: #FFFFFF;		color: black;		}		.ace-tm .ace_cursor {		color: black;		}		.ace-tm .ace_invisible {		color: rgb(191, 191, 191);		}		.ace-tm .ace_storage,		.ace-tm .ace_keyword {		color: blue;		}		.ace-tm .ace_constant {		color: rgb(197, 6, 11);		}		.ace-tm .ace_constant.ace_buildin {		color: rgb(88, 72, 246);		}		.ace-tm .ace_constant.ace_language {		color: rgb(88, 92, 246);		}		.ace-tm .ace_constant.ace_library {		color: rgb(6, 150, 14);		}		.ace-tm .ace_invalid {		background-color: rgba(255, 0, 0, 0.1);		color: red;		}		.ace-tm .ace_support.ace_function {		color: rgb(60, 76, 114);		}		.ace-tm .ace_support.ace_constant {		color: rgb(6, 150, 14);		}		.ace-tm .ace_support.ace_type,		.ace-tm .ace_support.ace_class {		color: rgb(109, 121, 222);		}		.ace-tm .ace_keyword.ace_operator {		color: rgb(104, 118, 135);		}		.ace-tm .ace_string {		color: rgb(3, 106, 7);		}		.ace-tm .ace_comment {		color: rgb(76, 136, 107);		}		.ace-tm .ace_comment.ace_doc {		color: rgb(0, 102, 255);		}		.ace-tm .ace_comment.ace_doc.ace_tag {		color: rgb(128, 159, 191);		}		.ace-tm .ace_constant.ace_numeric {		color: rgb(0, 0, 205);		}		.ace-tm .ace_variable {		color: rgb(49, 132, 149);		}		.ace-tm .ace_xml-pe {		color: rgb(104, 104, 91);		}		.ace-tm .ace_entity.ace_name.ace_function {		color: #0000A2;		}		.ace-tm .ace_heading {		color: rgb(12, 7, 255);		}		.ace-tm .ace_list {		color:rgb(185, 6, 144);		}		.ace-tm .ace_meta.ace_tag {		color:rgb(0, 22, 142);		}		.ace-tm .ace_string.ace_regex {		color: rgb(255, 0, 0)		}		.ace-tm .ace_marker-layer .ace_selection {		background: rgb(181, 213, 255);		}		.ace-tm.ace_multiselect .ace_selection.ace_start {		box-shadow: 0 0 3px 0px white;		}		.ace-tm .ace_marker-layer .ace_step {		background: rgb(252, 255, 0);		}		.ace-tm .ace_marker-layer .ace_stack {		background: rgb(164, 229, 101);		}		.ace-tm .ace_marker-layer .ace_bracket {		margin: -1px 0 0 -1px;		border: 1px solid rgb(192, 192, 192);		}		.ace-tm .ace_marker-layer .ace_active-line {		background: rgba(0, 0, 0, 0.07);		}		.ace-tm .ace_gutter-active-line {		background-color : #dcdcdc;		}		.ace-tm .ace_marker-layer .ace_selected-word {		background: rgb(250, 250, 255);		border: 1px solid rgb(200, 200, 250);		}		.ace-tm .ace_indent-guide {		background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAACCAYAAACZgbYnAAAAE0lEQVQImWP4////f4bLly//BwAmVgd1/w11/gAAAABJRU5ErkJggg==") right repeat-y;		}		';var n=s("../lib/dom");n.importCssString(o.cssText,o.cssClass)}),ace.define("ace/line_widgets",["require","exports","module","ace/lib/oop","ace/lib/dom","ace/range"],function(s,o,f){s("./lib/oop");var n=s("./lib/dom");s("./range").Range;function h(g){this.session=g,this.session.widgetManager=this,this.session.getRowLength=this.getRowLength,this.session.$getWidgetScreenLength=this.$getWidgetScreenLength,this.updateOnChange=this.updateOnChange.bind(this),this.renderWidgets=this.renderWidgets.bind(this),this.measureWidgets=this.measureWidgets.bind(this),this.session._changedWidgets=[],this.$onChangeEditor=this.$onChangeEditor.bind(this),this.session.on("change",this.updateOnChange),this.session.on("changeFold",this.updateOnFold),this.session.on("changeEditor",this.$onChangeEditor)}(function(){this.getRowLength=function(g){var d;return this.lineWidgets?d=this.lineWidgets[g]&&this.lineWidgets[g].rowCount||0:d=0,!this.$useWrapMode||!this.$wrapData[g]?1+d:this.$wrapData[g].length+1+d},this.$getWidgetScreenLength=function(){var g=0;return this.lineWidgets.forEach(function(d){d&&d.rowCount&&!d.hidden&&(g+=d.rowCount)}),g},this.$onChangeEditor=function(g){this.attach(g.editor)},this.attach=function(g){g&&g.widgetManager&&g.widgetManager!=this&&g.widgetManager.detach(),this.editor!=g&&(this.detach(),this.editor=g,g&&(g.widgetManager=this,g.renderer.on("beforeRender",this.measureWidgets),g.renderer.on("afterRender",this.renderWidgets)))},this.detach=function(g){var d=this.editor;if(d){this.editor=null,d.widgetManager=null,d.renderer.off("beforeRender",this.measureWidgets),d.renderer.off("afterRender",this.renderWidgets);var l=this.session.lineWidgets;l&&l.forEach(function(c){c&&c.el&&c.el.parentNode&&(c._inDocument=!1,c.el.parentNode.removeChild(c.el))})}},this.updateOnFold=function(g,d){var l=d.lineWidgets;if(!(!l||!g.action)){for(var c=g.data,a=c.start.row,F=c.end.row,p=g.action=="add",m=a+1;m<F;m++)l[m]&&(l[m].hidden=p);l[F]&&(p?l[a]?l[F].hidden=p:l[a]=l[F]:(l[a]==l[F]&&(l[a]=void 0),l[F].hidden=p))}},this.updateOnChange=function(g){var d=this.session.lineWidgets;if(d){var l=g.start.row,c=g.end.row-l;if(c!==0)if(g.action=="remove"){var a=d.splice(l+1,c);a.forEach(function(p){p&&this.removeLineWidget(p)},this),this.$updateRows()}else{var F=new Array(c);F.unshift(l,0),d.splice.apply(d,F),this.$updateRows()}}},this.$updateRows=function(){var g=this.session.lineWidgets;if(g){var d=!0;g.forEach(function(l,c){if(l)for(d=!1,l.row=c;l.$oldWidget;)l.$oldWidget.row=c,l=l.$oldWidget}),d&&(this.session.lineWidgets=null)}},this.addLineWidget=function(g){this.session.lineWidgets||(this.session.lineWidgets=new Array(this.session.getLength()));var d=this.session.lineWidgets[g.row];d&&(g.$oldWidget=d,d.el&&d.el.parentNode&&(d.el.parentNode.removeChild(d.el),d._inDocument=!1)),this.session.lineWidgets[g.row]=g,g.session=this.session;var l=this.editor.renderer;g.html&&!g.el&&(g.el=n.createElement("div"),g.el.innerHTML=g.html),g.el&&(n.addCssClass(g.el,"ace_lineWidgetContainer"),g.el.style.position="absolute",g.el.style.zIndex=5,l.container.appendChild(g.el),g._inDocument=!0),g.coverGutter||(g.el.style.zIndex=3),g.pixelHeight==null&&(g.pixelHeight=g.el.offsetHeight),g.rowCount==null&&(g.rowCount=g.pixelHeight/l.layerConfig.lineHeight);var c=this.session.getFoldAt(g.row,0);if(g.$fold=c,c){var a=this.session.lineWidgets;g.row==c.end.row&&!a[c.start.row]?a[c.start.row]=g:g.hidden=!0}return this.session._emit("changeFold",{data:{start:{row:g.row}}}),this.$updateRows(),this.renderWidgets(null,l),this.onWidgetChanged(g),g},this.removeLineWidget=function(g){if(g._inDocument=!1,g.session=null,g.el&&g.el.parentNode&&g.el.parentNode.removeChild(g.el),g.editor&&g.editor.destroy)try{g.editor.destroy()}catch{}if(this.session.lineWidgets){var d=this.session.lineWidgets[g.row];if(d==g)this.session.lineWidgets[g.row]=g.$oldWidget,g.$oldWidget&&this.onWidgetChanged(g.$oldWidget);else for(;d;){if(d.$oldWidget==g){d.$oldWidget=g.$oldWidget;break}d=d.$oldWidget}}this.session._emit("changeFold",{data:{start:{row:g.row}}}),this.$updateRows()},this.getWidgetsAtRow=function(g){for(var d=this.session.lineWidgets,l=d&&d[g],c=[];l;)c.push(l),l=l.$oldWidget;return c},this.onWidgetChanged=function(g){this.session._changedWidgets.push(g),this.editor&&this.editor.renderer.updateFull()},this.measureWidgets=function(g,d){var l=this.session._changedWidgets,c=d.layerConfig;if(!(!l||!l.length)){for(var a=1/0,F=0;F<l.length;F++){var p=l[F];if(!(!p||!p.el)&&p.session==this.session){if(!p._inDocument){if(this.session.lineWidgets[p.row]!=p)continue;p._inDocument=!0,d.container.appendChild(p.el)}p.h=p.el.offsetHeight,p.fixedWidth||(p.w=p.el.offsetWidth,p.screenWidth=Math.ceil(p.w/c.characterWidth));var m=p.h/c.lineHeight;p.coverLine&&(m-=this.session.getRowLineCount(p.row),m<0&&(m=0)),p.rowCount!=m&&(p.rowCount=m,p.row<a&&(a=p.row))}}a!=1/0&&(this.session._emit("changeFold",{data:{start:{row:a}}}),this.session.lineWidgetWidth=null),this.session._changedWidgets=[]}},this.renderWidgets=function(g,d){var l=d.layerConfig,c=this.session.lineWidgets;if(c){for(var a=Math.min(this.firstRow,l.firstRow),F=Math.max(this.lastRow,l.lastRow,c.length);a>0&&!c[a];)a--;this.firstRow=l.firstRow,this.lastRow=l.lastRow,d.$cursorLayer.config=l;for(var p=a;p<=F;p++){var m=c[p];if(!(!m||!m.el)){if(m.hidden){m.el.style.top=-100-(m.pixelHeight||0)+"px";continue}m._inDocument||(m._inDocument=!0,d.container.appendChild(m.el));var b=d.$cursorLayer.getPixelPosition({row:p,column:0},!0).top;m.coverLine||(b+=l.lineHeight*this.session.getRowLineCount(m.row)),m.el.style.top=b-l.offset+"px";var C=m.coverGutter?0:d.gutterWidth;m.fixedWidth||(C-=d.scrollLeft),m.el.style.left=C+"px",m.fullWidth&&m.screenWidth&&(m.el.style.minWidth=l.width+2*l.padding+"px"),m.fixedWidth?m.el.style.right=d.scrollBar.getWidth()+"px":m.el.style.right=""}}}}}).call(h.prototype),o.LineWidgets=h}),ace.define("ace/ext/error_marker",["require","exports","module","ace/line_widgets","ace/lib/dom","ace/range"],function(s,o,f){var n=s("../line_widgets").LineWidgets,h=s("../lib/dom"),g=s("../range").Range;function d(c,a,F){for(var p=0,m=c.length-1;p<=m;){var b=p+m>>1,C=F(a,c[b]);if(C>0)p=b+1;else if(C<0)m=b-1;else return b}return-(p+1)}function l(c,a,F){var p=c.getAnnotations().sort(g.comparePoints);if(p.length){var m=d(p,{row:a,column:-1},g.comparePoints);m<0&&(m=-m-1),m>=p.length?m=F>0?0:p.length-1:m===0&&F<0&&(m=p.length-1);var b=p[m];if(!(!b||!F)){if(b.row===a){do b=p[m+=F];while(b&&b.row===a);if(!b)return p.slice()}var C=[];a=b.row;do C[F<0?"unshift":"push"](b),b=p[m+=F];while(b&&b.row==a);return C.length&&C}}}o.showErrorMarker=function(c,a){var F=c.session;F.widgetManager||(F.widgetManager=new n(F),F.widgetManager.attach(c));var p=c.getCursorPosition(),m=p.row,b=F.widgetManager.getWidgetsAtRow(m).filter(function(N){return N.type=="errorMarker"})[0];b?b.destroy():m-=a;var C=l(F,m,a),k;if(C){var T=C[0];p.column=(T.pos&&typeof T.column!="number"?T.pos.sc:T.column)||0,p.row=T.row,k=c.renderer.$gutterLayer.$annotations[p.row]}else{if(b)return;k={text:["Looks good!"],className:"ace_ok"}}c.session.unfold(p.row),c.selection.moveToPosition(p);var w={row:p.row,fixedWidth:!0,coverGutter:!0,el:h.createElement("div"),type:"errorMarker"},A=w.el.appendChild(h.createElement("div")),M=w.el.appendChild(h.createElement("div"));M.className="error_widget_arrow "+k.className;var x=c.renderer.$cursorLayer.getPixelPosition(p).left;M.style.left=x+c.renderer.gutterWidth-5+"px",w.el.className="error_widget_wrapper",A.className="error_widget "+k.className,A.innerHTML=k.text.join("<br>"),A.appendChild(h.createElement("div"));var R=function(N,j,B){if(j===0&&(B==="esc"||B==="return"))return w.destroy(),{command:"null"}};w.destroy=function(){c.$mouseHandler.isMousePressed||(c.keyBinding.removeKeyboardHandler(R),F.widgetManager.removeLineWidget(w),c.off("changeSelection",w.destroy),c.off("changeSession",w.destroy),c.off("mouseup",w.destroy),c.off("change",w.destroy))},c.keyBinding.addKeyboardHandler(R),c.on("changeSelection",w.destroy),c.on("changeSession",w.destroy),c.on("mouseup",w.destroy),c.on("change",w.destroy),c.session.widgetManager.addLineWidget(w),w.el.onmousedown=c.focus.bind(c),c.renderer.scrollCursorIntoView(null,.5,{bottom:w.el.offsetHeight})},h.importCssString("		    .error_widget_wrapper {		        background: inherit;		        color: inherit;		        border:none		    }		    .error_widget {		        border-top: solid 2px;		        border-bottom: solid 2px;		        margin: 5px 0;		        padding: 10px 40px;		        white-space: pre-wrap;		    }		    .error_widget.ace_error, .error_widget_arrow.ace_error{		        border-color: #ff5a5a		    }		    .error_widget.ace_warning, .error_widget_arrow.ace_warning{		        border-color: #F1D817		    }		    .error_widget.ace_info, .error_widget_arrow.ace_info{		        border-color: #5a5a5a		    }		    .error_widget.ace_ok, .error_widget_arrow.ace_ok{		        border-color: #5aaa5a		    }		    .error_widget_arrow {		        position: absolute;		        border: solid 5px;		        border-top-color: transparent!important;		        border-right-color: transparent!important;		        border-left-color: transparent!important;		        top: -5px;		    }		","")}),ace.define("ace/ace",["require","exports","module","ace/lib/fixoldbrowsers","ace/lib/dom","ace/lib/event","ace/editor","ace/edit_session","ace/undomanager","ace/virtual_renderer","ace/worker/worker_client","ace/keyboard/hash_handler","ace/placeholder","ace/multi_select","ace/mode/folding/fold_mode","ace/theme/textmate","ace/ext/error_marker","ace/config"],function(s,o,f){s("./lib/fixoldbrowsers");var n=s("./lib/dom"),h=s("./lib/event"),g=s("./editor").Editor,d=s("./edit_session").EditSession,l=s("./undomanager").UndoManager,c=s("./virtual_renderer").VirtualRenderer;s("./worker/worker_client"),s("./keyboard/hash_handler"),s("./placeholder"),s("./multi_select"),s("./mode/folding/fold_mode"),s("./theme/textmate"),s("./ext/error_marker"),o.config=s("./config"),o.acequire=s,o.define=i(69),o.edit=function(a){if(typeof a=="string"){var F=a;if(a=document.getElementById(F),!a)throw new Error("ace.edit can't find div #"+F)}if(a&&a.env&&a.env.editor instanceof g)return a.env.editor;var p="";if(a&&/input|textarea/i.test(a.tagName)){var m=a;p=m.value,a=n.createElement("pre"),m.parentNode.replaceChild(a,m)}else a&&(p=n.getInnerText(a),a.innerHTML="");var b=o.createEditSession(p),C=new g(new c(a));C.setSession(b);var k={document:b,editor:C,onResize:C.resize.bind(C,null)};return m&&(k.textarea=m),h.addListener(window,"resize",k.onResize),C.on("destroy",function(){h.removeListener(window,"resize",k.onResize),k.editor.container.env=null}),C.container.env=C.env=k,C},o.createEditSession=function(a,F){var p=new d(a,F);return p.setUndoManager(new l),p},o.EditSession=d,o.UndoManager=l,o.version="1.2.6"}),function(){ace.acequire(["ace/ace"],function(s){s&&(s.config.init(!0),s.define=ace.define),window.ace||(window.ace=s);for(var o in s)s.hasOwnProperty(o)&&(window.ace[o]=s[o])})}(),u.exports=window.ace.acequire("ace/ace")},function(u,r){u.exports=function(){throw new Error("define cannot be used indirect")}},function(u,r){(function(i){u.exports=s();function s(){if(i.Blob)try{return new Blob(["asdf"],{type:"text/plain"}),Blob}catch{}var o=i.WebKitBlobBuilder||i.MozBlobBuilder||i.MSBlobBuilder;return function(f,n){var h=new o,g=n.endings,d=n.type;if(g)for(var l=0,c=f.length;l<c;++l)h.append(f[l],g);else for(var l=0,c=f.length;l<c;++l)h.append(f[l]);return d?h.getBlob(d):h.getBlob()}}}).call(r,function(){return this}())},function(u,r,i){ace.define("ace/mode/json_highlight_rules",["require","exports","module","ace/lib/oop","ace/mode/text_highlight_rules"],function(s,o,f){var n=s("../lib/oop"),h=s("./text_highlight_rules").TextHighlightRules,g=function(){this.$rules={start:[{token:"variable",regex:'["](?:(?:\\\\.)|(?:[^"\\\\]))*?["]\\s*(?=:)'},{token:"string",regex:'"',next:"string"},{token:"constant.numeric",regex:"0[xX][0-9a-fA-F]+\\b"},{token:"constant.numeric",regex:"[+-]?\\d+(?:(?:\\.\\d*)?(?:[eE][+-]?\\d+)?)?\\b"},{token:"constant.language.boolean",regex:"(?:true|false)\\b"},{token:"invalid.illegal",regex:"['](?:(?:\\\\.)|(?:[^'\\\\]))*?[']"},{token:"invalid.illegal",regex:"\\/\\/.*$"},{token:"paren.lparen",regex:"[[({]"},{token:"paren.rparen",regex:"[\\])}]"},{token:"text",regex:"\\s+"}],string:[{token:"constant.language.escape",regex:/\\(?:x[0-9a-fA-F]{2}|u[0-9a-fA-F]{4}|["\\\/bfnrt])/},{token:"string",regex:'[^"\\\\]+'},{token:"string",regex:'"',next:"start"},{token:"string",regex:"",next:"start"}]}};n.inherits(g,h),o.JsonHighlightRules=g}),ace.define("ace/mode/matching_brace_outdent",["require","exports","module","ace/range"],function(s,o,f){var n=s("../range").Range,h=function(){};(function(){this.checkOutdent=function(g,d){return/^\s+$/.test(g)?/^\s*\}/.test(d):!1},this.autoOutdent=function(g,d){var l=g.getLine(d),c=l.match(/^(\s*\})/);if(!c)return 0;var a=c[1].length,F=g.findMatchingBracket({row:d,column:a});if(!F||F.row==d)return 0;var p=this.$getIndent(g.getLine(F.row));g.replace(new n(d,0,d,a-1),p)},this.$getIndent=function(g){return g.match(/^\s*/)[0]}}).call(h.prototype),o.MatchingBraceOutdent=h}),ace.define("ace/mode/folding/cstyle",["require","exports","module","ace/lib/oop","ace/range","ace/mode/folding/fold_mode"],function(s,o,f){var n=s("../../lib/oop"),h=s("../../range").Range,g=s("./fold_mode").FoldMode,d=o.FoldMode=function(l){l&&(this.foldingStartMarker=new RegExp(this.foldingStartMarker.source.replace(/\|[^|]*?$/,"|"+l.start)),this.foldingStopMarker=new RegExp(this.foldingStopMarker.source.replace(/\|[^|]*?$/,"|"+l.end)))};n.inherits(d,g),function(){this.foldingStartMarker=/(\{|\[)[^\}\]]*$|^\s*(\/\*)/,this.foldingStopMarker=/^[^\[\{]*(\}|\])|^[\s\*]*(\*\/)/,this.singleLineBlockCommentRe=/^\s*(\/\*).*\*\/\s*$/,this.tripleStarBlockCommentRe=/^\s*(\/\*\*\*).*\*\/\s*$/,this.startRegionRe=/^\s*(\/\*|\/\/)#?region\b/,this._getFoldWidgetBase=this.getFoldWidget,this.getFoldWidget=function(l,c,a){var F=l.getLine(a);if(this.singleLineBlockCommentRe.test(F)&&!this.startRegionRe.test(F)&&!this.tripleStarBlockCommentRe.test(F))return"";var p=this._getFoldWidgetBase(l,c,a);return!p&&this.startRegionRe.test(F)?"start":p},this.getFoldWidgetRange=function(l,c,a,F){var p=l.getLine(a);if(this.startRegionRe.test(p))return this.getCommentRegionBlock(l,p,a);var C=p.match(this.foldingStartMarker);if(C){var m=C.index;if(C[1])return this.openingBracketBlock(l,C[1],a,m);var b=l.getCommentFoldRange(a,m+C[0].length,1);return b&&!b.isMultiLine()&&(F?b=this.getSectionRange(l,a):c!="all"&&(b=null)),b}if(c!=="markbegin"){var C=p.match(this.foldingStopMarker);if(C){var m=C.index+C[0].length;return C[1]?this.closingBracketBlock(l,C[1],a,m):l.getCommentFoldRange(a,m,-1)}}},this.getSectionRange=function(l,c){var a=l.getLine(c),F=a.search(/\S/),p=c,m=a.length;c=c+1;for(var b=c,C=l.getLength();++c<C;){a=l.getLine(c);var k=a.search(/\S/);if(k!==-1){if(F>k)break;var T=this.getFoldWidgetRange(l,"all",c);if(T){if(T.start.row<=p)break;if(T.isMultiLine())c=T.end.row;else if(F==k)break}b=c}}return new h(p,m,b,l.getLine(b).length)},this.getCommentRegionBlock=function(l,c,a){for(var F=c.search(/\s*$/),p=l.getLength(),m=a,b=/^\s*(?:\/\*|\/\/|--)#?(end)?region\b/,C=1;++a<p;){c=l.getLine(a);var k=b.exec(c);if(k&&(k[1]?C--:C++,!C))break}var T=a;if(T>m)return new h(m,F,T,c.length)}}.call(d.prototype)}),ace.define("ace/mode/json",["require","exports","module","ace/lib/oop","ace/mode/text","ace/mode/json_highlight_rules","ace/mode/matching_brace_outdent","ace/mode/behaviour/cstyle","ace/mode/folding/cstyle","ace/worker/worker_client"],function(s,o,f){var n=s("../lib/oop"),h=s("./text").Mode,g=s("./json_highlight_rules").JsonHighlightRules,d=s("./matching_brace_outdent").MatchingBraceOutdent,l=s("./behaviour/cstyle").CstyleBehaviour,c=s("./folding/cstyle").FoldMode,a=s("../worker/worker_client").WorkerClient,F=function(){this.HighlightRules=g,this.$outdent=new d,this.$behaviour=new l,this.foldingRules=new c};n.inherits(F,h),function(){this.getNextLineIndent=function(p,m,b){var C=this.$getIndent(m);if(p=="start"){var k=m.match(/^.*[\{\(\[]\s*$/);k&&(C+=b)}return C},this.checkOutdent=function(p,m,b){return this.$outdent.checkOutdent(m,b)},this.autoOutdent=function(p,m,b){this.$outdent.autoOutdent(m,b)},this.createWorker=function(p){var m=new a(["ace"],i(72),"JsonWorker");return m.attachToDocument(p.getDocument()),m.on("annotate",function(b){p.setAnnotations(b.data)}),m.on("terminate",function(){p.clearAnnotations()}),m},this.$id="ace/mode/json"}.call(F.prototype),o.Mode=F})},function(u,r){u.exports.id="ace/mode/json_worker",u.exports.src=`"no use strict";(function(window){function resolveModuleId(id,paths){for(var testPath=id,tail="";testPath;){var alias=paths[testPath];if("string"==typeof alias)return alias+tail;if(alias)return alias.location.replace(/\\/*$/,"/")+(tail||alias.main||alias.name);if(alias===!1)return"";var i=testPath.lastIndexOf("/");if(-1===i)break;tail=testPath.substr(i)+tail,testPath=testPath.slice(0,i)}return id}if(!(void 0!==window.window&&window.document||window.acequire&&window.define)){window.console||(window.console=function(){var msgs=Array.prototype.slice.call(arguments,0);postMessage({type:"log",data:msgs})},window.console.error=window.console.warn=window.console.log=window.console.trace=window.console),window.window=window,window.ace=window,window.onerror=function(message,file,line,col,err){postMessage({type:"error",data:{message:message,data:err.data,file:file,line:line,col:col,stack:err.stack}})},window.normalizeModule=function(parentId,moduleName){if(-1!==moduleName.indexOf("!")){var chunks=moduleName.split("!");return window.normalizeModule(parentId,chunks[0])+"!"+window.normalizeModule(parentId,chunks[1])}if("."==moduleName.charAt(0)){var base=parentId.split("/").slice(0,-1).join("/");for(moduleName=(base?base+"/":"")+moduleName;-1!==moduleName.indexOf(".")&&previous!=moduleName;){var previous=moduleName;moduleName=moduleName.replace(/^\\.\\//,"").replace(/\\/\\.\\//,"/").replace(/[^\\/]+\\/\\.\\.\\//,"")}}return moduleName},window.acequire=function acequire(parentId,id){if(id||(id=parentId,parentId=null),!id.charAt)throw Error("worker.js acequire() accepts only (parentId, id) as arguments");id=window.normalizeModule(parentId,id);var module=window.acequire.modules[id];if(module)return module.initialized||(module.initialized=!0,module.exports=module.factory().exports),module.exports;if(!window.acequire.tlns)return console.log("unable to load "+id);var path=resolveModuleId(id,window.acequire.tlns);return".js"!=path.slice(-3)&&(path+=".js"),window.acequire.id=id,window.acequire.modules[id]={},importScripts(path),window.acequire(parentId,id)},window.acequire.modules={},window.acequire.tlns={},window.define=function(id,deps,factory){if(2==arguments.length?(factory=deps,"string"!=typeof id&&(deps=id,id=window.acequire.id)):1==arguments.length&&(factory=id,deps=[],id=window.acequire.id),"function"!=typeof factory)return window.acequire.modules[id]={exports:factory,initialized:!0},void 0;deps.length||(deps=["require","exports","module"]);var req=function(childId){return window.acequire(id,childId)};window.acequire.modules[id]={exports:{},factory:function(){var module=this,returnExports=factory.apply(this,deps.map(function(dep){switch(dep){case"require":return req;case"exports":return module.exports;case"module":return module;default:return req(dep)}}));return returnExports&&(module.exports=returnExports),module}}},window.define.amd={},acequire.tlns={},window.initBaseUrls=function(topLevelNamespaces){for(var i in topLevelNamespaces)acequire.tlns[i]=topLevelNamespaces[i]},window.initSender=function(){var EventEmitter=window.acequire("ace/lib/event_emitter").EventEmitter,oop=window.acequire("ace/lib/oop"),Sender=function(){};return function(){oop.implement(this,EventEmitter),this.callback=function(data,callbackId){postMessage({type:"call",id:callbackId,data:data})},this.emit=function(name,data){postMessage({type:"event",name:name,data:data})}}.call(Sender.prototype),new Sender};var main=window.main=null,sender=window.sender=null;window.onmessage=function(e){var msg=e.data;if(msg.event&&sender)sender._signal(msg.event,msg.data);else if(msg.command)if(main[msg.command])main[msg.command].apply(main,msg.args);else{if(!window[msg.command])throw Error("Unknown command:"+msg.command);window[msg.command].apply(window,msg.args)}else if(msg.init){window.initBaseUrls(msg.tlns),acequire("ace/lib/es5-shim"),sender=window.sender=window.initSender();var clazz=acequire(msg.module)[msg.classname];main=window.main=new clazz(sender)}}}})(this),ace.define("ace/lib/oop",["require","exports","module"],function(acequire,exports){"use strict";exports.inherits=function(ctor,superCtor){ctor.super_=superCtor,ctor.prototype=Object.create(superCtor.prototype,{constructor:{value:ctor,enumerable:!1,writable:!0,configurable:!0}})},exports.mixin=function(obj,mixin){for(var key in mixin)obj[key]=mixin[key];return obj},exports.implement=function(proto,mixin){exports.mixin(proto,mixin)}}),ace.define("ace/range",["require","exports","module"],function(acequire,exports){"use strict";var comparePoints=function(p1,p2){return p1.row-p2.row||p1.column-p2.column},Range=function(startRow,startColumn,endRow,endColumn){this.start={row:startRow,column:startColumn},this.end={row:endRow,column:endColumn}};(function(){this.isEqual=function(range){return this.start.row===range.start.row&&this.end.row===range.end.row&&this.start.column===range.start.column&&this.end.column===range.end.column},this.toString=function(){return"Range: ["+this.start.row+"/"+this.start.column+"] -> ["+this.end.row+"/"+this.end.column+"]"},this.contains=function(row,column){return 0==this.compare(row,column)},this.compareRange=function(range){var cmp,end=range.end,start=range.start;return cmp=this.compare(end.row,end.column),1==cmp?(cmp=this.compare(start.row,start.column),1==cmp?2:0==cmp?1:0):-1==cmp?-2:(cmp=this.compare(start.row,start.column),-1==cmp?-1:1==cmp?42:0)},this.comparePoint=function(p){return this.compare(p.row,p.column)},this.containsRange=function(range){return 0==this.comparePoint(range.start)&&0==this.comparePoint(range.end)},this.intersects=function(range){var cmp=this.compareRange(range);return-1==cmp||0==cmp||1==cmp},this.isEnd=function(row,column){return this.end.row==row&&this.end.column==column},this.isStart=function(row,column){return this.start.row==row&&this.start.column==column},this.setStart=function(row,column){"object"==typeof row?(this.start.column=row.column,this.start.row=row.row):(this.start.row=row,this.start.column=column)},this.setEnd=function(row,column){"object"==typeof row?(this.end.column=row.column,this.end.row=row.row):(this.end.row=row,this.end.column=column)},this.inside=function(row,column){return 0==this.compare(row,column)?this.isEnd(row,column)||this.isStart(row,column)?!1:!0:!1},this.insideStart=function(row,column){return 0==this.compare(row,column)?this.isEnd(row,column)?!1:!0:!1},this.insideEnd=function(row,column){return 0==this.compare(row,column)?this.isStart(row,column)?!1:!0:!1},this.compare=function(row,column){return this.isMultiLine()||row!==this.start.row?this.start.row>row?-1:row>this.end.row?1:this.start.row===row?column>=this.start.column?0:-1:this.end.row===row?this.end.column>=column?0:1:0:this.start.column>column?-1:column>this.end.column?1:0},this.compareStart=function(row,column){return this.start.row==row&&this.start.column==column?-1:this.compare(row,column)},this.compareEnd=function(row,column){return this.end.row==row&&this.end.column==column?1:this.compare(row,column)},this.compareInside=function(row,column){return this.end.row==row&&this.end.column==column?1:this.start.row==row&&this.start.column==column?-1:this.compare(row,column)},this.clipRows=function(firstRow,lastRow){if(this.end.row>lastRow)var end={row:lastRow+1,column:0};else if(firstRow>this.end.row)var end={row:firstRow,column:0};if(this.start.row>lastRow)var start={row:lastRow+1,column:0};else if(firstRow>this.start.row)var start={row:firstRow,column:0};return Range.fromPoints(start||this.start,end||this.end)},this.extend=function(row,column){var cmp=this.compare(row,column);if(0==cmp)return this;if(-1==cmp)var start={row:row,column:column};else var end={row:row,column:column};return Range.fromPoints(start||this.start,end||this.end)},this.isEmpty=function(){return this.start.row===this.end.row&&this.start.column===this.end.column},this.isMultiLine=function(){return this.start.row!==this.end.row},this.clone=function(){return Range.fromPoints(this.start,this.end)},this.collapseRows=function(){return 0==this.end.column?new Range(this.start.row,0,Math.max(this.start.row,this.end.row-1),0):new Range(this.start.row,0,this.end.row,0)},this.toScreenRange=function(session){var screenPosStart=session.documentToScreenPosition(this.start),screenPosEnd=session.documentToScreenPosition(this.end);return new Range(screenPosStart.row,screenPosStart.column,screenPosEnd.row,screenPosEnd.column)},this.moveBy=function(row,column){this.start.row+=row,this.start.column+=column,this.end.row+=row,this.end.column+=column}}).call(Range.prototype),Range.fromPoints=function(start,end){return new Range(start.row,start.column,end.row,end.column)},Range.comparePoints=comparePoints,Range.comparePoints=function(p1,p2){return p1.row-p2.row||p1.column-p2.column},exports.Range=Range}),ace.define("ace/apply_delta",["require","exports","module"],function(acequire,exports){"use strict";exports.applyDelta=function(docLines,delta){var row=delta.start.row,startColumn=delta.start.column,line=docLines[row]||"";switch(delta.action){case"insert":var lines=delta.lines;if(1===lines.length)docLines[row]=line.substring(0,startColumn)+delta.lines[0]+line.substring(startColumn);else{var args=[row,1].concat(delta.lines);docLines.splice.apply(docLines,args),docLines[row]=line.substring(0,startColumn)+docLines[row],docLines[row+delta.lines.length-1]+=line.substring(startColumn)}break;case"remove":var endColumn=delta.end.column,endRow=delta.end.row;row===endRow?docLines[row]=line.substring(0,startColumn)+line.substring(endColumn):docLines.splice(row,endRow-row+1,line.substring(0,startColumn)+docLines[endRow].substring(endColumn))}}}),ace.define("ace/lib/event_emitter",["require","exports","module"],function(acequire,exports){"use strict";var EventEmitter={},stopPropagation=function(){this.propagationStopped=!0},preventDefault=function(){this.defaultPrevented=!0};EventEmitter._emit=EventEmitter._dispatchEvent=function(eventName,e){this._eventRegistry||(this._eventRegistry={}),this._defaultHandlers||(this._defaultHandlers={});var listeners=this._eventRegistry[eventName]||[],defaultHandler=this._defaultHandlers[eventName];if(listeners.length||defaultHandler){"object"==typeof e&&e||(e={}),e.type||(e.type=eventName),e.stopPropagation||(e.stopPropagation=stopPropagation),e.preventDefault||(e.preventDefault=preventDefault),listeners=listeners.slice();for(var i=0;listeners.length>i&&(listeners[i](e,this),!e.propagationStopped);i++);return defaultHandler&&!e.defaultPrevented?defaultHandler(e,this):void 0}},EventEmitter._signal=function(eventName,e){var listeners=(this._eventRegistry||{})[eventName];if(listeners){listeners=listeners.slice();for(var i=0;listeners.length>i;i++)listeners[i](e,this)}},EventEmitter.once=function(eventName,callback){var _self=this;callback&&this.addEventListener(eventName,function newCallback(){_self.removeEventListener(eventName,newCallback),callback.apply(null,arguments)})},EventEmitter.setDefaultHandler=function(eventName,callback){var handlers=this._defaultHandlers;if(handlers||(handlers=this._defaultHandlers={_disabled_:{}}),handlers[eventName]){var old=handlers[eventName],disabled=handlers._disabled_[eventName];disabled||(handlers._disabled_[eventName]=disabled=[]),disabled.push(old);var i=disabled.indexOf(callback);-1!=i&&disabled.splice(i,1)}handlers[eventName]=callback},EventEmitter.removeDefaultHandler=function(eventName,callback){var handlers=this._defaultHandlers;if(handlers){var disabled=handlers._disabled_[eventName];if(handlers[eventName]==callback)handlers[eventName],disabled&&this.setDefaultHandler(eventName,disabled.pop());else if(disabled){var i=disabled.indexOf(callback);-1!=i&&disabled.splice(i,1)}}},EventEmitter.on=EventEmitter.addEventListener=function(eventName,callback,capturing){this._eventRegistry=this._eventRegistry||{};var listeners=this._eventRegistry[eventName];return listeners||(listeners=this._eventRegistry[eventName]=[]),-1==listeners.indexOf(callback)&&listeners[capturing?"unshift":"push"](callback),callback},EventEmitter.off=EventEmitter.removeListener=EventEmitter.removeEventListener=function(eventName,callback){this._eventRegistry=this._eventRegistry||{};var listeners=this._eventRegistry[eventName];if(listeners){var index=listeners.indexOf(callback);-1!==index&&listeners.splice(index,1)}},EventEmitter.removeAllListeners=function(eventName){this._eventRegistry&&(this._eventRegistry[eventName]=[])},exports.EventEmitter=EventEmitter}),ace.define("ace/anchor",["require","exports","module","ace/lib/oop","ace/lib/event_emitter"],function(acequire,exports){"use strict";var oop=acequire("./lib/oop"),EventEmitter=acequire("./lib/event_emitter").EventEmitter,Anchor=exports.Anchor=function(doc,row,column){this.$onChange=this.onChange.bind(this),this.attach(doc),column===void 0?this.setPosition(row.row,row.column):this.setPosition(row,column)};(function(){function $pointsInOrder(point1,point2,equalPointsInOrder){var bColIsAfter=equalPointsInOrder?point1.column<=point2.column:point1.column<point2.column;return point1.row<point2.row||point1.row==point2.row&&bColIsAfter}function $getTransformedPoint(delta,point,moveIfEqual){var deltaIsInsert="insert"==delta.action,deltaRowShift=(deltaIsInsert?1:-1)*(delta.end.row-delta.start.row),deltaColShift=(deltaIsInsert?1:-1)*(delta.end.column-delta.start.column),deltaStart=delta.start,deltaEnd=deltaIsInsert?deltaStart:delta.end;return $pointsInOrder(point,deltaStart,moveIfEqual)?{row:point.row,column:point.column}:$pointsInOrder(deltaEnd,point,!moveIfEqual)?{row:point.row+deltaRowShift,column:point.column+(point.row==deltaEnd.row?deltaColShift:0)}:{row:deltaStart.row,column:deltaStart.column}}oop.implement(this,EventEmitter),this.getPosition=function(){return this.$clipPositionToDocument(this.row,this.column)},this.getDocument=function(){return this.document},this.$insertRight=!1,this.onChange=function(delta){if(!(delta.start.row==delta.end.row&&delta.start.row!=this.row||delta.start.row>this.row)){var point=$getTransformedPoint(delta,{row:this.row,column:this.column},this.$insertRight);this.setPosition(point.row,point.column,!0)}},this.setPosition=function(row,column,noClip){var pos;if(pos=noClip?{row:row,column:column}:this.$clipPositionToDocument(row,column),this.row!=pos.row||this.column!=pos.column){var old={row:this.row,column:this.column};this.row=pos.row,this.column=pos.column,this._signal("change",{old:old,value:pos})}},this.detach=function(){this.document.removeEventListener("change",this.$onChange)},this.attach=function(doc){this.document=doc||this.document,this.document.on("change",this.$onChange)},this.$clipPositionToDocument=function(row,column){var pos={};return row>=this.document.getLength()?(pos.row=Math.max(0,this.document.getLength()-1),pos.column=this.document.getLine(pos.row).length):0>row?(pos.row=0,pos.column=0):(pos.row=row,pos.column=Math.min(this.document.getLine(pos.row).length,Math.max(0,column))),0>column&&(pos.column=0),pos}}).call(Anchor.prototype)}),ace.define("ace/document",["require","exports","module","ace/lib/oop","ace/apply_delta","ace/lib/event_emitter","ace/range","ace/anchor"],function(acequire,exports){"use strict";var oop=acequire("./lib/oop"),applyDelta=acequire("./apply_delta").applyDelta,EventEmitter=acequire("./lib/event_emitter").EventEmitter,Range=acequire("./range").Range,Anchor=acequire("./anchor").Anchor,Document=function(textOrLines){this.$lines=[""],0===textOrLines.length?this.$lines=[""]:Array.isArray(textOrLines)?this.insertMergedLines({row:0,column:0},textOrLines):this.insert({row:0,column:0},textOrLines)};(function(){oop.implement(this,EventEmitter),this.setValue=function(text){var len=this.getLength()-1;this.remove(new Range(0,0,len,this.getLine(len).length)),this.insert({row:0,column:0},text)},this.getValue=function(){return this.getAllLines().join(this.getNewLineCharacter())},this.createAnchor=function(row,column){return new Anchor(this,row,column)},this.$split=0==="aaa".split(/a/).length?function(text){return text.replace(/\\r\\n|\\r/g,"\\n").split("\\n")}:function(text){return text.split(/\\r\\n|\\r|\\n/)},this.$detectNewLine=function(text){var match=text.match(/^.*?(\\r\\n|\\r|\\n)/m);this.$autoNewLine=match?match[1]:"\\n",this._signal("changeNewLineMode")},this.getNewLineCharacter=function(){switch(this.$newLineMode){case"windows":return"\\r\\n";case"unix":return"\\n";default:return this.$autoNewLine||"\\n"}},this.$autoNewLine="",this.$newLineMode="auto",this.setNewLineMode=function(newLineMode){this.$newLineMode!==newLineMode&&(this.$newLineMode=newLineMode,this._signal("changeNewLineMode"))},this.getNewLineMode=function(){return this.$newLineMode},this.isNewLine=function(text){return"\\r\\n"==text||"\\r"==text||"\\n"==text},this.getLine=function(row){return this.$lines[row]||""},this.getLines=function(firstRow,lastRow){return this.$lines.slice(firstRow,lastRow+1)},this.getAllLines=function(){return this.getLines(0,this.getLength())},this.getLength=function(){return this.$lines.length},this.getTextRange=function(range){return this.getLinesForRange(range).join(this.getNewLineCharacter())},this.getLinesForRange=function(range){var lines;if(range.start.row===range.end.row)lines=[this.getLine(range.start.row).substring(range.start.column,range.end.column)];else{lines=this.getLines(range.start.row,range.end.row),lines[0]=(lines[0]||"").substring(range.start.column);var l=lines.length-1;range.end.row-range.start.row==l&&(lines[l]=lines[l].substring(0,range.end.column))}return lines},this.insertLines=function(row,lines){return console.warn("Use of document.insertLines is deprecated. Use the insertFullLines method instead."),this.insertFullLines(row,lines)},this.removeLines=function(firstRow,lastRow){return console.warn("Use of document.removeLines is deprecated. Use the removeFullLines method instead."),this.removeFullLines(firstRow,lastRow)},this.insertNewLine=function(position){return console.warn("Use of document.insertNewLine is deprecated. Use insertMergedLines(position, ['', '']) instead."),this.insertMergedLines(position,["",""])},this.insert=function(position,text){return 1>=this.getLength()&&this.$detectNewLine(text),this.insertMergedLines(position,this.$split(text))},this.insertInLine=function(position,text){var start=this.clippedPos(position.row,position.column),end=this.pos(position.row,position.column+text.length);return this.applyDelta({start:start,end:end,action:"insert",lines:[text]},!0),this.clonePos(end)},this.clippedPos=function(row,column){var length=this.getLength();void 0===row?row=length:0>row?row=0:row>=length&&(row=length-1,column=void 0);var line=this.getLine(row);return void 0==column&&(column=line.length),column=Math.min(Math.max(column,0),line.length),{row:row,column:column}},this.clonePos=function(pos){return{row:pos.row,column:pos.column}},this.pos=function(row,column){return{row:row,column:column}},this.$clipPosition=function(position){var length=this.getLength();return position.row>=length?(position.row=Math.max(0,length-1),position.column=this.getLine(length-1).length):(position.row=Math.max(0,position.row),position.column=Math.min(Math.max(position.column,0),this.getLine(position.row).length)),position},this.insertFullLines=function(row,lines){row=Math.min(Math.max(row,0),this.getLength());var column=0;this.getLength()>row?(lines=lines.concat([""]),column=0):(lines=[""].concat(lines),row--,column=this.$lines[row].length),this.insertMergedLines({row:row,column:column},lines)},this.insertMergedLines=function(position,lines){var start=this.clippedPos(position.row,position.column),end={row:start.row+lines.length-1,column:(1==lines.length?start.column:0)+lines[lines.length-1].length};return this.applyDelta({start:start,end:end,action:"insert",lines:lines}),this.clonePos(end)},this.remove=function(range){var start=this.clippedPos(range.start.row,range.start.column),end=this.clippedPos(range.end.row,range.end.column);return this.applyDelta({start:start,end:end,action:"remove",lines:this.getLinesForRange({start:start,end:end})}),this.clonePos(start)},this.removeInLine=function(row,startColumn,endColumn){var start=this.clippedPos(row,startColumn),end=this.clippedPos(row,endColumn);return this.applyDelta({start:start,end:end,action:"remove",lines:this.getLinesForRange({start:start,end:end})},!0),this.clonePos(start)},this.removeFullLines=function(firstRow,lastRow){firstRow=Math.min(Math.max(0,firstRow),this.getLength()-1),lastRow=Math.min(Math.max(0,lastRow),this.getLength()-1);var deleteFirstNewLine=lastRow==this.getLength()-1&&firstRow>0,deleteLastNewLine=this.getLength()-1>lastRow,startRow=deleteFirstNewLine?firstRow-1:firstRow,startCol=deleteFirstNewLine?this.getLine(startRow).length:0,endRow=deleteLastNewLine?lastRow+1:lastRow,endCol=deleteLastNewLine?0:this.getLine(endRow).length,range=new Range(startRow,startCol,endRow,endCol),deletedLines=this.$lines.slice(firstRow,lastRow+1);return this.applyDelta({start:range.start,end:range.end,action:"remove",lines:this.getLinesForRange(range)}),deletedLines},this.removeNewLine=function(row){this.getLength()-1>row&&row>=0&&this.applyDelta({start:this.pos(row,this.getLine(row).length),end:this.pos(row+1,0),action:"remove",lines:["",""]})},this.replace=function(range,text){if(range instanceof Range||(range=Range.fromPoints(range.start,range.end)),0===text.length&&range.isEmpty())return range.start;if(text==this.getTextRange(range))return range.end;this.remove(range);var end;return end=text?this.insert(range.start,text):range.start},this.applyDeltas=function(deltas){for(var i=0;deltas.length>i;i++)this.applyDelta(deltas[i])},this.revertDeltas=function(deltas){for(var i=deltas.length-1;i>=0;i--)this.revertDelta(deltas[i])},this.applyDelta=function(delta,doNotValidate){var isInsert="insert"==delta.action;(isInsert?1>=delta.lines.length&&!delta.lines[0]:!Range.comparePoints(delta.start,delta.end))||(isInsert&&delta.lines.length>2e4&&this.$splitAndapplyLargeDelta(delta,2e4),applyDelta(this.$lines,delta,doNotValidate),this._signal("change",delta))},this.$splitAndapplyLargeDelta=function(delta,MAX){for(var lines=delta.lines,l=lines.length,row=delta.start.row,column=delta.start.column,from=0,to=0;;){from=to,to+=MAX-1;var chunk=lines.slice(from,to);if(to>l){delta.lines=chunk,delta.start.row=row+from,delta.start.column=column;break}chunk.push(""),this.applyDelta({start:this.pos(row+from,column),end:this.pos(row+to,column=0),action:delta.action,lines:chunk},!0)}},this.revertDelta=function(delta){this.applyDelta({start:this.clonePos(delta.start),end:this.clonePos(delta.end),action:"insert"==delta.action?"remove":"insert",lines:delta.lines.slice()})},this.indexToPosition=function(index,startRow){for(var lines=this.$lines||this.getAllLines(),newlineLength=this.getNewLineCharacter().length,i=startRow||0,l=lines.length;l>i;i++)if(index-=lines[i].length+newlineLength,0>index)return{row:i,column:index+lines[i].length+newlineLength};return{row:l-1,column:lines[l-1].length}},this.positionToIndex=function(pos,startRow){for(var lines=this.$lines||this.getAllLines(),newlineLength=this.getNewLineCharacter().length,index=0,row=Math.min(pos.row,lines.length),i=startRow||0;row>i;++i)index+=lines[i].length+newlineLength;return index+pos.column}}).call(Document.prototype),exports.Document=Document}),ace.define("ace/lib/lang",["require","exports","module"],function(acequire,exports){"use strict";exports.last=function(a){return a[a.length-1]},exports.stringReverse=function(string){return string.split("").reverse().join("")},exports.stringRepeat=function(string,count){for(var result="";count>0;)1&count&&(result+=string),(count>>=1)&&(string+=string);return result};var trimBeginRegexp=/^\\s\\s*/,trimEndRegexp=/\\s\\s*$/;exports.stringTrimLeft=function(string){return string.replace(trimBeginRegexp,"")},exports.stringTrimRight=function(string){return string.replace(trimEndRegexp,"")},exports.copyObject=function(obj){var copy={};for(var key in obj)copy[key]=obj[key];return copy},exports.copyArray=function(array){for(var copy=[],i=0,l=array.length;l>i;i++)copy[i]=array[i]&&"object"==typeof array[i]?this.copyObject(array[i]):array[i];return copy},exports.deepCopy=function deepCopy(obj){if("object"!=typeof obj||!obj)return obj;var copy;if(Array.isArray(obj)){copy=[];for(var key=0;obj.length>key;key++)copy[key]=deepCopy(obj[key]);return copy}if("[object Object]"!==Object.prototype.toString.call(obj))return obj;copy={};for(var key in obj)copy[key]=deepCopy(obj[key]);return copy},exports.arrayToMap=function(arr){for(var map={},i=0;arr.length>i;i++)map[arr[i]]=1;return map},exports.createMap=function(props){var map=Object.create(null);for(var i in props)map[i]=props[i];return map},exports.arrayRemove=function(array,value){for(var i=0;array.length>=i;i++)value===array[i]&&array.splice(i,1)},exports.escapeRegExp=function(str){return str.replace(/([.*+?^\${}()|[\\]\\/\\\\])/g,"\\\\$1")},exports.escapeHTML=function(str){return str.replace(/&/g,"&#38;").replace(/"/g,"&#34;").replace(/'/g,"&#39;").replace(/</g,"&#60;")},exports.getMatchOffsets=function(string,regExp){var matches=[];return string.replace(regExp,function(str){matches.push({offset:arguments[arguments.length-2],length:str.length})}),matches},exports.deferredCall=function(fcn){var timer=null,callback=function(){timer=null,fcn()},deferred=function(timeout){return deferred.cancel(),timer=setTimeout(callback,timeout||0),deferred};return deferred.schedule=deferred,deferred.call=function(){return this.cancel(),fcn(),deferred},deferred.cancel=function(){return clearTimeout(timer),timer=null,deferred},deferred.isPending=function(){return timer},deferred},exports.delayedCall=function(fcn,defaultTimeout){var timer=null,callback=function(){timer=null,fcn()},_self=function(timeout){null==timer&&(timer=setTimeout(callback,timeout||defaultTimeout))};return _self.delay=function(timeout){timer&&clearTimeout(timer),timer=setTimeout(callback,timeout||defaultTimeout)},_self.schedule=_self,_self.call=function(){this.cancel(),fcn()},_self.cancel=function(){timer&&clearTimeout(timer),timer=null},_self.isPending=function(){return timer},_self}}),ace.define("ace/worker/mirror",["require","exports","module","ace/range","ace/document","ace/lib/lang"],function(acequire,exports){"use strict";acequire("../range").Range;var Document=acequire("../document").Document,lang=acequire("../lib/lang"),Mirror=exports.Mirror=function(sender){this.sender=sender;var doc=this.doc=new Document(""),deferredUpdate=this.deferredUpdate=lang.delayedCall(this.onUpdate.bind(this)),_self=this;sender.on("change",function(e){var data=e.data;if(data[0].start)doc.applyDeltas(data);else for(var i=0;data.length>i;i+=2){if(Array.isArray(data[i+1]))var d={action:"insert",start:data[i],lines:data[i+1]};else var d={action:"remove",start:data[i],end:data[i+1]};doc.applyDelta(d,!0)}return _self.$timeout?deferredUpdate.schedule(_self.$timeout):(_self.onUpdate(),void 0)})};(function(){this.$timeout=500,this.setTimeout=function(timeout){this.$timeout=timeout},this.setValue=function(value){this.doc.setValue(value),this.deferredUpdate.schedule(this.$timeout)},this.getValue=function(callbackId){this.sender.callback(this.doc.getValue(),callbackId)},this.onUpdate=function(){},this.isPending=function(){return this.deferredUpdate.isPending()}}).call(Mirror.prototype)}),ace.define("ace/mode/json/json_parse",["require","exports","module"],function(){"use strict";var at,ch,text,value,escapee={'"':'"',"\\\\":"\\\\","/":"/",b:"\\b",f:"\\f",n:"\\n",r:"\\r",t:"	"},error=function(m){throw{name:"SyntaxError",message:m,at:at,text:text}},next=function(c){return c&&c!==ch&&error("Expected '"+c+"' instead of '"+ch+"'"),ch=text.charAt(at),at+=1,ch},number=function(){var number,string="";for("-"===ch&&(string="-",next("-"));ch>="0"&&"9">=ch;)string+=ch,next();if("."===ch)for(string+=".";next()&&ch>="0"&&"9">=ch;)string+=ch;if("e"===ch||"E"===ch)for(string+=ch,next(),("-"===ch||"+"===ch)&&(string+=ch,next());ch>="0"&&"9">=ch;)string+=ch,next();return number=+string,isNaN(number)?(error("Bad number"),void 0):number},string=function(){var hex,i,uffff,string="";if('"'===ch)for(;next();){if('"'===ch)return next(),string;if("\\\\"===ch)if(next(),"u"===ch){for(uffff=0,i=0;4>i&&(hex=parseInt(next(),16),isFinite(hex));i+=1)uffff=16*uffff+hex;string+=String.fromCharCode(uffff)}else{if("string"!=typeof escapee[ch])break;string+=escapee[ch]}else string+=ch}error("Bad string")},white=function(){for(;ch&&" ">=ch;)next()},word=function(){switch(ch){case"t":return next("t"),next("r"),next("u"),next("e"),!0;case"f":return next("f"),next("a"),next("l"),next("s"),next("e"),!1;case"n":return next("n"),next("u"),next("l"),next("l"),null}error("Unexpected '"+ch+"'")},array=function(){var array=[];if("["===ch){if(next("["),white(),"]"===ch)return next("]"),array;for(;ch;){if(array.push(value()),white(),"]"===ch)return next("]"),array;next(","),white()}}error("Bad array")},object=function(){var key,object={};if("{"===ch){if(next("{"),white(),"}"===ch)return next("}"),object;for(;ch;){if(key=string(),white(),next(":"),Object.hasOwnProperty.call(object,key)&&error('Duplicate key "'+key+'"'),object[key]=value(),white(),"}"===ch)return next("}"),object;next(","),white()}}error("Bad object")};return value=function(){switch(white(),ch){case"{":return object();case"[":return array();case'"':return string();case"-":return number();default:return ch>="0"&&"9">=ch?number():word()}},function(source,reviver){var result;return text=source,at=0,ch=" ",result=value(),white(),ch&&error("Syntax error"),"function"==typeof reviver?function walk(holder,key){var k,v,value=holder[key];if(value&&"object"==typeof value)for(k in value)Object.hasOwnProperty.call(value,k)&&(v=walk(value,k),void 0!==v?value[k]=v:delete value[k]);return reviver.call(holder,key,value)}({"":result},""):result}}),ace.define("ace/mode/json_worker",["require","exports","module","ace/lib/oop","ace/worker/mirror","ace/mode/json/json_parse"],function(acequire,exports){"use strict";var oop=acequire("../lib/oop"),Mirror=acequire("../worker/mirror").Mirror,parse=acequire("./json/json_parse"),JsonWorker=exports.JsonWorker=function(sender){Mirror.call(this,sender),this.setTimeout(200)};oop.inherits(JsonWorker,Mirror),function(){this.onUpdate=function(){var value=this.doc.getValue(),errors=[];try{value&&parse(value)}catch(e){var pos=this.doc.indexToPosition(e.at-1);errors.push({row:pos.row,column:pos.column,text:e.message,type:"error"})}this.sender.emit("annotate",errors)}}.call(JsonWorker.prototype)}),ace.define("ace/lib/es5-shim",["require","exports","module"],function(){function Empty(){}function doesDefinePropertyWork(object){try{return Object.defineProperty(object,"sentinel",{}),"sentinel"in object}catch(exception){}}function toInteger(n){return n=+n,n!==n?n=0:0!==n&&n!==1/0&&n!==-(1/0)&&(n=(n>0||-1)*Math.floor(Math.abs(n))),n}Function.prototype.bind||(Function.prototype.bind=function(that){var target=this;if("function"!=typeof target)throw new TypeError("Function.prototype.bind called on incompatible "+target);var args=slice.call(arguments,1),bound=function(){if(this instanceof bound){var result=target.apply(this,args.concat(slice.call(arguments)));return Object(result)===result?result:this}return target.apply(that,args.concat(slice.call(arguments)))};return target.prototype&&(Empty.prototype=target.prototype,bound.prototype=new Empty,Empty.prototype=null),bound});var defineGetter,defineSetter,lookupGetter,lookupSetter,supportsAccessors,call=Function.prototype.call,prototypeOfArray=Array.prototype,prototypeOfObject=Object.prototype,slice=prototypeOfArray.slice,_toString=call.bind(prototypeOfObject.toString),owns=call.bind(prototypeOfObject.hasOwnProperty);if((supportsAccessors=owns(prototypeOfObject,"__defineGetter__"))&&(defineGetter=call.bind(prototypeOfObject.__defineGetter__),defineSetter=call.bind(prototypeOfObject.__defineSetter__),lookupGetter=call.bind(prototypeOfObject.__lookupGetter__),lookupSetter=call.bind(prototypeOfObject.__lookupSetter__)),2!=[1,2].splice(0).length)if(function(){function makeArray(l){var a=Array(l+2);return a[0]=a[1]=0,a}var lengthBefore,array=[];return array.splice.apply(array,makeArray(20)),array.splice.apply(array,makeArray(26)),lengthBefore=array.length,array.splice(5,0,"XXX"),lengthBefore+1==array.length,lengthBefore+1==array.length?!0:void 0
}()){var array_splice=Array.prototype.splice;Array.prototype.splice=function(start,deleteCount){return arguments.length?array_splice.apply(this,[void 0===start?0:start,void 0===deleteCount?this.length-start:deleteCount].concat(slice.call(arguments,2))):[]}}else Array.prototype.splice=function(pos,removeCount){var length=this.length;pos>0?pos>length&&(pos=length):void 0==pos?pos=0:0>pos&&(pos=Math.max(length+pos,0)),length>pos+removeCount||(removeCount=length-pos);var removed=this.slice(pos,pos+removeCount),insert=slice.call(arguments,2),add=insert.length;if(pos===length)add&&this.push.apply(this,insert);else{var remove=Math.min(removeCount,length-pos),tailOldPos=pos+remove,tailNewPos=tailOldPos+add-remove,tailCount=length-tailOldPos,lengthAfterRemove=length-remove;if(tailOldPos>tailNewPos)for(var i=0;tailCount>i;++i)this[tailNewPos+i]=this[tailOldPos+i];else if(tailNewPos>tailOldPos)for(i=tailCount;i--;)this[tailNewPos+i]=this[tailOldPos+i];if(add&&pos===lengthAfterRemove)this.length=lengthAfterRemove,this.push.apply(this,insert);else for(this.length=lengthAfterRemove+add,i=0;add>i;++i)this[pos+i]=insert[i]}return removed};Array.isArray||(Array.isArray=function(obj){return"[object Array]"==_toString(obj)});var boxedString=Object("a"),splitString="a"!=boxedString[0]||!(0 in boxedString);if(Array.prototype.forEach||(Array.prototype.forEach=function(fun){var object=toObject(this),self=splitString&&"[object String]"==_toString(this)?this.split(""):object,thisp=arguments[1],i=-1,length=self.length>>>0;if("[object Function]"!=_toString(fun))throw new TypeError;for(;length>++i;)i in self&&fun.call(thisp,self[i],i,object)}),Array.prototype.map||(Array.prototype.map=function(fun){var object=toObject(this),self=splitString&&"[object String]"==_toString(this)?this.split(""):object,length=self.length>>>0,result=Array(length),thisp=arguments[1];if("[object Function]"!=_toString(fun))throw new TypeError(fun+" is not a function");for(var i=0;length>i;i++)i in self&&(result[i]=fun.call(thisp,self[i],i,object));return result}),Array.prototype.filter||(Array.prototype.filter=function(fun){var value,object=toObject(this),self=splitString&&"[object String]"==_toString(this)?this.split(""):object,length=self.length>>>0,result=[],thisp=arguments[1];if("[object Function]"!=_toString(fun))throw new TypeError(fun+" is not a function");for(var i=0;length>i;i++)i in self&&(value=self[i],fun.call(thisp,value,i,object)&&result.push(value));return result}),Array.prototype.every||(Array.prototype.every=function(fun){var object=toObject(this),self=splitString&&"[object String]"==_toString(this)?this.split(""):object,length=self.length>>>0,thisp=arguments[1];if("[object Function]"!=_toString(fun))throw new TypeError(fun+" is not a function");for(var i=0;length>i;i++)if(i in self&&!fun.call(thisp,self[i],i,object))return!1;return!0}),Array.prototype.some||(Array.prototype.some=function(fun){var object=toObject(this),self=splitString&&"[object String]"==_toString(this)?this.split(""):object,length=self.length>>>0,thisp=arguments[1];if("[object Function]"!=_toString(fun))throw new TypeError(fun+" is not a function");for(var i=0;length>i;i++)if(i in self&&fun.call(thisp,self[i],i,object))return!0;return!1}),Array.prototype.reduce||(Array.prototype.reduce=function(fun){var object=toObject(this),self=splitString&&"[object String]"==_toString(this)?this.split(""):object,length=self.length>>>0;if("[object Function]"!=_toString(fun))throw new TypeError(fun+" is not a function");if(!length&&1==arguments.length)throw new TypeError("reduce of empty array with no initial value");var result,i=0;if(arguments.length>=2)result=arguments[1];else for(;;){if(i in self){result=self[i++];break}if(++i>=length)throw new TypeError("reduce of empty array with no initial value")}for(;length>i;i++)i in self&&(result=fun.call(void 0,result,self[i],i,object));return result}),Array.prototype.reduceRight||(Array.prototype.reduceRight=function(fun){var object=toObject(this),self=splitString&&"[object String]"==_toString(this)?this.split(""):object,length=self.length>>>0;if("[object Function]"!=_toString(fun))throw new TypeError(fun+" is not a function");if(!length&&1==arguments.length)throw new TypeError("reduceRight of empty array with no initial value");var result,i=length-1;if(arguments.length>=2)result=arguments[1];else for(;;){if(i in self){result=self[i--];break}if(0>--i)throw new TypeError("reduceRight of empty array with no initial value")}do i in this&&(result=fun.call(void 0,result,self[i],i,object));while(i--);return result}),Array.prototype.indexOf&&-1==[0,1].indexOf(1,2)||(Array.prototype.indexOf=function(sought){var self=splitString&&"[object String]"==_toString(this)?this.split(""):toObject(this),length=self.length>>>0;if(!length)return-1;var i=0;for(arguments.length>1&&(i=toInteger(arguments[1])),i=i>=0?i:Math.max(0,length+i);length>i;i++)if(i in self&&self[i]===sought)return i;return-1}),Array.prototype.lastIndexOf&&-1==[0,1].lastIndexOf(0,-3)||(Array.prototype.lastIndexOf=function(sought){var self=splitString&&"[object String]"==_toString(this)?this.split(""):toObject(this),length=self.length>>>0;if(!length)return-1;var i=length-1;for(arguments.length>1&&(i=Math.min(i,toInteger(arguments[1]))),i=i>=0?i:length-Math.abs(i);i>=0;i--)if(i in self&&sought===self[i])return i;return-1}),Object.getPrototypeOf||(Object.getPrototypeOf=function(object){return object.__proto__||(object.constructor?object.constructor.prototype:prototypeOfObject)}),!Object.getOwnPropertyDescriptor){var ERR_NON_OBJECT="Object.getOwnPropertyDescriptor called on a non-object: ";Object.getOwnPropertyDescriptor=function(object,property){if("object"!=typeof object&&"function"!=typeof object||null===object)throw new TypeError(ERR_NON_OBJECT+object);if(owns(object,property)){var descriptor,getter,setter;if(descriptor={enumerable:!0,configurable:!0},supportsAccessors){var prototype=object.__proto__;object.__proto__=prototypeOfObject;var getter=lookupGetter(object,property),setter=lookupSetter(object,property);if(object.__proto__=prototype,getter||setter)return getter&&(descriptor.get=getter),setter&&(descriptor.set=setter),descriptor}return descriptor.value=object[property],descriptor}}}if(Object.getOwnPropertyNames||(Object.getOwnPropertyNames=function(object){return Object.keys(object)}),!Object.create){var createEmpty;createEmpty=null===Object.prototype.__proto__?function(){return{__proto__:null}}:function(){var empty={};for(var i in empty)empty[i]=null;return empty.constructor=empty.hasOwnProperty=empty.propertyIsEnumerable=empty.isPrototypeOf=empty.toLocaleString=empty.toString=empty.valueOf=empty.__proto__=null,empty},Object.create=function(prototype,properties){var object;if(null===prototype)object=createEmpty();else{if("object"!=typeof prototype)throw new TypeError("typeof prototype["+typeof prototype+"] != 'object'");var Type=function(){};Type.prototype=prototype,object=new Type,object.__proto__=prototype}return void 0!==properties&&Object.defineProperties(object,properties),object}}if(Object.defineProperty){var definePropertyWorksOnObject=doesDefinePropertyWork({}),definePropertyWorksOnDom="undefined"==typeof document||doesDefinePropertyWork(document.createElement("div"));if(!definePropertyWorksOnObject||!definePropertyWorksOnDom)var definePropertyFallback=Object.defineProperty}if(!Object.defineProperty||definePropertyFallback){var ERR_NON_OBJECT_DESCRIPTOR="Property description must be an object: ",ERR_NON_OBJECT_TARGET="Object.defineProperty called on non-object: ",ERR_ACCESSORS_NOT_SUPPORTED="getters & setters can not be defined on this javascript engine";Object.defineProperty=function(object,property,descriptor){if("object"!=typeof object&&"function"!=typeof object||null===object)throw new TypeError(ERR_NON_OBJECT_TARGET+object);if("object"!=typeof descriptor&&"function"!=typeof descriptor||null===descriptor)throw new TypeError(ERR_NON_OBJECT_DESCRIPTOR+descriptor);if(definePropertyFallback)try{return definePropertyFallback.call(Object,object,property,descriptor)}catch(exception){}if(owns(descriptor,"value"))if(supportsAccessors&&(lookupGetter(object,property)||lookupSetter(object,property))){var prototype=object.__proto__;object.__proto__=prototypeOfObject,delete object[property],object[property]=descriptor.value,object.__proto__=prototype}else object[property]=descriptor.value;else{if(!supportsAccessors)throw new TypeError(ERR_ACCESSORS_NOT_SUPPORTED);owns(descriptor,"get")&&defineGetter(object,property,descriptor.get),owns(descriptor,"set")&&defineSetter(object,property,descriptor.set)}return object}}Object.defineProperties||(Object.defineProperties=function(object,properties){for(var property in properties)owns(properties,property)&&Object.defineProperty(object,property,properties[property]);return object}),Object.seal||(Object.seal=function(object){return object}),Object.freeze||(Object.freeze=function(object){return object});try{Object.freeze(function(){})}catch(exception){Object.freeze=function(freezeObject){return function(object){return"function"==typeof object?object:freezeObject(object)}}(Object.freeze)}if(Object.preventExtensions||(Object.preventExtensions=function(object){return object}),Object.isSealed||(Object.isSealed=function(){return!1}),Object.isFrozen||(Object.isFrozen=function(){return!1}),Object.isExtensible||(Object.isExtensible=function(object){if(Object(object)===object)throw new TypeError;for(var name="";owns(object,name);)name+="?";object[name]=!0;var returnValue=owns(object,name);return delete object[name],returnValue}),!Object.keys){var hasDontEnumBug=!0,dontEnums=["toString","toLocaleString","valueOf","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","constructor"],dontEnumsLength=dontEnums.length;for(var key in{toString:null})hasDontEnumBug=!1;Object.keys=function(object){if("object"!=typeof object&&"function"!=typeof object||null===object)throw new TypeError("Object.keys called on a non-object");var keys=[];for(var name in object)owns(object,name)&&keys.push(name);if(hasDontEnumBug)for(var i=0,ii=dontEnumsLength;ii>i;i++){var dontEnum=dontEnums[i];owns(object,dontEnum)&&keys.push(dontEnum)}return keys}}Date.now||(Date.now=function(){return(new Date).getTime()});var ws="	\\n\v\\f\\r   ᠎             　\\u2028\\u2029\uFEFF";if(!String.prototype.trim||ws.trim()){ws="["+ws+"]";var trimBeginRegexp=RegExp("^"+ws+ws+"*"),trimEndRegexp=RegExp(ws+ws+"*$");String.prototype.trim=function(){return(this+"").replace(trimBeginRegexp,"").replace(trimEndRegexp,"")}}var toObject=function(o){if(null==o)throw new TypeError("can't convert "+o+" to object");return Object(o)}});`},function(u,r){ace.define("ace/ext/searchbox",["require","exports","module","ace/lib/dom","ace/lib/lang","ace/lib/event","ace/keyboard/hash_handler","ace/lib/keys"],function(i,s,o){var f=i("../lib/dom"),n=i("../lib/lang"),h=i("../lib/event"),g="		.ace_search {		background-color: #ddd;		border: 1px solid #cbcbcb;		border-top: 0 none;		max-width: 325px;		overflow: hidden;		margin: 0;		padding: 4px;		padding-right: 6px;		padding-bottom: 0;		position: absolute;		top: 0px;		z-index: 99;		white-space: normal;		}		.ace_search.left {		border-left: 0 none;		border-radius: 0px 0px 5px 0px;		left: 0;		}		.ace_search.right {		border-radius: 0px 0px 0px 5px;		border-right: 0 none;		right: 0;		}		.ace_search_form, .ace_replace_form {		border-radius: 3px;		border: 1px solid #cbcbcb;		float: left;		margin-bottom: 4px;		overflow: hidden;		}		.ace_search_form.ace_nomatch {		outline: 1px solid red;		}		.ace_search_field {		background-color: white;		color: black;		border-right: 1px solid #cbcbcb;		border: 0 none;		-webkit-box-sizing: border-box;		-moz-box-sizing: border-box;		box-sizing: border-box;		float: left;		height: 22px;		outline: 0;		padding: 0 7px;		width: 214px;		margin: 0;		}		.ace_searchbtn,		.ace_replacebtn {		background: #fff;		border: 0 none;		border-left: 1px solid #dcdcdc;		cursor: pointer;		float: left;		height: 22px;		margin: 0;		position: relative;		}		.ace_searchbtn:last-child,		.ace_replacebtn:last-child {		border-top-right-radius: 3px;		border-bottom-right-radius: 3px;		}		.ace_searchbtn:disabled {		background: none;		cursor: default;		}		.ace_searchbtn {		background-position: 50% 50%;		background-repeat: no-repeat;		width: 27px;		}		.ace_searchbtn.prev {		background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAgAAAAFCAYAAAB4ka1VAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAADFJREFUeNpiSU1NZUAC/6E0I0yACYskCpsJiySKIiY0SUZk40FyTEgCjGgKwTRAgAEAQJUIPCE+qfkAAAAASUVORK5CYII=);    		}		.ace_searchbtn.next {		background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAgAAAAFCAYAAAB4ka1VAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAADRJREFUeNpiTE1NZQCC/0DMyIAKwGJMUAYDEo3M/s+EpvM/mkKwCQxYjIeLMaELoLMBAgwAU7UJObTKsvAAAAAASUVORK5CYII=);    		}		.ace_searchbtn_close {		background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAA4AAAAcCAYAAABRVo5BAAAAZ0lEQVR42u2SUQrAMAhDvazn8OjZBilCkYVVxiis8H4CT0VrAJb4WHT3C5xU2a2IQZXJjiQIRMdkEoJ5Q2yMqpfDIo+XY4k6h+YXOyKqTIj5REaxloNAd0xiKmAtsTHqW8sR2W5f7gCu5nWFUpVjZwAAAABJRU5ErkJggg==) no-repeat 50% 0;		border-radius: 50%;		border: 0 none;		color: #656565;		cursor: pointer;		float: right;		font: 16px/16px Arial;		height: 14px;		margin: 5px 1px 9px 5px;		padding: 0;		text-align: center;		width: 14px;		}		.ace_searchbtn_close:hover {		background-color: #656565;		background-position: 50% 100%;		color: white;		}		.ace_replacebtn.prev {		width: 54px		}		.ace_replacebtn.next {		width: 27px		}		.ace_button {		margin-left: 2px;		cursor: pointer;		-webkit-user-select: none;		-moz-user-select: none;		-o-user-select: none;		-ms-user-select: none;		user-select: none;		overflow: hidden;		opacity: 0.7;		border: 1px solid rgba(100,100,100,0.23);		padding: 1px;		-moz-box-sizing: border-box;		box-sizing:    border-box;		color: black;		}		.ace_button:hover {		background-color: #eee;		opacity:1;		}		.ace_button:active {		background-color: #ddd;		}		.ace_button.checked {		border-color: #3399ff;		opacity:1;		}		.ace_search_options{		margin-bottom: 3px;		text-align: right;		-webkit-user-select: none;		-moz-user-select: none;		-o-user-select: none;		-ms-user-select: none;		user-select: none;		}",d=i("../keyboard/hash_handler").HashHandler,l=i("../lib/keys");f.importCssString(g,"ace_searchbox");var c='<div class="ace_search right">		    <button type="button" action="hide" class="ace_searchbtn_close"></button>		    <div class="ace_search_form">		        <input class="ace_search_field" placeholder="Search for" spellcheck="false"></input>		        <button type="button" action="findNext" class="ace_searchbtn next"></button>		        <button type="button" action="findPrev" class="ace_searchbtn prev"></button>		        <button type="button" action="findAll" class="ace_searchbtn" title="Alt-Enter">All</button>		    </div>		    <div class="ace_replace_form">		        <input class="ace_search_field" placeholder="Replace with" spellcheck="false"></input>		        <button type="button" action="replaceAndFindNext" class="ace_replacebtn">Replace</button>		        <button type="button" action="replaceAll" class="ace_replacebtn">All</button>		    </div>		    <div class="ace_search_options">		        <span action="toggleRegexpMode" class="ace_button" title="RegExp Search">.*</span>		        <span action="toggleCaseSensitive" class="ace_button" title="CaseSensitive Search">Aa</span>		        <span action="toggleWholeWords" class="ace_button" title="Whole Word Search">\\b</span>		    </div>		</div>'.replace(/>\s+/g,">"),a=function(F,p,m){var b=f.createElement("div");b.innerHTML=c,this.element=b.firstChild,this.$init(),this.setEditor(F)};(function(){this.setEditor=function(F){F.searchBox=this,F.container.appendChild(this.element),this.editor=F},this.$initElements=function(F){this.searchBox=F.querySelector(".ace_search_form"),this.replaceBox=F.querySelector(".ace_replace_form"),this.searchOptions=F.querySelector(".ace_search_options"),this.regExpOption=F.querySelector("[action=toggleRegexpMode]"),this.caseSensitiveOption=F.querySelector("[action=toggleCaseSensitive]"),this.wholeWordOption=F.querySelector("[action=toggleWholeWords]"),this.searchInput=this.searchBox.querySelector(".ace_search_field"),this.replaceInput=this.replaceBox.querySelector(".ace_search_field")},this.$init=function(){var F=this.element;this.$initElements(F);var p=this;h.addListener(F,"mousedown",function(m){setTimeout(function(){p.activeInput.focus()},0),h.stopPropagation(m)}),h.addListener(F,"click",function(m){var b=m.target||m.srcElement,C=b.getAttribute("action");C&&p[C]?p[C]():p.$searchBarKb.commands[C]&&p.$searchBarKb.commands[C].exec(p),h.stopPropagation(m)}),h.addCommandKeyListener(F,function(m,b,C){var k=l.keyCodeToString(C),T=p.$searchBarKb.findKeyCommand(b,k);T&&T.exec&&(T.exec(p),h.stopEvent(m))}),this.$onChange=n.delayedCall(function(){p.find(!1,!1)}),h.addListener(this.searchInput,"input",function(){p.$onChange.schedule(20)}),h.addListener(this.searchInput,"focus",function(){p.activeInput=p.searchInput,p.searchInput.value&&p.highlight()}),h.addListener(this.replaceInput,"focus",function(){p.activeInput=p.replaceInput,p.searchInput.value&&p.highlight()})},this.$closeSearchBarKb=new d([{bindKey:"Esc",name:"closeSearchBar",exec:function(F){F.searchBox.hide()}}]),this.$searchBarKb=new d,this.$searchBarKb.bindKeys({"Ctrl-f|Command-f":function(F){var p=F.isReplace=!F.isReplace;F.replaceBox.style.display=p?"":"none",F.searchInput.focus()},"Ctrl-H|Command-Option-F":function(F){F.replaceBox.style.display="",F.replaceInput.focus()},"Ctrl-G|Command-G":function(F){F.findNext()},"Ctrl-Shift-G|Command-Shift-G":function(F){F.findPrev()},esc:function(F){setTimeout(function(){F.hide()})},Return:function(F){F.activeInput==F.replaceInput&&F.replace(),F.findNext()},"Shift-Return":function(F){F.activeInput==F.replaceInput&&F.replace(),F.findPrev()},"Alt-Return":function(F){F.activeInput==F.replaceInput&&F.replaceAll(),F.findAll()},Tab:function(F){(F.activeInput==F.replaceInput?F.searchInput:F.replaceInput).focus()}}),this.$searchBarKb.addCommands([{name:"toggleRegexpMode",bindKey:{win:"Alt-R|Alt-/",mac:"Ctrl-Alt-R|Ctrl-Alt-/"},exec:function(F){F.regExpOption.checked=!F.regExpOption.checked,F.$syncOptions()}},{name:"toggleCaseSensitive",bindKey:{win:"Alt-C|Alt-I",mac:"Ctrl-Alt-R|Ctrl-Alt-I"},exec:function(F){F.caseSensitiveOption.checked=!F.caseSensitiveOption.checked,F.$syncOptions()}},{name:"toggleWholeWords",bindKey:{win:"Alt-B|Alt-W",mac:"Ctrl-Alt-B|Ctrl-Alt-W"},exec:function(F){F.wholeWordOption.checked=!F.wholeWordOption.checked,F.$syncOptions()}}]),this.$syncOptions=function(){f.setCssClass(this.regExpOption,"checked",this.regExpOption.checked),f.setCssClass(this.wholeWordOption,"checked",this.wholeWordOption.checked),f.setCssClass(this.caseSensitiveOption,"checked",this.caseSensitiveOption.checked),this.find(!1,!1)},this.highlight=function(F){this.editor.session.highlight(F||this.editor.$search.$options.re),this.editor.renderer.updateBackMarkers()},this.find=function(F,p,m){var b=this.editor.find(this.searchInput.value,{skipCurrent:F,backwards:p,wrap:!0,regExp:this.regExpOption.checked,caseSensitive:this.caseSensitiveOption.checked,wholeWord:this.wholeWordOption.checked,preventScroll:m}),C=!b&&this.searchInput.value;f.setCssClass(this.searchBox,"ace_nomatch",C),this.editor._emit("findSearchBox",{match:!C}),this.highlight()},this.findNext=function(){this.find(!0,!1)},this.findPrev=function(){this.find(!0,!0)},this.findAll=function(){var F=this.editor.findAll(this.searchInput.value,{regExp:this.regExpOption.checked,caseSensitive:this.caseSensitiveOption.checked,wholeWord:this.wholeWordOption.checked}),p=!F&&this.searchInput.value;f.setCssClass(this.searchBox,"ace_nomatch",p),this.editor._emit("findSearchBox",{match:!p}),this.highlight(),this.hide()},this.replace=function(){this.editor.getReadOnly()||this.editor.replace(this.replaceInput.value)},this.replaceAndFindNext=function(){this.editor.getReadOnly()||(this.editor.replace(this.replaceInput.value),this.findNext())},this.replaceAll=function(){this.editor.getReadOnly()||this.editor.replaceAll(this.replaceInput.value)},this.hide=function(){this.element.style.display="none",this.editor.keyBinding.removeKeyboardHandler(this.$closeSearchBarKb),this.editor.focus()},this.show=function(F,p){this.element.style.display="",this.replaceBox.style.display=p?"":"none",this.isReplace=p,F&&(this.searchInput.value=F),this.find(!1,!1,!0),this.searchInput.focus(),this.searchInput.select(),this.editor.keyBinding.addKeyboardHandler(this.$closeSearchBarKb)},this.isFocused=function(){var F=document.activeElement;return F==this.searchInput||F==this.replaceInput}}).call(a.prototype),s.SearchBox=a,s.Search=function(F,p){var m=F.searchBox||new a(F);m.show(F.session.getTextRange(),p)}}),function(){ace.acequire(["ace/ext/searchbox"],function(){})}()},function(u,r){ace.define("ace/theme/jsoneditor",["require","exports","module","ace/lib/dom"],function(i,s,o){s.isDark=!1,s.cssClass="ace-jsoneditor",s.cssText='.ace-jsoneditor .ace_gutter {		background: #ebebeb;		color: #333		}				.ace-jsoneditor.ace_editor {		font-family: droid sans mono, consolas, monospace, courier new, courier, sans-serif;		line-height: 1.3;		background-color: #fff;		}		.ace-jsoneditor .ace_print-margin {		width: 1px;		background: #e8e8e8		}		.ace-jsoneditor .ace_scroller {		background-color: #FFFFFF		}		.ace-jsoneditor .ace_text-layer {		color: gray		}		.ace-jsoneditor .ace_variable {		color: #1a1a1a		}		.ace-jsoneditor .ace_cursor {		border-left: 2px solid #000000		}		.ace-jsoneditor .ace_overwrite-cursors .ace_cursor {		border-left: 0px;		border-bottom: 1px solid #000000		}		.ace-jsoneditor .ace_marker-layer .ace_selection {		background: lightgray		}		.ace-jsoneditor.ace_multiselect .ace_selection.ace_start {		box-shadow: 0 0 3px 0px #FFFFFF;		border-radius: 2px		}		.ace-jsoneditor .ace_marker-layer .ace_step {		background: rgb(255, 255, 0)		}		.ace-jsoneditor .ace_marker-layer .ace_bracket {		margin: -1px 0 0 -1px;		border: 1px solid #BFBFBF		}		.ace-jsoneditor .ace_marker-layer .ace_active-line {		background: #FFFBD1		}		.ace-jsoneditor .ace_gutter-active-line {		background-color : #dcdcdc		}		.ace-jsoneditor .ace_marker-layer .ace_selected-word {		border: 1px solid lightgray		}		.ace-jsoneditor .ace_invisible {		color: #BFBFBF		}		.ace-jsoneditor .ace_keyword,		.ace-jsoneditor .ace_meta,		.ace-jsoneditor .ace_support.ace_constant.ace_property-value {		color: #AF956F		}		.ace-jsoneditor .ace_keyword.ace_operator {		color: #484848		}		.ace-jsoneditor .ace_keyword.ace_other.ace_unit {		color: #96DC5F		}		.ace-jsoneditor .ace_constant.ace_language {		color: darkorange		}		.ace-jsoneditor .ace_constant.ace_numeric {		color: red		}		.ace-jsoneditor .ace_constant.ace_character.ace_entity {		color: #BF78CC		}		.ace-jsoneditor .ace_invalid {		color: #FFFFFF;		background-color: #FF002A;		}		.ace-jsoneditor .ace_fold {		background-color: #AF956F;		border-color: #000000		}		.ace-jsoneditor .ace_storage,		.ace-jsoneditor .ace_support.ace_class,		.ace-jsoneditor .ace_support.ace_function,		.ace-jsoneditor .ace_support.ace_other,		.ace-jsoneditor .ace_support.ace_type {		color: #C52727		}		.ace-jsoneditor .ace_string {		color: green		}		.ace-jsoneditor .ace_comment {		color: #BCC8BA		}		.ace-jsoneditor .ace_entity.ace_name.ace_tag,		.ace-jsoneditor .ace_entity.ace_other.ace_attribute-name {		color: #606060		}		.ace-jsoneditor .ace_markup.ace_underline {		text-decoration: underline		}		.ace-jsoneditor .ace_indent-guide {		background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAACCAYAAACZgbYnAAAAE0lEQVQImWP4////f4bLly//BwAmVgd1/w11/gAAAABJRU5ErkJggg==") right repeat-y		}';var f=i("../lib/dom");f.importCssString(s.cssText,s.cssClass)})}])})})(Sp);var JA=Sp.exports;const QA=zn(JA);var Kd=Xe.extend({className:"g-widget-metadata-row",events:{"click .g-widget-metadata-edit-button":"editMetadata"},initialize:function(t){if(!xe.has(this.parentView.modes,t.mode))throw new Error("Unsupported metadatum mode "+t.mode+" detected.");this.mode=t.mode,this.key=t.key,this.value=t.value,this.accessLevel=t.accessLevel,this.parentView=t.parentView,this.fieldName=t.fieldName,this.apiPath=t.apiPath,this.onMetadataEdited=t.onMetadataEdited,this.onMetadataAdded=t.onMetadataAdded},_validate:function(t,e,u){var r=this.parentView.modes[e];if(xe.has(r,"validation")&&xe.has(r.validation,"from")&&xe.has(r.validation.from,t)){var i=r.validation.from[t][0],s=r.validation.from[t][1];if(!i(u))return He.trigger("g:alert",{text:s,type:"warning"}),!1}return!0},toggleEditor:function(t,e,u,r){var i=u instanceof On?"json":"simple",s=(r||{}).value||u.$el.attr("g-value");if(this._validate(i,e,s)){var o=u.$el;u.destroy(),o.addClass("editing").empty();var f=xe.extend({el:o,item:this.parentView.item,key:o.attr("g-key"),value:o.attr("g-value"),accessLevel:this.accessLevel,newDatum:!1,parentView:this,fieldName:this.fieldName,apiPath:this.apiPath,onMetadataEdited:this.onMetadataEdited,onMetadataAdded:this.onMetadataAdded},r||{});this.parentView.modes[e].editor(f).render()}},editMetadata:function(){this.$el.addClass("editing"),this.$el.empty();var t={item:this.parentView.item,key:this.$el.attr("g-key"),value:this.$el.attr("g-value"),accessLevel:this.accessLevel,newDatum:!1,parentView:this,fieldName:this.fieldName,apiPath:this.apiPath,onMetadataEdited:this.onMetadataEdited,onMetadataAdded:this.onMetadataAdded};if(this.mode==="json")try{var e=JSON.parse(this.$el.attr("g-value"));e!==void 0&&!xe.isObject(e)&&(t.value=e)}catch{}this.parentView.modes[this.mode].editor(t).render().$el.appendTo(this.$el)},render:function(){return this.$el.attr({"g-key":this.key,"g-value":xe.bind(this.parentView.modes[this.mode].displayValue,this)()}).empty(),this.$el.html(this.parentView.modes[this.mode].template({key:this.key,value:xe.bind(this.parentView.modes[this.mode].displayValue,this)(),accessLevel:this.accessLevel,AccessType:nt})),this}}),Cn=Xe.extend({events:{"click .g-widget-metadata-cancel-button":"cancelEdit","click .g-widget-metadata-save-button":"save","click .g-widget-metadata-delete-button":"deleteMetadatum","click .g-widget-metadata-toggle-button":function(t){var e;this instanceof On?e="simple":e="json",this.parentView.toggleEditor(t,e,this,{key:this.$el.find(".g-widget-metadata-key-input").val(),value:this.getCurrentValue()})}},initialize:function(t){this.item=t.item,this.key=t.key||"",this.fieldName=t.fieldName||"meta",this.value=t.value!==void 0?t.value:"",this.accessLevel=t.accessLevel,this.newDatum=t.newDatum,this.fieldName=t.fieldName,this.apiPath=t.apiPath,this.onMetadataEdited=t.onMetadataEdited,this.onMetadataAdded=t.onMetadataAdded},editTemplate:GA,getCurrentValue:function(){return this.$el.find(".g-widget-metadata-value-input").val()},deleteMetadatum:function(t){t.stopImmediatePropagation();var u=ke(t.currentTarget).parent().parent(),r={text:"Are you sure you want to delete the metadatum <b>"+xe.escape(this.key)+"</b>?",escapedHtml:!0,yesText:"Delete",confirmCallback:()=>{this.item.removeMetadata(this.key,function(){u.remove()},null,{field:this.fieldName,path:this.apiPath})}};n0(r)},cancelEdit:function(t){t.stopImmediatePropagation();var u=ke(t.currentTarget).parent().parent();this.newDatum?u.remove():this.parentView.render()},save:function(t,e){t.stopImmediatePropagation();var r=ke(t.currentTarget).parent(),i=r.find(".g-widget-metadata-key-input").val(),s=e!==void 0?e:r.find(".g-widget-metadata-value-input").val();if(this.newDatum&&i===""){He.trigger("g:alert",{text:"A key is required for all metadata.",type:"warning"});return}var o=()=>{this.key=i,this.value=s,this.parentView.key=this.key,this.parentView.value=this.value,this instanceof On?this.parentView.mode="json":this.parentView.mode="simple",this.parentView.render(),this.newDatum=!1},f=function(n){He.trigger("g:alert",{text:n.message,type:"danger"})};this.newDatum?this.onMetadataAdded?this.onMetadataAdded(i,s,o,f):this.item.addMetadata(i,s,o,f,{field:this.fieldName,path:this.apiPath}):this.onMetadataEdited?this.onMetadataEdited(i,this.key,s,o,f):this.item.editMetadata(i,this.key,s,o,f,{field:this.fieldName,path:this.apiPath})},render:function(){return this.$el.html(this.editTemplate({item:this.item,key:this.key,value:this.value,accessLevel:this.accessLevel,newDatum:this.newDatum,AccessType:nt})),this.$el.find(".g-widget-metadata-key-input").trigger("focus"),this}}),On=Cn.extend({editTemplate:NA,getCurrentValue:function(){return this.editor.getText()},save:function(t){try{Cn.prototype.save.call(this,t,this.editor.get())}catch{He.trigger("g:alert",{text:"The field contains invalid JSON and can not be saved.",type:"warning"})}},render:function(){Cn.prototype.render.apply(this,arguments);const t=this.$el.find(".g-json-editor");return this.editor=new QA(t[0],{mode:"tree",modes:["code","tree"],onError:()=>{He.trigger("g:alert",{text:"The field contains invalid JSON and can not be viewed in Tree Mode.",type:"warning"})}}),this.value!==void 0&&(this.editor.setText(JSON.stringify(this.value)),this.editor.expandAll()),this}}),$n=Xe.extend({events:{"click .g-add-json-metadata":function(t){this.addMetadata(t,"json")},"click .g-add-simple-metadata":function(t){this.addMetadata(t,"simple")}},initialize:function(t){this.item=t.item,this.fieldName=t.fieldName||"meta",this.title=t.title||"Metadata",this.apiPath=t.apiPath,this.accessLevel=t.accessLevel,this.onMetadataEdited=t.onMetadataEdited,this.onMetadataAdded=t.onMetadataAdded,this.item.on("g:changed",function(){this.render()},this),this.render()},modes:{simple:{editor:function(t){return new Cn(t)},displayValue:function(){return this.value},template:YA},json:{editor:function(t){return t.value!==void 0&&(t.value=JSON.parse(t.value)),new On(t)},displayValue:function(){return JSON.stringify(this.value,null,4)},validation:{from:{simple:[function(t){try{return JSON.parse(t),!0}catch{}return!1},"The simple field is not valid JSON and can not be converted."]}},template:HA}},setItem:function(t){return this.item=t,this},getModeFromValue:function(t){return xe.isString(t)?"simple":"json"},addMetadata:function(t,e){var u=this.modes[e].editor,r=e==="json"?"{}":"",i=new Kd({className:"g-widget-metadata-row editing",mode:e,key:"",value:r,item:this.item,fieldName:this.fieldName,apiPath:this.apiPath,accessLevel:this.accessLevel,parentView:this,onMetadataEdited:this.onMetadataEdited,onMetadataAdded:this.onMetadataAdded});i.$el.appendTo(this.$(".g-widget-metadata-container")),new u({item:this.item,key:"",value:r,fieldName:this.fieldName,apiPath:this.apiPath,accessLevel:this.accessLevel,newDatum:!0,parentView:i,onMetadataEdited:this.onMetadataEdited,onMetadataAdded:this.onMetadataAdded}).render().$el.appendTo(i.$el)},render:function(){var t=this.item.get(this.fieldName)||{},e=Object.keys(t);return e.sort(dg),this.$el.html(zA({item:this.item,title:this.title,accessLevel:this.accessLevel,AccessType:nt})),xe.each(e,function(u){this.$el.find(".g-widget-metadata-container").append(new Kd({mode:this.getModeFromValue(t[u]),key:u,value:t[u],accessLevel:this.accessLevel,parentView:this,fieldName:this.fieldName,apiPath:this.apiPath,onMetadataEdited:this.onMetadataEdited,onMetadataAdded:this.onMetadataAdded}).render().$el)},this),this}});function Yd(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=us(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function us(t){var e=""+t,u=XA.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var XA=/["&<>]/;function _p(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void _p(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function ZA(t){var e="",u={},r,i,s;try{var o=t||{};(function(f,n,h,g,d,l){s=1,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",u["g-upload-widget-subtitle"]=r=function(){var c=this&&this.block,a=this&&this.attributes||{};s=2,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",g&&d&&(s=3,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-dialog-subtitle">',s=4,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",d==="folder"?(s=5,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<i class="icon-folder-open"></i>'):d==="item"?(s=7,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<i class="icon-doc-text-inv"></i>'):d==="file"&&(s=9,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<i class="icon-doc-inv"></i>'),s=10,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+us((r=g.name())==null?"":r)+"</div>")},s=12,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",u["g-upload-widget-browse-or-drop"]=r=function(){var c=this&&this.block,a=this&&this.attributes||{};s=13,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-drop-zone">',s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<i class="icon-docs"></i>',s=15,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+" ",s=15,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+us((r=f)==null?"":r)+"</div>",s=16,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="form-group hide">',s=17,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+"<input"+(' id="g-files" type="file"'+Yd("multiple",n?"multiple":null,!0,!1))+"/></div>"},s=19,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",u["g-upload-widget-progress"]=r=function(){var c=this&&this.block,a=this&&this.attributes||{};s=20,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-current-progress-message"></div>',s=21,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-progress-current progress progress-striped hide">',s=22,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="progress-bar progress-bar-info" role="progressbar"></div></div>',s=23,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-overall-progress-message">',s=23,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+us((r=h)==null?"":r)+"</div>",s=24,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-progress-overall progress progress-striped hide">',s=25,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="progress-bar progress-bar-info" role="progressbar"></div></div>',s=26,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-upload-error-message g-validation-failed-message"></div>'},s=28,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",u["g-upload-widget-start-button"]=r=function(){var c=this&&this.block,a=this&&this.attributes||{};s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+"<button"+(' class="g-start-upload btn btn-small btn-primary disabled" type="submit"'+Yd("disabled",!0,!0,!1))+">",s=30,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<i class="icon-upload"></i>',s=31,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+" Start Upload</button>"},s=3,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",e=e+'<div class="modal-dialog">',s=4,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",e=e+'<div class="modal-content">',s=5,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",e=e+'<form class="modal-form" id="g-upload-form" role="form">',s=6,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",e=e+'<div class="modal-header">',s=7,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',s=7,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",e=e+"&times;</button>",s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",e=e+'<h4 class="modal-title">',s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",e=e+us((r=l)==null?"":r)+"</h4>",s=9,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",u["g-upload-widget-subtitle"](),e=e+"</div>",s=10,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",e=e+'<div class="modal-body">',s=11,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",u["g-upload-widget-browse-or-drop"](),s=12,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",u["g-upload-widget-progress"](),e=e+"</div>",s=13,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",e=e+'<div class="modal-footer">',s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",e=e+"Close</a>",s=15,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidget.pug",u["g-upload-widget-start-button"](),e=e+"</div></form></div></div>"}).call(this,"browseText"in o?o.browseText:typeof browseText<"u"?browseText:void 0,"multiFile"in o?o.multiFile:typeof multiFile<"u"?multiFile:void 0,"noneSelectedText"in o?o.noneSelectedText:typeof noneSelectedText<"u"?noneSelectedText:void 0,"parent"in o?o.parent:typeof parent<"u"?parent:void 0,"parentType"in o?o.parentType:typeof parentType<"u"?parentType:void 0,"title"in o?o.title:typeof title<"u"?title:void 0)}catch(f){_p(f,i,s)}return e}function Jd(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=ss(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function ss(t){var e=""+t,u=ex.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var ex=/["&<>]/;function Dp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Dp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function tx(t){var e="",u={},r,i,s;try{var o=t||{};(function(f,n,h,g,d,l){s=1,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",u["g-upload-widget-subtitle"]=r=function(){var c=this&&this.block,a=this&&this.attributes||{};s=2,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",g&&d&&(s=3,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-dialog-subtitle">',s=4,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",d==="folder"?(s=5,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<i class="icon-folder-open"></i>'):d==="item"?(s=7,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<i class="icon-doc-text-inv"></i>'):d==="file"&&(s=9,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<i class="icon-doc-inv"></i>'),s=10,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+ss((r=g.name())==null?"":r)+"</div>")},s=12,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",u["g-upload-widget-browse-or-drop"]=r=function(){var c=this&&this.block,a=this&&this.attributes||{};s=13,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-drop-zone">',s=14,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<i class="icon-docs"></i>',s=15,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+" ",s=15,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+ss((r=f)==null?"":r)+"</div>",s=16,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="form-group hide">',s=17,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+"<input"+(' id="g-files" type="file"'+Jd("multiple",n?"multiple":null,!0,!1))+"/></div>"},s=19,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",u["g-upload-widget-progress"]=r=function(){var c=this&&this.block,a=this&&this.attributes||{};s=20,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-current-progress-message"></div>',s=21,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-progress-current progress progress-striped hide">',s=22,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="progress-bar progress-bar-info" role="progressbar"></div></div>',s=23,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-overall-progress-message">',s=23,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+ss((r=h)==null?"":r)+"</div>",s=24,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-progress-overall progress progress-striped hide">',s=25,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="progress-bar progress-bar-info" role="progressbar"></div></div>',s=26,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<div class="g-upload-error-message g-validation-failed-message"></div>'},s=28,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",u["g-upload-widget-start-button"]=r=function(){var c=this&&this.block,a=this&&this.attributes||{};s=29,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+"<button"+(' class="g-start-upload btn btn-small btn-primary disabled" type="submit"'+Jd("disabled",!0,!0,!1))+">",s=30,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+'<i class="icon-upload"></i>',s=31,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetMixins.pug",e=e+" Start Upload</button>"},s=3,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetNonModal.pug",e=e+'<form id="g-upload-form">',s=4,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetNonModal.pug",l&&(s=5,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetNonModal.pug",e=e+"<h4>",s=5,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetNonModal.pug",e=e+ss((r=l)==null?"":r)+"</h4>"),s=6,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetNonModal.pug",u["g-upload-widget-subtitle"](),s=7,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetNonModal.pug",u["g-upload-widget-browse-or-drop"](),s=8,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetNonModal.pug",u["g-upload-widget-progress"](),s=9,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetNonModal.pug",e=e+'<div class="g-nonmodal-upload-buttons-container">',s=10,i="/home/circleci/project/girder/girder/web/src/templates/widgets/uploadWidgetNonModal.pug",u["g-upload-widget-start-button"](),e=e+"</div></form>"}).call(this,"browseText"in o?o.browseText:typeof browseText<"u"?browseText:void 0,"multiFile"in o?o.multiFile:typeof multiFile<"u"?multiFile:void 0,"noneSelectedText"in o?o.noneSelectedText:typeof noneSelectedText<"u"?noneSelectedText:void 0,"parent"in o?o.parent:typeof parent<"u"?parent:void 0,"parentType"in o?o.parentType:typeof parentType<"u"?parentType:void 0,"title"in o?o.title:typeof title<"u"?title:void 0)}catch(f){Dp(f,i,s)}return e}var jo=Xe.extend({events:{"submit #g-upload-form":function(t){t.preventDefault(),this.startUpload()},"click .g-resume-upload":function(){this.$(".g-upload-error-message").html(""),this.currentFile.resumeUpload()},"click .g-restart-upload":function(){this.$(".g-upload-error-message").html(""),this.uploadNextFile()},"change #g-files":function(){var t=this.$("#g-files")[0].files;t.length&&(this.files=t,this.filesChanged())},"click .g-drop-zone":function(){this.$("#g-files").trigger("click")},"dragenter .g-drop-zone":function(t){t.stopPropagation(),t.preventDefault(),t.originalEvent.dataTransfer.dropEffect="copy",this.$(".g-drop-zone").addClass("g-dropzone-show").html('<i class="icon-bullseye"/> Drop files here')},"dragleave .g-drop-zone":function(t){t.stopPropagation(),t.preventDefault(),this.$(".g-drop-zone").removeClass("g-dropzone-show").html('<i class="icon-docs"/> Browse or drop files')},"dragover .g-drop-zone":function(t){var e=t.originalEvent.dataTransfer;if(e){var u=e.effectAllowed;e.dropEffect=u==="move"||u==="linkMove"?"move":"copy",t.preventDefault()}},"drop .g-drop-zone":"filesDropped"},initialize:function(t){t.noParent?(this.parent=null,this.parentType=null):(this.parent=t.parent||t.folder,this.parentType=t.parentType||"folder"),this.files=[],this.totalSize=0,this.title=xe.has(t,"title")?t.title:"Upload files",this.modal=xe.has(t,"modal")?t.modal:!0,this.multiFile=xe.has(t,"multiFile")?t.multiFile:this.parentType!=="file",this.overrideStart=t.overrideStart||!1,this.otherParams=t.otherParams||{},this._browseText=this.multiFile?"Browse or drop files here":"Browse or drop a file here",this._noneSelectedText=this.multiFile?"No files selected":"No file selected"},render:function(){var t={parent:this.parent,parentType:this.parentType,title:this.title,multiFile:this.multiFile,browseText:this._browseText,noneSelectedText:this._noneSelectedText};if(this.modal){this.$el.html(ZA(t));var e;this.parentType==="file"&&(e=this.parent.get("_id")),this.$el.girderModal(this).on("hidden.bs.modal",()=>{ke(".g-resume-upload").length&&this.currentFile&&this.currentFile.abortUpload(),F0("upload",void 0,e)}),b0("upload",void 0,e)}else this.$el.html(tx(t));return this},filesDropped:function(t){t.stopPropagation(),t.preventDefault(),this.$(".g-drop-zone").removeClass("g-dropzone-show").html(`<i class="icon-docs"/> ${this._browseText}`);var e=t.originalEvent.dataTransfer;if(!xe.every(e.items,u=>this._isFile(u))){this.$(".g-upload-error-message").html("Only files may be uploaded.");return}this.files=e.files,!this.multiFile&&this.files.length>1&&(this.files=[this.files[0]]),this.filesChanged()},filesChanged:function(){if(this.files.length===0)this.$(".g-overall-progress-message").text(this._noneSelectedText),this.setUploadEnabled(!1);else{this.totalSize=0,xe.each(this.files,function(e){this.totalSize+=e.size},this);var t;this.files.length>1?t="Selected "+this.files.length+" files":t="Selected <b>"+this.files[0].name+"</b>",this.$(".g-overall-progress-message").html('<i class="icon-ok"/> '+t+"  ("+Zt(this.totalSize)+") -- Press start button"),this.setUploadEnabled(!0),this.$(".g-progress-overall,.g-progress-current").addClass("hide"),this.$(".g-current-progress-message").empty(),this.$(".g-upload-error-message").empty()}this.trigger("g:filesChanged",this.files)},startUpload:function(){this.setUploadEnabled(!1),this.$(".g-drop-zone").addClass("hide"),this.$(".g-progress-overall").removeClass("hide"),this.$(".g-upload-error-message").empty(),this.multiFile&&this.$(".g-progress-current").removeClass("hide"),this.currentIndex=0,this.overallProgress=0,this.trigger("g:uploadStarted"),this.overrideStart||this.uploadNextFile()},setUploadEnabled:function(t){this.$(".g-start-upload").girderEnable(t)},uploadNextFile:function(){if(this.currentIndex>=this.files.length){this.modal&&this.$el.modal("hide"),this.trigger("g:uploadFinished",{files:this.files,totalSize:this.totalSize});return}if(this.currentFile=this.parentType==="file"?this.parent:new Eo,this.currentFile.on("g:upload.complete",function(){this.files[this.currentIndex].id=this.currentFile.id,this.currentIndex+=1,this.uploadNextFile()},this).on("g:upload.chunkSent",function(e){this.overallProgress+=e.bytes},this).on("g:upload.progress",function(e){var u=e.startByte+e.loaded;this.$(".g-progress-current>.progress-bar").css("width",Math.ceil(100*u/e.total)+"%"),this.$(".g-progress-overall>.progress-bar").css("width",Math.ceil(100*(this.overallProgress+e.loaded)/this.totalSize)+"%"),this.$(".g-current-progress-message").html('<i class="icon-doc-text"/>'+(this.currentIndex+1)+" of "+this.files.length+" - <b>"+e.file.name+"</b>: "+Zt(u)+" / "+Zt(e.total)),this.$(".g-overall-progress-message").html("Overall progress: "+Zt(this.overallProgress+e.loaded)+" / "+Zt(this.totalSize))},this).on("g:upload.error",function(e){var u=e.message+' <a class="g-resume-upload">Click to resume upload</a>';ke(".g-upload-error-message").html(u)},this).on("g:upload.errorStarting",function(e){var u=e.message+' <a class="g-restart-upload">Click to restart upload</a>';ke(".g-upload-error-message").html(u)},this),this.parentType==="file")this.currentFile.updateContents(this.files[this.currentIndex]);else{var t=this.otherParams;xe.isFunction(this.otherParams)&&(t=this.otherParams(this)),this.currentFile.upload(this.parent,this.files[this.currentIndex],null,t)}},_isFile:function(t){var e=t.getAsEntry;if(xe.isFunction(e)||(e=t.webkitGetAsEntry),!xe.isFunction(e))return!0;var u=e.call(t);return u&&u.isFile}});function Qd(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=ns(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function ns(t){var e=""+t,u=rx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var rx=/["&<>]/;function Mp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Mp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function ix(t){var e="",u,r,i;try{var s=t||{};(function(o,f,g,h){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug";var g=0;i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",function(){var d=h;if(typeof d.length=="number")for(var l=0,c=d.length;l<c;l++){var a=d[l];i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+"<li>",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+"<a"+(' class="g-breadcrumb-link"'+Qd("g-index",g,!0,!1))+">",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",a.resourceName==="user"?(i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<i class="icon-user"></i>'):a.resourceName==="collection"&&(i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<i class="icon-sitemap"></i>'),i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+ns((u=a.name())==null?"":u)+"</a></li>",i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",g+=1}else{var c=0;for(var l in d){c++;var a=d[l];i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+"<li>",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+"<a"+(' class="g-breadcrumb-link"'+Qd("g-index",g,!0,!1))+">",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",a.resourceName==="user"?(i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<i class="icon-user"></i>'):a.resourceName==="collection"&&(i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<i class="icon-sitemap"></i>'),i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+ns((u=a.name())==null?"":u)+"</a></li>",i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",g+=1}}}.call(this),i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",o&&(i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<li class="active">',i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",o.resourceName==="user"?(i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<i class="icon-user"></i>'):o.resourceName==="collection"&&(i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<i class="icon-sitemap"></i>'),i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+ns((u=o.name())==null?"":u)+"</li>"),i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",f&&(i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<a class="g-description-preview">',i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+ns((u=f)==null?"":u)+"</a>"),i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<div class="pull-right">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<div class="g-child-count-container hide">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<div class="g-subfolder-count-container" title="total folders">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<i class="icon-folder"></i>',i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<div class="g-subfolder-count"></div></div>',i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",g>0&&(i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<div class="g-item-count-container" title="total items">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<i class="icon-doc-text-inv"></i>',i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<div class="g-item-count"></div></div>'),e=e+"</div>",i=34,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",g>0&&(i=35,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<div class="g-level-up-button-container">',i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<a class="g-hierarchy-level-up" title="Go up one level">',i=37,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyBreadcrumb.pug",e=e+'<i class="icon-level-up"></i></a></div>'),e=e+"</div>"}).call(this,"current"in s?s.current:typeof current<"u"?current:void 0,"descriptionText"in s?s.descriptionText:typeof descriptionText<"u"?descriptionText:void 0,"idx"in s?s.idx:typeof idx<"u"?idx:void 0,"links"in s?s.links:typeof links<"u"?links:void 0)}catch(o){Mp(o,r,i)}return e}function ma(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Tp(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Tp(t){var e=""+t,u=ux.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var ux=/["&<>]/;function Pp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Pp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function sx(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+'<div class="g-hierarchy-pages-header">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+'<div class="g-hierarchycenter">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+'<ul class="pagination pagination-sm">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",o>1&&!f?(i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+'<li class="g-page-prev">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+'<a id="g-previous-paginated">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+"« Prev</a></li>"):(i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+'<li class="g-page-prev disabled">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+'<a id="g-previous-paginated">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+"« Prev</a></li>"),i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+"<li>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+"<span>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+"Page:",i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+"<input"+(' id="g-page-selection-input"'+ma("disabled",f,!0,!1)+' type="number" min="1"'+ma("max",n,!0,!1)+ma("value",o,!0,!1))+"/>",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+"<span>",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+"of ",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+Tp((u=n)==null?"":u)+"</span></span></li>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",o+1<=n&&!f?(i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+'<li class="g-page-next">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+'<a id="g-next-paginated">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+"Next »</a></li>"):(i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+'<li class="g-page-next disabled">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+'<a id="g-next-paginated">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyPaginated.pug",e=e+"Next »</a></li>"),e=e+"</ul></div></div>"}).call(this,"currentPage"in s?s.currentPage:typeof currentPage<"u"?currentPage:void 0,"disabled"in s?s.disabled:typeof disabled<"u"?disabled:void 0,"totalPages"in s?s.totalPages:typeof totalPages<"u"?totalPages:void 0)}catch(o){Pp(o,r,i)}return e}function Xd(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=gu(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function gu(t){var e=""+t,u=nx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var nx=/["&<>]/;function Lp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Lp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function ox(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h,g,d,l,c,a,F){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<div class="g-hierarchy-widget">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<div class="g-hierarchy-breadcrumb-bar">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<ol class="breadcrumb"></ol></div>',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",c&&(i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<div class="g-hierarchy-actions-header">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",n&&(i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<input class="g-select-all" type="checkbox" title="Select / Unselect all"/>',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<div class="btn-group">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<button class="g-checked-actions-button btn btn-sm btn-default dropdown-toggle" data-toggle="dropdown" disabled="disabled" title="Checked actions">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-check"></i>',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-down-dir"></i></button>',i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<ul class="g-checked-actions-menu dropdown-menu" role="menu"></ul></div>'),i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<div class="g-folder-header-buttons">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",F==="folder"?(i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<button class="g-folder-info-button btn btn-sm btn-info" title="Show folder info">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-info"></i></button>',i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",g>=o.WRITE&&(i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<button class="g-upload-here-button btn btn-sm btn-success" title="Upload here">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-upload"></i></button>'),i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",g>=o.ADMIN&&(i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<button class="g-folder-access-button g-edit-access btn btn-sm btn-warning" title="Access control">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-lock"></i></button>')):F==="collection"&&(i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<button class="g-collection-info-button btn btn-sm btn-info" title="Show collection info">',i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-info"></i></button>',i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",g>=o.ADMIN&&(i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<button class="g-edit-access btn btn-sm btn-warning" title="Access control">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-lock"></i></button>')),i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<div class="btn-group">',i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+"<button"+(' class="g-folder-actions-button btn btn-sm btn-default dropdown-toggle" data-toggle="dropdown"'+Xd("title",`${f(F)} actions`,!0,!1))+">",i=35,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",F==="collection"?(i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-sitemap"></i>'):F==="user"?(i=38,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-user"></i>'):F==="folder"&&(i=40,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-folder-open"></i>'),i=41,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-down-dir"></i></button>',i=42,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<ul class="g-folder-actions-menu dropdown-menu pull-right" role="menu">',i=43,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<li class="dropdown-header" role="presentation">',i=44,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",F==="collection"?(i=45,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-sitemap"></i>'):F==="user"?(i=47,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-user"></i>'):F==="folder"&&(i=49,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-folder-open"></i>'),i=50,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+" ",i=50,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+gu((u=d.name())==null?"":u)+"</li>",i=51,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",(F==="folder"||F==="collection")&&(i=52,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<li role="presentation">',i=53,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+"<a"+(' class="g-download-folder" role="menuitem"'+Xd("href",d.downloadUrl(),!0,!1))+">",i=54,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-download"></i>',i=55,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+"Download ",i=55,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+gu((u=F)==null?"":u)+"</a></li>"),i=56,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",g>=o.WRITE&&(i=57,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<li role="presentation">',i=58,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<a class="g-create-subfolder" role="menuitem">',i=59,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-folder"></i>',i=60,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+"Create folder here</a></li>",i=61,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",(F==="folder"||F==="collection")&&(i=62,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",F==="folder"&&(i=63,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<li role="presentation">',i=64,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<a class="g-create-item" role="menuitem">',i=65,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-doc"></i>',i=66,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+"Create item here</a></li>"),i=67,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<li role="presentation">',i=68,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<a class="g-edit-folder" role="menuitem">',i=69,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-edit"></i>',i=70,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+"Edit ",i=70,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+gu((u=F)==null?"":u)+"</a></li>")),i=71,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",g>=o.ADMIN&&(F==="folder"||F==="collection")&&(i=72,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<li class="divider" role="presentation"></li>',i=73,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<li role="presentation">',i=74,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<a class="g-delete-folder" role="menuitem">',i=75,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-trash"></i>',i=76,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+"Delete this ",i=76,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+gu((u=F)==null?"":u)+"</a></li>"),e=e+"</ul></div></div>",i=77,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<div class="g-clear-right"></div></div>'),i=78,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",l&&(i=79,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<div class="g-select-folder-container">',i=80,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<ul class="g-folder-list">',i=81,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<li class="g-folder-list-entry" public="true">',i=82,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<button class="g-select-folder btn btn-sm btn-info">',i=83,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-folder"></i>',i=84,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+" Select this ",i=84,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+gu((u=F)==null?"":u),i=84,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+".",i=85,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-right-dir"></i></button></li></ul></div>'),i=86,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<div class="g-folder-list-container"></div>',i=87,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<div class="g-item-list-container"></div>',i=88,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<div class="g-empty-parent-message g-info-message-container hide">',i=89,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<i class="icon-info-circled"></i>',i=90,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",h?(i=91,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+" This folder has no suitable items."):(i=93,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+" This folder is empty."),e=e+"</div>",i=94,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<div class="g-hierarachy-paginated-bar"></div></div>',i=95,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",a&&(i=96,r="/home/circleci/project/girder/girder/web/src/templates/widgets/hierarchyWidget.pug",e=e+'<div class="g-folder-metadata"></div>')}).call(this,"AccessType"in s?s.AccessType:typeof AccessType<"u"?AccessType:void 0,"capitalize"in s?s.capitalize:typeof capitalize<"u"?capitalize:void 0,"checkboxes"in s?s.checkboxes:typeof checkboxes<"u"?checkboxes:void 0,"itemFilter"in s?s.itemFilter:typeof itemFilter<"u"?itemFilter:void 0,"level"in s?s.level:typeof level<"u"?level:void 0,"model"in s?s.model:typeof model<"u"?model:void 0,"onFolderSelect"in s?s.onFolderSelect:typeof onFolderSelect<"u"?onFolderSelect:void 0,"showActions"in s?s.showActions:typeof showActions<"u"?showActions:void 0,"showMetadata"in s?s.showMetadata:typeof showMetadata<"u"?showMetadata:void 0,"type"in s?s.type:typeof type<"u"?type:void 0)}catch(o){Lp(o,r,i)}return e}var Rt=null,ax=Xe.extend({events:{"click a.g-breadcrumb-link":function(t){var e=ke(t.currentTarget);this.trigger("g:breadcrumbClicked",parseInt(e.attr("g-index"),10))}},initialize:function(t){this.objects=t.objects},render:function(){var t=this.objects.slice(0),e=t.pop(),u=ke(fi(e.get("description")||"")).text();return this.$el.html(ix({links:t,current:e,descriptionText:u})),this}}),cx=Xe.extend({events:{"change #g-page-selection-input":function(t){const e=Number(t.target.value);this.itemListWidget&&e<=this.itemListWidget.getNumPages()&&e>0&&(this.disabled=!0,this.itemListWidget.setPage(e).done(()=>{this.disabled=!1,this.render()})),this.render()},"click li.g-page-next:not(.disabled) a#g-next-paginated":function(){this.disabled=!0,this.itemListWidget.setPage(Number(this.$("#g-page-selection-input").val())+1).done(()=>{this.disabled=!1,this.render()}),this.render()},"click li.g-page-prev:not(.disabled) a#g-previous-paginated":function(){this.disabled=!0,this.itemListWidget.setPage(Number(this.$("#g-page-selection-input").val())-1).done(()=>{this.disabled=!1,this.render()}),this.render()}},initialize:function(t){this.itemListWidget=t.itemListWidget,this.disabled=!1},render:function(){return this.$el.html(sx({totalPages:this.itemListWidget&&this.itemListWidget.getNumPages(),currentPage:this.itemListWidget&&this.itemListWidget.getCurrentPage(),disabled:this.disabled})),this}}),lx=Xe.extend({events:{"click a.g-create-subfolder":"createFolderDialog","click a.g-edit-folder":"editFolderDialog","click button.g-select-folder":"selectFolder","click a.g-delete-folder":"deleteFolderDialog","click .g-folder-info-button":"showInfoDialog","click .g-collection-info-button":"showInfoDialog","click .g-description-preview":"showInfoDialog","click a.g-create-item":"createItemDialog","click .g-upload-here-button":"uploadDialog","click .g-edit-access":"editAccess","click .g-hierarchy-level-up":"upOneLevel","click a.g-download-checked":"downloadChecked","click a.g-pick-checked":"pickChecked","click a.g-move-picked":"movePickedResources","click a.g-copy-picked":"copyPickedResources","click a.g-clear-picked":"clearPickedResources","click a.g-delete-checked":"deleteCheckedDialog","click .g-list-checkbox":"checkboxListener","change .g-select-all":function(t){this.folderListView.checkAll(t.currentTarget.checked),this.itemListView&&this.itemListView.checkAll(t.currentTarget.checked)}},initialize:function(t){this.parentModel=t.parentModel,this.upload=t.upload,this._showActions=xe.has(t,"showActions")?t.showActions:!0,this._showItems=xe.has(t,"showItems")?t.showItems:!0,this._itemFilter=t.itemFilter,this._checkboxes=xe.has(t,"checkboxes")?t.checkboxes:!0,this._downloadLinks=xe.has(t,"downloadLinks")?t.downloadLinks:!0,this._viewLinks=xe.has(t,"viewLinks")?t.viewLinks:!0,this._showSizes=xe.has(t,"showSizes")?t.showSizes:!0,this._showMetadata=xe.has(t,"showMetadata")?t.showMetadata:!0,this._routing=xe.has(t,"routing")?t.routing:!0,this._appendPages=xe.has(t,"appendPages")?t.appendPages:!1,this._onItemClick=t.onItemClick||function(e){tt.navigate("item/"+e.get("_id"),{trigger:!0})},this._defaultSelectedResource=t.defaultSelectedResource,this._highlightItem=xe.has(t,"highlightItem")?t.highlightItem:!1,this._paginated=xe.has(t,"paginated")?t.paginated:!1,this._onFolderSelect=t.onFolderSelect,this.folderAccess=t.folderAccess,this.folderCreate=t.folderCreate,this.folderEdit=t.folderEdit,this.itemCreate=t.itemCreate,this.breadcrumbs=[this.parentModel],this.breadcrumbView=new ax({objects:this.breadcrumbs,parentView:this}),this.breadcrumbView.on("g:breadcrumbClicked",function(e){this.breadcrumbs=this.breadcrumbs.slice(0,e+1),this.setCurrentModel(this.breadcrumbs[e]),this._setRoute()},this),this.checkedMenuWidget=new ap({pickedCount:this.getPickedCount(),pickedCopyAllowed:this.getPickedCopyAllowed(),pickedMoveAllowed:this.getPickedMoveAllowed(),pickedDesc:this.getPickedDescription(),parentView:this}),this.folderListView=new bp({folderFilter:this._itemFilter,parentType:this.parentModel.resourceName,parentId:this.parentModel.get("_id"),checkboxes:this._checkboxes,parentView:this}),this.folderListView.on("g:folderClicked",function(e){this.descend(e),this.uploadWidget&&(this.uploadWidget.folder=e)},this).off("g:checkboxesChanged").on("g:checkboxesChanged",this.updateChecked,this).off("g:changed").on("g:changed",function(){this.folderCount=this.folderListView.collection.length,this._childCountCheck()},this),this.parentModel.resourceName==="folder"?this._fetchToRoot(this.parentModel):(this.itemCount=0,this.render()),He.on("g:login",()=>{this.constructor.resetPickedResources()},this)},_childCountCheck:function(){var t=this.$(".g-empty-parent-message").addClass("hide");this.folderCount===0&&this.itemCount===0&&t.removeClass("hide")},_initFolderViewSubwidgets:function(){this.itemListView||(this.itemListView=new yp({itemFilter:this._itemFilter,folderId:this.parentModel.id,public:this.parentModel.get("public"),accessLevel:this.parentModel.getAccessLevel(),checkboxes:this._checkboxes,downloadLinks:this._downloadLinks,viewLinks:this._viewLinks,showSizes:this._showSizes,selectedItem:this._defaultSelectedResource,highlightItem:this._highlightItem,paginated:this._paginated,parentView:this}),this.listenTo(this.itemListView,"g:itemClicked",this._onItemClick),this.listenTo(this.itemListView,"g:checkboxesChanged",this.updateChecked),this.listenTo(this.itemListView,"g:changed",()=>{this.itemCount=this.itemListView.collection.length,this._childCountCheck(),this._paginated&&this.hierarchyPaginated&&this.itemListView.getNumPages()>1?(this.parentModel.resourceName!=="collection"&&this.hierarchyPaginated.setElement(this.$(".g-hierarachy-paginated-bar")).render(),this.$(".g-hierarchy-breadcrumb-bar").addClass("g-hierarchy-sticky"),this.$(".g-hierarachy-paginated-bar").addClass("g-hierarchy-sticky"),this.$(".g-hierarchy-breadcrumb-bar").css({top:0}),this.$(".g-hierarachy-paginated-bar").css({bottom:0}),this.$(".g-hierarachy-paginated-bar").removeClass("hidden")):this.$(".g-hierarachy-paginated-bar").addClass("hidden")}),this.listenTo(this.itemListView,"g:paginated",()=>{this._paginated&&!this.hierarchyPaginated&&(this.hierarchyPaginated=new cx({parentView:this,itemListWidget:this.itemListView}))})),this.metadataWidget||(this.metadataWidget=new $n({item:this.parentModel,parentView:this,accessLevel:this.parentModel.getAccessLevel()}))},_setRoute:function(){if(this._routing){var t=this.breadcrumbs[0].resourceName+"/"+this.breadcrumbs[0].get("_id");this.parentModel.resourceName==="folder"&&(t+="/folder/"+this.parentModel.get("_id")),tt.navigate(t),He.trigger("g:hierarchy.route",{route:t})}},_fetchToRoot:function(t){t.getRootPath().done(e=>{const u=e.map(r=>new yg[Fg(r.type)](r.object));this.breadcrumbs.unshift(...u),this.render()})},render:function(){return this.folderCount=null,this.itemCount=null,this.$el.html(ox({type:this.parentModel.resourceName,model:this.parentModel,level:this.parentModel.getAccessLevel(),AccessType:nt,onFolderSelect:this._onFolderSelect,showActions:this._showActions,showMetadata:this._showMetadata,checkboxes:this._checkboxes,capitalize:hg,itemFilter:this._itemFilter})),this.$(".g-folder-actions-menu>li>a").length===0&&this.$(".g-folder-actions-button").girderEnable(!1),this.breadcrumbView.setElement(this.$(".g-hierarchy-breadcrumb-bar>ol")).render(),this.checkedMenuWidget.dropdownToggle=this.$(".g-checked-actions-button"),this.checkedMenuWidget.setElement(this.$(".g-checked-actions-menu")).render(),this.folderListView.setElement(this.$(".g-folder-list-container")).render(),this.hierarchyPaginated&&this.parentModel.resourceName!=="collection"&&this.hierarchyPaginated.setElement(this.$(".g-hierarachy-paginated-bar")).render(),this.parentModel.resourceName==="folder"&&this._showItems&&(this._initFolderViewSubwidgets(),this.itemListView.setElement(this.$(".g-item-list-container")).render(),this.metadataWidget.setItem(this.parentModel),this.metadataWidget.accessLevel=this.parentModel.getAccessLevel(),this._showMetadata&&this.metadataWidget.setElement(this.$(".g-folder-metadata")).render()),this.parentModel.resourceName==="collection"&&this._showMetadata&&(this.metadataWidget||(this.metadataWidget=new $n({item:this.parentModel,parentView:this,accessLevel:this.parentModel.getAccessLevel()})),this.metadataWidget.setItem(this.parentModel),this.metadataWidget.accessLevel=this.parentModel.getAccessLevel(),this.metadataWidget.setElement(this.$(".g-folder-metadata")).render()),this.upload?this.uploadDialog():this.folderAccess?this.editAccess():this.folderCreate?this.createFolderDialog():this.folderEdit?this.editFolderDialog():this.itemCreate&&this.createItemDialog(),this.fetchAndShowChildCount(),this},descend:function(t){this.breadcrumbs.push(t),this.setCurrentModel(t)},upOneLevel:function(){this.breadcrumbs.pop(),this.setCurrentModel(this.breadcrumbs[this.breadcrumbs.length-1])},selectFolder:function(){xe.isFunction(this._onFolderSelect)&&this._onFolderSelect(this.parentModel)},createFolderDialog:function(){new Ja({el:ke("#g-dialog-container"),parentModel:this.parentModel,parentView:this}).on("g:saved",function(t){this.folderListView.insertFolder(t),this.parentModel.has("nFolders")&&this.parentModel.increment("nFolders"),this.updateChecked()},this).render()},createItemDialog:function(){new El({el:ke("#g-dialog-container"),parentModel:this.parentModel,parentView:this}).on("g:saved",function(t){this.itemListView.insertItem(t),this.parentModel.has("nItems")&&this.parentModel.increment("nItems"),this.updateChecked()},this).render()},editFolderDialog:function(){this.parentModel.resourceName==="folder"?new Ja({el:ke("#g-dialog-container"),parentModel:this.parentModel,folder:this.parentModel,parentView:this}).on("g:saved",function(){He.trigger("g:alert",{icon:"ok",text:"Folder info updated.",type:"success",timeout:4e3}),this.breadcrumbView.render()},this).on("g:fileUploaded",function(t){var e=new iu({_id:t.model.get("itemId")});e.once("g:fetched",function(){this.itemListView.insertItem(e),this.parentModel.has("nItems")&&this.parentModel.increment("nItems"),this.updateChecked()},this).fetch()},this).render():this.parentModel.resourceName==="collection"&&new ko({el:ke("#g-dialog-container"),model:this.parentModel,parentView:this}).on("g:saved",function(){this.breadcrumbView.render(),this.trigger("g:collectionChanged")},this).render()},deleteFolderDialog:function(){var t=this.parentModel.resourceName,e={text:"Are you sure you want to delete the "+t+" <b>"+this.parentModel.escape("name")+"</b>?",escapedHtml:!0,yesText:"Delete",confirmCallback:()=>{this.parentModel.on("g:deleted",function(){t==="collection"?tt.navigate("collections",{trigger:!0}):t==="folder"&&(this.breadcrumbs.pop(),this.setCurrentModel(this.breadcrumbs.slice(-1)[0]))},this).destroy({throwError:!0,progress:!0})}};t==="collection"&&(this.parentModel.get("nFolders")!==0||this.parentModel.get("size")!==0)&&(e=xe.extend({name:this.parentModel.escape("name"),additionalText:"<b>"+this.parentModel.escape("name")+"</b> contains <b>"+this.parentModel.escape("nFolders")+" folders</b> taking up <b>"+Zt(parseInt(this.parentModel.get("size"),10))+"</b>",msgConfirmation:!0},e)),n0(e)},showInfoDialog:function(){var t={el:ke("#g-dialog-container"),model:this.parentModel,parentView:this};this.parentModel.resourceName==="collection"?new lp(t).render():this.parentModel.resourceName==="folder"&&new mp(t).render()},fetchAndShowChildCount:function(){this.$(".g-child-count-container").addClass("hide");var t=()=>{const e=Ha(this.parentModel.get("nFolders"));this.$(".g-child-count-container").removeClass("hide"),this.$(".g-subfolder-count").text(e);const u=e===1?`${e} total folder`:`${e} total folders`;if(this.$(".g-subfolder-count-container").attr("title",u),this.parentModel.has("nItems")){const r=Ha(this.parentModel.get("nItems"));this.$(".g-item-count").text(r);const i=r===1?`${r} total item`:`${r} total items`;this.$(".g-item-count-container").attr("title",i)}};return this.parentModel.has("nFolders")?t():(this.parentModel.set("nFolders",0),this.parentModel.once("g:fetched.details",function(){t()},this).fetch({extraPath:"details"})),this.parentModel.off("change:nItems",t,this).on("change:nItems",t,this).off("change:nFolders",t,this).on("change:nFolders",t,this),this},setCurrentModel:function(t,e){e=e||{},this.parentModel=t,this.breadcrumbView.objects=this.breadcrumbs,this.folderListView.initialize({parentType:t.resourceName,parentId:t.get("_id"),checkboxes:this._checkboxes,folderFilter:this._itemFilter}),this.updateChecked(),t.resourceName==="folder"&&(this.itemListView&&this.itemListView.initialize({folderId:t.get("_id"),checkboxes:this._checkboxes,downloadLinks:this._downloadLinks,viewLinks:this._viewLinks,itemFilter:this._itemFilter,showSizes:this._showSizes,paginated:this._paginated,public:this.parentModel.get("public"),accessLevel:this.parentModel.getAccessLevel()}),this._initFolderViewSubwidgets()),this.render(),(!xe.has(e,"setRoute")||e.setRoute)&&this._setRoute(),this.trigger("g:setCurrentModel")},_describeResources:function(t){for(var e=["folder","item"],u=[],r=0;r<e.length;r+=1){var i=e[r];t[i]&&t[i].length&&u.push(t[i].length+" "+i+(t[i].length!==1?"s":""))}switch(u.length){case 0:return"nothing";case 1:return u[0];case 2:return u[0]+" and "+u[1]}},deleteCheckedDialog:function(){var t=this.folderListView.checked,e;this.itemListView&&this.itemListView.checked.length&&(e=this.itemListView.checked);var u=this._describeResources({folder:t,item:e}),r={text:"Are you sure you want to delete the checked resources ("+u+")?",yesText:"Delete",confirmCallback:()=>{var i=this._getCheckedResourceParam(),s=this._getCheckedResourceSize();ut({url:"resource",method:"POST",data:{resources:i,progress:!0},headers:{"X-HTTP-Method-Override":"DELETE"}}).done(()=>{e&&e.length&&this.parentModel.has("nItems")&&this.parentModel.increment("nItems",-e.length),t.length&&this.parentModel.has("nFolders")&&this.parentModel.increment("nFolders",-t.length),this.parentModel.has("size")&&s.items&&this.parentModel.increment("size",-s.items),this.setCurrentModel(this.parentModel,{setRoute:!1})})}};n0(r)},uploadDialog:function(){var t=ke("#g-dialog-container");new jo({el:t,parent:this.parentModel,parentType:this.parentType,parentView:this}).on("g:uploadFinished",function(e){F0("upload"),this.upload=!1,this.parentModel.has("nItems")&&this.parentModel.increment("nItems",e.files.length),this.parentModel.has("size")&&this.parentModel.increment("size",e.totalSize),this.setCurrentModel(this.parentModel,{setRoute:!1})},this).render()},updateChecked:function(){var t=this.folderListView.checked,e=[],u=nt.ADMIN;xe.every(t,function(s){var o=this.folderListView.collection.get(s);return u=Math.min(u,o.getAccessLevel()),u>nt.READ},this);var r=nt.ADMIN;this.itemListView&&(e=this.itemListView.checked,e.length&&(r=Math.min(r,this.parentModel.getAccessLevel())));const i=t.length+e.length>0;this.$(".g-folder-actions-button").girderEnable(!i),this.checkedMenuWidget.update({minFolderLevel:u,minItemLevel:r,folderCount:t.length,itemCount:e.length,pickedCount:this.getPickedCount(),pickedCopyAllowed:this.getPickedCopyAllowed(),pickedMoveAllowed:this.getPickedMoveAllowed(),pickedDesc:this.getPickedDescription()})},getPickedCount:function(){var t=0;return Rt&&Rt.resources&&xe.each(Rt.resources,function(e){t+=e.length}),t},getPickedCopyAllowed:function(){return!(!Rt||this.parentModel.resourceName!=="folder"&&Rt.resources.item&&Rt.resources.item.length||this.parentModel.getAccessLevel()<nt.WRITE)},getPickedMoveAllowed:function(){return!(!this.getPickedCopyAllowed()||Rt.minFolderLevel<nt.ADMIN||Rt.minItemLevel<nt.WRITE)},getPickedDescription:function(){return!Rt||!Rt.resources?"":this._describeResources(Rt.resources)},_getCheckedResourceParam:function(t){var e={folder:[],item:[]},u=this.folderListView.checked;if(xe.each(u,function(i){var s=this.folderListView.collection.get(i);e.folder.push(s.id)},this),this.itemListView){var r=this.itemListView.checked;xe.each(r,function(i){var s=this.itemListView.collection.get(i);e.item.push(s.id)},this)}return xe.each(e,function(i,s){i.length||delete e[s]}),t?e:JSON.stringify(e)},_getCheckedResourceSize:function(){var t={items:0,folders:0},e=this.folderListView.checked;if(xe.each(e,function(r){var i=this.folderListView.collection.get(r);t.folders+=i.get("size")||0},this),this.itemListView){var u=this.itemListView.checked;xe.each(u,function(r){var i=this.itemListView.collection.get(r);t.items+=i.get("size")||0},this)}return t},downloadChecked:function(){var t=Zi()+"/resource/download",e=this._getCheckedResourceParam(),u={resources:e};this.redirectViaForm("POST",t,u)},pickChecked:function(){Rt||(Rt={resources:{},minItemLevel:nt.ADMIN,minFolderLevel:nt.ADMIN});var t=this.folderListView.checked;if(xe.every(t,function(f){var n=this.folderListView.collection.get(f);return Rt.minFolderLevel=Math.min(Rt.minFolderLevel,n.getAccessLevel()),Rt.minFolderLevel>nt.READ},this),this.itemListView){var e=this.itemListView.checked;e.length&&(Rt.minItemLevel=Math.min(Rt.minItemLevel,this.parentModel.getAccessLevel()))}var u=this._getCheckedResourceParam(!0),r=this._describeResources(u),i=Rt.resources;xe.each(i,function(f,n){u[n]?u[n]=xe.union(f,u[n]):u[n]=f}),Rt.resources=u,this.updateChecked();var s=this.getPickedDescription(),o=s+" picked.";r!==s&&(o=r+" added to picked resources.  Now "+o),He.trigger("g:alert",{icon:"ok",text:o,type:"info",timeout:4e3})},_incrementCounts:function(t,e){this.parentModel.has("nItems")&&this.parentModel.increment("nItems",e),this.parentModel.has("nFolders")&&this.parentModel.increment("nFolders",t)},movePickedResources:function(){if(this.getPickedMoveAllowed()){var t=JSON.stringify(Rt.resources),e=(Rt.resources.folder||[]).length,u=(Rt.resources.item||[]).length;ut({url:"resource/move",method:"PUT",data:{resources:t,parentType:this.parentModel.resourceName,parentId:this.parentModel.get("_id"),progress:!0}}).done(()=>{this._incrementCounts(e,u),this.setCurrentModel(this.parentModel,{setRoute:!1})}),this.clearPickedResources()}},copyPickedResources:function(){if(this.getPickedCopyAllowed()){var t=JSON.stringify(Rt.resources),e=(Rt.resources.folder||[]).length,u=(Rt.resources.item||[]).length;ut({url:"resource/copy",method:"POST",data:{resources:t,parentType:this.parentModel.resourceName,parentId:this.parentModel.get("_id"),progress:!0}}).done(()=>{this._incrementCounts(e,u),this.setCurrentModel(this.parentModel,{setRoute:!1})}),this.clearPickedResources()}},clearPickedResources:function(t){this.constructor.resetPickedResources(),this.updateChecked(),t&&He.trigger("g:alert",{icon:"ok",text:"Cleared picked resources",type:"info",timeout:4e3})},redirectViaForm:function(t,e,u){var r=ke("<form/>").attr({action:e,method:t});xe.each(u,function(i,s){r.append(ke("<input/>").attr({type:"text",name:s,value:i}))}),ke(r).appendTo("body").trigger("submit").remove()},editAccess:function(){new Ao({el:ke("#g-dialog-container"),modelType:this.parentModel.resourceName,model:this.parentModel,parentView:this}).on("g:accessListSaved",function(t){t.recurse&&this.refreshFolderList()},this)},refreshFolderList:function(){this.folderListView.collection.fetch(null,!0)},selectItem:function(t){this.itemListView.selectItem(t)},getSelectedItem:function(){return this.itemListView.getSelectedItem()},checkboxListener:function(t){var e=ke(t.currentTarget);if(this._lastCheckbox&&t.shiftKey){var u=this.$el.find(":checkbox"),r=u.index(this._lastCheckbox),i=u.index(e);u.slice(Math.min(r,i),Math.max(r,i)+1).prop("checked",e.prop("checked")),this.folderListView.recomputeChecked(),this.itemListView&&this.itemListView.recomputeChecked(),this.updateChecked()}this._lastCheckbox=e}},{resetPickedResources:function(t){Rt=t||null},getPickedResources:function(){return Rt}});const $u=lx;function Jt(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=os(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function os(t){var e=""+t,u=dx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var dx=/["&<>]/;function Rp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Rp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Fx(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h,g){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",g=g||{id:""},i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+"<select"+(' class="form-control" id="g-root-selector"'+Jt("required",!0,!0,!1))+">",i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",g.id||(i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+"<option"+(' value=""'+Jt("disabled",!0,!0,!1)+Jt("selected",!0,!0,!1)+Jt("hidden",!0,!0,!1))+">",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+"Select a root...</option>"),i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",function(){var d=o;if(typeof d.length=="number")for(var l=0,c=d.length;l<c;l++){var a=d[l];if(i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",a==="Home"&&h)i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+"<option"+(Jt("value",h.id,!0,!1)+Jt("selected",g.id===h.id,!0,!1))+">",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+"Home</option>";else if(a in n){i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug";var F=n[a];i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+"<optgroup"+Jt("label",a,!0,!1)+">",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",function(){var p=F.models;if(typeof p.length=="number")for(var m=0,b=p.length;m<b;m++){var C=p[m];i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",(!h||C.id!==h.id)&&(i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+"<option"+(Jt("value",C.id,!0,!1)+Jt("data-group",a,!0,!1)+Jt("selected",C.id===g.id,!0,!1))+">",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+os((u=f(C))==null?"":u)+"</option>")}else{var b=0;for(var m in p){b++;var C=p[m];i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",(!h||C.id!==h.id)&&(i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+"<option"+(Jt("value",C.id,!0,!1)+Jt("data-group",a,!0,!1)+Jt("selected",C.id===g.id,!0,!1))+">",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+os((u=f(C))==null?"":u)+"</option>")}}}.call(this),e=e+"</optgroup>"}}else{var c=0;for(var l in d){c++;var a=d[l];if(i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",a==="Home"&&h)i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+"<option"+(Jt("value",h.id,!0,!1)+Jt("selected",g.id===h.id,!0,!1))+">",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+"Home</option>";else if(a in n){i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug";var F=n[a];i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+"<optgroup"+Jt("label",a,!0,!1)+">",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",function(){var k=F.models;if(typeof k.length=="number")for(var T=0,w=k.length;T<w;T++){var A=k[T];i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",(!h||A.id!==h.id)&&(i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+"<option"+(Jt("value",A.id,!0,!1)+Jt("data-group",a,!0,!1)+Jt("selected",A.id===g.id,!0,!1))+">",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+os((u=f(A))==null?"":u)+"</option>")}else{var w=0;for(var T in k){w++;var A=k[T];i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",(!h||A.id!==h.id)&&(i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+"<option"+(Jt("value",A.id,!0,!1)+Jt("data-group",a,!0,!1)+Jt("selected",A.id===g.id,!0,!1))+">",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/rootSelectorWidget.pug",e=e+os((u=f(A))==null?"":u)+"</option>")}}}.call(this),e=e+"</optgroup>"}}}}.call(this),e=e+"</select>"}).call(this,"display"in s?s.display:typeof display<"u"?display:void 0,"format"in s?s.format:typeof format<"u"?format:void 0,"groups"in s?s.groups:typeof groups<"u"?groups:void 0,"home"in s?s.home:typeof home<"u"?home:void 0,"selected"in s?s.selected:typeof selected<"u"?selected:void 0)}catch(o){Rp(o,r,i)}return e}var Bp=Xe.extend({events:{"change #g-root-selector":"_selectRoot"},initialize:function(t){t=t||{},this.pageLimit=t.pageLimit||25,this.groups={Collections:new vl,Users:new xu},this.groups.Collections.pageLimit=t.pageLimit,this.groups.Users.pageLimit=t.pageLimit,this.groups.Users.sortField="login",xe.extend(this.groups,t.groups),xe.each(this.groups,e=>{this.listenTo(e,"g:changed",()=>{this._updateGroup(e)})}),this.home=t.home,this.listenTo(He,"g:login",this.fetch),this.selected=t.selected,this.selectByResource=t.selectByResource,this.display=t.display||["Home","Collections","Users"],this.fetch()},render:function(){return this._home=this.home||ft(),this.selectByResource&&this.setRootByBaseParent(this.selectByResource),this.$el.html(Fx({home:this._home,groups:this.groups,display:this.display,selected:this.selected,format:this._formatName})),this},setRootByBaseParent:function(t){xe.isObject(t)&&(t.attributes||{}).baseParentId!==void 0&&(t=t.attributes.baseParentId),xe.isString(t)&&xe.each(this.groups,e=>{e.get(t)!==void 0&&(this.selected=e.get(t))})},_selectRoot:function(){var t=this.$(":selected"),e=t.val(),u=t.data("group")||null;this.selected=null,xe.has(this.groups,u)?this.selected=this.groups[u].get(e):this._home&&this._home.id===e&&(this.selected=this._home),this.trigger("g:selected",{root:this.selected,group:u})},_updateGroup:function(t){this.trigger("g:group",{collection:t}),this.render()},_formatName:function(t){var e=t.id;switch(t.get("_modelType")){case"user":e=t.get("login");break;case"folder":case"collection":e=t.get("name");break}return e},fetch:function(){var t=this.reset;xe.each(this.groups,function(e){e.fetch(null,t)})}});function an(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=pu(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function pu(t){var e=""+t,u=hx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var hx=/["&<>]/;function Ip(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Ip(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function gx(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h,g,d,l){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<div class="modal-dialog">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<div class="modal-content">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<div class="modal-header">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+"&times;</button>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<h4 class="modal-title">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+pu((u=l)==null?"":u)+"</h4></div>",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<div class="modal-body g-browser-widget">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<div class="g-hierarchy-root-container form-group"></div>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<div class="g-hierarchy-widget-container g-wait-for-root form-group hidden"></div>',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",n&&(i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<div class="g-input-element form-group">',i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<label class="control-label" for="g-input-element">',i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+pu((u=n.label)==null?"":u)+"</label>",i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+"<input"+(' class="form-control" id="g-input-element" type="text"'+an("placeholder",n.placeholder,!0,!1)+an("value",n.default,!0,!1))+"/></div>"),i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<div class="help-block g-wait-for-root hidden">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+pu((u=f)==null?"":u)+"</div>",i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",h&&(i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<div class="g-selected-model g-wait-for-root form-group hidden">',i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<label class="control-label" for="g-selected-model">',i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+"Selected ",i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+pu((u=g?"item":"folder")==null?"":u)+"</label>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+"<input"+(' class="form-control" id="g-selected-model" type="text"'+an("readonly",!0,!0,!1)+an("value",o,!0,!1))+"/></div>"),i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<div class="g-validation-failed-message hidden"></div></div>',i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<div class="modal-footer">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+"Cancel</a>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<button class="g-submit-button btn btn-small btn-primary" type="submit">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+'<i class="icon-edit"></i>',i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/browserWidget.pug",e=e+pu((u=d)==null?"":u)+"</button></div></div></div>"}).call(this,"defaultSelectedResource"in s?s.defaultSelectedResource:typeof defaultSelectedResource<"u"?defaultSelectedResource:void 0,"help"in s?s.help:typeof help<"u"?help:void 0,"input"in s?s.input:typeof input<"u"?input:void 0,"preview"in s?s.preview:typeof preview<"u"?preview:void 0,"selectItem"in s?s.selectItem:typeof selectItem<"u"?selectItem:void 0,"submit"in s?s.submit:typeof submit<"u"?submit:void 0,"title"in s?s.title:typeof title<"u"?title:void 0)}catch(o){Ip(o,r,i)}return e}var Al=Xe.extend({events:{"click .g-submit-button":function(){this._validate()}},initialize:function(t){t=t||{},this.titleText=t.titleText||"Select an item",this.validate=t.validate||xe.constant(ke.Deferred().resolve().promise()),this.helpText=t.helpText,this.showItems=t.showItems,this.showPreview=xe.isUndefined(t.showPreview)?!0:!!t.showPreview,this.submitText=t.submitText||"Save",this.root=t.root,this.defaultSelectedResource=t.defaultSelectedResource,this.input=t.input,this.selectItem=!!t.selectItem,this.showMetadata=!!t.showMetadata,this.highlightItem=!!t.highlightItem,this.paginated=!!t.paginated,this._selected=null,this.defaultSelectedResource&&(t.rootSelectorSettings||(t.rootSelectorSettings={}),t.rootSelectorSettings.selectByResource||(t.rootSelectorSettings.selectByResource=this.defaultSelectedResource)),this._rootSelectionView=new Bp(xe.extend({parentView:this},t.rootSelectorSettings)),this.listenTo(this._rootSelectionView,"g:selected",function(e){this.root=e.root,this._renderHierarchyView()}),this.defaultSelectedResource&&!this.root&&this._calculateDefaultSelectedRoot()},render:function(){const t=this.defaultSelectedResource&&this.defaultSelectedResource.get("name");return this.$el.html(gx({title:this.titleText,help:this.helpText,preview:this.showPreview,submit:this.submitText,input:this.input,selectItem:this.selectItem,defaultSelectedResource:t})).girderModal(this),this._renderRootSelection(),this},selectedModel:function(){return this._selected},_renderRootSelection:function(){this._rootSelectionView.setElement(this.$(".g-hierarchy-root-container")).render(),this._renderHierarchyView()},_renderHierarchyView:function(){this._hierarchyView&&(this.stopListening(this._hierarchyView),this._hierarchyView.off(),this.$(".g-hierarchy-widget-container").empty()),this.root&&(this.$(".g-wait-for-root").removeClass("hidden"),this._hierarchyView=new $u({el:this.$(".g-hierarchy-widget-container"),parentView:this,parentModel:this.root,checkboxes:!1,routing:!1,showActions:!1,showItems:this.showItems,onItemClick:xe.bind(this._selectItem,this),defaultSelectedResource:this.defaultSelectedResource,highlightItem:this.highlightItem,paginated:this.paginated,showMetadata:this.showMetadata}),this.listenTo(this._hierarchyView,"g:setCurrentModel",this._selectModel),this._selectModel())},_resetSelection:function(t){this._selected=t,this.$(".g-validation-failed-message").addClass("hidden"),this.$(".g-selected-model").removeClass("has-error"),this.$(".g-input-element").removeClass("has-error"),this.$("#g-selected-model").val(""),this._selected&&(this.$("#g-selected-model").val(this._selected.get("name")),this.highlightItem&&this.selectItem?this._hierarchyView.selectItem(this._selected):this._hierarchyView.selectFolder(this._selected))},_selectItem:function(t){this.selectItem&&this._resetSelection(t)},_selectModel:function(){this.selectItem||this._resetSelection(this._hierarchyView.parentModel)},_validate:function(){let t;this.input&&this.input.validate?(t=this.input.validate(this.$("#g-input-element").val()),t===void 0?(console.warn("Static validation is deprecated, return a promise instead"),t=ke.Deferred().resolve().promise()):xe.isFunction(t.then)||(console.warn("Static validation is deprecated, return a promise instead"),t=ke.Deferred().reject(t).promise())):t=ke.Deferred().resolve().promise();const e=this.selectedModel();let u=this.validate(e);u===void 0?(console.warn("Static validation is deprecated, return a promise instead"),u=ke.Deferred().resolve().promise()):xe.isFunction(u.then)||(console.warn("Static validation is deprecated, return a promise instead"),u=ke.Deferred().reject(u).promise());let r=null,i=null;ke.when(t.catch(s=>{r=s}),u.catch(s=>{i=s})).done(()=>{this.$(".g-selected-model").removeClass("has-error"),this.$(".g-input-element").removeClass("has-error"),this.$(".g-validation-failed-message").addClass("hidden").html(""),!r&&!i?(this.root=this._hierarchyView.parentModel,this.$el.modal("hide"),this.trigger("g:saved",e,this.$("#g-input-element").val())):!r&&i?(this.$(".g-selected-model").addClass("has-error"),this.$(".g-validation-failed-message").removeClass("hidden").text(i)):r&&!i?(this.$(".g-input-element").addClass("has-error"),this.$(".g-validation-failed-message").removeClass("hidden").text(r)):r&&i&&(this.$(".g-selected-model").addClass("has-error"),this.$(".g-input-element").addClass("has-error"),this.$(".g-validation-failed-message").removeClass("hidden").html(xe.escape(r)+"<br>"+xe.escape(i)))})},_calculateDefaultSelectedRoot:function(){if(!this.selectItem){this.root=this.defaultSelectedResource;return}const t={folder:Sr,collection:ai,user:p0};let e="folder",u=null;if(this.defaultSelectedResource.get("folderId")?u=this.defaultSelectedResource.get("folderId"):this.defaultSelectedResource.get("parentCollection")&&(e=this.defaultSelectedResource.get("parentCollection"),u=this.defaultSelectedResource.get("parentId")),t[e]&&u){const r=new t[e];r.set({_id:u}).on("g:fetched",function(){this.root=r,this.render()},this).on("g:error",function(){this.render()},this).fetch()}}});function px(t){var e=""+t,u=fx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var fx=/["&<>]/;function Op(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Op(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function mx(t){var e="",u,r,i;try{var s=t||{};(function(o){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<div class="g-body-title">',i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"Import existing data from the filesystem</div>",i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<div class="g-body-subtitle">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+px((u=o.name())==null?"":u)+"</div>",i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<div class="g-import-instructions">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"Use this page to import existing data from this assetstore's filesystem.",i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+`
`,i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"Specify a root directory on the filesystem, and it will be imported recursively.",i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+`
`,i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"The directory does not need to be under the assetstore's root dir. You must also",i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+`
`,i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"specify a destination collection, user, or folder ID under which to place the",i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+`
`,i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"imported data. Files that are imported are not managed directly by the server.",i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+`
`,i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"They will not be copied, but will be served from their existing location. When",i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+`
`,i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"the referencing files in Girder are deleted, the underlying imported file will",i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+`
`,i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"not be removed.",i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+`
`,i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"</div>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<form class="g-filesystem-import-form">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<div class="form-group">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<label for="g-filesystem-import-path">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"Import path (absolute path to directory or file)</label>",i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<input class="form-control input-sm" id="g-filesystem-import-path" type="text"/></div>',i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<div class="form-group">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<label for="g-filesystem-import-dest-type">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"Destination type</label>",i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<select class="form-control" id="g-filesystem-import-dest-type">',i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<option value="folder">',i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"Folder</option>",i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<option value="user">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"User</option>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<option value="collection">',i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"Collection</option></select></div>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<div class="form-group">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<label for="g-filesystem-import-dest-id">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"Destination ID</label>",i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<div class="input-group input-group-sm">',i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<input class="form-control input-sm" id="g-filesystem-import-dest-id" type="text" placeholder="Existing folder, user, or collection ID to use as the destination"/>',i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<div class="input-group-btn">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<button class="g-open-browser btn btn-default" type="button">',i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<i class="icon-folder-open"></i></button></div></div></div>',i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<div class="form-group">',i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<label for="g-filesystem-import-leaf-items">',i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"Leaf Folders as Items</label>",i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<select class="form-control" id="g-filesystem-import-leaf-items">',i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<option value="false">',i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"False</option>",i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<option value="true">',i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+"True</option></select></div>",i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<div class="g-validation-failed-message"></div>',i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<button class="g-submit-assetstore-import btn btn-success" type="submit">',i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+'<i class="icon-link-ext"></i>',i=41,r="/home/circleci/project/girder/girder/web/src/templates/body/filesystemImport.pug",e=e+" Begin import</button></form>"}).call(this,"assetstore"in s?s.assetstore:typeof assetstore<"u"?assetstore:void 0)}catch(o){Op(o,r,i)}return e}var $p=Xe.extend({events:{"submit .g-filesystem-import-form":function(t){t.preventDefault();var e=this.$("#g-filesystem-import-dest-id").val().trim().split(/\s/)[0],u=this.$("#g-filesystem-import-dest-type").val(),r=this.$("#g-filesystem-import-leaf-items").val();this.$(".g-validation-failed-message").empty(),this.assetstore.off("g:imported").on("g:imported",function(){tt.navigate(u+"/"+e,{trigger:!0})},this).on("g:error",function(i){this.$(".g-validation-failed-message").text(i.responseJSON.message)},this).import({importPath:this.$("#g-filesystem-import-path").val().trim(),leafFoldersAsItems:r,destinationId:e,destinationType:u,progress:!0})},"click .g-open-browser":"_openBrowser"},initialize:function(t){this._browserWidgetView=new Al({parentView:this,titleText:"Destination",helpText:"Browse to a location to select it as the destination.",submitText:"Select Destination",validate:function(e){const u=ke.Deferred();return e?u.resolve():u.reject("Please select a valid root."),u.promise()}}),this.listenTo(this._browserWidgetView,"g:saved",function(e){this.$("#g-filesystem-import-dest-id").val(e.id),this.$("#g-filesystem-import-dest-type").val(e.get("_modelType")),ut({url:`resource/${e.id}/path`,method:"GET",data:{type:e.get("_modelType")}}).done(u=>{this.$("#g-filesystem-import-dest-id").val()===e.id&&this.$("#g-filesystem-import-dest-id").val(`${e.id} (${u})`)})}),this.assetstore=t.assetstore,this.render()},render:function(){return this.$el.html(mx({assetstore:this.assetstore})),this},_openBrowser:function(){this._browserWidgetView.setElement(ke("#g-dialog-container")).render()}});function Zd(t){var e=""+t,u=vx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var vx=/["&<>]/;function Np(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Np(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function bx(t){var e="",u,r,i;try{var s=t||{};(function(o){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<div class="g-body-title">',i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"Import existing data from S3</div>",i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<div class="g-body-subtitle">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+Zd((u=o.get("name"))==null?"":u)+"</div>",i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<div class="g-import-instructions g-s3import-instructions">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"Use this page to import existing data from this assetstore's S3 bucket",i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+`
`,i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"(",i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"<b>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+Zd((u=o.get("bucket"))==null?"":u)+"</b>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"). You may import a specific directory of keys",i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+`
`,i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"within the bucket, or a specific key by path. If you wish to import the entire",i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+`
`,i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"bucket into the selected destination, simply leave the import path field blank.",i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+`
`,i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"If you specify a directory, it will be imported recursively. You must also",i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+`
`,i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"specify a destination collection, user, or folder ID under which to place the",i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+`
`,i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"imported data.",i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+`
`,i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"</div>",i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<form class="g-s3-import-form">',i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<div class="form-group">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<label for="g-s3-import-path">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"Import path (key or directory)</label>",i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<input class="form-control input-sm" id="g-s3-import-path" type="text"/></div>',i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<div class="form-group">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<label for="g-s3-import-dest-type">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"Destination type</label>",i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<select class="form-control" id="g-s3-import-dest-type">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<option value="folder">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"Folder</option>",i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<option value="user">',i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"User</option>",i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<option value="collection">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"Collection</option></select></div>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<div class="form-group">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<label for="g-s3-import-dest-id">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+"Destination ID</label>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<div class="input-group input-group-sm">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<input class="form-control input-sm" id="g-s3-import-dest-id" type="text" placeholder="Existing folder, user, or collection ID to use as the destination"/>',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<div class="input-group-btn">',i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<button class="g-open-browser btn btn-default" type="button">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<i class="icon-folder-open"></i></button></div></div></div>',i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<div class="g-validation-failed-message"></div>',i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<button class="g-submit-assetstore-import g-submit-s3-import btn btn-success" type="submit">',i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+'<i class="icon-link-ext"></i>',i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/s3Import.pug",e=e+" Begin import</button></form>"}).call(this,"assetstore"in s?s.assetstore:typeof assetstore<"u"?assetstore:void 0)}catch(o){Np(o,r,i)}return e}var Wp=Xe.extend({events:{"submit .g-s3-import-form":function(t){t.preventDefault();var e=this.$("#g-s3-import-dest-id").val().trim().split(/\s/)[0],u=this.$("#g-s3-import-dest-type").val();this.$(".g-validation-failed-message").empty(),this.assetstore.off("g:imported").on("g:imported",function(){tt.navigate(u+"/"+e,{trigger:!0})},this).on("g:error",function(r){this.$(".g-validation-failed-message").text(r.responseJSON.message)},this).import({importPath:this.$("#g-s3-import-path").val().trim(),destinationId:e,destinationType:u,progress:!0})},"click .g-open-browser":"_openBrowser"},initialize:function(t){this._browserWidgetView=new Al({parentView:this,titleText:"Destination",helpText:"Browse to a location to select it as the destination.",submitText:"Select Destination",validate:function(e){const u=ke.Deferred();return e?u.resolve():u.reject("Please select a valid root."),u.promise()}}),this.listenTo(this._browserWidgetView,"g:saved",function(e){this.$("#g-s3-import-dest-id").val(e.id),this.$("#g-s3-import-dest-type").val(e.get("_modelType")),ut({url:`resource/${e.id}/path`,method:"GET",data:{type:e.get("_modelType")}}).done(u=>{this.$("#g-s3-import-dest-id").val()===e.id&&this.$("#g-s3-import-dest-id").val(`${e.id} (${u})`)})}),this.assetstore=t.assetstore,this.render()},render:function(){return this.$el.html(bx({assetstore:this.assetstore})),this},_openBrowser:function(){this._browserWidgetView.setElement(ke("#g-dialog-container")).render()}}),xl={};xl[lr.FILESYSTEM]=$p;xl[lr.S3]=Wp;var kl=Xe.extend({events:{"click .g-set-current":"setCurrentAssetstore","click .g-delete-assetstore":"deleteAssetstore","click .g-edit-assetstore":"editAssetstore"},initialize:function(t){x0("fetch"),this.plots=[],this.assetstoreEdit=t.assetstoreEdit||!1,this.importableTypes=[lr.FILESYSTEM,lr.S3].concat(t.importableTypes||[]),this.newAssetstoreWidget=new tp({parentView:this}).on("g:created",this.addAssetstore,this),this.collection=new pg,this.collection.on("g:changed",function(){this.render()},this).fetch()},destroy:function(){this._destroyPlots(),Xe.prototype.destroy.call(this)},_destroyPlots:function(){for(const t of this.plots)t.data("jqplot").destroy();this.plots=[]},render:function(){if(!ft()||!ft().get("admin")){this.$el.text("Must be logged in as admin to view this page.");return}return this._destroyPlots(),this.$el.html(tA({assetstores:this.collection.toArray(),types:lr,importableTypes:this.importableTypes,getAssetstoreImportRoute:this.getAssetstoreImportRoute})),this.newAssetstoreWidget.setElement(this.$("#g-new-assetstore-container")).render(),xe.each(this.$(".g-assetstore-capacity-chart"),this.capacityChart,this),this.assetstoreEdit&&(this.editAssetstoreDialog(this.assetstoreEdit),this.assetstoreEdit=!1),this},addAssetstore:function(t){this.collection.add(t),this.render()},capacityChart:function(t){var e=this.collection.get(ke(t).attr("cid")),u=e.get("capacity"),r=u.total-u.free,i=[["Used ("+Zt(r)+")",r],["Free ("+Zt(u.free)+")",u.free]],s=ke(t).jqplot([i],{seriesDefaults:{renderer:ke.jqplot.PieRenderer,rendererOptions:{sliceMargin:2,shadow:!1,highlightMouseOver:!1,showDataLabels:!0,padding:5,startAngle:180}},legend:{show:!0,location:"e",background:"transparent",border:"none"},grid:{background:"transparent",border:"none",borderWidth:0,shadow:!1},gridPadding:{top:10,right:10,bottom:10,left:10}});this.plots.push(s)},setCurrentAssetstore:function(t){var e=ke(t.currentTarget),u=this.collection.get(e.attr("cid"));u.set({current:!0}),u.off("g:saved").on("g:saved",function(){He.trigger("g:alert",{icon:"ok",text:"Changed current assetstore.",type:"success",timeout:4e3}),this.collection.fetch({},!0)},this).off("g:error").on("g:error",function(r){He.trigger("g:alert",{icon:"cancel",text:r.responseJSON.message,type:"danger"})}).save()},deleteAssetstore:function(t){var e=ke(t.currentTarget),u=this.collection.get(e.attr("cid"));n0({text:"Are you sure you want to delete the assetstore <b>"+u.escape("name")+"</b>?  There are no files stored in it, and no data will be lost.",escapedHtml:!0,yesText:"Delete",confirmCallback:()=>{u.on("g:deleted",function(){He.trigger("g:alert",{icon:"ok",text:"Assetstore deleted.",type:"success",timeout:4e3}),this.collection.fetch({},!0)},this).off("g:error").on("g:error",function(r){He.trigger("g:alert",{icon:"attention",text:r.responseJSON.message,type:"danger",timeout:4e3})},this).destroy()}})},editAssetstore:function(t){var e=ke(t.currentTarget).attr("cid");this.editAssetstoreDialog(e)},editAssetstoreDialog:function(t){var e=this.collection.get(t),u=ke("#g-dialog-container"),r=new Cl({el:u,model:e,parentView:this}).off("g:saved").on("g:saved",function(){this.render()},this);r.render()}},{import:function(t){var e=new yo({_id:t});e.once("g:fetched",function(){var u=xl[e.get("type")];if(u)He.trigger("g:navigateTo",u,{assetstore:e});else throw new Error("No such view")}).fetch()}});function wx(t){var e=""+t,u=yx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var yx=/["&<>]/;function Hp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Hp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Up(t){var e="",u,r,i;try{var s=t||{};(function(o){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/paginateWidget.pug",e=e+'<ul class="pagination pagination-sm">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/paginateWidget.pug",e=e+'<li class="g-page-prev disabled">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/paginateWidget.pug",e=e+"<a>",i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/paginateWidget.pug",e=e+"&laquo; Prev</a></li>",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/paginateWidget.pug",e=e+'<li class="active">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/paginateWidget.pug",e=e+'<a class="g-page-number">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/paginateWidget.pug",e=e+"Page ",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/paginateWidget.pug",e=e+wx((u=o.pageNum()+1)==null?"":u)+"</a></li>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/paginateWidget.pug",e=e+'<li class="g-page-next disabled">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/paginateWidget.pug",e=e+"<a>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/paginateWidget.pug",e=e+"Next &raquo;</a></li></ul>"}).call(this,"collection"in s?s.collection:typeof collection<"u"?collection:void 0)}catch(o){Hp(o,r,i)}return e}var Nu=Xe.extend({events:{"click .g-page-next:not(.disabled)":function(){this.collection.fetchNextPage()},"click .g-page-prev:not(.disabled)":function(){this.collection.fetchPreviousPage()}},initialize:function(t){this.collection=t.collection},render:function(){return this.$el.html(Up({collection:this.collection})),this.$(".g-page-next").girderEnable(this.collection.hasNextPage()),this.$(".g-page-prev").girderEnable(this.collection.hasPreviousPage()),this}});function gr(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Mi(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Mi(t){var e=""+t,u=Cx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Cx=/["&<>]/;function qp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void qp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Ex(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h,g){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-collection-list-header">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-collection-pagination"></div>',i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<form class="g-collection-search-form form-inline" role="form">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="form-group g-collections-search-container"></div></form>',i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",g()&&(i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<button class="g-collection-create-button btn btn-sm btn-default">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<i class="icon-plus-squared"></i>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+" Create collection</button>"),e=e+"</div>",i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",function(){var d=f;if(typeof d.length=="number")for(var l=0,c=d.length;l<c;l++){var a=d[l];i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<div"+(' class="g-collection-list-entry g-top-level-list-entry"'+gr("public",a.get("public")?"true":"false",!0,!1))+">",i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-collection-right-column">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-collection-created">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<i class="icon-clock"></i>',i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"Created on",i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<span class="g-collection-created-date">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+" ",i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+Mi((u=n(a.get("created"),o))==null?"":u)+"</span></div>",i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",a.has("size")&&(i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-space-used">',i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<i class="icon-floppy"></i>',i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"Currently using",i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<span class="g-user-space-used">',i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+" ",i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+Mi((u=h(a.get("size")))==null?"":u)+"</span></div>"),e=e+"</div>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-list-public-status-icon">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",a.get("public")?(i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<i class="icon-globe" title="Public collection"></i>'):(i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<i class="icon-lock" title="Private collection"></i>'),e=e+"</div>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-top-level-list-title-container">',i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-collection-title">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<a"+(' class="g-collection-link"'+gr("g-collection-cid",a.cid,!0,!1))+">",i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<b>",i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+Mi((u=a.name())==null?"":u)+"</b></a>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<span"+(' class="g-text-fade"'+gr("public",a.get("public")?"true":"false",!0,!1))+"></span></div>",i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",a.get("description")&&(i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-collection-subtitle">',i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<a"+(' class="g-show-description" state="hidden"'+gr("cid",a.cid,!0,!1))+">",i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<span>",i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"Show description</span>",i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<i class="icon-down-dir"></i></a></div>'),e=e+"</div>",i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-clear-right"></div>',i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<div"+(' class="g-collection-description hide"'+gr("cid",a.cid,!0,!1))+"></div></div>"}else{var c=0;for(var l in d){c++;var a=d[l];i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<div"+(' class="g-collection-list-entry g-top-level-list-entry"'+gr("public",a.get("public")?"true":"false",!0,!1))+">",i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-collection-right-column">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-collection-created">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<i class="icon-clock"></i>',i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"Created on",i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<span class="g-collection-created-date">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+" ",i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+Mi((u=n(a.get("created"),o))==null?"":u)+"</span></div>",i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",a.has("size")&&(i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-space-used">',i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<i class="icon-floppy"></i>',i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"Currently using",i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<span class="g-user-space-used">',i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+" ",i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+Mi((u=h(a.get("size")))==null?"":u)+"</span></div>"),e=e+"</div>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-list-public-status-icon">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",a.get("public")?(i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<i class="icon-globe" title="Public collection"></i>'):(i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<i class="icon-lock" title="Private collection"></i>'),e=e+"</div>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-top-level-list-title-container">',i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-collection-title">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<a"+(' class="g-collection-link"'+gr("g-collection-cid",a.cid,!0,!1))+">",i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<b>",i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+Mi((u=a.name())==null?"":u)+"</b></a>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<span"+(' class="g-text-fade"'+gr("public",a.get("public")?"true":"false",!0,!1))+"></span></div>",i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",a.get("description")&&(i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-collection-subtitle">',i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<a"+(' class="g-show-description" state="hidden"'+gr("cid",a.cid,!0,!1))+">",i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<span>",i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"Show description</span>",i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<i class="icon-down-dir"></i></a></div>'),e=e+"</div>",i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+'<div class="g-clear-right"></div>',i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionList.pug",e=e+"<div"+(' class="g-collection-description hide"'+gr("cid",a.cid,!0,!1))+"></div></div>"}}}.call(this)}).call(this,"DATE_MINUTE"in s?s.DATE_MINUTE:typeof DATE_MINUTE<"u"?DATE_MINUTE:void 0,"collections"in s?s.collections:typeof collections<"u"?collections:void 0,"formatDate"in s?s.formatDate:typeof formatDate<"u"?formatDate:void 0,"formatSize"in s?s.formatSize:typeof formatSize<"u"?formatSize:void 0,"getCurrentUser"in s?s.getCurrentUser:typeof getCurrentUser<"u"?getCurrentUser:void 0)}catch(o){qp(o,r,i)}return e}var zp=Xe.extend({events:{"click a.g-collection-link":function(t){var e=ke(t.currentTarget).attr("g-collection-cid");tt.navigate("collection/"+this.collection.get(e).id,{trigger:!0})},"click button.g-collection-create-button":"createCollectionDialog","submit .g-collections-search-form":function(t){t.preventDefault()},"click .g-show-description":"_toggleDescription"},initialize:function(t){x0("fetch"),this.collection=new vl,this.collection.on("g:changed",function(){this.render()},this).fetch(),this.paginateWidget=new Nu({collection:this.collection,parentView:this}),this.searchWidget=new Xt({placeholder:"Search collections...",types:["collection"],parentView:this}).on("g:resultClicked",this._gotoCollection,this),this.create=t.dialog==="create"},createCollectionDialog:function(){var t=ke("#g-dialog-container");new ko({el:t,parentView:this}).on("g:saved",function(e){tt.navigate("collection/"+e.get("_id"),{trigger:!0})},this).render()},render:function(){return this.$el.html(Ex({collections:this.collection.toArray(),getCurrentUser:ft,formatDate:pi,DATE_MINUTE:ml,formatSize:Zt})),this.paginateWidget.setElement(this.$(".g-collection-pagination")).render(),this.searchWidget.setElement(this.$(".g-collections-search-container")).render(),this.create&&this.createCollectionDialog(),this},_gotoCollection:function(t){var e=new ai;e.set("_id",t.id).on("g:fetched",function(){tt.navigate("/collection/"+e.get("_id"),{trigger:!0})},this).fetch()},_toggleDescription:function(t){const e=ke(t.currentTarget),u=e.attr("cid"),r=this.$(`.g-collection-description[cid="${u}"]`);e.attr("state")==="hidden"?(fi(this.collection.get(u).get("description"),r),r.removeClass("hide"),e.attr("state","visible"),e.find("i").removeClass("icon-down-dir").addClass("icon-up-dir"),e.find("span").text("Hide description")):(r.addClass("hide"),e.attr("state","hidden"),e.find("i").removeClass("icon-up-dir").addClass("icon-down-dir"),e.find("span").text("Show description"))}});function Ax(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Vp(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Vp(t){var e=""+t,u=xx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var xx=/["&<>]/;function Gp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Gp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function kx(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<div class="g-collection-header">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<div class="btn-group pull-right">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<button class="g-collection-actions-button btn btn-default dropdown-toggle" data-toggle="dropdown" title="Collection actions">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<i class="icon-sitemap"></i>',i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+" Actions",i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<i class="icon-down-dir"></i></button>',i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<ul class="g-collection-actions-menu dropdown-menu pull-right" role="menu">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<li role="presentation">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+"<a"+(' class="g-download-collection" role="menuitem"'+Ax("href",f.downloadUrl(),!0,!1))+">",i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<i class="icon-download"></i>',i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+"Download collection</a></li>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",f.getAccessLevel()>=o.WRITE&&(i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<li class="divider" role="presentation"></li>',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<li role="presentation">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<a class="g-edit-collection" role="menuitem">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<i class="icon-edit"></i>',i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+"Edit collection</a></li>"),i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",f.getAccessLevel()>=o.ADMIN&&(i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<li class="divider" role="presentation"></li>',i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<li role="presentation">',i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<a class="g-collection-access-control" role="menuitem">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<i class="icon-lock"></i>',i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+"Access control</a></li>",i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<li role="presentation">',i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<a class="g-delete-collection" role="menuitem">',i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<i class="icon-trash"></i>',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+"Delete collection</a></li>"),e=e+"</ul></div>",i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<div class="g-collection-name g-body-title">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+Vp((u=f.name())==null?"":u)+"</div>",i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",f.get("description")&&(i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<div class="g-collection-description">',i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+((u=n(f.get("description")))==null?"":u)+"</div>"),i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<div class="g-clear-right"></div></div>',i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/collectionPage.pug",e=e+'<div class="g-collection-hierarchy-container"></div>'}).call(this,"AccessType"in s?s.AccessType:typeof AccessType<"u"?AccessType:void 0,"collection"in s?s.collection:typeof collection<"u"?collection:void 0,"renderMarkdown"in s?s.renderMarkdown:typeof renderMarkdown<"u"?renderMarkdown:void 0)}catch(o){Gp(o,r,i)}return e}var So=Xe.extend({events:{"click .g-edit-collection":"editCollection","click .g-collection-access-control":"editAccess","click .g-delete-collection":"deleteConfirmation"},initialize:function(t){x0("fetch"),this.upload=t.upload||!1,this.access=t.access||!1,this.edit=t.edit||!1,this.folderAccess=t.folderAccess||!1,this.folderCreate=t.folderCreate||!1,this.folderEdit=t.folderEdit||!1,this.itemCreate=t.itemCreate||!1,t.collection?(this.model=t.collection,t.folderId?(this.folder=new Sr,this.folder.set({_id:t.folderId}).on("g:fetched",function(){this.render()},this).on("g:error",function(){this.folder=null,this.render()},this).fetch()):this.render()):t.id&&(this.model=new ai,this.model.set("_id",t.id),this.model.on("g:fetched",function(){this.render()},this).fetch())},editCollection:function(){var t=ke("#g-dialog-container");this.editCollectionWidget||(this.editCollectionWidget=new ko({el:t,model:this.model,parentView:this}).on("g:saved",function(){this.render()},this)),this.editCollectionWidget.render()},render:function(){return this.$el.html(kx({collection:this.model,AccessType:nt,renderMarkdown:fi})),this.hierarchyWidget?this.hierarchyWidget.setElement(this.$(".g-collection-hierarchy-container")).render():this.hierarchyWidget=new $u({el:this.$(".g-collection-hierarchy-container"),parentModel:this.folder||this.model,upload:this.upload,folderAccess:this.folderAccess,folderEdit:this.folderEdit,folderCreate:this.folderCreate,itemCreate:this.itemCreate,parentView:this}).on("g:setCurrentModel",()=>{this.$(".g-collection-header .g-collection-actions-button").hide()}),this.upload=!1,this.folderAccess=!1,this.folderEdit=!1,this.folderCreate=!1,this.itemCreate=!1,this.edit?this.editCollection():this.access&&this.editAccess(),this},editAccess:function(){new Ao({el:ke("#g-dialog-container"),modelType:"collection",model:this.model,parentView:this}).on("g:accessListSaved",function(t){t.recurse&&this.hierarchyWidget.refreshFolderList()},this)},deleteConfirmation:function(){let t={text:"Are you sure you want to delete the collection <b>"+this.model.escape("name")+this.model.escape("nFolders")+"</b>?",yesText:"Delete",escapedHtml:!0,confirmCallback:()=>{this.model.on("g:deleted",function(){He.trigger("g:alert",{icon:"ok",text:"Collection deleted.",type:"success",timeout:4e3}),tt.navigate("collections",{trigger:!0})}).destroy()}};(this.model.get("nFolders")!==0||this.model.get("size")!==0)&&(t=xe.extend({additionalText:"<b>"+this.model.escape("name")+"</b> contains <b>"+this.model.escape("nFolders")+" folders</b> taking up <b>"+Zt(parseInt(this.model.get("size"),10))+"</b>",msgConfirmation:!0,name:this.model.escape("name")},t)),n0(t)}},{fetchAndInit:function(t,e){var u=new ai;u.set({_id:t}).on("g:fetched",function(){He.trigger("g:navigateTo",So,xe.extend({collection:u},e||{}))},this).fetch()}}),jl=Xe.extend({initialize:function(t){x0("fetch"),this.folder=t.folder,this.upload=t.upload||!1,this.folderAccess=t.folderAccess||!1,this.folderCreate=t.folderCreate||!1,this.folderEdit=t.folderEdit||!1,this.itemCreate=t.itemCreate||!1,this.render()},render:function(){return this.hierarchyWidget=new $u({el:this.$el,parentModel:this.folder,upload:this.upload,folderAccess:this.folderAccess,folderEdit:this.folderEdit,folderCreate:this.folderCreate,itemCreate:this.itemCreate,parentView:this}),this}},{fetchAndInit:function(t,e){var u=new Sr;u.set({_id:t}).on("g:fetched",function(){He.trigger("g:navigateTo",jl,xe.extend({folder:u},e||{}))},this).fetch()}});const e2={}.GIRDER_VERSION||null,Kp=e2===null?null:`${e2}`;function va(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Ti(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Ti(t){var e=""+t,u=jx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var jx=/["&<>]/;function Yp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Yp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Sx(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<div class="g-frontpage-header">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<div class="g-frontpage-logo-container">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<img class="g-frontpage-logo" src="Girder_Mark.png"/></div>',i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<div class="g-frontpage-title-container">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<div class="g-frontpage-title">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+Ti((u=f)==null?"":u)+"</div>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<div class="g-frontpage-subtitle">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"Data management platform</div></div></div>",i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<div class="g-frontpage-body">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<div class="g-frontpage-paragraph">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<div class="g-frontpage-welcome-text-content">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<b class="g-frontpage-welcome-text">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"Welcome to ",i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+Ti((u=f)==null?"":u),i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"!</b></div>",i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<ul>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",n?(i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<li>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"You are currently logged in as",i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<b>",i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" ",i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+Ti((u=n.get("login"))==null?"":u)+"</b>",i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+".",i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<ul>",i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<li>",i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"To explore the data hosted on this server, start with the",i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<a class="g-collections-link" href="#collections">',i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" Collections</a>",i=41,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" page.</li>",i=43,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<li>",i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"To explore your data, go to your",i=45,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<a"+(' class="g-my-folders-link"'+va("href",`#user/${n.id}`,!0,!1))+">",i=45,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" personal data space</a>",i=46,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" or your",i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<a"+(' class="g-my-account-link"'+va("href",`#useraccount/${n.id}/info`,!0,!1))+">",i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" user account page</a>",i=48,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+".</li></ul></li>"):(i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<li>",i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"You are currently browsing anonymously.</li>",i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<ul>",i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<li>",i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"To explore the data hosted on this server, start with the",i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<a class="g-collections-link" href="#collections">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" Collections</a>",i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" page.</li>",i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<li>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"To create an account, use the",i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<a class="g-register-link">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" Register</a>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" link in the upper right corner.</li>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<li>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"If you already have an account you can",i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<a class="g-login-link">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" log in</a>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" with the link in the upper right corner.</li></ul>"),i=50,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<li>",i=51,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",f==="Girder"?(i=52,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"Girder is"):(i=54,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+Ti((u=f)==null?"":u),i=54,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" is powered by Girder,"),i=55,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"Kitware's open-source platform for data management, analytics, and",i=56,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+`
`,i=56,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"visualization. To learn more about how Kitware and Girder can help to solve your",i=57,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+`
`,i=57,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"data challenges, read our series of",i=58,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<a target="_blank" href="https://blog.kitware.com/tag/girder/">',i=58,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" blog posts</a>",i=59,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"or",i=60,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<a target="_blank" href="http://www.kitware.com/contact-us">',i=60,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" contact us</a>",i=61,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"directly.",i=63,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<ul>",i=64,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<li>",i=65,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"To learn more about Girder's software, including how you can host your own",i=66,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+`
`,i=66,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"instance either locally or in the cloud, see the",i=67,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<a target="_blank" href="http://girder.readthedocs.io/en/latest/user-guide.html">',i=67,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" User Guide</a>",i=68,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+", the",i=69,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<a target="_blank" href="http://girder.readthedocs.io/en/latest">',i=69,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" full documentation</a>",i=70,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+", or visit the",i=71,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<a target="_blank" href="https://github.com/girder/girder">',i=71,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" GitHub repository</a>",i=72,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+".</li></ul></li>",i=74,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<li>",i=75,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"To use the REST API to interact with this server, check out the",i=76,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<a"+va("href",o,!0,!1)+">",i=76,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" interactive web API docs</a>",i=77,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+".</li>",i=79,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",h&&(i=80,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"<li>",i=81,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+"This instance of ",i=81,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+Ti((u=f)==null?"":u),i=81,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+" was built from version",i=82,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+'<code class="g-version">',i=82,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+Ti((u=h)==null?"":u)+"</code>",i=83,r="/home/circleci/project/girder/girder/web/src/templates/body/frontPage.pug",e=e+".</li>"),e=e+"</ul></div></div>"}).call(this,"apiRoot"in s?s.apiRoot:typeof apiRoot<"u"?apiRoot:void 0,"brandName"in s?s.brandName:typeof brandName<"u"?brandName:void 0,"currentUser"in s?s.currentUser:typeof currentUser<"u"?currentUser:void 0,"version"in s?s.version:typeof version<"u"?version:void 0)}catch(o){Yp(o,r,i)}return e}var Nn=Xe.extend({events:{"click .g-register-link":function(){He.trigger("g:registerUi")},"click .g-login-link":function(){He.trigger("g:loginUi")},"click .g-quicksearch-link":function(){ke(".g-quick-search-container .g-search-field").trigger("focus")}},initialize:function(t){x0("fetch"),this.brandName=t.brandName||"Girder",this.render()},render:function(){return this.$el.html(Sx({apiRoot:Zi(),currentUser:ft(),version:Kp,brandName:this.brandName})),this}});function Qr(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=_x(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function _x(t){var e=""+t,u=Dx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Dx=/["&<>]/;function Jp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Jp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Mx(t){var e="",u,r;try{var i=t||{};(function(s,o,f,n,h){r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<div class="modal-dialog">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<div class="modal-content">',r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<form class="modal-form" id="g-group-edit-form" role="form">',r=4,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<div class="modal-header">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"&times;</button>",r=6,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<h4 class="modal-title">',r=7,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",f?(r=8,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Edit group"):(r=10,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Create group"),e=e+"</h4></div>",r=11,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<div class="modal-body">',r=12,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<div class="g-public-container">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<div class="radio">',r=14,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"<label>",r=15,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"<input"+(' id="g-access-private" type="radio" name="privacy"'+Qr("checked",h?void 0:"checked",!0,!1))+"/>",r=17,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<i class="icon-lock"></i>',r=18,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Private &mdash; Only members can see this group</label></div>",r=19,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<div class="radio">',r=20,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"<label>",r=21,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"<input"+(' id="g-access-public" type="radio" name="privacy"'+Qr("checked",h?"checked":void 0,!0,!1))+"/>",r=23,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<i class="icon-globe"></i>',r=24,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Public &mdash; Anyone can see this group</label></div></div>",r=25,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<div class="form-group">',r=26,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<label class="control-label" for="g-name">',r=26,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Name</label>",r=27,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<input class="input-sm form-control" id="g-name" type="text" placeholder="Enter group name"/></div>',r=28,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<div class="form-group">',r=29,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<label class="control-label" for="g-description">',r=29,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Description (optional)</label>",r=30,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<textarea class="input-sm form-control" id="g-description" placeholder="Enter group description"></textarea></div>',r=31,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",n&&(r=32,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<div class="form-group">',r=33,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<label class="control-label" for="g-add-to-group">',r=33,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Allow members to be directly added to this group</label>",r=34,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<select class="form-control input-sm" id="g-add-to-group">',r=35,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",o==="yesadmin"?(r=36,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"<option"+(' value="default"'+Qr("selected",s==="default",!0,!1))+">",r=36,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Default - Yes, allow group administrators to add members</option>"):o==="yesmod"?(r=38,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"<option"+(' value="default"'+Qr("selected",s==="default",!0,!1))+">",r=38,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Default - Yes, allow group administrators and moderators to add members</option>"):(r=40,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"<option"+(' value="default"'+Qr("selected",s==="default",!0,!1))+">",r=40,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Default - No</option>"),r=41,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"<option"+(' value="no"'+Qr("selected",s==="no",!0,!1))+">",r=41,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"No - members must be invited and accept invitations</option>",r=42,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",n==="mod"&&(r=43,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"<option"+(' value="yesmod"'+Qr("selected",s==="yesmod",!0,!1))+">",r=43,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Yes - allow group administrators and moderators to directly add members</option>"),r=44,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"<option"+(' value="yesadmin"'+Qr("selected",s==="yesadmin",!0,!1))+">",r=44,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Yes - allow group administrators to directly add members</option></select></div>"),r=45,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<div class="g-validation-failed-message"></div></div>',r=46,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<div class="modal-footer">',r=47,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',r=47,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Cancel</a>",r=48,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<button class="g-save-group btn btn-small btn-primary" type="submit">',r=49,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",f?(r=50,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<i class="icon-edit"></i>',r=51,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Save"):(r=53,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+'<i class="icon-plus-squared"></i>',r=54,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editGroupWidget.pug",e=e+"Create"),e=e+"</button></div></form></div></div>"}).call(this,"addAllowed"in i?i.addAllowed:typeof addAllowed<"u"?addAllowed:void 0,"addToGroupPolicy"in i?i.addToGroupPolicy:typeof addToGroupPolicy<"u"?addToGroupPolicy:void 0,"group"in i?i.group:typeof group<"u"?group:void 0,"groupAddAllowed"in i?i.groupAddAllowed:typeof groupAddAllowed<"u"?groupAddAllowed:void 0,"publicFlag"in i?i.publicFlag:typeof publicFlag<"u"?publicFlag:void 0)}catch(s){Jp(s,u,r)}return e}var Sl=Xe.extend({events:{"submit #g-group-edit-form":function(t){t.preventDefault();var e={name:this.$("#g-name").val(),description:this.$("#g-description").val(),public:this.$("#g-access-public").is(":checked")};this.$("#g-add-to-group").length&&(e.addAllowed=this.$("#g-add-to-group").val()),this.model?this.updateGroup(e):this.createGroup(e),this.$("button.g-save-group").girderEnable(!1),this.$(".g-validation-failed-message").text("")},"change .g-public-container .radio input":"privacyChanged"},initialize:function(t){this.model=t.model||null},render:function(){var t=this.model?this.model.get("public"):!1,e,u=this.model?this.model.get("_addToGroupPolicy"):null;ft().get("admin")&&(u==="nomod"||u==="yesmod"?e="mod":(u==="noadmin"||u==="yesadmin")&&(e="admin"));var r=this.$el.html(Mx({group:this.model,publicFlag:t,addToGroupPolicy:u,groupAddAllowed:e,addAllowed:this.model?this.model.get("addAllowed"):!1})).girderModal(this).on("shown.bs.modal",()=>{this.$("#g-name").trigger("focus"),this.model?b0("edit"):b0("create")}).on("hidden.bs.modal",()=>{this.create?F0("create"):F0("edit")}).on("ready.girder.modal",()=>{this.model?(this.$("#g-name").val(this.model.get("name")),this.$("#g-description").val(this.model.get("description")),this.create=!1):this.create=!0});return r.trigger(ke.Event("ready.girder.modal",{relatedTarget:r})),this.$("#g-name").trigger("focus"),this.privacyChanged(),this},createGroup:function(t){var e=new Ki;e.set(t),e.on("g:saved",function(){this.$el.modal("hide"),this.trigger("g:saved",e)},this).on("g:error",function(u){this.$(".g-validation-failed-message").text(u.responseJSON.message),this.$("button.g-save-group").girderEnable(!0),this.$("#g-"+u.responseJSON.field).trigger("focus")},this).save()},updateGroup:function(t){this.model.set(t),this.model.off().on("g:saved",function(){this.$el.modal("hide"),this.trigger("g:saved",this.model)},this).on("g:error",function(e){this.$(".g-validation-failed-message").text(e.responseJSON.message),this.$("button.g-save-group").girderEnable(!0),this.$("#g-"+e.responseJSON.field).trigger("focus")},this).save()},privacyChanged:function(){this.$(".g-public-container .radio").removeClass("g-selected");var t=this.$(".g-public-container .radio input:checked");t.parents(".radio").addClass("g-selected")}});function cn(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Pi(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Pi(t){var e=""+t,u=Tx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Tx=/["&<>]/;function Qp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Qp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Px(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-groups-list-header">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-group-pagination"></div>',i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<form class="g-group-search-form form-inline" role="form">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="form-group g-groups-search-container"></div></form>',i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",n()&&(i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<button class="g-group-create-button btn btn-sm btn-default">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<i class="icon-plus-squared"></i>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+" Create Group</button>"),e=e+"</div>",i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",function(){var g=h;if(typeof g.length=="number")for(var d=0,l=g.length;d<l;d++){var c=g[d];i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+"<div"+(' class="g-group-list-entry g-top-level-list-entry"'+cn("public",c.get("public")?"true":"false",!0,!1))+">",i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-group-right-column">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-group-created">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<i class="icon-clock"></i>',i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+"Created on",i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<span class="g-group-created-date">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+" ",i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+Pi((u=f(c.get("created"),o))==null?"":u)+"</span></div></div>",i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-list-public-status-icon">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",c.get("public")?(i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<i class="icon-globe" title="Public group"></i>'):(i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<i class="icon-lock" title="Private group"></i>'),e=e+"</div>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-top-level-list-title-container">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-group-title">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+"<a"+(' class="g-group-link"'+cn("g-group-cid",c.cid,!0,!1))+">",i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+"<b>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+Pi((u=c.name())==null?"":u)+"</b></a></div>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-group-subtitle">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<span class="g-group-description">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+Pi((u=c.get("description"))==null?"":u)+"</span></div></div>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-clear-right"></div></div>'}else{var l=0;for(var d in g){l++;var c=g[d];i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+"<div"+(' class="g-group-list-entry g-top-level-list-entry"'+cn("public",c.get("public")?"true":"false",!0,!1))+">",i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-group-right-column">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-group-created">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<i class="icon-clock"></i>',i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+"Created on",i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<span class="g-group-created-date">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+" ",i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+Pi((u=f(c.get("created"),o))==null?"":u)+"</span></div></div>",i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-list-public-status-icon">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",c.get("public")?(i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<i class="icon-globe" title="Public group"></i>'):(i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<i class="icon-lock" title="Private group"></i>'),e=e+"</div>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-top-level-list-title-container">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-group-title">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+"<a"+(' class="g-group-link"'+cn("g-group-cid",c.cid,!0,!1))+">",i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+"<b>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+Pi((u=c.name())==null?"":u)+"</b></a></div>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-group-subtitle">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<span class="g-group-description">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+Pi((u=c.get("description"))==null?"":u)+"</span></div></div>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/groupList.pug",e=e+'<div class="g-clear-right"></div></div>'}}}.call(this)}).call(this,"DATE_DAY"in s?s.DATE_DAY:typeof DATE_DAY<"u"?DATE_DAY:void 0,"formatDate"in s?s.formatDate:typeof formatDate<"u"?formatDate:void 0,"getCurrentUser"in s?s.getCurrentUser:typeof getCurrentUser<"u"?getCurrentUser:void 0,"groups"in s?s.groups:typeof groups<"u"?groups:void 0)}catch(o){Qp(o,r,i)}return e}var Xp=Xe.extend({events:{"click a.g-group-link":function(t){var e=ke(t.currentTarget).attr("g-group-cid");tt.navigate("group/"+this.collection.get(e).id,{trigger:!0})},"submit .g-group-search-form":function(t){t.preventDefault()},"click .g-group-create-button":function(){this.createGroupDialog()}},initialize:function(t){x0("fetch"),this.collection=new mg,this.collection.on("g:changed",function(){this.render()},this).fetch(),this.paginateWidget=new Nu({collection:this.collection,parentView:this}),this.searchWidget=new Xt({placeholder:"Search groups...",types:["group"],parentView:this}).on("g:resultClicked",this._gotoGroup,this),this.create=t.dialog==="create"},render:function(){return this.$el.html(Px({groups:this.collection.toArray(),getCurrentUser:ft,formatDate:pi,DATE_DAY:vo})),this.paginateWidget.setElement(this.$(".g-group-pagination")).render(),this.searchWidget.setElement(this.$(".g-groups-search-container")).render(),this.create&&(this.createGroupDialog(),this.create=!1),this},createGroupDialog:function(){new Sl({el:ke("#g-dialog-container"),parentView:this}).off("g:saved").on("g:saved",function(t){var e=ft().get("groups")||[];e.push(t.get("_id")),ft().set("groups",e),tt.navigate("group/"+t.get("_id"),{trigger:!0})},this).render()},_gotoGroup:function(t){var e=new Ki;e.set("_id",t.id).on("g:fetched",function(){tt.navigate("group/"+e.get("_id"),{trigger:!0})},this).fetch()}});function t2(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Za(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Za(t){var e=""+t,u=Lx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Lx=/["&<>]/;function Zp(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Zp(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Rx(t){var e="",u,r,i;try{var s=t||{};(function(o){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+'<div class="btn-group">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+'<a class="g-sort-order-button g-up btn btn-sm" title="Sort order">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+'<i class="icon-sort-name-up"></i></a>',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+'<a class="g-sort-order-button g-down btn btn-sm" title="Sort order">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+'<i class="icon-sort-name-down"></i></a>',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+'<button class="g-collection-sort-actions btn btn-sm btn-default dropdown-toggle" data-toggle="dropdown" title="Sort by Field">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+"Sort by",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+'<i class="icon-down-dir"></i></button>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+'<ul class="g-collection-sort-menu dropdown-menu" role="menu">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",function(){var f=o;if(typeof f.length=="number")for(var n=0,h=f.length;n<h;n++){var g=f[n];i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+'<li role="presentation">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+"<a"+(' class="g-collection-sort-link" role="menuitem"'+t2("g-sort",n,!0,!1))+">",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+Za((u=g)==null?"":u)+"</a></li>"}else{var h=0;for(var n in f){h++;var g=f[n];i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+'<li role="presentation">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+"<a"+(' class="g-collection-sort-link" role="menuitem"'+t2("g-sort",n,!0,!1))+">",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/sortCollectionWidget.pug",e=e+Za((u=g)==null?"":u)+"</a></li>"}}}.call(this),e=e+"</ul></div>"}).call(this,"fields"in s?s.fields:typeof fields<"u"?fields:void 0)}catch(o){Zp(o,r,i)}return e}var Bx=Xe.extend({events:{"click a.g-collection-sort-link":function(t){var e=ke(t.currentTarget).attr("g-sort");this.collection.sortField=e,this.collection.fetch({},!0)},"click a.g-sort-order-button":function(){this.collection.sortDir===fs?this.collection.sortDir=Uh:this.collection.sortDir=fs,this.collection.fetch({},!0)}},initialize:function(t){this.collection=t.collection,this.fields=t.fields},render:function(){return this.$el.html(Rx({collection:this.collection,fields:this.fields})),this.collection.sortDir===fs?this.$(".g-down").addClass("hide"):this.$(".g-up").addClass("hide"),this}});function ba(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=pr(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function pr(t){var e=""+t,u=Ix.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Ix=/["&<>]/;function ef(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void ef(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Ox(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h,g,d){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug";const l=f&&f.get("admin");i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug";const c=d===1?`${d} total user`:`${d} total users`;i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-list-header">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-pagination"></div>',i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",f&&(i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+"<div"+(' class="g-user-count-container"'+ba("title",c,!0,!1))+">",i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<i class="icon-user"></i>',i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<span class="g-user-count">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+pr((u=d)==null?"":u)+"</span></div>"),i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-sort"></div>',i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<form class="g-user-search-form form-inline" role="form">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="form-group g-users-search-container"></div></form>',i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",l&&(i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<button class="g-user-create-button btn btn-sm btn-default">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<i class="icon-plus-squared"></i>',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+" Create user</button>"),e=e+"</div>",i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",function(){var a=g;if(typeof a.length=="number")for(var F=0,p=a.length;F<p;F++){var m=a[F];i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-list-entry">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-right-column">',i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-joined">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<i class="icon-clock"></i>',i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+"Joined on",i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<span class="g-user-joined-date">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+" ",i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+pr((u=n(m.get("created"),o))==null?"":u)+"</span></div>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",m.get("size")!==void 0&&(i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-space-used">',i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<i class="icon-floppy"></i>',i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+"Currently using",i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<span class="g-user-space-used">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+" ",i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+pr((u=h(m.get("size")))==null?"":u)+"</span></div>"),i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",m.get("status")==="disabled"?(i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-status">',i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<i class="icon-cancel-circled"></i>',i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+"Account disabled</div>"):m.get("status")==="pending"&&(i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-status">',i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<i class="icon-attention-circled"></i>',i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+"Account pending approval</div>"),e=e+"</div>",i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-title">',i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+"<a"+(' class="g-user-link"'+ba("g-user-cid",m.cid,!0,!1))+">",i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+"<b>",i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+pr((u=m.name())==null?"":u)+"</b></a></div>",i=41,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-subtitle">',i=42,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<span class="g-user-login">',i=42,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+" ",i=42,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+pr((u=m.get("login"))==null?"":u)+"</span></div>",i=43,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-clear-right"></div></div>'}else{var p=0;for(var F in a){p++;var m=a[F];i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-list-entry">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-right-column">',i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-joined">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<i class="icon-clock"></i>',i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+"Joined on",i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<span class="g-user-joined-date">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+" ",i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+pr((u=n(m.get("created"),o))==null?"":u)+"</span></div>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",m.get("size")!==void 0&&(i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-space-used">',i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<i class="icon-floppy"></i>',i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+"Currently using",i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<span class="g-user-space-used">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+" ",i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+pr((u=h(m.get("size")))==null?"":u)+"</span></div>"),i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",m.get("status")==="disabled"?(i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-status">',i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<i class="icon-cancel-circled"></i>',i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+"Account disabled</div>"):m.get("status")==="pending"&&(i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-status">',i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<i class="icon-attention-circled"></i>',i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+"Account pending approval</div>"),e=e+"</div>",i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-title">',i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+"<a"+(' class="g-user-link"'+ba("g-user-cid",m.cid,!0,!1))+">",i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+"<b>",i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+pr((u=m.name())==null?"":u)+"</b></a></div>",i=41,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-user-subtitle">',i=42,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<span class="g-user-login">',i=42,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+" ",i=42,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+pr((u=m.get("login"))==null?"":u)+"</span></div>",i=43,r="/home/circleci/project/girder/girder/web/src/templates/body/userList.pug",e=e+'<div class="g-clear-right"></div></div>'}}}.call(this)}).call(this,"DATE_DAY"in s?s.DATE_DAY:typeof DATE_DAY<"u"?DATE_DAY:void 0,"currentUser"in s?s.currentUser:typeof currentUser<"u"?currentUser:void 0,"formatDate"in s?s.formatDate:typeof formatDate<"u"?formatDate:void 0,"formatSize"in s?s.formatSize:typeof formatSize<"u"?formatSize:void 0,"users"in s?s.users:typeof users<"u"?users:void 0,"usersCount"in s?s.usersCount:typeof usersCount<"u"?usersCount:void 0)}catch(o){ef(o,r,i)}return e}var _l=Xe.extend({events:{"click a.g-user-link":function(t){var e=ke(t.currentTarget).attr("g-user-cid");tt.navigate("user/"+this.collection.get(e).id,{trigger:!0})},"click button.g-user-create-button":"createUserDialog","submit .g-user-search-form":function(t){t.preventDefault()}},initialize:function(t){x0("fetch"),this.collection=new xu;const e=[];if(e.push(this.collection.fetch()),this.paginateWidget=new Nu({collection:this.collection,parentView:this}),this.sortCollectionWidget=new Bx({collection:this.collection,parentView:this,fields:{lastName:"Last Name",created:"Creation Date",size:"Used Space"}}),this.searchWidget=new Xt({placeholder:"Search users...",types:["user"],modes:"prefix",parentView:this}).on("g:resultClicked",this._gotoUser,this),ft()){const u=xu.getTotalCount().done(r=>{this.usersCount=r});e.push(u)}this.register=t.dialog==="register"&&ft()&&ft().get("admin"),ke.when(...e).done(()=>{this.listenTo(this.collection,"g:changed",this.render),this.render()})},render:function(){return this.$el.html(Ox({users:this.collection.toArray(),currentUser:ft(),usersCount:this.usersCount,formatDate:pi,formatSize:Zt,DATE_DAY:vo})),this.paginateWidget.setElement(this.$(".g-user-pagination")).render(),this.sortCollectionWidget.setElement(this.$(".g-user-sort")).render(),this.searchWidget.setElement(this.$(".g-users-search-container")).render(),this.register&&this.createUserDialog(),this},_gotoUser:function(t){var e=new p0;e.set("_id",t.id).on("g:fetched",function(){tt.navigate("user/"+e.get("_id"),{trigger:!0})},this).fetch()},createUserDialog:function(){var t=ke("#g-dialog-container");new wl({el:t,parentView:this}).on("g:userCreated",function(e){tt.navigate("user/"+e.user.id,{trigger:!0})},this).render()}});function wa(t){var e=""+t,u=$x.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var $x=/["&<>]/;function tf(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void tf(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Nx(t){var e="",u,r,i;try{var s=t||{};(function(o,f){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<div class="g-user-header">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",f.getAccessLevel()>=o.WRITE&&(i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<div class="btn-group pull-right">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<button class="g-user-actions-button btn btn-default dropdown-toggle" data-toggle="dropdown" title="Item actions">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<i class="icon-user"></i>',i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+" Actions",i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<i class="icon-down-dir"></i></button>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<ul class="g-item-actions-menu dropdown-menu pull-right" role="menu">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<li role="presentation">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<a class="g-edit-user" role="menuitem">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<i class="icon-edit"></i>',i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+"Edit user</a></li>",i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",f.getAccessLevel()>=o.ADMIN&&(i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<li class="divider" role="presentation"></li>',i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",f.get("status")==="pending"?(i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<li role="presentation">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<a class="g-approve-user" role="menuitem">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<i class="icon-ok-squared"></i>',i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+"Approve account</a></li>"):f.get("status")==="enabled"?(i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<li role="presentation">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<a class="g-disable-user" role="menuitem">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<i class="icon-cancel"></i>',i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+"Disable account</a></li>"):f.get("status")==="disabled"&&(i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<li role="presentation">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<a class="g-enable-user" role="menuitem">',i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<i class="icon-ok"></i>',i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+"Enable account</a></li>"),i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<li role="presentation">',i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<a class="g-delete-user" role="menuitem">',i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<i class="icon-trash"></i>',i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+"Delete user</a></li>"),e=e+"</ul></div>"),i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<div class="g-user-name g-body-title">',i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+wa((u=f.get("firstName"))==null?"":u),i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+" ",i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+wa((u=f.get("lastName"))==null?"":u)+"</div>",i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<div class="g-user-login g-body-subtitle">',i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+wa((u=f.get("login"))==null?"":u)+"</div></div>",i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/userPage.pug",e=e+'<div class="g-user-hierarchy-container"></div>'}).call(this,"AccessType"in s?s.AccessType:typeof AccessType<"u"?AccessType:void 0,"user"in s?s.user:typeof user<"u"?user:void 0)}catch(o){tf(o,r,i)}return e}var Wu=Xe.extend({events:{"click a.g-edit-user":function(){var t="useraccount/"+this.model.get("_id")+"/info";tt.navigate(t,{trigger:!0})},"click a.g-delete-user":function(){n0({text:"Are you sure you want to delete the user <b>"+this.model.escape("login")+"</b>?",yesText:"Delete",escapedHtml:!0,confirmCallback:()=>{this.model.on("g:deleted",function(){tt.navigate("",{trigger:!0})}).destroy()}})},"click a.g-approve-user":function(){this._setAndSave({status:"enabled"},"Approved user account.")},"click a.g-disable-user":function(){this._setAndSave({status:"disabled"},"Disabled user account.")},"click a.g-enable-user":function(){this._setAndSave({status:"enabled"},"Enabled user account.")}},initialize:function(t){x0("fetch"),this.folderId=t.folderId||null,this.upload=t.upload||!1,this.folderAccess=t.folderAccess||!1,this.folderCreate=t.folderCreate||!1,this.folderEdit=t.folderEdit||!1,this.itemCreate=t.itemCreate||!1,t.user?(this.model=t.user,t.folderId?(this.folder=new Sr,this.folder.set({_id:t.folderId}).on("g:fetched",function(){this.render()},this).on("g:error",function(){this.folder=null,this.render()},this).fetch()):this.render()):t.id&&(this.model=new p0,this.model.set("_id",t.id),this.model.on("g:fetched",function(){this.render()},this).fetch())},render:function(){return this.$el.html(Nx({user:this.model,AccessType:nt})),this.hierarchyWidget?this.hierarchyWidget.setElement(this.$(".g-user-hierarchy-container")).render():this.hierarchyWidget=new $u({el:this.$(".g-user-hierarchy-container"),parentModel:this.folder||this.model,upload:this.upload,folderAccess:this.folderAccess,folderEdit:this.folderEdit,folderCreate:this.folderCreate,itemCreate:this.itemCreate,parentView:this}),this.upload=!1,this.folderAccess=!1,this.folderEdit=!1,this.folderCreate=!1,this.itemCreate=!1,this},_setAndSave:function(t,e){this.model.set(t),this.model.off("g:saved").on("g:saved",function(){He.trigger("g:alert",{icon:"ok",text:e,type:"success",timeout:4e3}),this.render()},this).off("g:error").on("g:error",function(u){He.trigger("g:alert",{icon:"cancel",text:u.responseJSON.message,type:"danger"})}).save()}},{fetchAndInit:function(t,e){var u=new p0;u.set({_id:t}).on("g:fetched",function(){He.trigger("g:navigateTo",Wu,xe.extend({user:u},e||{}))},this).on("g:error",function(){He.trigger("g:navigateTo",_l)},this).fetch()}});function ln(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=as(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function as(t){var e=""+t,u=Wx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Wx=/["&<>]/;function rf(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void rf(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Hx(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<div class="g-group-admins-header g-group-list-header" title="Group administrators can edit group properties and can add, invite, and remove group members, moderators, and administrators.">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-star"></i>',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"<span>",i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"Administrators</span></div>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<div class="g-group-admins-body">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<ul class="g-group-admins">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",function(){var h=f;if(typeof h.length=="number")for(var g=0,d=h.length;g<d;g++){var l=h[g];i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"<li"+(ln("userid",l.id,!0,!1)+ln("username",l.name,!0,!1))+">",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<a class="g-member-name">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-user"></i>',i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"<span>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+as((u=l.name)==null?"":u),i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+" (",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+as((u=l.login)==null?"":u),i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+")</span></a>",i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<div class="g-group-member-controls pull-right">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",n>=o.ADMIN&&(i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<span class="dropdown">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<a class="g-group-admin-demote dropdown-toggle" title="Demote user" data-toggle="dropdown">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-down-big"></i>',i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-down-dir"></i></a>',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<ul class="dropdown-menu pull-right" role="menu">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<li role="presentation">',i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<a class="g-demote-moderator" role="menuitem">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-minus"></i>',i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"<span>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"Demote to moderator</span></a></li>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<li role="presentation">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<a class="g-demote-member" role="menuitem">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-minus"></i>',i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"<span>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"Demote to member</span></a></li></ul></span>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<a class="g-group-admin-remove" title="Remove user from the group">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-block"></i></a>'),e=e+"</div></li>"}else{var d=0;for(var g in h){d++;var l=h[g];i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"<li"+(ln("userid",l.id,!0,!1)+ln("username",l.name,!0,!1))+">",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<a class="g-member-name">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-user"></i>',i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"<span>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+as((u=l.name)==null?"":u),i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+" (",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+as((u=l.login)==null?"":u),i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+")</span></a>",i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<div class="g-group-member-controls pull-right">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",n>=o.ADMIN&&(i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<span class="dropdown">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<a class="g-group-admin-demote dropdown-toggle" title="Demote user" data-toggle="dropdown">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-down-big"></i>',i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-down-dir"></i></a>',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<ul class="dropdown-menu pull-right" role="menu">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<li role="presentation">',i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<a class="g-demote-moderator" role="menuitem">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-minus"></i>',i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"<span>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"Demote to moderator</span></a></li>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<li role="presentation">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<a class="g-demote-member" role="menuitem">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-minus"></i>',i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"<span>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"Demote to member</span></a></li></ul></span>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<a class="g-group-admin-remove" title="Remove user from the group">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-block"></i></a>'),e=e+"</div></li>"}}}.call(this),i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",f.length||(i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<div class="g-member-list-empty">',i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+'<i class="icon-info-circled"></i>',i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"<span>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupAdminList.pug",e=e+"There are no administrators in this group.</span></div>"),e=e+"</ul></div>"}).call(this,"accessType"in s?s.accessType:typeof accessType<"u"?accessType:void 0,"admins"in s?s.admins:typeof admins<"u"?admins:void 0,"level"in s?s.level:typeof level<"u"?level:void 0)}catch(o){rf(o,r,i)}return e}var uf=Xe.extend({events:{"click .g-demote-moderator":function(t){var e=ke(t.currentTarget).parents(".g-group-admins>li"),u=e.attr("userid");n0({text:"Are you sure you want to demote <b>"+xe.escape(e.attr("username"))+"</b> to a moderator?",escapedHtml:!0,confirmCallback:()=>{var r=new p0({_id:u});this.model.off("g:promoted").on("g:promoted",()=>{this.trigger("g:moderatorAdded")},this).promoteUser(r,nt.WRITE)}})},"click .g-demote-member":function(t){var e=ke(t.currentTarget).parents(".g-group-admins>li");n0({text:"Are you sure you want to remove admin privileges from <b>"+xe.escape(e.attr("username"))+"</b>?",escapedHtml:!0,confirmCallback:()=>{this.trigger("g:demoteUser",e.attr("userid"))}})},"click a.g-group-admin-remove":function(t){var e=ke(t.currentTarget).parents("li");n0({text:"Are you sure you want to remove <b> "+xe.escape(e.attr("username"))+"</b> from this group?",escapedHtml:!0,confirmCallback:()=>{this.trigger("g:removeMember",e.attr("userid"))}})},"click a.g-member-name":function(t){He.trigger("g:navigateTo",Wu,{id:ke(t.currentTarget).parents("li").attr("userid")})}},initialize:function(t){this.model=t.group,this.admins=t.admins},render:function(){return this.$el.html(Hx({group:this.model,level:this.model.get("_accessLevel"),admins:this.admins,accessType:nt})),this}});function dn(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=cs(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function cs(t){var e=""+t,u=Ux.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Ux=/["&<>]/;function sf(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void sf(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function qx(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+'<ul class="g-group-invites">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",function(){var h=f;if(typeof h.length=="number")for(var g=0,d=h.length;g<d;g++){var l=h[g];i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+"<li"+(dn("cid",l.cid,!0,!1)+dn("username",l.name(),!0,!1))+">",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+'<a class="g-member-name">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+'<i class="icon-user"></i>',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+"<span>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+cs((u=l.name())==null?"":u),i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+" (",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+cs((u=l.get("login"))==null?"":u),i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+")</span></a>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+'<div class="g-group-member-controls pull-right">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",n>=o.WRITE&&(i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+'<a class="g-group-uninvite" title="Uninvite this user">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+'<i class="icon-block"></i></a>'),e=e+"</div></li>"}else{var d=0;for(var g in h){d++;var l=h[g];i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+"<li"+(dn("cid",l.cid,!0,!1)+dn("username",l.name(),!0,!1))+">",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+'<a class="g-member-name">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+'<i class="icon-user"></i>',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+"<span>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+cs((u=l.name())==null?"":u),i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+" (",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+cs((u=l.get("login"))==null?"":u),i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+")</span></a>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+'<div class="g-group-member-controls pull-right">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",n>=o.WRITE&&(i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+'<a class="g-group-uninvite" title="Uninvite this user">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+'<i class="icon-block"></i></a>'),e=e+"</div></li>"}}}.call(this),i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",f.length||(i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+'<div class="g-member-list-empty">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+'<i class="icon-info-circled"></i>',i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+"<span>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteList.pug",e=e+"There are no pending invitations to this group.</span></div>"),e=e+"</ul>"}).call(this,"accessType"in s?s.accessType:typeof accessType<"u"?accessType:void 0,"invitees"in s?s.invitees:typeof invitees<"u"?invitees:void 0,"level"in s?s.level:typeof level<"u"?level:void 0)}catch(o){sf(o,r,i)}return e}var nf=Xe.extend({events:{"click .g-group-uninvite":function(t){var e=ke(t.currentTarget).parents("li");n0({text:"Are you sure you want to remove the invitation for <b>"+xe.escape(e.attr("username"))+"</b>?",escapedHtml:!0,confirmCallback:()=>{var u=this.collection.get(e.attr("cid"));this.group.off("g:removed").on("g:removed",()=>{this.collection.remove(u),this.render(),this.parentView.render()}).removeMember(u.get("_id"))}})},"click a.g-member-name":function(t){var e=this.collection.get(ke(t.currentTarget).parents("li").attr("cid"));tt.navigate("user/"+e.get("_id"),{trigger:!0})}},initialize:function(t){this.collection=t.invitees,this.group=t.group},render:function(){return this.$el.html(qx({level:this.group.get("_accessLevel"),invitees:this.collection.toArray(),accessType:nt})),this}});function zx(t){var e=""+t,u=Vx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Vx=/["&<>]/;function of(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void of(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Gx(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="modal-dialog">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="modal-content">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="modal-header">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"&times;</button>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<h4 class="modal-title">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Invite user to group</h4>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="g-dialog-subtitle">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<i class="icon-user"></i>',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"<span>",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+zx((u=h.text)==null?"":u)+"</span></div></div>",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="modal-body">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<label class="control-label">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Select a role for this user</label>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel-group" id="g-invite-role-container">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel panel-default">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel-heading" data-toggle="collapse" data-parent="#g-invite-role-container" data-target="#g-invite-role-member">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel-title">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"<a>",i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Invite as member</a></div></div>",i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel-collapse collapse in" id="g-invite-role-member">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel-body">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"<p>",i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Group members are able to gain all privileges granted to",i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+`
`,i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"the group itself on other resources. They are able to view the",i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+`
`,i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"group, but may not change properties of the group.</p>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="g-invite-as-member btn btn-primary">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<i class="icon-mail"></i>',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"<span>",i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Invite as member</span></div>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",n&&(i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="g-add-as-member btn btn-warning g-add-user-button">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<i class="icon-plus"></i>',i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"<span>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Add as member</span></div>"),e=e+"</div></div></div>",i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",f>=o.ADMIN&&(i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel panel-default">',i=34,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel-heading" data-toggle="collapse" data-parent="#g-invite-role-container" data-target="#g-invite-role-moderator">',i=37,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel-title">',i=38,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"<a>",i=38,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Invite as moderator</a></div></div>",i=39,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel-collapse collapse" id="g-invite-role-moderator">',i=40,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel-body">',i=41,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"<p>",i=42,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Group moderators are members of the group who are also",i=43,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+`
`,i=43,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"granted the power to add and remove users from the group.</p>",i=44,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="g-invite-as-moderator btn btn-primary">',i=45,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<i class="icon-mail"></i>',i=46,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"<span>",i=46,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Invite as moderator</span></div>",i=47,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",n&&(i=48,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="g-add-as-moderator btn btn-warning g-add-user-button">',i=49,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<i class="icon-plus"></i>',i=50,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"<span>",i=50,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Add as moderator</span></div>"),e=e+"</div></div></div>"),i=52,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",f>=o.ADMIN&&(i=53,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel panel-default">',i=54,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel-heading" data-toggle="collapse" data-parent="#g-invite-role-container" data-target="#g-invite-role-admin">',i=57,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel-title">',i=58,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"<a>",i=58,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Invite as administrator</a></div></div>",i=59,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel-collapse collapse" id="g-invite-role-admin">',i=60,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="panel-body">',i=61,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"<p>",i=62,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Group administrators have all the power of group moderators,",i=63,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+`
`,i=63,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"and additionally can promote group members to moderators",i=64,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+`
`,i=64,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"or administrators. They also have the power to delete the",i=65,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+`
`,i=65,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"group entirely.</p>",i=66,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="g-invite-as-admin btn btn-primary">',i=67,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<i class="icon-mail"></i>',i=68,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"<span>",i=68,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Invite as administrator</span></div>",i=69,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",n&&(i=70,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="g-add-as-admin btn btn-warning g-add-user-button">',i=71,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<i class="icon-plus"></i>',i=72,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"<span>",i=72,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Add as administrator</span></div>"),e=e+"</div></div></div>"),e=e+"</div>",i=74,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="g-validation-failed-message"></div></div>',i=75,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<div class="modal-footer">',i=76,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',i=76,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupInviteDialog.pug",e=e+"Cancel</a></div></div></div>"}).call(this,"accessType"in s?s.accessType:typeof accessType<"u"?accessType:void 0,"level"in s?s.level:typeof level<"u"?level:void 0,"mayAdd"in s?s.mayAdd:typeof mayAdd<"u"?mayAdd:void 0,"user"in s?s.user:typeof user<"u"?user:void 0)}catch(o){of(o,r,i)}return e}function r2(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=ls(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function ls(t){var e=""+t,u=Kx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Kx=/["&<>]/;function af(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void af(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Yx(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<div class="g-group-members-header g-group-list-header">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-users"></i>',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"<span>",i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"Members</span>",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",f>=o.WRITE&&(i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<form class="g-group-invite-form form-inline" role="form">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"<span>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-mail-alt"></i></span>',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<div class="form-group g-group-invite-container"></div></form>'),i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<div class="g-member-pagination"></div></div>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<div class="g-group-members-body">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<ul class="g-group-members">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",function(){var h=n;if(typeof h.length=="number")for(var g=0,d=h.length;g<d;g++){var l=h[g];i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"<li"+r2("cid",l.cid,!0,!1)+">",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<a class="g-member-name">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-user"></i>',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"<span>",i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+ls((u=l.name())==null?"":u),i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+" (",i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+ls((u=l.get("login"))==null?"":u),i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+")</span></a>",i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<div class="g-group-member-controls pull-right">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",f>=o.ADMIN&&(i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<span class="dropdown">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<a class="g-group-member-promote dropdown-toggle" title="Promote user" data-toggle="dropdown">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-up-big"></i>',i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-down-dir"></i></a>',i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<ul class="dropdown-menu pull-right" role="menu">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<li role="presentation">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<a class="g-promote-moderator" role="menuitem">',i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-plus"></i>',i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"<span>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"Promote to moderator</span></a></li>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<li role="presentation">',i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<a class="g-promote-admin" role="menuitem">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-plus"></i>',i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"<span>",i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"Promote to administrator</span></a></li></ul></span>"),i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",f>=o.WRITE&&(i=34,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<a class="g-group-member-remove" title="Remove user from the group">',i=35,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-block"></i></a>'),e=e+"</div></li>"}else{var d=0;for(var g in h){d++;var l=h[g];i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"<li"+r2("cid",l.cid,!0,!1)+">",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<a class="g-member-name">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-user"></i>',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"<span>",i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+ls((u=l.name())==null?"":u),i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+" (",i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+ls((u=l.get("login"))==null?"":u),i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+")</span></a>",i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<div class="g-group-member-controls pull-right">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",f>=o.ADMIN&&(i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<span class="dropdown">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<a class="g-group-member-promote dropdown-toggle" title="Promote user" data-toggle="dropdown">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-up-big"></i>',i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-down-dir"></i></a>',i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<ul class="dropdown-menu pull-right" role="menu">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<li role="presentation">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<a class="g-promote-moderator" role="menuitem">',i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-plus"></i>',i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"<span>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"Promote to moderator</span></a></li>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<li role="presentation">',i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<a class="g-promote-admin" role="menuitem">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-plus"></i>',i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"<span>",i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"Promote to administrator</span></a></li></ul></span>"),i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",f>=o.WRITE&&(i=34,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<a class="g-group-member-remove" title="Remove user from the group">',i=35,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-block"></i></a>'),e=e+"</div></li>"}}}.call(this),i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",n.length||(i=37,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<div class="g-member-list-empty">',i=38,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+'<i class="icon-info-circled"></i>',i=39,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"<span>",i=39,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupMemberList.pug",e=e+"There are no members in this group.</span></div>"),e=e+"</ul></div>"}).call(this,"accessType"in s?s.accessType:typeof accessType<"u"?accessType:void 0,"level"in s?s.level:typeof level<"u"?level:void 0,"members"in s?s.members:typeof members<"u"?members:void 0)}catch(o){af(o,r,i)}return e}var Jx=Xe.extend({events:{"click .g-invite-as-member":function(){this._sendInvitation(nt.READ)},"click .g-invite-as-moderator":function(){this._sendInvitation(nt.WRITE)},"click .g-invite-as-admin":function(){this._sendInvitation(nt.ADMIN)},"click .g-add-as-member":function(){this._sendInvitation(nt.READ,!0)},"click .g-add-as-moderator":function(){this._sendInvitation(nt.WRITE,!0)},"click .g-add-as-admin":function(){this._sendInvitation(nt.ADMIN,!0)}},initialize:function(t){this.group=t.group,this.user=t.user},render:function(){return this.$el.html(Gx({group:this.group,user:this.user,level:this.group.get("_accessLevel"),accessType:nt,mayAdd:this.group.mayAddMembers()})).girderModal(this),this},_sendInvitation:function(t,e){this.$el.modal("hide"),this.trigger("g:sendInvite",{user:this.user,group:this.group,level:t,force:e})}}),cf=Xe.extend({events:{"click a.g-member-name":function(t){var e=this.membersColl.get(ke(t.currentTarget).parents("li").attr("cid"));tt.navigate("user/"+e.get("_id"),{trigger:!0})},"click a.g-group-member-remove":function(t){var e=this.membersColl.get(ke(t.currentTarget).parents("li").attr("cid"));n0({text:"Are you sure you want to remove <b> "+xe.escape(e.name())+"</b> from this group?",escapedHtml:!0,confirmCallback:()=>{this.trigger("g:removeMember",e)}})},"click .g-promote-moderator":function(t){var e=ke(t.currentTarget).parents(".g-group-members>li").attr("cid"),u=this.membersColl.get(e);this.model.off("g:promoted").on("g:promoted",function(){this.trigger("g:moderatorAdded")},this).promoteUser(u,nt.WRITE)},"click .g-promote-admin":function(t){var e=ke(t.currentTarget).parents(".g-group-members>li").attr("cid"),u=this.membersColl.get(e);this.model.off("g:promoted").on("g:promoted",function(){this.trigger("g:adminAdded")},this).promoteUser(u,nt.ADMIN)}},initialize:function(t){this.model=t.group,this.modsAndAdmins=xe.union(xe.pluck(t.admins,"id"),xe.pluck(t.moderators,"id")),this.membersColl=new xu,this.membersColl.altUrl="group/"+this.model.get("_id")+"/member",this.membersColl.on("g:changed",function(){this.render()},this).fetch()},render:function(){for(var t=[],e=0;e<this.membersColl.models.length;e+=1){var u=this.membersColl.models[e];ke.inArray(u.id,this.modsAndAdmins)<0&&t.push(u)}return this.$el.html(Yx({group:this.model,members:t,level:this.model.get("_accessLevel"),accessType:nt})),new Nu({el:this.$(".g-member-pagination"),collection:this.membersColl,parentView:this}).render(),this.userSearch=new Xt({el:this.$(".g-group-invite-container"),placeholder:"Invite a user to join...",types:["user"],parentView:this}).off().on("g:resultClicked",this._inviteUser,this).render(),this},_inviteUser:function(t){this.userSearch.resetState(),new Jx({el:ke("#g-dialog-container"),group:this.model,user:t,parentView:this}).on("g:sendInvite",function(e){this.trigger("g:sendInvite",e)},this).render()}});function Fn(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=ds(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function ds(t){var e=""+t,u=Qx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Qx=/["&<>]/;function lf(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void lf(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Xx(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<div class="g-group-mods-header g-group-list-header" title="Group moderators can invite and approve group members.">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<i class="icon-shield"></i>',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+"<span>",i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+"Moderators</span></div>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<div class="g-group-mods-body">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<ul class="g-group-mods">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",function(){var h=n;if(typeof h.length=="number")for(var g=0,d=h.length;g<d;g++){var l=h[g];i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+"<li"+(Fn("userid",l.id,!0,!1)+Fn("username",l.name,!0,!1))+">",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<a class="g-member-name">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<i class="icon-user"></i>',i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+"<span>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+ds((u=l.name)==null?"":u),i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+" (",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+ds((u=l.login)==null?"":u),i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+")</span></a>",i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<div class="g-group-member-controls pull-right">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",f>=o.ADMIN&&(i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<a class="g-group-mod-promote" title="Promote to administrator">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<i class="icon-up-big"></i></a>',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<a class="g-group-mod-demote" title="Demote to member">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<i class="icon-down-big"></i></a>',i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<a class="g-group-mod-remove" title="Remove user from the group">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<i class="icon-block"></i></a>'),e=e+"</div></li>"}else{var d=0;for(var g in h){d++;var l=h[g];i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+"<li"+(Fn("userid",l.id,!0,!1)+Fn("username",l.name,!0,!1))+">",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<a class="g-member-name">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<i class="icon-user"></i>',i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+"<span>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+ds((u=l.name)==null?"":u),i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+" (",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+ds((u=l.login)==null?"":u),i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+")</span></a>",i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<div class="g-group-member-controls pull-right">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",f>=o.ADMIN&&(i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<a class="g-group-mod-promote" title="Promote to administrator">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<i class="icon-up-big"></i></a>',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<a class="g-group-mod-demote" title="Demote to member">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<i class="icon-down-big"></i></a>',i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<a class="g-group-mod-remove" title="Remove user from the group">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<i class="icon-block"></i></a>'),e=e+"</div></li>"}}}.call(this),i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",n.length||(i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<div class="g-member-list-empty">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+'<i class="icon-info-circled"></i>',i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+"<span>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/groupModList.pug",e=e+"There are no moderators in this group.</span></div>"),e=e+"</ul></div>"}).call(this,"accessType"in s?s.accessType:typeof accessType<"u"?accessType:void 0,"level"in s?s.level:typeof level<"u"?level:void 0,"moderators"in s?s.moderators:typeof moderators<"u"?moderators:void 0)}catch(o){lf(o,r,i)}return e}var df=Xe.extend({events:{"click .g-group-mod-promote":function(t){var e=ke(t.currentTarget).parents("li").attr("userid"),u=new p0({_id:e});this.model.off("g:promoted").on("g:promoted",function(){this.trigger("g:adminAdded")},this).promoteUser(u,nt.ADMIN)},"click .g-group-mod-demote":function(t){var e=ke(t.currentTarget).parents("li");n0({text:"Are you sure you want to remove moderator privileges from <b>"+xe.escape(e.attr("username"))+"</b>?",escapedHtml:!0,confirmCallback:()=>{this.trigger("g:demoteUser",e.attr("userid"))}})},"click a.g-group-mod-remove":function(t){var e=ke(t.currentTarget).parents("li");n0({text:"Are you sure you want to remove <b> "+xe.escape(e.attr("username"))+"</b> from this group?",escapedHtml:!0,confirmCallback:()=>{this.trigger("g:removeMember",e.attr("userid"))}})},"click a.g-member-name":function(t){He.trigger("g:navigateTo",Wu,{id:ke(t.currentTarget).parents("li").attr("userid")})}},initialize:function(t){this.model=t.group,this.moderators=t.moderators},render:function(){return this.$el.html(Xx({group:this.model,level:this.model.get("_accessLevel"),moderators:this.moderators,accessType:nt})),this}});function i2(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Li(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Li(t){var e=""+t,u=Zx.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Zx=/["&<>]/;function Ff(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Ff(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function ek(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h,g,d,l,c){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-header">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="btn-group pull-right">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",(d||g||f()||n.get("_accessLevel")>=o.ADMIN)&&(i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<button class="g-group-actions-button btn btn-default dropdown-toggle" data-toggle="dropdown" title="Group actions">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-users"></i>',i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" Actions",i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-down-dir"></i></button>',i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<ul class="g-group-actions-menu dropdown-menu pull-right" role="menu">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",d?(i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<li role="presentation">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a class="g-group-leave" role="menuitem">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-block"></i>',i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"Leave group</a></li>"):g?(i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<li role="presentation">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a class="g-group-join" role="menuitem">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-login"></i>',i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"Join group</a></li>"):f()&&(i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<li role="presentation">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a class="g-group-request-invite" role="menuitem">',i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-export"></i>',i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"Request membership</a></li>"),i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",n.get("_accessLevel")>=o.ADMIN&&(i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<li class="divider" role="presentation"></li>',i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<li role="presentation">',i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a class="g-edit-group" role="menuitem">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-edit"></i>',i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"Edit group</a></li>"),i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",n.get("_accessLevel")>=o.ADMIN&&(i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<li class="divider" role="presentation"></li>',i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<li role="presentation">',i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a class="g-group-delete" role="menuitem">',i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-trash"></i>',i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"Delete group</a></li>"),e=e+"</ul>"),e=e+"</div>",i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-name g-body-title">',i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+Li((u=n.name())==null?"":u)+"</div>",i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-description g-body-subtitle">',i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+Li((u=n.get("description"))==null?"":u)+"</div>",i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-clear-right"></div></div>',i=42,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",f()&&(i=43,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",d?(i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-status-container g-member">',i=45,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-ok"></i>',i=46,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",h?(i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" You are an ",i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"<b>",i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"administrator</b>",i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" of this group."):l?(i=49,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" You are a ",i=49,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"<b>",i=49,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"moderator</b>",i=49,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" of this group."):(i=51,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" You are a ",i=51,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"<b>",i=51,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"member</b>",i=51,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" of this group."),e=e+"</div>"):g?(i=53,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-status-container g-invited">',i=54,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-mail-alt"></i>',i=55,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" You have been invited to this group.",i=56,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a class="g-group-join">',i=56,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" Join group</a></div>"):c?(i=58,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-status-container g-requested-invite">',i=59,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-comment"></i>',i=60,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" You have requested to join this group.</div>"):(i=62,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-status-container g-nonmember">',i=63,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-minus-circled"></i>',i=64,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" You are not a member of this group.",i=65,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a class="g-group-request-invite">',i=65,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" Request membership</a></div>"),i=66,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",n.get("_accessLevel")>=o.ADMIN&&!h&&(i=67,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-status-container g-admin">',i=68,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-star"></i>',i=69,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" You have ",i=69,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"<b>",i=69,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"administrator</b>",i=69,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" privileges.</div>")),i=71,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<ul class="g-group-tabs nav nav-tabs">',i=72,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<li class="active">',i=73,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a href="#g-group-tab-roles" data-toggle="tab" name="roles">',i=74,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-th-list"></i>',i=75,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" Roles</a></li>",i=76,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"<li>",i=77,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a href="#g-group-tab-pending" data-toggle="tab" name="pending">',i=78,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-inbox"></i>',i=79,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"Pending",i=80,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div id="g-group-tab-pending-status"></div></a></li></ul>',i=82,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="tab-content">',i=83,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="tab-pane active" id="g-group-tab-roles">',i=84,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-admins-container"></div>',i=85,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-mods-container"></div>',i=86,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-members-container"></div></div>',i=87,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="tab-pane" id="g-group-tab-pending">',i=88,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-requests-container">',i=89,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-requests-header g-group-list-header">',i=90,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-comment"></i>',i=91,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" Requests for membership</div>",i=93,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-requests-body">',i=94,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<ul class="g-group-requests">',i=95,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",function(){var a=n.get("requests");if(typeof a.length=="number")for(var F=0,p=a.length;F<p;F++){var m=a[F];i=96,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"<li"+i2("userid",m.id,!0,!1)+">",i=97,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a class="g-member-name">',i=98,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-user"></i>',i=99,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" ",i=99,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+Li((u=m.name)==null?"":u),i=99,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" (",i=99,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+Li((u=m.login)==null?"":u),i=99,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+")</a>",i=100,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-member-controls pull-right">',i=101,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",n.get("_accessLevel")>=o.WRITE&&(i=102,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a class="g-group-request-accept" title="Add to group">',i=103,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-thumbs-up"></i></a>',i=104,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a class="g-group-request-deny" title="Deny request">',i=105,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-thumbs-down"></i></a>'),e=e+"</div></li>"}else{var p=0;for(var F in a){p++;var m=a[F];i=96,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+"<li"+i2("userid",m.id,!0,!1)+">",i=97,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a class="g-member-name">',i=98,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-user"></i>',i=99,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" ",i=99,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+Li((u=m.name)==null?"":u),i=99,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" (",i=99,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+Li((u=m.login)==null?"":u),i=99,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+")</a>",i=100,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-member-controls pull-right">',i=101,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",n.get("_accessLevel")>=o.WRITE&&(i=102,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a class="g-group-request-accept" title="Add to group">',i=103,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-thumbs-up"></i></a>',i=104,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<a class="g-group-request-deny" title="Deny request">',i=105,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-thumbs-down"></i></a>'),e=e+"</div></li>"}}}.call(this),i=106,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",n.get("requests").length||(i=107,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-member-list-empty">',i=108,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-info-circled"></i>',i=109,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" There are no outstanding invitation requests for this group.</div>"),e=e+"</ul></div></div>",i=111,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-invites-container">',i=112,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-invites-header g-group-list-header">',i=113,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<i class="icon-mail-alt"></i>',i=114,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+" Sent invitations</div>",i=116,r="/home/circleci/project/girder/girder/web/src/templates/body/groupPage.pug",e=e+'<div class="g-group-invites-body"></div></div></div></div>'}).call(this,"AccessType"in s?s.AccessType:typeof AccessType<"u"?AccessType:void 0,"getCurrentUser"in s?s.getCurrentUser:typeof getCurrentUser<"u"?getCurrentUser:void 0,"group"in s?s.group:typeof group<"u"?group:void 0,"isAdmin"in s?s.isAdmin:typeof isAdmin<"u"?isAdmin:void 0,"isInvited"in s?s.isInvited:typeof isInvited<"u"?isInvited:void 0,"isMember"in s?s.isMember:typeof isMember<"u"?isMember:void 0,"isModerator"in s?s.isModerator:typeof isModerator<"u"?isModerator:void 0,"isRequested"in s?s.isRequested:typeof isRequested<"u"?isRequested:void 0)}catch(o){Ff(o,r,i)}return e}var _o=Xe.extend({events:{"click .g-edit-group":"editGroup","click .g-group-join":"joinGroup","click .g-group-leave":"leaveGroup","click .g-group-delete":"deleteGroup","click .g-group-request-invite":"requestInvitation","click .g-group-request-accept":"acceptMembershipRequest","click .g-group-request-deny":"denyMembershipRequest","click #g-group-tab-pending a.g-member-name":function(t){var e=ke(t.currentTarget).parents("li").attr("userid");tt.navigate("user/"+e,{trigger:!0})}},initialize:function(t){x0("fetch"),this.tab=t.tab||"roles",this.edit=t.edit||!1,t.group?(this.model=t.group,this.model.on("g:accessFetched",function(){this.render()},this).fetchAccess()):t.id&&(this.model=new Ki,this.model.set("_id",t.id),this.model.on("g:fetched",function(){this.model.on("g:accessFetched",function(){this.render()},this).fetchAccess()},this).fetch())},editGroup:function(){var t=ke("#g-dialog-container");this.editGroupWidget||(this.editGroupWidget=new Sl({el:t,model:this.model,parentView:this}).off("g:saved").on("g:saved",function(){this.render()},this)),this.editGroupWidget.render()},deleteGroup:function(){n0({text:"Are you sure you want to delete the group <b>"+this.model.escape("name")+"</b>?",escapedHtml:!0,confirmCallback:()=>{this.model.on("g:deleted",function(){tt.navigate("groups",{trigger:!0})}).destroy()}})},render:function(){if(this.isMember=!1,this.isInvited=!1,this.isRequested=!1,this.isModerator=!1,this.isAdmin=!1,ft()&&(xe.every(ft().get("groups"),function(e){return e===this.model.get("_id")?(this.isMember=!0,!1):!0},this),xe.every(ft().get("groupInvites"),function(e){return e.groupId===this.model.get("_id")?(this.isInvited=!0,!1):!0},this),xe.every(this.model.get("requests")||[],function(e){return e.id===ft().get("_id")?(this.isRequested=!0,!1):!0},this)),this.isMember&&xe.every(this.model.get("access").users||[],function(e){return e.id===ft().get("_id")?(e.level===nt.WRITE?this.isModerator=!0:e.level===nt.ADMIN&&(this.isAdmin=!0),!1):!0},this),this.$el.html(ek({group:this.model,getCurrentUser:ft,AccessType:nt,isInvited:this.isInvited,isRequested:this.isRequested,isMember:this.isMember,isModerator:this.isModerator,isAdmin:this.isAdmin})),this.invitees)this._renderInvitesWidget();else{var t=this.$(".g-group-invites-body");new Os({el:t,parentView:this}).render(),this.invitees=new xu,this.invitees.altUrl="group/"+this.model.get("_id")+"/invitation",this.invitees.on("g:changed",()=>{this._renderInvitesWidget(),this.updatePendingStatus()},this).fetch()}return this._updateRolesLists(),tt.navigate("group/"+this.model.get("_id")+"/"+this.tab,{replace:!0}),this.edit&&(this.model.get("_accessLevel")>=nt.ADMIN&&this.editGroup(),this.edit=!1),xe.each(ke(".g-group-tabs>li>a"),e=>{var u=ke(e);u.tab().on("shown.bs.tab",r=>{this.tab=ke(r.currentTarget).attr("name"),tt.navigate("group/"+this.model.get("_id")+"/"+this.tab)}),u.attr("name")===this.tab&&u.tab("show")}),this},_renderInvitesWidget:function(){new nf({el:this.$(".g-group-invites-body"),invitees:this.invitees,group:this.model,parentView:this}).render(),this.updatePendingStatus()},updatePendingStatus:function(){var t=this.invitees.length+this.model.get("requests").length;ke("#g-group-tab-pending-status").text(" ("+t+")")},joinGroup:function(){this.model.off("g:joined").on("g:joined",function(){this.invitees.fetch(null,!0)},this).joinGroup()},leaveGroup:function(){n0({text:"Are you sure you want to leave this group?",confirmCallback:()=>{this.model.off("g:removed").on("g:removed",()=>{this.render()}).removeMember(ft().get("_id"))}})},removeMember:function(t){var e=t;ke.type(t)!=="string"&&(e=t.get("_id")),this.model.off("g:removed").on("g:removed",function(){this.render()},this).removeMember(e)},requestInvitation:function(){this.model.off("g:inviteRequested").on("g:inviteRequested",function(){this.render()},this).requestInvitation()},acceptMembershipRequest:function(t){var e=ke(t.currentTarget).parents("li").attr("userid");this.model.off("g:invited").on("g:invited",this.render,this).sendInvitation(e,nt.READ,!0)},denyMembershipRequest:function(t){var e=ke(t.currentTarget).parents("li").attr("userid");this.model.off("g:removed").on("g:removed",this.render,this).removeMember(e)},_updateRolesLists:function(){var t=[],e=[];xe.each(this.model.get("access").users,function(u){u.level===nt.WRITE?t.push(u):u.level===nt.ADMIN&&e.push(u)},this),this.adminsWidget=new uf({el:this.$(".g-group-admins-container"),group:this.model,admins:e,parentView:this}).off().on("g:demoteUser",function(u){this.model.off("g:demoted").on("g:demoted",this.render,this).demoteUser(u,nt.ADMIN)},this).on("g:removeMember",this.removeMember,this).on("g:moderatorAdded",this.render,this).render(),this.modsWidget=new df({el:this.$(".g-group-mods-container"),group:this.model,moderators:t,parentView:this}).on("g:demoteUser",function(u){this.model.off("g:demoted").on("g:demoted",this.render,this).demoteUser(u,nt.WRITE)},this).on("g:removeMember",this.removeMember,this).on("g:adminAdded",this.render,this).render(),this.membersWidget=new cf({el:this.$(".g-group-members-container"),group:this.model,admins:e,moderators:t,parentView:this}).on("g:sendInvite",function(u){var r={force:u.force||!1};this.model.off("g:invited").on("g:invited",function(){this.invitees.fetch(null,!0),u.force&&this.model.fetchAccess()},this).off("g:error").on("g:error",function(i){He.trigger("g:alert",{text:i.responseJSON.message,type:"warning"})},this).sendInvitation(u.user.id,u.level,!1,r)},this).on("g:removeMember",this.removeMember,this).on("g:moderatorAdded",this.render,this).on("g:adminAdded",this.render,this)}},{fetchAndInit:function(t,e){var u=new Ki;u.set({_id:t}).once("g:fetched",function(){He.trigger("g:navigateTo",_o,xe.extend({group:u},e||{}))},this).fetch()}});function u2(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=tk(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function tk(t){var e=""+t,u=rk.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var rk=/["&<>]/;function hf(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void hf(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function ik(t){var e="",u,r;try{var i=t||{};(function(s){r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<div class="modal-dialog">',r=2,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<div class="modal-content">',r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<form class="modal-form" id="g-file-edit-form" role="form">',r=4,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<div class="modal-header">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+"&times;</button>",r=6,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<h4 class="modal-title">',r=6,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+"Edit file</h4></div>",r=7,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<div class="modal-body">',r=8,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<div class="form-group">',r=9,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<label class="control-label" for="g-name">',r=9,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+"Name</label>",r=10,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+"<input"+(' class="input-sm form-control" id="g-name" type="text" placeholder="Enter file name"'+u2("value",s.name(),!0,!1))+"/></div>",r=12,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<div class="form-group">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<label class="control-label" for="g-mimetype">',r=13,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+"MIME type</label>",r=14,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+"<input"+(' class="input-sm form-control" id="g-mimetype" type="text" placeholder="Enter MIME type"'+u2("value",s.get("mimeType"),!0,!1))+"/></div>",r=16,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<div class="g-validation-failed-message"></div></div>',r=17,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<div class="modal-footer">',r=18,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',r=18,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+"Cancel</a>",r=19,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<button class="g-save-file btn btn-small btn-primary" type="submit">',r=20,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+'<i class="icon-edit"></i>',r=21,u="/home/circleci/project/girder/girder/web/src/templates/widgets/editFileWidget.pug",e=e+"Save</button></div></form></div></div>"}).call(this,"file"in i?i.file:typeof file<"u"?file:void 0)}catch(s){hf(s,u,r)}return e}var gf=Xe.extend({events:{"submit #g-file-edit-form":function(){var t={name:this.$("#g-name").val(),mimeType:this.$("#g-mimetype").val()};return this.file.set(t),this.file.off(null,null,this).on("g:saved",function(){this.$el.modal("hide"),this.trigger("g:saved",this.file)},this).on("g:error",function(e){this.$(".g-validation-failed-message").text(e.responseJSON.message),this.$("button.g-save-file").girderEnable(!0),this.$("#g-"+e.responseJSON.field).trigger("focus")},this).save(),this.$("button.g-save-file").girderEnable(!1),this.$(".g-validation-failed-message").empty(),!1}},initialize:function(t){this.file=t.file||null},render:function(){return this.file.get("mimeType")===void 0&&this.file.set("mimeType",""),this.$el.html(ik({file:this.file})).girderModal(this).on("shown.bs.modal",()=>{this.$("#g-name").trigger("select").trigger("focus")}).on("hidden.bs.modal",()=>{F0("fileedit",void 0,this.file.get("_id"))}),b0("fileedit",void 0,this.file.get("_id")),this}});function cu(t){var e=""+t,u=uk.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var uk=/["&<>]/;function pf(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void pf(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function sk(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<div class="modal-dialog">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<div class="modal-content">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<div class="modal-header">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+"&times;</button>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<h4 class="modal-title">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+"File information</h4>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<div class="g-dialog-subtitle">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<i class="icon-doc-inv"></i>',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+"<span>",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+cu((u=f.name())==null?"":u)+"</span></div></div>",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<div class="modal-body">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<div class="g-file-info-lines">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<div class="g-file-info-line" property="created">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<i class="icon-clock"></i>',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+"<span>",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+cu((u="Created ")==null?"":u)+"</span>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<span class="g-bold-part">',i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+cu((u=n(f.get("created"),o))==null?"":u)+"</span></div>",i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<div class="g-file-info-line" property="mimeType">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<i class="icon-info"></i>',i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+"<span>",i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+"MIME type:</span>",i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<span class="g-bold-part">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+" ",i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+cu((u=f.get("mimeType")||"unknown")==null?"":u)+"</span></div>",i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",f.has("size")&&(i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<div class="g-file-info-line" property="size">',i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<i class="icon-hdd"></i>',i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+"<span>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+"Size:</span>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<span class="g-bold-part">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+" ",i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+cu((u=f.get("size"))==null?"":u),i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+" bytes</span></div>"),i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<div class="g-file-info-line" property="id">',i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<i class="icon-share"></i>',i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+"<span>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+"Unique ID:</span>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<span class="g-bold-part">',i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+" ",i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+cu((u=f.id)==null?"":u)+"</span></div></div></div>",i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<div class="modal-footer">',i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileInfoDialog.pug",e=e+"Close</a></div></div></div>"}).call(this,"DATE_SECOND"in s?s.DATE_SECOND:typeof DATE_SECOND<"u"?DATE_SECOND:void 0,"file"in s?s.file:typeof file<"u"?file:void 0,"formatDate"in s?s.formatDate:typeof formatDate<"u"?formatDate:void 0)}catch(o){pf(o,r,i)}return e}var ff=Xe.extend({initialize:function(t){this.parentItem=t.parentItem},render:function(){return this.$el.html(sk({file:this.model,formatDate:pi,DATE_SECOND:Iu})).girderModal(this),this}});function G0(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Ri(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Ri(t){var e=""+t,u=nk.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var nk=/["&<>]/;function mf(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void mf(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function ok(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h,g){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<ul class="g-file-list">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",function(){var d=f;if(typeof d.length=="number")for(var l=0,c=d.length;l<c;l++){var a=d[l];i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<li class="g-file-list-entry">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+"<a"+(' class="g-file-list-link"'+G0("cid",a.cid,!0,!1)+' title="Download file"'+G0("target",a.get("linkUrl")?"_blank":"_self",!0,!1)+G0("href",a.downloadUrl(),!0,!1)+' rel="noopener noreferrer"')+">",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",a.get("linkUrl")?(i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-link"></i>',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<span class="g-file-name">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+Ri((u=a.name())==null?"":u)+"</span>",i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-link-ext"></i>'):(i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-doc-inv"></i>',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+Ri((u=a.name())==null?"":u)),e=e+"</a>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+"<a"+(' class="g-view-inline" title="View in browser" target="_blank" rel="noopener noreferrer"'+G0("href",a.downloadUrl({contentDisposition:"inline"}),!0,!1))+">",i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-eye"></i></a>',i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+"<a"+(' class="g-show-info"'+G0("file-cid",a.cid,!0,!1)+' title="Show info"')+">",i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-info"></i></a>',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",a.has("size")&&(i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<div class="g-file-size">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+Ri((u=n(a.get("size")))==null?"":u)+"</div>"),i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+"<div"+(' class="g-file-actions-container"'+G0("file-cid",a.cid,!0,!1))+">",i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",g&&g.get("_accessLevel")>=o.WRITE&&(i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<a class="g-update-info" title="Edit file info">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-edit"></i></a>',i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<a class="g-update-contents" title="Replace file contents">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-upload"></i></a>',i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<a class="g-delete-file" title="Delete file">',i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-cancel"></i></a>'),e=e+"</div></li>"}else{var c=0;for(var l in d){c++;var a=d[l];i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<li class="g-file-list-entry">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+"<a"+(' class="g-file-list-link"'+G0("cid",a.cid,!0,!1)+' title="Download file"'+G0("target",a.get("linkUrl")?"_blank":"_self",!0,!1)+G0("href",a.downloadUrl(),!0,!1)+' rel="noopener noreferrer"')+">",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",a.get("linkUrl")?(i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-link"></i>',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<span class="g-file-name">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+Ri((u=a.name())==null?"":u)+"</span>",i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-link-ext"></i>'):(i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-doc-inv"></i>',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+Ri((u=a.name())==null?"":u)),e=e+"</a>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+"<a"+(' class="g-view-inline" title="View in browser" target="_blank" rel="noopener noreferrer"'+G0("href",a.downloadUrl({contentDisposition:"inline"}),!0,!1))+">",i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-eye"></i></a>',i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+"<a"+(' class="g-show-info"'+G0("file-cid",a.cid,!0,!1)+' title="Show info"')+">",i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-info"></i></a>',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",a.has("size")&&(i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<div class="g-file-size">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+Ri((u=n(a.get("size")))==null?"":u)+"</div>"),i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+"<div"+(' class="g-file-actions-container"'+G0("file-cid",a.cid,!0,!1))+">",i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",g&&g.get("_accessLevel")>=o.WRITE&&(i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<a class="g-update-info" title="Edit file info">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-edit"></i></a>',i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<a class="g-update-contents" title="Replace file contents">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-upload"></i></a>',i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<a class="g-delete-file" title="Delete file">',i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-cancel"></i></a>'),e=e+"</div></li>"}}}.call(this),i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",h&&(i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<li class="g-show-more">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<a class="g-show-more-files">',i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+'<i class="icon-level-down"></i>',i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/fileList.pug",e=e+"Show more files...</a></li>"),e=e+"</ul>"}).call(this,"AccessType"in s?s.AccessType:typeof AccessType<"u"?AccessType:void 0,"files"in s?s.files:typeof files<"u"?files:void 0,"formatSize"in s?s.formatSize:typeof formatSize<"u"?formatSize:void 0,"hasMore"in s?s.hasMore:typeof hasMore<"u"?hasMore:void 0,"parentItem"in s?s.parentItem:typeof parentItem<"u"?parentItem:void 0)}catch(o){mf(o,r,i)}return e}var vf=Xe.extend({events:{"click a.g-show-more-files":function(){this.collection.fetchNextPage()},"click a.g-show-info":function(t){var e=ke(t.currentTarget).attr("file-cid");new ff({el:ke("#g-dialog-container"),model:this.collection.get(e),parentItem:this.parentItem,parentView:this}).render()},"click a.g-update-contents":function(t){var e=ke(t.currentTarget).parent().attr("file-cid");this.uploadDialog(e)},"click a.g-update-info":function(t){var e=ke(t.currentTarget).parent().attr("file-cid");this.editFileDialog(e)},"click a.g-delete-file":function(t){var e=ke(t.currentTarget).parent().attr("file-cid"),u=this.collection.get(e);n0({text:"Are you sure you want to delete the file <b>"+u.escape("name")+"</b>?",yesText:"Delete",escapedHtml:!0,confirmCallback:()=>{u.once("g:deleted",function(){He.trigger("g:alert",{icon:"ok",type:"success",text:"File deleted.",timeout:4e3}),this.render()},this).once("g:error",function(){He.trigger("g:alert",{icon:"cancel",text:"Failed to delete file.",type:"danger",timeout:4e3})}).destroy()}})}},initialize:function(t){this.upload=t.upload,this.fileEdit=t.fileEdit,this.checked=[],this.collection=new bl,this.collection.altUrl="item/"+(t.itemId||t.item.get("_id"))+"/files",this.collection.append=!0,this.collection.on("g:changed",function(){this.render(),this.trigger("g:changed")},this).fetch(),this.parentItem=t.item},editFileDialog:function(t){this.editFileWidget=new gf({el:ke("#g-dialog-container"),file:this.collection.get(t),parentView:this}).off("g:saved",null,this).on("g:saved",function(){this.render()},this),this.editFileWidget.render()},uploadDialog:function(t){new jo({el:ke("#g-dialog-container"),title:"Replace file contents",parent:this.collection.get(t),parentType:"file",parentView:this}).on("g:uploadFinished",function(){He.trigger("g:alert",{icon:"ok",text:"File contents updated.",type:"success",timeout:4e3})},this).render()},render:function(){return this.checked=[],this.$el.html(ok({files:this.collection.toArray(),hasMore:this.collection.hasNextPage(),AccessType:nt,formatSize:Zt,parentItem:this.parentItem})),this.fileEdit?(this.editFileDialog(this.fileEdit),this.fileEdit=!1):this.upload&&(this.uploadDialog(this.upload),this.upload=!1),this},insertFile:function(t){this.collection.add(t),this.render(),this.trigger("g:changed")}});function hn(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Bi(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Bi(t){var e=""+t,u=ak.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var ak=/["&<>]/;function bf(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void bf(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function ck(t){var e="",u,r,i;try{var s=t||{};(function(o){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+'<ol class="breadcrumb">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",function(){var f=o;if(typeof f.length=="number")for(var n=0,h=f.length;n<h;n++){var g=f[n];i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+"<li>",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+"<a"+(' class="g-item-breadcrumb-link"'+hn("data-id",g.object._id,!0,!1)+hn("data-type",g.type,!0,!1))+">",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",g.type==="user"?(i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+'<i class="icon-user"></i>',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+Bi((u=g.object.login)==null?"":u)):g.type==="collection"?(i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+'<i class="icon-sitemap"></i>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+Bi((u=g.object.name)==null?"":u)):(i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+Bi((u=g.object.name)==null?"":u)),e=e+"</a></li>"}else{var h=0;for(var n in f){h++;var g=f[n];i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+"<li>",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+"<a"+(' class="g-item-breadcrumb-link"'+hn("data-id",g.object._id,!0,!1)+hn("data-type",g.type,!0,!1))+">",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",g.type==="user"?(i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+'<i class="icon-user"></i>',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+Bi((u=g.object.login)==null?"":u)):g.type==="collection"?(i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+'<i class="icon-sitemap"></i>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+Bi((u=g.object.name)==null?"":u)):(i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+Bi((u=g.object.name)==null?"":u)),e=e+"</a></li>"}}}.call(this),i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+'<div class="pull-right">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+'<a class="g-hierarchy-level-up" title="Go to parent folder">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/itemBreadcrumb.pug",e=e+'<i class="icon-level-up"></i></a></div></ol>'}).call(this,"parentChain"in s?s.parentChain:typeof parentChain<"u"?parentChain:void 0)}catch(o){bf(o,r,i)}return e}var wf=Xe.extend({events:{"click a.g-item-breadcrumb-link":function(t){var e=ke(t.currentTarget);tt.navigate(e.data("type")+"/"+e.data("id"),{trigger:!0})},"click a.g-hierarchy-level-up":function(){var t=this.parentChain.pop().object;tt.navigate("folder/"+t._id,{trigger:!0})}},initialize:function(t){this.parentChain=t.parentChain,this.render()},render:function(){return this.$el.html(ck({parentChain:this.parentChain})),this}});function lk(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=ei(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function ei(t){var e=""+t,u=dk.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var dk=/["&<>]/;function yf(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void yf(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Fk(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h,g,d,l){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-breadcrumb-container"></div>',i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-header">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="pull-right">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",n>=o.WRITE&&(i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<button class="g-upload-into-item btn btn-sm btn-success" title="Upload files into item">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<i class="icon-upload"></i></button>'),i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="btn-group">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<button class="g-item-actions-button btn btn-sm btn-default dropdown-toggle" data-toggle="dropdown" title="Item actions">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<i class="icon-doc-text-inv"></i>',i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+" Actions",i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<i class="icon-down-dir"></i></button>',i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<ul class="g-item-actions-menu dropdown-menu pull-right" role="menu">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<li role="presentation">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+"<a"+(' class="g-download-item" role="menuitem"'+lk("href",d.downloadUrl(),!0,!1))+">",i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<i class="icon-download"></i>',i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+"Download item</a></li>",i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",n>=o.WRITE&&(i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<li class="divider" role="presentation"></li>',i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<li role="presentation">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<a class="g-edit-item" role="menuitem">',i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<i class="icon-edit"></i>',i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+"Edit item</a></li>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<li class="divider" role="presentation"></li>',i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<li role="presentation">',i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<a class="g-delete-item" role="menuitem">',i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<i class="icon-trash"></i>',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+"Delete item</a></li>"),e=e+"</ul></div></div>",i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-name g-body-title">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+ei((u=d.name())==null?"":u)+"</div></div>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-description">',i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+((u=l(d.get("description")))==null?"":u)+"</div>",i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-info">',i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-info-header">',i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<i class="icon-info"></i>',i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+"Info</div>",i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-size g-info-list-entry">',i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<i class="icon-hdd"></i>',i=41,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",d.get("size")<1024?(i=42,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+ei((u=d.get("size"))==null?"":u),i=42,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+" bytes"):(i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+ei((u=g(d.get("size")))==null?"":u),i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+" (",i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+ei((u=d.get("size"))==null?"":u),i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+" bytes)"),e=e+"</div>",i=45,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-created g-info-list-entry">',i=46,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<i class="icon-clock"></i>',i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+"Created on ",i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+ei((u=h(d.get("created"),f))==null?"":u)+"</div>",i=48,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-updated g-info-list-entry">',i=49,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<i class="icon-clock"></i>',i=50,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+"Updated on ",i=50,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+ei((u=h(d.get("updated"),f))==null?"":u)+"</div>",i=51,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-id g-info-list-entry">',i=52,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<i class="icon-share"></i>',i=53,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+"Unique ID: ",i=53,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+ei((u=d.id)==null?"":u)+"</div></div>",i=55,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-metadata"></div>',i=57,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-files">',i=58,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-files-header">',i=59,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<i class="icon-docs"></i>',i=60,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+" Files &amp; links</div>",i=61,r="/home/circleci/project/girder/girder/web/src/templates/body/itemPage.pug",e=e+'<div class="g-item-files-container"></div></div>'}).call(this,"AccessType"in s?s.AccessType:typeof AccessType<"u"?AccessType:void 0,"DATE_SECOND"in s?s.DATE_SECOND:typeof DATE_SECOND<"u"?DATE_SECOND:void 0,"accessLevel"in s?s.accessLevel:typeof accessLevel<"u"?accessLevel:void 0,"formatDate"in s?s.formatDate:typeof formatDate<"u"?formatDate:void 0,"formatSize"in s?s.formatSize:typeof formatSize<"u"?formatSize:void 0,"item"in s?s.item:typeof item<"u"?item:void 0,"renderMarkdown"in s?s.renderMarkdown:typeof renderMarkdown<"u"?renderMarkdown:void 0)}catch(o){yf(o,r,i)}return e}var Dl=Xe.extend({events:{"click .g-edit-item":"editItem","click .g-delete-item":"deleteItem","click .g-upload-into-item":"uploadIntoItem"},initialize:function(t){x0("fetch"),this.edit=t.edit||!1,this.fileEdit=t.fileEdit||!1,this.upload=t.upload||!1,t.item?(this.model=t.item,this.render()):console.error("Implement fetch then render item")},uploadIntoItem:function(){new jo({el:ke("#g-dialog-container"),parent:this.model,parentType:"item",parentView:this}).on("g:uploadFinished",function(){F0("upload"),this.upload=!1,He.trigger("g:alert",{icon:"ok",text:"Files added.",type:"success",timeout:4e3}),this.fileListWidget.collection.fetch(null,!0)},this).render()},editItem:function(){var t=ke("#g-dialog-container");this.editItemWidget||(this.editItemWidget=new El({el:t,item:this.model,parentView:this}).off("g:saved").on("g:saved",function(){this.render()},this)),this.editItemWidget.render()},deleteItem:function(){var t=this.model.get("folderId"),e=this.model.get("baseParentType")+"/"+this.model.get("baseParentId")+"/folder/"+t;n0({text:"Are you sure you want to delete <b>"+this.model.escape("name")+"</b>?",yesText:"Delete",escapedHtml:!0,confirmCallback:()=>{this.model.on("g:deleted",()=>{tt.navigate(e,{trigger:!0})}).off("g:error").on("g:error",()=>{this.render(),He.trigger("g:alert",{icon:"cancel",text:"Failed to delete item.",type:"danger",timeout:4e3})},this).destroy()}})},render:function(){return this.model.getAccessLevel(t=>{this.accessLevel=t,this.$el.html(Fk({item:this.model,accessLevel:t,AccessType:nt,formatSize:Zt,formatDate:pi,renderMarkdown:fi,DATE_SECOND:Iu})),this.fileListWidget=new vf({el:this.$(".g-item-files-container"),item:this.model,fileEdit:this.fileEdit,upload:this.upload,parentView:this}),this.fileListWidget.once("g:changed",function(){this.trigger("g:rendered")},this),this.fileEdit=!1,this.upload=!1,this.metadataWidget=new $n({el:this.$(".g-item-metadata"),item:this.model,accessLevel:t,parentView:this}),this.model.getRootPath(e=>{this.breadcrumbWidget=new wf({el:this.$(".g-item-breadcrumb-container"),parentChain:e,parentView:this})}),this.edit&&(this.editItem(),this.edit=!1)}),this}},{fetchAndInit:function(t,e){var u=new iu;u.set({_id:t}).on("g:fetched",function(){He.trigger("g:navigateTo",Dl,xe.extend({item:u},e||{}))},this).fetch()}});function lu(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Br(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Br(t){var e=""+t,u=hk.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var hk=/["&<>]/;function Cf(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Cf(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function gk(t){var e="",u,r,i;try{var s=t||{};(function(o){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+'<div class="g-body-title">',i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+"Plugins</div>",i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+'<div class="g-plugin-list-container">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",function(){var f=o;if(typeof f.length=="number")for(var n=0,h=f.length;n<h;n++){var g=f[n];i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug";var d=g.value.version?g.value.version.indexOf("0.")===0:!0;i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+"<div"+(' class="g-plugin-list-item"'+lu("data-name",g.key,!0,!1))+">",i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+'<div class="g-plugin-name">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",g.value.url?(i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+"<a"+(lu("href",g.value.url,!0,!1)+' target="_blank"')+">",i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+Br((u=g.value.name)==null?"":u)+"</a>"):(i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+"<span>",i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+Br((u=g.value.name)==null?"":u)+"</span>"),i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",g.value.version&&(i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+'<span class="g-plugin-version">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+"Version ",i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+Br((u=g.value.version)==null?"":u)+"</span>"),i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",d&&(i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+'<span class="g-plugin-list-item-notice g-plugin-list-item-experimental-notice" title="WARNING: this plugin is an alpha version and is subject to breaking changes; use at your own risk.">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+"Experimental</span>"),i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",g.value.configRoute&&(i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+"<a"+(' class="g-plugin-config-link"'+lu("g-route",g.value.configRoute,!0,!1)+' title="Configure Plugin"')+">",i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+'<i class="icon-cog"></i></a>'),e=e+"</div>",i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+'<div class="g-plugin-description">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+Br((u=g.value.description)==null?"":u)+"</div></div>"}else{var h=0;for(var n in f){h++;var g=f[n];i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug";var d=g.value.version?g.value.version.indexOf("0.")===0:!0;i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+"<div"+(' class="g-plugin-list-item"'+lu("data-name",g.key,!0,!1))+">",i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+'<div class="g-plugin-name">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",g.value.url?(i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+"<a"+(lu("href",g.value.url,!0,!1)+' target="_blank"')+">",i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+Br((u=g.value.name)==null?"":u)+"</a>"):(i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+"<span>",i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+Br((u=g.value.name)==null?"":u)+"</span>"),i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",g.value.version&&(i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+'<span class="g-plugin-version">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+"Version ",i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+Br((u=g.value.version)==null?"":u)+"</span>"),i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",d&&(i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+'<span class="g-plugin-list-item-notice g-plugin-list-item-experimental-notice" title="WARNING: this plugin is an alpha version and is subject to breaking changes; use at your own risk.">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+"Experimental</span>"),i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",g.value.configRoute&&(i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+"<a"+(' class="g-plugin-config-link"'+lu("g-route",g.value.configRoute,!0,!1)+' title="Configure Plugin"')+">",i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+'<i class="icon-cog"></i></a>'),e=e+"</div>",i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+'<div class="g-plugin-description">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/plugins.pug",e=e+Br((u=g.value.description)==null?"":u)+"</div></div>"}}}.call(this),e=e+"</div>"}).call(this,"allPlugins"in s?s.allPlugins:typeof allPlugins<"u"?allPlugins:void 0)}catch(o){Cf(o,r,i)}return e}var Ef=Xe.extend({events:{"click a.g-plugin-config-link":function(t){var e=ke(t.currentTarget).attr("g-route");tt.navigate(e,{trigger:!0})}},initialize:function(t){x0("fetch"),t.all?(this.allPlugins=t.all,this.render()):ut({url:"system/plugins",method:"GET"}).done(e=>{this.allPlugins=e.all,this.render()}).fail(()=>{tt.navigate("/",{trigger:!0})})},render:function(){return xe.each(this.allPlugins,function(t,e){t.configRoute=Eg(e)},this),this.$el.html(gk({allPlugins:this._sortPlugins(this.allPlugins)})),this},_sortPlugins:function(t){var e=xe.map(t,function(u,r){return{key:r,value:u}});return e.sort(function(u,r){return u.value.name.localeCompare(r.value.name)}),e}}),pk=Vi.extend({resourceName:"system/setting/collection_creation_policy",fetchAccess:function(){return ut({url:`${this.resourceName}/access`,method:"GET"}).done(t=>(this.set("access",t),this.trigger("g:accessFetched"),t)).fail(t=>{this.trigger("g:error",t)})}});function jt(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Af(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Af(t){var e=""+t,u=fk.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var fk=/["&<>]/;function xf(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void xf(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function mk(t){var e="",u,r,i;try{var s=t||{};(function(o,f){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="g-body-title">',i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"System configuration</div>",i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<form class="g-settings-form" role="form">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="g-settings-form-container">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<h4>",i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Instance Branding</h4>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-brand-name">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Brand Name</label>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-brand-name" type="text"'+jt("value",f["core.brand_name"]||"",!0,!1)+' title="The brand name of the application."')+"/></div>",i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-contact-email-address">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Contact email address</label>",i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-contact-email-address" type="text"'+jt("value",f["core.contact_email_address"]||"",!0,!1)+' title="The contact email address for users to obtain support with this instance."')+"/></div>",i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-banner-color">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Banner Color</label>",i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div id="g-core-banner-color-container">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-banner-color" type="color"'+jt("value",f["core.banner_color"],!0,!1)+' title="The banner color of the application."')+"/>",i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<button class="form-control input-sm" id="g-core-banner-default-color" type="button" title="Default color">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"default</button></div></div></div>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-privacy-notice">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Privacy Notice Link</label>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-privacy-notice" type="text"'+jt("value",f["core.privacy_notice"]||"",!0,!1)+' title="The privacy notice link."')+"/></div>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-cookie-lifetime">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Cookie duration (days)</label>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-cookie-lifetime" type="text"'+jt("value",f["core.cookie_lifetime"]||"",!0,!1)+' title="How long users will stay logged in."')+"/></div>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="g-settings-form-container">',i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<h4>",i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Administrative Policy</h4>",i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-registration-policy">',i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Registration policy</label>",i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<select class="form-control input-sm" id="g-core-registration-policy">',i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="open"'+jt("selected",f["core.registration_policy"]==="open",!0,!1))+">",i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Open registration</option>",i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="closed"'+jt("selected",f["core.registration_policy"]==="closed",!0,!1))+">",i=41,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Closed registration</option>",i=42,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="approve"'+jt("selected",f["core.registration_policy"]==="approve",!0,!1))+">",i=43,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Admin approval required</option></select></div>",i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=45,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-email-verification">',i=45,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Email verification</label>",i=46,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<select class="form-control input-sm" id="g-core-email-verification">',i=47,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="required"'+jt("selected",f["core.email_verification"]==="required",!0,!1))+">",i=48,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Required</option>",i=49,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="optional"'+jt("selected",f["core.email_verification"]==="optional",!0,!1))+">",i=50,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Optional</option>",i=51,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="disabled"'+jt("selected",f["core.email_verification"]==="disabled",!0,!1))+">",i=52,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Disabled</option></select></div>",i=53,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=54,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-add-to-group-policy">',i=54,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Allow members to be directly added to groups</label>",i=55,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<select class="form-control input-sm" id="g-core-add-to-group-policy">',i=56,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="never"'+jt("selected",f["core.add_to_group_policy"]==="never",!0,!1))+">",i=58,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"No, members must be invited and accept invitations</option>",i=59,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="noadmin"'+jt("selected",f["core.add_to_group_policy"]==="noadmin",!0,!1))+">",i=61,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"No, except for group administrators when enabled per group</option>",i=62,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="nomod"'+jt("selected",f["core.add_to_group_policy"]==="nomod",!0,!1))+">",i=64,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"No, except for group administrators and moderators when enabled per group</option>",i=65,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="yesadmin"'+jt("selected",f["core.add_to_group_policy"]==="yesadmin",!0,!1))+">",i=67,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Yes, by group administrators unless disabled per group</option>",i=68,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="yesmod"'+jt("selected",f["core.add_to_group_policy"]==="yesmod",!0,!1))+">",i=70,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Yes, by group administrators and moderators unless disabled per group</option></select></div>",i=71,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="g-collection-create-policy-container">',i=72,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<label>",i=72,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Collection creation policy</label>",i=73,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<p>",i=74,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Allow additional users and groups to create collections.</p>",i=75,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<input class="g-setting-switch" type="checkbox" checked="checked" data-size="mini" data-on-color="primary"/>',i=77,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="access-widget-container"></div>',i=78,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<textarea class="hide" id="g-core-collection-create-policy">',i=79,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+Af((u=o.stringify(f["core.collection_create_policy"]))==null?"":u)+"</textarea></div>",i=80,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=81,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-user-default-folders">',i=81,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Create default folders for new users</label>",i=82,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<select class="form-control input-sm" id="g-core-user-default-folders">',i=83,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="none"'+jt("selected",f["core.user_default_folders"]==="none",!0,!1))+">",i=84,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"No</option>",i=85,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="public_private"'+jt("selected",f["core.user_default_folders"]==="public_private",!0,!1))+">",i=86,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'Yes, "Public" and "Private"</option></select></div>',i=87,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=88,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="checkbox">',i=89,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-api-keys">',i=90,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' id="g-core-api-keys" type="checkbox"'+jt("checked",f["core.api_keys"],!0,!1))+"/>",i=91,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Enable API keys</label></div></div>",i=92,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=93,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="checkbox">',i=94,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-enable-password-login">',i=95,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' id="g-core-enable-password-login" type="checkbox"'+jt("checked",f["core.enable_password_login"],!0,!1))+"/>",i=97,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Enable password login</label></div></div></div>",i=98,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="g-settings-form-container">',i=99,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<h4>",i=99,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Email Creation</h4>",i=100,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=101,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-email-from-address">',i=101,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Email from address</label>",i=102,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-email-from-address" type="text"'+jt("value",f["core.email_from_address"]||"",!0,!1)+' title="The email address the system will use when sending emails."')+"/></div>",i=105,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=106,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-email-host">',i=106,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Email host</label>",i=107,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-email-host" type="text"'+jt("value",f["core.email_host"]||"",!0,!1)+' title="The host email server that is shown as a link in the footer of emails."')+"/></div></div>",i=110,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="g-settings-form-container">',i=111,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<h4>",i=111,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Email Delivery</h4>",i=112,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=113,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-smtp-host">',i=113,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"SMTP host</label>",i=114,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-smtp-host" type="text"'+jt("value",f["core.smtp_host"]||"",!0,!1)+' title="The hostname of the SMTP server used to send emails."')+"/></div>",i=117,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=118,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-smtp-port">',i=118,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"SMTP port</label>",i=119,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-smtp-port" type="text"'+jt("value",f["core.smtp.port"]||"",!0,!1)+' title="The port number of the SMTP server used to send emails."')+"/></div>",i=122,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=123,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-smtp-encryption">',i=123,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"SMTP encryption</label>",i=124,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<select class="form-control input-sm" id="g-core-smtp-encryption">',i=125,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="none"'+jt("selected",f["core.smtp.encryption"]==="none",!0,!1))+">",i=126,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"None</option>",i=127,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="starttls"'+jt("selected",f["core.smtp.encryption"]==="starttls",!0,!1))+">",i=128,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Use STARTTLS</option>",i=129,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<option"+(' value="ssl"'+jt("selected",f["core.smtp.encryption"]==="ssl",!0,!1))+">",i=130,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Use SSL/TLS</option></select></div>",i=131,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=132,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-smtp-username">',i=132,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"SMTP username</label>",i=133,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-smtp-username" type="text"'+jt("value",f["core.smtp.username"]||"",!0,!1)+' title="The username, if any, used to authenticate to the SMTP server used to send emails."')+"/></div>",i=136,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=137,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-smtp-password">',i=137,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"SMTP password</label>",i=138,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-smtp-password" type="password"'+jt("value",f["core.smtp.password"]||"",!0,!1)+' title="The password, if any, used to authenticate to the SMTP server used to send emails."')+"/></div></div>",i=142,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="panel-group" id="g-configuration-accordion">',i=143,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="panel panel-default">',i=144,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="panel-heading" data-toggle="collapse" data-parent="#g-configuration-accordion" data-target="#g-advanced-settings-tab">',i=147,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="panel-title">',i=148,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<a>",i=149,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<b>",i=149,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Advanced Settings</b></a></div></div>",i=150,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="panel-collapse collapse" id="g-advanced-settings-tab">',i=151,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="panel-body">',i=152,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<p>",i=152,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"These settings should only be changed if you are certain of what you are doing.</p>",i=153,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=154,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-server-root">',i=154,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Server root URL</label>",i=155,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-server-root" type="text"'+jt("value",f["core.server_root"]||"",!0,!1)+' placeholder="Detect automatically"')+"/></div>",i=158,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=159,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-upload-minimum-chunk-size">',i=159,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Upload minimum chunk size (bytes)</label>",i=160,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<br/>",i=161,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<span>",i=161,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"This applies to Filesystem assetstores.</span>",i=162,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-upload-minimum-chunk-size" type="text"'+jt("value",f["core.upload_minimum_chunk_size"]||"",!0,!1)+' title="For large files, the minimum size of all but the last chunk."')+"/></div>",i=165,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=166,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<label>",i=166,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Server Notification Stream</label>",i=167,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<br/>",i=168,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<span>",i=168,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Disabling this may improve server performance with many concurrent web client users.</span>",i=169,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="checkbox">',i=170,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-enable-notification-stream">',i=171,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' id="g-core-enable-notification-stream" type="checkbox"'+jt("checked",f["core.enable_notification_stream"],!0,!1))+"/>",i=173,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"Enabled</label></div></div>",i=174,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="g-settings-form-container">',i=175,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<h4>",i=175,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"CORS</h4>",i=176,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<p>",i=177,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"CORS (Cross-origin resource sharing) allows access from other websites.",i=178,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+`
`,i=178,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"These settings are described in",i=179,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+`
`,i=179,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"detail ",i=179,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<a href="http://girder.readthedocs.org/en/latest/security.html#cors-cross-origin-resource-sharing" target="_blank">',i=179,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"here</a>",i=179,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+".</p>",i=180,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=181,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-cors-allow-origin">',i=181,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"CORS Allowed Origins</label>",i=182,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-cors-allow-origin" type="text"'+jt("value",f["core.cors.allow_origin"]||"",!0,!1)+' title="A comma-separated list of allowed base URLs that can make cross-site requests. This may include *."')+"/></div>",i=185,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=186,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-cors-allow-methods">',i=186,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"CORS Allowed Methods</label>",i=187,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-cors-allow-methods" type="text"'+jt("value",f["core.cors.allow_methods"]||"",!0,!1)+' placeholder="Default: allow all methods" title="A comma-separated list of allowed methods"')+"/></div>",i=191,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=192,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<label for="g-core-cors-allow-headers">',i=192,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"CORS Allowed Headers</label>",i=193,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<input"+(' class="form-control input-sm" id="g-core-cors-allow-headers" type="text"'+jt("value",f["core.cors.allow_headers"]||"",!0,!1)+' title="A comma-separated list of allowed headers."')+"/></div></div></div></div></div></div>",i=196,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"<p></p>",i=197,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="form-group">',i=198,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<button class="g-submit-settings btn btn-default btn-sm">',i=198,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"",i=198,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<i class="icon-ok"></i>',i=198,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+"  Save</button></div>",i=199,r="/home/circleci/project/girder/girder/web/src/templates/body/systemConfiguration.pug",e=e+'<div class="g-validation-failed-message" id="g-settings-error-message"></div></form>'}).call(this,"JSON"in s?s.JSON:typeof JSON<"u"?JSON:void 0,"settings"in s?s.settings:typeof settings<"u"?settings:void 0)}catch(o){xf(o,r,i)}return e}/**
  * bootstrap-switch - Turn checkboxes and radio buttons into toggle switches.
  *
  * @version v3.3.5
  * @homepage https://bttstrp.github.io/bootstrap-switch
  * @author Mattia Larentis <mattia@larentis.eu> (http://larentis.eu)
  * @license MIT
  */(function(t){(function(e,u){u(cc())})(yr,function(e){var u=r(e);function r(w){return w&&w.__esModule?w:{default:w}}var i=Object.assign||function(w){for(var A=1;A<arguments.length;A++){var M=arguments[A];for(var x in M)Object.prototype.hasOwnProperty.call(M,x)&&(w[x]=M[x])}return w};function s(w,A){if(!(w instanceof A))throw new TypeError("Cannot call a class as a function")}var o=function(){function w(A,M){for(var x=0;x<M.length;x++){var R=M[x];R.enumerable=R.enumerable||!1,R.configurable=!0,"value"in R&&(R.writable=!0),Object.defineProperty(A,R.key,R)}}return function(A,M,x){return M&&w(A.prototype,M),x&&w(A,x),A}}(),f=u.default||window.jQuery||window.$;function n(w,A){var M=w.state,x=w.size,R=w.disabled,N=w.readonly,j=w.indeterminate,B=w.inverse;return[M?"on":"off",x,R?"disabled":void 0,N?"readonly":void 0,j?"indeterminate":void 0,B?"inverse":void 0,A?"id-"+A:void 0].filter(function(q){return q==null})}function h(){return{state:this.$element.is(":checked"),size:this.$element.data("size"),animate:this.$element.data("animate"),disabled:this.$element.is(":disabled"),readonly:this.$element.is("[readonly]"),indeterminate:this.$element.data("indeterminate"),inverse:this.$element.data("inverse"),radioAllOff:this.$element.data("radio-all-off"),onColor:this.$element.data("on-color"),offColor:this.$element.data("off-color"),onText:this.$element.data("on-text"),offText:this.$element.data("off-text"),labelText:this.$element.data("label-text"),handleWidth:this.$element.data("handle-width"),labelWidth:this.$element.data("label-width"),baseClass:this.$element.data("base-class"),wrapperClass:this.$element.data("wrapper-class")}}function g(){var w=this,A=this.$on.add(this.$off).add(this.$label).css("width",""),M=this.options.handleWidth==="auto"?Math.round(Math.max(this.$on.width(),this.$off.width())):this.options.handleWidth;return A.width(M),this.$label.width(function(x,R){return w.options.labelWidth!=="auto"?w.options.labelWidth:R<M?M:R}),this.privateHandleWidth=this.$on.outerWidth(),this.privateLabelWidth=this.$label.outerWidth(),this.$container.width(this.privateHandleWidth*2+this.privateLabelWidth),this.$wrapper.width(this.privateHandleWidth+this.privateLabelWidth)}function d(){var w=this,A=arguments.length>0&&arguments[0]!==void 0?arguments[0]:this.ope;this.$container.css("margin-left",function(){var M=[0,"-"+w.privateHandleWidth+"px"];return w.options.indeterminate?"-"+w.privateHandleWidth/2+"px":A?w.options.inverse?M[1]:M[0]:w.options.inverse?M[0]:M[1]})}function l(w){return this.options.baseClass+"-"+w}function c(){var w=this,A=function(){w.setPrevOptions(),g.call(w),d.call(w),setTimeout(function(){return w.options.animate&&w.$wrapper.addClass(l.call(w,"animate"))},50)};if(this.$wrapper.is(":visible")){A();return}var M=window.setInterval(function(){return w.$wrapper.is(":visible")&&(A()||!0)&&window.clearInterval(M)},50)}function a(){var w=this;return this.$element.on({"setPreviousOptions.bootstrapSwitch":function(){return w.setPrevOptions()},"previousState.bootstrapSwitch":function(){w.options=w.prevOptions,w.options.indeterminate&&w.$wrapper.addClass(l.call(w,"indeterminate")),w.$element.prop("checked",w.options.state).trigger("change.bootstrapSwitch",!0)},"change.bootstrapSwitch":function(M,x){M.preventDefault(),M.stopImmediatePropagation();var R=w.$element.is(":checked");d.call(w,R),R!==w.options.state&&(w.options.state=R,w.$wrapper.toggleClass(l.call(w,"off")).toggleClass(l.call(w,"on")),x||(w.$element.is(":radio")&&f('[name="'+w.$element.attr("name")+'"]').not(w.$element).prop("checked",!1).trigger("change.bootstrapSwitch",!0),w.$element.trigger("switchChange.bootstrapSwitch",[R])))},"focus.bootstrapSwitch":function(M){M.preventDefault(),w.$wrapper.addClass(l.call(w,"focused"))},"blur.bootstrapSwitch":function(M){M.preventDefault(),w.$wrapper.removeClass(l.call(w,"focused"))},"keydown.bootstrapSwitch":function(M){!M.which||w.options.disabled||w.options.readonly||(M.which===37||M.which===39)&&(M.preventDefault(),M.stopImmediatePropagation(),w.state(M.which===39))}})}function F(){var w=this;return this.$on.on("click.bootstrapSwitch",function(A){return A.preventDefault(),A.stopPropagation(),w.state(!1),w.$element.trigger("focus.bootstrapSwitch")}),this.$off.on("click.bootstrapSwitch",function(A){return A.preventDefault(),A.stopPropagation(),w.state(!0),w.$element.trigger("focus.bootstrapSwitch")})}function p(){var w=this,A=void 0,M=void 0,x={click:function(N){N.stopPropagation()},"mousedown.bootstrapSwitch touchstart.bootstrapSwitch":function(N){A||w.options.disabled||w.options.readonly||(N.preventDefault(),N.stopPropagation(),A=(N.pageX||N.originalEvent.touches[0].pageX)-parseInt(w.$container.css("margin-left"),10),w.options.animate&&w.$wrapper.removeClass(l.call(w,"animate")),w.$element.trigger("focus.bootstrapSwitch"))},"mousemove.bootstrapSwitch touchmove.bootstrapSwitch":function(N){if(A!=null){var j=(N.pageX||N.originalEvent.touches[0].pageX)-A;N.preventDefault(),!(j<-w.privateHandleWidth||j>0)&&(M=j,w.$container.css("margin-left",M+"px"))}},"mouseup.bootstrapSwitch touchend.bootstrapSwitch":function(N){if(A){if(N.preventDefault(),w.options.animate&&w.$wrapper.addClass(l.call(w,"animate")),M){var j=M>-(w.privateHandleWidth/2);M=!1,w.state(w.options.inverse?!j:j)}else w.state(!w.options.state);A=!1}},"mouseleave.bootstrapSwitch":function(){w.$label.trigger("mouseup.bootstrapSwitch")}};this.$label.on(x)}function m(){var w=this,A=this.$element.closest("label");A.on("click",function(M){M.preventDefault(),M.stopImmediatePropagation(),M.target===A[0]&&w.toggleState()})}function b(){function w(){return f(this).data("bootstrap-switch")}function A(){return f(this).bootstrapSwitch("state",this.checked)}var M=this.$element.closest("form");M.data("bootstrap-switch")||M.on("reset.bootstrapSwitch",function(){window.setTimeout(function(){M.find("input").filter(w).each(A)},1)}).data("bootstrap-switch",!0)}function C(w){var A=this;return f.isArray(w)?w.map(function(M){return l.call(A,M)}):[l.call(this,w)]}var k=function(){function w(A){var M=this,x=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};s(this,w),this.$element=f(A),this.options=f.extend({},f.fn.bootstrapSwitch.defaults,h.call(this),x),this.prevOptions={},this.$wrapper=f("<div>",{class:function(){return n(M.options,M.$element.attr("id")).map(function(N){return l.call(M,N)}).concat([M.options.baseClass],C.call(M,M.options.wrapperClass)).join(" ")}}),this.$container=f("<div>",{class:l.call(this,"container")}),this.$on=f("<span>",{html:this.options.onText,class:l.call(this,"handle-on")+" "+l.call(this,this.options.onColor)}),this.$off=f("<span>",{html:this.options.offText,class:l.call(this,"handle-off")+" "+l.call(this,this.options.offColor)}),this.$label=f("<span>",{html:this.options.labelText,class:l.call(this,"label")}),this.$element.on("init.bootstrapSwitch",function(){return M.options.onInit(A)}),this.$element.on("switchChange.bootstrapSwitch",function(){for(var R=arguments.length,N=Array(R),j=0;j<R;j++)N[j]=arguments[j];var B=M.options.onSwitchChange.apply(A,N);B===!1&&(M.$element.is(":radio")?f('[name="'+M.$element.attr("name")+'"]').trigger("previousState.bootstrapSwitch",!0):M.$element.trigger("previousState.bootstrapSwitch",!0))}),this.$container=this.$element.wrap(this.$container).parent(),this.$wrapper=this.$container.wrap(this.$wrapper).parent(),this.$element.before(this.options.inverse?this.$off:this.$on).before(this.$label).before(this.options.inverse?this.$on:this.$off),this.options.indeterminate&&this.$element.prop("indeterminate",!0),c.call(this),a.call(this),F.call(this),p.call(this),b.call(this),m.call(this),this.$element.trigger("init.bootstrapSwitch",this.options.state)}return o(w,[{key:"setPrevOptions",value:function(){this.prevOptions=i({},this.options)}},{key:"state",value:function(M,x){return typeof M>"u"?this.options.state:this.options.disabled||this.options.readonly||this.options.state&&!this.options.radioAllOff&&this.$element.is(":radio")?this.$element:(this.$element.is(":radio")?f('[name="'+this.$element.attr("name")+'"]').trigger("setPreviousOptions.bootstrapSwitch"):this.$element.trigger("setPreviousOptions.bootstrapSwitch"),this.options.indeterminate&&this.indeterminate(!1),this.$element.prop("checked",!!M).trigger("change.bootstrapSwitch",x),this.$element)}},{key:"toggleState",value:function(M){return this.options.disabled||this.options.readonly?this.$element:this.options.indeterminate?(this.indeterminate(!1),this.state(!0)):this.$element.prop("checked",!this.options.state).trigger("change.bootstrapSwitch",M)}},{key:"size",value:function(M){return typeof M>"u"?this.options.size:(this.options.size!=null&&this.$wrapper.removeClass(l.call(this,this.options.size)),M&&this.$wrapper.addClass(l.call(this,M)),g.call(this),d.call(this),this.options.size=M,this.$element)}},{key:"animate",value:function(M){return typeof M>"u"?this.options.animate:this.options.animate===!!M?this.$element:this.toggleAnimate()}},{key:"toggleAnimate",value:function(){return this.options.animate=!this.options.animate,this.$wrapper.toggleClass(l.call(this,"animate")),this.$element}},{key:"disabled",value:function(M){return typeof M>"u"?this.options.disabled:this.options.disabled===!!M?this.$element:this.toggleDisabled()}},{key:"toggleDisabled",value:function(){return this.options.disabled=!this.options.disabled,this.$element.prop("disabled",this.options.disabled),this.$wrapper.toggleClass(l.call(this,"disabled")),this.$element}},{key:"readonly",value:function(M){return typeof M>"u"?this.options.readonly:this.options.readonly===!!M?this.$element:this.toggleReadonly()}},{key:"toggleReadonly",value:function(){return this.options.readonly=!this.options.readonly,this.$element.prop("readonly",this.options.readonly),this.$wrapper.toggleClass(l.call(this,"readonly")),this.$element}},{key:"indeterminate",value:function(M){return typeof M>"u"?this.options.indeterminate:this.options.indeterminate===!!M?this.$element:this.toggleIndeterminate()}},{key:"toggleIndeterminate",value:function(){return this.options.indeterminate=!this.options.indeterminate,this.$element.prop("indeterminate",this.options.indeterminate),this.$wrapper.toggleClass(l.call(this,"indeterminate")),d.call(this),this.$element}},{key:"inverse",value:function(M){return typeof M>"u"?this.options.inverse:this.options.inverse===!!M?this.$element:this.toggleInverse()}},{key:"toggleInverse",value:function(){this.$wrapper.toggleClass(l.call(this,"inverse"));var M=this.$on.clone(!0),x=this.$off.clone(!0);return this.$on.replaceWith(x),this.$off.replaceWith(M),this.$on=x,this.$off=M,this.options.inverse=!this.options.inverse,this.$element}},{key:"onColor",value:function(M){return typeof M>"u"?this.options.onColor:(this.options.onColor&&this.$on.removeClass(l.call(this,this.options.onColor)),this.$on.addClass(l.call(this,M)),this.options.onColor=M,this.$element)}},{key:"offColor",value:function(M){return typeof M>"u"?this.options.offColor:(this.options.offColor&&this.$off.removeClass(l.call(this,this.options.offColor)),this.$off.addClass(l.call(this,M)),this.options.offColor=M,this.$element)}},{key:"onText",value:function(M){return typeof M>"u"?this.options.onText:(this.$on.html(M),g.call(this),d.call(this),this.options.onText=M,this.$element)}},{key:"offText",value:function(M){return typeof M>"u"?this.options.offText:(this.$off.html(M),g.call(this),d.call(this),this.options.offText=M,this.$element)}},{key:"labelText",value:function(M){return typeof M>"u"?this.options.labelText:(this.$label.html(M),g.call(this),this.options.labelText=M,this.$element)}},{key:"handleWidth",value:function(M){return typeof M>"u"?this.options.handleWidth:(this.options.handleWidth=M,g.call(this),d.call(this),this.$element)}},{key:"labelWidth",value:function(M){return typeof M>"u"?this.options.labelWidth:(this.options.labelWidth=M,g.call(this),d.call(this),this.$element)}},{key:"baseClass",value:function(){return this.options.baseClass}},{key:"wrapperClass",value:function(M){if(typeof M>"u")return this.options.wrapperClass;var x=M||f.fn.bootstrapSwitch.defaults.wrapperClass;return this.$wrapper.removeClass(C.call(this,this.options.wrapperClass).join(" ")),this.$wrapper.addClass(C.call(this,x).join(" ")),this.options.wrapperClass=x,this.$element}},{key:"radioAllOff",value:function(M){if(typeof M>"u")return this.options.radioAllOff;var x=!!M;return this.options.radioAllOff===x?this.$element:(this.options.radioAllOff=x,this.$element)}},{key:"onInit",value:function(M){return typeof M>"u"?this.options.onInit:(this.options.onInit=M||f.fn.bootstrapSwitch.defaults.onInit,this.$element)}},{key:"onSwitchChange",value:function(M){return typeof M>"u"?this.options.onSwitchChange:(this.options.onSwitchChange=M||f.fn.bootstrapSwitch.defaults.onSwitchChange,this.$element)}},{key:"destroy",value:function(){var M=this.$element.closest("form");return M.length&&M.off("reset.bootstrapSwitch").removeData("bootstrap-switch"),this.$container.children().not(this.$element).remove(),this.$element.unwrap().unwrap().off(".bootstrapSwitch").removeData("bootstrap-switch"),this.$element}}]),w}();function T(w){for(var A=arguments.length,M=Array(A>1?A-1:0),x=1;x<A;x++)M[x-1]=arguments[x];function R(N,j){var B=f(j),q=B.data("bootstrap-switch"),U=q||new k(j,w);return q||B.data("bootstrap-switch",U),typeof w=="string"?U[w].apply(U,M):N}return Array.prototype.reduce.call(this,R,this)}f.fn.bootstrapSwitch=T,f.fn.bootstrapSwitch.Constructor=k,f.fn.bootstrapSwitch.defaults={state:!0,size:null,animate:!0,disabled:!1,readonly:!1,indeterminate:!1,inverse:!1,radioAllOff:!1,onColor:"primary",offColor:"default",onText:"ON",offText:"OFF",labelText:"&nbsp",handleWidth:"auto",labelWidth:"auto",baseClass:"bootstrap-switch",wrapperClass:"wrapper",onInit:function(){},onSwitchChange:function(){}}})})();var kf=Xe.extend({events:{"submit .g-settings-form":function(t){t.preventDefault(),this.$(".g-submit-settings").girderEnable(!1),this.$("#g-settings-error-message").empty(),this.$("#g-core-collection-create-policy").val(JSON.stringify(this._covertCollectionCreationPolicy()));var e=xe.map(this.settingsKeys,u=>{const r=this.$("#g-"+u.replace(/[_.]/g,"-"));return xe.contains(["core.api_keys","core.enable_password_login","core.enable_notification_stream"],u)?{key:u,value:r.is(":checked")}:{key:u,value:r.val()||null}});ut({method:"PUT",url:"system/setting",data:{list:JSON.stringify(e)},error:null}).done(()=>{this.$(".g-submit-settings").girderEnable(!0),He.trigger("g:alert",{icon:"ok",text:"Settings saved.",type:"success",timeout:4e3})}).fail(u=>{this.$(".g-submit-settings").girderEnable(!0),this.$("#g-settings-error-message").text(u.responseJSON.message)})},"click #g-core-banner-default-color":function(){this.$("#g-core-banner-color").val(this.defaults["core.banner_color"])}},initialize:function(){x0("fetch");var t=["core.api_keys","core.contact_email_address","core.brand_name","core.banner_color","core.privacy_notice","core.cookie_lifetime","core.enable_password_login","core.email_from_address","core.email_host","core.registration_policy","core.email_verification","core.server_root","core.smtp_host","core.smtp.port","core.smtp.encryption","core.smtp.username","core.smtp.password","core.upload_minimum_chunk_size","core.enable_notification_stream","core.cors.allow_origin","core.cors.allow_methods","core.cors.allow_headers","core.add_to_group_policy","core.collection_create_policy","core.user_default_folders"];this.settingsKeys=t,ut({url:"system/setting",method:"GET",data:{list:JSON.stringify(t)}}).done(e=>{this.settings=e,this.render()})},render:function(){this.$el.html(mk({settings:this.settings,JSON:window.JSON}));var t=this.settings["core.collection_create_policy"]?this.settings["core.collection_create_policy"].open:!1;return this.$(".g-setting-switch").bootstrapSwitch().bootstrapSwitch("state",t).off("switchChange.bootstrapSwitch").on("switchChange.bootstrapSwitch",(e,u)=>{u?this._renderCollectionCreationPolicyAccessWidget():(this.accessWidget.destroy(),this.accessWidget=null)}),t&&this._renderCollectionCreationPolicyAccessWidget(),this},_renderCollectionCreationPolicyAccessWidget:function(){var t=new pk;this.accessWidget=new Ao({el:this.$(".g-collection-create-policy-container .access-widget-container"),modelType:"collection_creation_policy",model:t,parentView:this,modal:!1,hideRecurseOption:!0,hideSaveButton:!0,hidePrivacyEditor:!0,hideAccessType:!0,noAccessFlag:!0})},_covertCollectionCreationPolicy:function(){var t=null;if(this.$(".g-setting-switch").bootstrapSwitch("state")){t={open:this.$(".g-setting-switch").bootstrapSwitch("state")};var e=this.accessWidget.getAccessList();xe.each(xe.keys(e),u=>{t[u]=xe.pluck(e[u],"id")})}else t=this.settings["core.collection_create_policy"],t.open=!1;return t}});function _i(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=ec(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function ec(t){var e=""+t,u=vk.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var vk=/["&<>]/;function jf(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void jf(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function bk(t){var e="",u,r,i;try{var s=t||{};(function(o,f){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<div class="modal-dialog">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<div class="modal-content">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<form class="modal-form" id="g-api-key-edit-form" role="form">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<div class="modal-header">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<button class="close" data-dismiss="modal" aria-hidden="true" type="button">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"&times;</button>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<h4 class="modal-title">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",o?(i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"Edit API key"):(i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"Create new API key"),e=e+"</h4></div>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<div class="modal-body">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<div class="form-group">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<label class="control-label" for="g-api-key-name">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"Name</label>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<input class="input-sm form-control" id="g-api-key-name" type="text" placeholder="Enter a name for this API key"/></div>',i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<div class="form-group">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<label class="control-label" for="g-api-key-token-duration">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"Token duration in days (optional)</label>",i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<input class="input-sm form-control" id="g-api-key-token-duration" placeholder="Enter number of days"/></div>',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<label class="control-label">',i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"Permission scope for this key</label>",i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<div class="g-scope-selection-container">',i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<div class="radio">',i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"<label>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"<input"+(' id="g-scope-mode-full" type="radio" name="scopeType" value="full"'+_i("checked",!0,!0,!1))+"/>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"Allow all actions on behalf of my user</label></div>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<div class="radio">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"<label>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<input id="g-scope-mode-custom" type="radio" name="scopeType" value="custom"/>',i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"Only allow specific permissions for this key:</label></div>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",function(){var n=f;if(typeof n.length=="number")for(var h=0,g=n.length;h<g;h++){var d=n[h];i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<div class="checkbox disabled">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"<label"+(' class="g-custom-scope-description"'+_i("title",d.description,!0,!1))+">",i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"<input"+(' class="g-custom-scope-checkbox" type="checkbox"'+_i("value",d.id,!0,!1)+_i("disabled",!0,!0,!1))+"/>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"<span>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+ec((u=d.name)==null?"":u)+"</span></label></div>"}else{var g=0;for(var h in n){g++;var d=n[h];i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<div class="checkbox disabled">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"<label"+(' class="g-custom-scope-description"'+_i("title",d.description,!0,!1))+">",i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"<input"+(' class="g-custom-scope-checkbox" type="checkbox"'+_i("value",d.id,!0,!1)+_i("disabled",!0,!0,!1))+"/>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"<span>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+ec((u=d.name)==null?"":u)+"</span></label></div>"}}}.call(this),e=e+"</div>",i=34,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<div class="g-validation-failed-message"></div></div>',i=35,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<div class="modal-footer">',i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<a class="btn btn-small btn-default" data-dismiss="modal">',i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+"Cancel</a>",i=37,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<button class="g-save-api-key btn btn-small btn-primary" type="submit">',i=38,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",o?(i=39,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<i class="icon-edit"></i>',i=40,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+" Save"):(i=42,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+'<i class="icon-plus-squared"></i>',i=43,r="/home/circleci/project/girder/girder/web/src/templates/widgets/editApiKeyWidget.pug",e=e+" Create"),e=e+"</button></div></form></div></div>"}).call(this,"apiKey"in s?s.apiKey:typeof apiKey<"u"?apiKey:void 0,"tokenScopes"in s?s.tokenScopes:typeof tokenScopes<"u"?tokenScopes:void 0)}catch(o){jf(o,r,i)}return e}var Sf=Xe.extend({events:{"submit #g-api-key-edit-form":function(t){t.preventDefault();var e={name:this.$("#g-api-key-name").val(),tokenDuration:this.$("#g-api-key-token-duration").val(),scope:null};this._getSelectedScopeMode()==="custom"&&(e.scope=xe.map(this.$(".g-custom-scope-checkbox:checked"),function(u){return ke(u).val()})),this.saveModel(this.model,e),this.$("button.g-save-api-key").girderEnable(!1),this.$(".g-validation-failed-message").text("")},"change .g-scope-selection-container .radio input":function(){var t=this._getSelectedScopeMode();t==="full"?this.$(".g-custom-scope-checkbox").girderEnable(!1).parent().parent().girderEnable(!1):t==="custom"&&this.$(".g-custom-scope-checkbox").girderEnable(!0).parent().parent().girderEnable(!0)}},initialize:function(t){this.model=t.model||null,this.scopeInfo=null,this._shouldRender=!1,ut({url:"token/scopes"}).done(e=>{this.scopeInfo=e,this._shouldRender&&(this._shouldRender=!1,this.render())})},render:function(){if(!this.scopeInfo){this._shouldRender=!0;return}let t=this.scopeInfo.custom;ft().get("admin")&&(t=t.concat(this.scopeInfo.adminCustom));var e=this.$el.html(bk({apiKey:this.model,tokenScopes:t})).girderModal(this).on("shown.bs.modal",()=>{this.$("#g-api-key-name").trigger("focus")}).on("ready.girder.modal",()=>{this.model&&(this.$("#g-api-key-name").val(this.model.get("name")),this.$("#g-api-key-token-duration").val(this.model.get("tokenDuration")||""),this.model.get("scope")&&(this.$("#g-scope-mode-custom").attr("checked","checked").trigger("change"),this.$(".g-custom-scope-checkbox").girderEnable(!0),xe.each(this.model.get("scope"),function(u){this.$('.g-custom-scope-checkbox[value="'+u+'"]').attr("checked","checked")},this)))});return e.trigger(ke.Event("ready.girder.modal",{relatedTarget:e})),this.$("#g-api-key-name").trigger("focus"),this},saveModel:function(t,e){t=t||new Fl,t.set(e),t.once("g:saved",function(){this.$el.modal("hide"),this.trigger("g:saved",t)},this).off("g:error",null,this).on("g:error",function(u){this.$(".g-validation-failed-message").text(u.responseJSON.message),this.$("button.g-save-api-key").girderEnable(!0)},this).save()},_getSelectedScopeMode:function(){return this.$(".g-scope-selection-container .radio input:checked").attr("value")}});function Xr(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=Ir(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Ir(t){var e=""+t,u=wk.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var wk=/["&<>]/;function _f(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void _f(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function yk(t){var e="",u,r,i;try{var s=t||{};(function(o,f){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",o.length===0?(i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<div class="g-api-keys-empty-message">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"You have no existing API keys. Click the button below to create one.</div>"):(i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<div class="g-api-key-list-header">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Your API keys</div>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<table class="g-api-key-table">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<thead>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<tr>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<th col="name">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Name</th>",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<th col="key">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Key</th>",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<th col="scope">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Scope</th>",i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<th col="active">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Active</th>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<th col="tokenDuration">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Token duration</th>",i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<th col="lastUse">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Last used</th>",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<th col="actions">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Actions</th></tr></thead>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<tbody>",i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",function(){var n=o;if(typeof n.length=="number")for(var h=0,g=n.length;h<g;h++){var d=n[h];if(i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<tr"+(' class="g-api-key-container"'+Xr("api-key-id",d.id,!0,!1)+Xr("cid",d.cid,!0,!1))+">",i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="name">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+Ir((u=d.get("name"))==null?"":u)+"</td>",i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="key">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<a"+(' class="g-show-api-key" data-toggle="popover"'+Xr("data-content",d.get("key"),!0,!1))+">",i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"show</a></td>",i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="scope">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",d.get("scope")?(i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<span>",i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Custom scopes</span>"):(i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<span>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Full access</span>"),e=e+"</td>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="active">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+Ir((u=d.get("active")?"Yes":"No")==null?"":u)+"</td>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="tokenDuration">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",d.get("tokenDuration")?(i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<span>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+Ir((u=d.get("tokenDuration"))==null?"":u),i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+" days</span>"):(i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<span>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Default</span>"),e=e+"</td>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="lastUse">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",d.get("lastUse")){i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug";var l=f(d.get("lastUse"));i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<span"+Xr("title",l,!0,!1)+">",i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+Ir((u=l.fromNow())==null?"":u)+"</span>"}else i=35,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<span>",i=35,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Never</span>";e=e+"</td>",i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="actions">',i=37,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<button class="btn btn-sm btn-primary g-api-key-edit" title="Edit">',i=38,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<i class="icon-edit"></i></button>',i=39,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",d.get("active")?(i=40,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<button class="btn btn-sm btn-warning g-api-key-toggle-active" title="Deactivate">',i=41,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<i class="icon-minus-circled"></i></button>'):(i=43,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<button class="btn btn-sm btn-success g-api-key-toggle-active" title="Activate">',i=44,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<i class="icon-plus-circled"></i></button>'),i=45,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<button class="btn btn-sm btn-danger g-api-key-delete" title="Delete key">',i=46,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<i class="icon-cancel"></i></button></td></tr>'}else{var g=0;for(var h in n){g++;var d=n[h];if(i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<tr"+(' class="g-api-key-container"'+Xr("api-key-id",d.id,!0,!1)+Xr("cid",d.cid,!0,!1))+">",i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="name">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+Ir((u=d.get("name"))==null?"":u)+"</td>",i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="key">',i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<a"+(' class="g-show-api-key" data-toggle="popover"'+Xr("data-content",d.get("key"),!0,!1))+">",i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"show</a></td>",i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="scope">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",d.get("scope")?(i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<span>",i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Custom scopes</span>"):(i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<span>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Full access</span>"),e=e+"</td>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="active">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+Ir((u=d.get("active")?"Yes":"No")==null?"":u)+"</td>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="tokenDuration">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",d.get("tokenDuration")?(i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<span>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+Ir((u=d.get("tokenDuration"))==null?"":u),i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+" days</span>"):(i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<span>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Default</span>"),e=e+"</td>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="lastUse">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",d.get("lastUse")){i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug";var l=f(d.get("lastUse"));i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<span"+Xr("title",l,!0,!1)+">",i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+Ir((u=l.fromNow())==null?"":u)+"</span>"}else i=35,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"<span>",i=35,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Never</span>";e=e+"</td>",i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<td col="actions">',i=37,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<button class="btn btn-sm btn-primary g-api-key-edit" title="Edit">',i=38,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<i class="icon-edit"></i></button>',i=39,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",d.get("active")?(i=40,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<button class="btn btn-sm btn-warning g-api-key-toggle-active" title="Deactivate">',i=41,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<i class="icon-minus-circled"></i></button>'):(i=43,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<button class="btn btn-sm btn-success g-api-key-toggle-active" title="Activate">',i=44,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<i class="icon-plus-circled"></i></button>'),i=45,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<button class="btn btn-sm btn-danger g-api-key-delete" title="Delete key">',i=46,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<i class="icon-cancel"></i></button></td></tr>'}}}.call(this),e=e+"</tbody></table>"),i=48,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<div class="g-paginate-container"></div>',i=49,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<div class="g-api-key-list-bottom-buttons">',i=50,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+'<button class="btn btn-default g-api-key-new">',i=50,r="/home/circleci/project/girder/girder/web/src/templates/widgets/apiKeyList.pug",e=e+"Create new key</button></div>"}).call(this,"apiKeys"in s?s.apiKeys:typeof apiKeys<"u"?apiKeys:void 0,"moment"in s?s.moment:typeof moment<"u"?moment:void 0)}catch(o){_f(o,r,i)}return e}var Df=Xe.extend({events:{"click .g-api-key-toggle-active":function(t){var e=this._getModelFromEvent(t),u=()=>{e.once("g:setActive",function(){this.render()},this).setActive(!e.get("active"))};e.get("active")?n0({text:"Deactivating this API key will delete any existing tokens created with it, and will not be usable until it is activated again. Are you sure you want to deactivate it?",yesText:"Yes",yesClass:"btn-warning",escapedHtml:!0,confirmCallback:u}):u()},"click .g-api-key-new":function(){this._renderEditWidget()},"click .g-api-key-edit":function(t){var e=this._getModelFromEvent(t);this._renderEditWidget(e)},"click .g-api-key-delete":function(t){var e=this._getModelFromEvent(t);n0({text:"Are you sure you want to delete the API key <b>"+e.escape("name")+"</b>? Any client applications using this key will no longer be able to authenticate.",yesText:"Delete",escapedHtml:!0,confirmCallback:()=>{e.on("g:deleted",function(){He.trigger("g:alert",{icon:"ok",text:"API key deleted.",type:"success",timeout:3e3}),this.render()},this).destroy()}})}},initialize:function(t){this.model=t.user,this.fetched=!1,this.collection=new gg,this.collection.on("g:changed",function(){this.fetched=!0,this.render(),this.trigger("g:changed")},this).fetch({userId:this.model.id}),this.paginateWidget=new Nu({collection:this.collection,parentView:this})},render:function(){if(this.fetched)return this.$el.html(yk({apiKeys:this.collection.toArray(),moment:Ze})),this.$(".g-show-api-key").popover({container:this.$(".g-api-key-table"),placement:"top"}),this.paginateWidget.setElement(this.$(".g-paginate-container")).render(),this},_getModelFromEvent:function(t){var e=ke(t.currentTarget).parents(".g-api-key-container").attr("cid");return this.collection.get(e)},_renderEditWidget:function(t){this.editApiKeyWidget||(this.editApiKeyWidget=new Sf({el:ke("#g-dialog-container"),parentView:this}).on("g:saved",function(e){this.collection.get(e.cid)||this.collection.add(e),this.render()},this)),this.editApiKeyWidget.model=t||null,this.editApiKeyWidget.render()}}),$s={},Ck=function(){return typeof Promise=="function"&&Promise.prototype&&Promise.prototype.then},Mf={},mi={},Ek={}.toString,Ml=Array.isArray||function(t){return Ek.call(t)=="[object Array]"},Ak=Ml;function xk(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},t.foo()===42}catch{return!1}}xt.TYPED_ARRAY_SUPPORT=xk();var s2=xt.TYPED_ARRAY_SUPPORT?2147483647:1073741823;function xt(t,e,u){return!xt.TYPED_ARRAY_SUPPORT&&!(this instanceof xt)?new xt(t,e,u):typeof t=="number"?Tf(this,t):Tk(this,t,e,u)}xt.TYPED_ARRAY_SUPPORT&&(xt.prototype.__proto__=Uint8Array.prototype,xt.__proto__=Uint8Array,typeof Symbol<"u"&&Symbol.species&&xt[Symbol.species]===xt&&Object.defineProperty(xt,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}));function Tl(t){if(t>=s2)throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x"+s2.toString(16)+" bytes");return t|0}function kk(t){return t!==t}function ku(t,e){var u;return xt.TYPED_ARRAY_SUPPORT?(u=new Uint8Array(e),u.__proto__=xt.prototype):(u=t,u===null&&(u=new xt(e)),u.length=e),u}function Tf(t,e){var u=ku(t,e<0?0:Tl(e)|0);if(!xt.TYPED_ARRAY_SUPPORT)for(var r=0;r<e;++r)u[r]=0;return u}function jk(t,e){var u=Lf(e)|0,r=ku(t,u),i=r.write(e);return i!==u&&(r=r.slice(0,i)),r}function tc(t,e){for(var u=e.length<0?0:Tl(e.length)|0,r=ku(t,u),i=0;i<u;i+=1)r[i]=e[i]&255;return r}function Sk(t,e,u,r){if(u<0||e.byteLength<u)throw new RangeError("'offset' is out of bounds");if(e.byteLength<u+(r||0))throw new RangeError("'length' is out of bounds");var i;return u===void 0&&r===void 0?i=new Uint8Array(e):r===void 0?i=new Uint8Array(e,u):i=new Uint8Array(e,u,r),xt.TYPED_ARRAY_SUPPORT?i.__proto__=xt.prototype:i=tc(t,i),i}function _k(t,e){if(xt.isBuffer(e)){var u=Tl(e.length)|0,r=ku(t,u);return r.length===0||e.copy(r,0,0,u),r}if(e){if(typeof ArrayBuffer<"u"&&e.buffer instanceof ArrayBuffer||"length"in e)return typeof e.length!="number"||kk(e.length)?ku(t,0):tc(t,e);if(e.type==="Buffer"&&Array.isArray(e.data))return tc(t,e.data)}throw new TypeError("First argument must be a string, Buffer, ArrayBuffer, Array, or array-like object.")}function Pf(t,e){e=e||1/0;for(var u,r=t.length,i=null,s=[],o=0;o<r;++o){if(u=t.charCodeAt(o),u>55295&&u<57344){if(!i){if(u>56319){(e-=3)>-1&&s.push(239,191,189);continue}else if(o+1===r){(e-=3)>-1&&s.push(239,191,189);continue}i=u;continue}if(u<56320){(e-=3)>-1&&s.push(239,191,189),i=u;continue}u=(i-55296<<10|u-56320)+65536}else i&&(e-=3)>-1&&s.push(239,191,189);if(i=null,u<128){if((e-=1)<0)break;s.push(u)}else if(u<2048){if((e-=2)<0)break;s.push(u>>6|192,u&63|128)}else if(u<65536){if((e-=3)<0)break;s.push(u>>12|224,u>>6&63|128,u&63|128)}else if(u<1114112){if((e-=4)<0)break;s.push(u>>18|240,u>>12&63|128,u>>6&63|128,u&63|128)}else throw new Error("Invalid code point")}return s}function Lf(t){if(xt.isBuffer(t))return t.length;if(typeof ArrayBuffer<"u"&&typeof ArrayBuffer.isView=="function"&&(ArrayBuffer.isView(t)||t instanceof ArrayBuffer))return t.byteLength;typeof t!="string"&&(t=""+t);var e=t.length;return e===0?0:Pf(t).length}function Dk(t,e,u,r){for(var i=0;i<r&&!(i+u>=e.length||i>=t.length);++i)e[i+u]=t[i];return i}function Mk(t,e,u,r){return Dk(Pf(e,t.length-u),t,u,r)}function Tk(t,e,u,r){if(typeof e=="number")throw new TypeError('"value" argument must not be a number');return typeof ArrayBuffer<"u"&&e instanceof ArrayBuffer?Sk(t,e,u,r):typeof e=="string"?jk(t,e):_k(t,e)}xt.prototype.write=function(e,u,r){u===void 0?(r=this.length,u=0):r===void 0&&typeof u=="string"?(r=this.length,u=0):isFinite(u)&&(u=u|0,isFinite(r)?r=r|0:r=void 0);var i=this.length-u;if((r===void 0||r>i)&&(r=i),e.length>0&&(r<0||u<0)||u>this.length)throw new RangeError("Attempt to write outside buffer bounds");return Mk(this,e,u,r)};xt.prototype.slice=function(e,u){var r=this.length;e=~~e,u=u===void 0?r:~~u,e<0?(e+=r,e<0&&(e=0)):e>r&&(e=r),u<0?(u+=r,u<0&&(u=0)):u>r&&(u=r),u<e&&(u=e);var i;if(xt.TYPED_ARRAY_SUPPORT)i=this.subarray(e,u),i.__proto__=xt.prototype;else{var s=u-e;i=new xt(s,void 0);for(var o=0;o<s;++o)i[o]=this[o+e]}return i};xt.prototype.copy=function(e,u,r,i){if(r||(r=0),!i&&i!==0&&(i=this.length),u>=e.length&&(u=e.length),u||(u=0),i>0&&i<r&&(i=r),i===r||e.length===0||this.length===0)return 0;if(u<0)throw new RangeError("targetStart out of bounds");if(r<0||r>=this.length)throw new RangeError("sourceStart out of bounds");if(i<0)throw new RangeError("sourceEnd out of bounds");i>this.length&&(i=this.length),e.length-u<i-r&&(i=e.length-u+r);var s=i-r,o;if(this===e&&r<u&&u<i)for(o=s-1;o>=0;--o)e[o+u]=this[o+r];else if(s<1e3||!xt.TYPED_ARRAY_SUPPORT)for(o=0;o<s;++o)e[o+u]=this[o+r];else Uint8Array.prototype.set.call(e,this.subarray(r,r+s),u);return s};xt.prototype.fill=function(e,u,r){if(typeof e=="string"){if(typeof u=="string"?(u=0,r=this.length):typeof r=="string"&&(r=this.length),e.length===1){var i=e.charCodeAt(0);i<256&&(e=i)}}else typeof e=="number"&&(e=e&255);if(u<0||this.length<u||this.length<r)throw new RangeError("Out of range index");if(r<=u)return this;u=u>>>0,r=r===void 0?this.length:r>>>0,e||(e=0);var s;if(typeof e=="number")for(s=u;s<r;++s)this[s]=e;else{var o=xt.isBuffer(e)?e:new xt(e),f=o.length;for(s=0;s<r-u;++s)this[s+u]=o[s%f]}return this};xt.concat=function(e,u){if(!Ak(e))throw new TypeError('"list" argument must be an Array of Buffers');if(e.length===0)return ku(null,0);var r;if(u===void 0)for(u=0,r=0;r<e.length;++r)u+=e[r].length;var i=Tf(null,u),s=0;for(r=0;r<e.length;++r){var o=e[r];if(!xt.isBuffer(o))throw new TypeError('"list" argument must be an Array of Buffers');o.copy(i,s),s+=o.length}return i};xt.byteLength=Lf;xt.prototype._isBuffer=!0;xt.isBuffer=function(e){return!!(e!=null&&e._isBuffer)};mi.alloc=function(t){var e=new xt(t);return e.fill(0),e};mi.from=function(t){return new xt(t)};var z0={},Pl,Pk=[0,26,44,70,100,134,172,196,242,292,346,404,466,532,581,655,733,815,901,991,1085,1156,1258,1364,1474,1588,1706,1828,1921,2051,2185,2323,2465,2611,2761,2876,3034,3196,3362,3532,3706];z0.getSymbolSize=function(e){if(!e)throw new Error('"version" cannot be null or undefined');if(e<1||e>40)throw new Error('"version" should be in range from 1 to 40');return e*4+17};z0.getSymbolTotalCodewords=function(e){return Pk[e]};z0.getBCHDigit=function(t){for(var e=0;t!==0;)e++,t>>>=1;return e};z0.setToSJISFunction=function(e){if(typeof e!="function")throw new Error('"toSJISFunc" is not a valid function.');Pl=e};z0.isKanjiModeEnabled=function(){return typeof Pl<"u"};z0.toSJIS=function(e){return Pl(e)};var Do={};(function(t){t.L={bit:1},t.M={bit:0},t.Q={bit:3},t.H={bit:2};function e(u){if(typeof u!="string")throw new Error("Param is not a string");var r=u.toLowerCase();switch(r){case"l":case"low":return t.L;case"m":case"medium":return t.M;case"q":case"quartile":return t.Q;case"h":case"high":return t.H;default:throw new Error("Unknown EC Level: "+u)}}t.isValid=function(r){return r&&typeof r.bit<"u"&&r.bit>=0&&r.bit<4},t.from=function(r,i){if(t.isValid(r))return r;try{return e(r)}catch{return i}}})(Do);function Rf(){this.buffer=[],this.length=0}Rf.prototype={get:function(t){var e=Math.floor(t/8);return(this.buffer[e]>>>7-t%8&1)===1},put:function(t,e){for(var u=0;u<e;u++)this.putBit((t>>>e-u-1&1)===1)},getLengthInBits:function(){return this.length},putBit:function(t){var e=Math.floor(this.length/8);this.buffer.length<=e&&this.buffer.push(0),t&&(this.buffer[e]|=128>>>this.length%8),this.length++}};var Lk=Rf,n2=mi;function Ns(t){if(!t||t<1)throw new Error("BitMatrix size must be defined and greater than 0");this.size=t,this.data=n2.alloc(t*t),this.reservedBit=n2.alloc(t*t)}Ns.prototype.set=function(t,e,u,r){var i=t*this.size+e;this.data[i]=u,r&&(this.reservedBit[i]=!0)};Ns.prototype.get=function(t,e){return this.data[t*this.size+e]};Ns.prototype.xor=function(t,e,u){this.data[t*this.size+e]^=u};Ns.prototype.isReserved=function(t,e){return this.reservedBit[t*this.size+e]};var Rk=Ns,Bf={};(function(t){var e=z0.getSymbolSize;t.getRowColCoords=function(r){if(r===1)return[];for(var i=Math.floor(r/7)+2,s=e(r),o=s===145?26:Math.ceil((s-13)/(2*i-2))*2,f=[s-7],n=1;n<i-1;n++)f[n]=f[n-1]-o;return f.push(6),f.reverse()},t.getPositions=function(r){for(var i=[],s=t.getRowColCoords(r),o=s.length,f=0;f<o;f++)for(var n=0;n<o;n++)f===0&&n===0||f===0&&n===o-1||f===o-1&&n===0||i.push([s[f],s[n]]);return i}})(Bf);var If={},Bk=z0.getSymbolSize,o2=7;If.getPositions=function(e){var u=Bk(e);return[[0,0],[u-o2,0],[0,u-o2]]};var Of={};(function(t){t.Patterns={PATTERN000:0,PATTERN001:1,PATTERN010:2,PATTERN011:3,PATTERN100:4,PATTERN101:5,PATTERN110:6,PATTERN111:7};var e={N1:3,N2:3,N3:40,N4:10};t.isValid=function(i){return i!=null&&i!==""&&!isNaN(i)&&i>=0&&i<=7},t.from=function(i){return t.isValid(i)?parseInt(i,10):void 0},t.getPenaltyN1=function(i){for(var s=i.size,o=0,f=0,n=0,h=null,g=null,d=0;d<s;d++){f=n=0,h=g=null;for(var l=0;l<s;l++){var c=i.get(d,l);c===h?f++:(f>=5&&(o+=e.N1+(f-5)),h=c,f=1),c=i.get(l,d),c===g?n++:(n>=5&&(o+=e.N1+(n-5)),g=c,n=1)}f>=5&&(o+=e.N1+(f-5)),n>=5&&(o+=e.N1+(n-5))}return o},t.getPenaltyN2=function(i){for(var s=i.size,o=0,f=0;f<s-1;f++)for(var n=0;n<s-1;n++){var h=i.get(f,n)+i.get(f,n+1)+i.get(f+1,n)+i.get(f+1,n+1);(h===4||h===0)&&o++}return o*e.N2},t.getPenaltyN3=function(i){for(var s=i.size,o=0,f=0,n=0,h=0;h<s;h++){f=n=0;for(var g=0;g<s;g++)f=f<<1&2047|i.get(h,g),g>=10&&(f===1488||f===93)&&o++,n=n<<1&2047|i.get(g,h),g>=10&&(n===1488||n===93)&&o++}return o*e.N3},t.getPenaltyN4=function(i){for(var s=0,o=i.data.length,f=0;f<o;f++)s+=i.data[f];var n=Math.abs(Math.ceil(s*100/o/5)-10);return n*e.N4};function u(r,i,s){switch(r){case t.Patterns.PATTERN000:return(i+s)%2===0;case t.Patterns.PATTERN001:return i%2===0;case t.Patterns.PATTERN010:return s%3===0;case t.Patterns.PATTERN011:return(i+s)%3===0;case t.Patterns.PATTERN100:return(Math.floor(i/2)+Math.floor(s/3))%2===0;case t.Patterns.PATTERN101:return i*s%2+i*s%3===0;case t.Patterns.PATTERN110:return(i*s%2+i*s%3)%2===0;case t.Patterns.PATTERN111:return(i*s%3+(i+s)%2)%2===0;default:throw new Error("bad maskPattern:"+r)}}t.applyMask=function(i,s){for(var o=s.size,f=0;f<o;f++)for(var n=0;n<o;n++)s.isReserved(n,f)||s.xor(n,f,u(i,n,f))},t.getBestMask=function(i,s){for(var o=Object.keys(t.Patterns).length,f=0,n=1/0,h=0;h<o;h++){s(h),t.applyMask(h,i);var g=t.getPenaltyN1(i)+t.getPenaltyN2(i)+t.getPenaltyN3(i)+t.getPenaltyN4(i);t.applyMask(h,i),g<n&&(n=g,f=h)}return f}})(Of);var Mo={},si=Do,gn=[1,1,1,1,1,1,1,1,1,1,2,2,1,2,2,4,1,2,4,4,2,4,4,4,2,4,6,5,2,4,6,6,2,5,8,8,4,5,8,8,4,5,8,11,4,8,10,11,4,9,12,16,4,9,16,16,6,10,12,18,6,10,17,16,6,11,16,19,6,13,18,21,7,14,21,25,8,16,20,25,8,17,23,25,9,17,23,34,9,18,25,30,10,20,27,32,12,21,29,35,12,23,34,37,12,25,34,40,13,26,35,42,14,28,38,45,15,29,40,48,16,31,43,51,17,33,45,54,18,35,48,57,19,37,51,60,19,38,53,63,20,40,56,66,21,43,59,70,22,45,62,74,24,47,65,77,25,49,68,81],pn=[7,10,13,17,10,16,22,28,15,26,36,44,20,36,52,64,26,48,72,88,36,64,96,112,40,72,108,130,48,88,132,156,60,110,160,192,72,130,192,224,80,150,224,264,96,176,260,308,104,198,288,352,120,216,320,384,132,240,360,432,144,280,408,480,168,308,448,532,180,338,504,588,196,364,546,650,224,416,600,700,224,442,644,750,252,476,690,816,270,504,750,900,300,560,810,960,312,588,870,1050,336,644,952,1110,360,700,1020,1200,390,728,1050,1260,420,784,1140,1350,450,812,1200,1440,480,868,1290,1530,510,924,1350,1620,540,980,1440,1710,570,1036,1530,1800,570,1064,1590,1890,600,1120,1680,1980,630,1204,1770,2100,660,1260,1860,2220,720,1316,1950,2310,750,1372,2040,2430];Mo.getBlocksCount=function(e,u){switch(u){case si.L:return gn[(e-1)*4+0];case si.M:return gn[(e-1)*4+1];case si.Q:return gn[(e-1)*4+2];case si.H:return gn[(e-1)*4+3];default:return}};Mo.getTotalCodewordsCount=function(e,u){switch(u){case si.L:return pn[(e-1)*4+0];case si.M:return pn[(e-1)*4+1];case si.Q:return pn[(e-1)*4+2];case si.H:return pn[(e-1)*4+3];default:return}};var $f={},To={},Nf=mi,ms=Nf.alloc(512),Wn=Nf.alloc(256);(function(){for(var e=1,u=0;u<255;u++)ms[u]=e,Wn[e]=u,e<<=1,e&256&&(e^=285);for(u=255;u<512;u++)ms[u]=ms[u-255]})();To.log=function(e){if(e<1)throw new Error("log("+e+")");return Wn[e]};To.exp=function(e){return ms[e]};To.mul=function(e,u){return e===0||u===0?0:ms[Wn[e]+Wn[u]]};(function(t){var e=mi,u=To;t.mul=function(i,s){for(var o=e.alloc(i.length+s.length-1),f=0;f<i.length;f++)for(var n=0;n<s.length;n++)o[f+n]^=u.mul(i[f],s[n]);return o},t.mod=function(i,s){for(var o=e.from(i);o.length-s.length>=0;){for(var f=o[0],n=0;n<s.length;n++)o[n]^=u.mul(s[n],f);for(var h=0;h<o.length&&o[h]===0;)h++;o=o.slice(h)}return o},t.generateECPolynomial=function(i){for(var s=e.from([1]),o=0;o<i;o++)s=t.mul(s,[1,u.exp(o)]);return s}})($f);var Wf={},Po={};Po.byteLength=$k;Po.toByteArray=Wk;Po.fromByteArray=qk;var wr=[],Y0=[],Ik=typeof Uint8Array<"u"?Uint8Array:Array,ya="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";for(var du=0,Ok=ya.length;du<Ok;++du)wr[du]=ya[du],Y0[ya.charCodeAt(du)]=du;Y0["-".charCodeAt(0)]=62;Y0["_".charCodeAt(0)]=63;function Hf(t){var e=t.length;if(e%4>0)throw new Error("Invalid string. Length must be a multiple of 4");var u=t.indexOf("=");u===-1&&(u=e);var r=u===e?0:4-u%4;return[u,r]}function $k(t){var e=Hf(t),u=e[0],r=e[1];return(u+r)*3/4-r}function Nk(t,e,u){return(e+u)*3/4-u}function Wk(t){var e,u=Hf(t),r=u[0],i=u[1],s=new Ik(Nk(t,r,i)),o=0,f=i>0?r-4:r,n;for(n=0;n<f;n+=4)e=Y0[t.charCodeAt(n)]<<18|Y0[t.charCodeAt(n+1)]<<12|Y0[t.charCodeAt(n+2)]<<6|Y0[t.charCodeAt(n+3)],s[o++]=e>>16&255,s[o++]=e>>8&255,s[o++]=e&255;return i===2&&(e=Y0[t.charCodeAt(n)]<<2|Y0[t.charCodeAt(n+1)]>>4,s[o++]=e&255),i===1&&(e=Y0[t.charCodeAt(n)]<<10|Y0[t.charCodeAt(n+1)]<<4|Y0[t.charCodeAt(n+2)]>>2,s[o++]=e>>8&255,s[o++]=e&255),s}function Hk(t){return wr[t>>18&63]+wr[t>>12&63]+wr[t>>6&63]+wr[t&63]}function Uk(t,e,u){for(var r,i=[],s=e;s<u;s+=3)r=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(t[s+2]&255),i.push(Hk(r));return i.join("")}function qk(t){for(var e,u=t.length,r=u%3,i=[],s=16383,o=0,f=u-r;o<f;o+=s)i.push(Uk(t,o,o+s>f?f:o+s));return r===1?(e=t[u-1],i.push(wr[e>>2]+wr[e<<4&63]+"==")):r===2&&(e=(t[u-2]<<8)+t[u-1],i.push(wr[e>>10]+wr[e>>4&63]+wr[e<<2&63]+"=")),i.join("")}var Ll={};/*! ieee754. BSD-3-Clause License. Feross Aboukhadijeh <https://feross.org/opensource> */Ll.read=function(t,e,u,r,i){var s,o,f=i*8-r-1,n=(1<<f)-1,h=n>>1,g=-7,d=u?i-1:0,l=u?-1:1,c=t[e+d];for(d+=l,s=c&(1<<-g)-1,c>>=-g,g+=f;g>0;s=s*256+t[e+d],d+=l,g-=8);for(o=s&(1<<-g)-1,s>>=-g,g+=r;g>0;o=o*256+t[e+d],d+=l,g-=8);if(s===0)s=1-h;else{if(s===n)return o?NaN:(c?-1:1)*(1/0);o=o+Math.pow(2,r),s=s-h}return(c?-1:1)*o*Math.pow(2,s-r)};Ll.write=function(t,e,u,r,i,s){var o,f,n,h=s*8-i-1,g=(1<<h)-1,d=g>>1,l=i===23?Math.pow(2,-24)-Math.pow(2,-77):0,c=r?0:s-1,a=r?1:-1,F=e<0||e===0&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(f=isNaN(e)?1:0,o=g):(o=Math.floor(Math.log(e)/Math.LN2),e*(n=Math.pow(2,-o))<1&&(o--,n*=2),o+d>=1?e+=l/n:e+=l*Math.pow(2,1-d),e*n>=2&&(o++,n/=2),o+d>=g?(f=0,o=g):o+d>=1?(f=(e*n-1)*Math.pow(2,i),o=o+d):(f=e*Math.pow(2,d-1)*Math.pow(2,i),o=0));i>=8;t[u+c]=f&255,c+=a,f/=256,i-=8);for(o=o<<i|f,h+=i;h>0;t[u+c]=o&255,c+=a,o/=256,h-=8);t[u+c-a]|=F*128};/*!
 * The buffer module from node.js, for the browser.
 *
 * @author   Feross Aboukhadijeh <https://feross.org>
 * @license  MIT
 */(function(t){var e=Po,u=Ll,r=typeof Symbol=="function"&&typeof Symbol.for=="function"?Symbol.for("nodejs.util.inspect.custom"):null;t.Buffer=f,t.SlowBuffer=b,t.INSPECT_MAX_BYTES=50;var i=2147483647;t.kMaxLength=i,f.TYPED_ARRAY_SUPPORT=s(),!f.TYPED_ARRAY_SUPPORT&&typeof console<"u"&&typeof console.error=="function"&&console.error("This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.");function s(){try{var O=new Uint8Array(1),I={foo:function(){return 42}};return Object.setPrototypeOf(I,Uint8Array.prototype),Object.setPrototypeOf(O,I),O.foo()===42}catch{return!1}}Object.defineProperty(f.prototype,"parent",{enumerable:!0,get:function(){if(f.isBuffer(this))return this.buffer}}),Object.defineProperty(f.prototype,"offset",{enumerable:!0,get:function(){if(f.isBuffer(this))return this.byteOffset}});function o(O){if(O>i)throw new RangeError('The value "'+O+'" is invalid for option "size"');var I=new Uint8Array(O);return Object.setPrototypeOf(I,f.prototype),I}function f(O,I,v){if(typeof O=="number"){if(typeof I=="string")throw new TypeError('The "string" argument must be of type string. Received type number');return d(O)}return n(O,I,v)}f.poolSize=8192;function n(O,I,v){if(typeof O=="string")return l(O,I);if(ArrayBuffer.isView(O))return a(O);if(O==null)throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof O);if(Ie(O,ArrayBuffer)||O&&Ie(O.buffer,ArrayBuffer)||typeof SharedArrayBuffer<"u"&&(Ie(O,SharedArrayBuffer)||O&&Ie(O.buffer,SharedArrayBuffer)))return F(O,I,v);if(typeof O=="number")throw new TypeError('The "value" argument must not be of type number. Received type number');var E=O.valueOf&&O.valueOf();if(E!=null&&E!==O)return f.from(E,I,v);var L=p(O);if(L)return L;if(typeof Symbol<"u"&&Symbol.toPrimitive!=null&&typeof O[Symbol.toPrimitive]=="function")return f.from(O[Symbol.toPrimitive]("string"),I,v);throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof O)}f.from=function(O,I,v){return n(O,I,v)},Object.setPrototypeOf(f.prototype,Uint8Array.prototype),Object.setPrototypeOf(f,Uint8Array);function h(O){if(typeof O!="number")throw new TypeError('"size" argument must be of type number');if(O<0)throw new RangeError('The value "'+O+'" is invalid for option "size"')}function g(O,I,v){return h(O),O<=0?o(O):I!==void 0?typeof v=="string"?o(O).fill(I,v):o(O).fill(I):o(O)}f.alloc=function(O,I,v){return g(O,I,v)};function d(O){return h(O),o(O<0?0:m(O)|0)}f.allocUnsafe=function(O){return d(O)},f.allocUnsafeSlow=function(O){return d(O)};function l(O,I){if((typeof I!="string"||I==="")&&(I="utf8"),!f.isEncoding(I))throw new TypeError("Unknown encoding: "+I);var v=C(O,I)|0,E=o(v),L=E.write(O,I);return L!==v&&(E=E.slice(0,L)),E}function c(O){for(var I=O.length<0?0:m(O.length)|0,v=o(I),E=0;E<I;E+=1)v[E]=O[E]&255;return v}function a(O){if(Ie(O,Uint8Array)){var I=new Uint8Array(O);return F(I.buffer,I.byteOffset,I.byteLength)}return c(O)}function F(O,I,v){if(I<0||O.byteLength<I)throw new RangeError('"offset" is outside of buffer bounds');if(O.byteLength<I+(v||0))throw new RangeError('"length" is outside of buffer bounds');var E;return I===void 0&&v===void 0?E=new Uint8Array(O):v===void 0?E=new Uint8Array(O,I):E=new Uint8Array(O,I,v),Object.setPrototypeOf(E,f.prototype),E}function p(O){if(f.isBuffer(O)){var I=m(O.length)|0,v=o(I);return v.length===0||O.copy(v,0,0,I),v}if(O.length!==void 0)return typeof O.length!="number"||z(O.length)?o(0):c(O);if(O.type==="Buffer"&&Array.isArray(O.data))return c(O.data)}function m(O){if(O>=i)throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x"+i.toString(16)+" bytes");return O|0}function b(O){return+O!=O&&(O=0),f.alloc(+O)}f.isBuffer=function(I){return I!=null&&I._isBuffer===!0&&I!==f.prototype},f.compare=function(I,v){if(Ie(I,Uint8Array)&&(I=f.from(I,I.offset,I.byteLength)),Ie(v,Uint8Array)&&(v=f.from(v,v.offset,v.byteLength)),!f.isBuffer(I)||!f.isBuffer(v))throw new TypeError('The "buf1", "buf2" arguments must be one of type Buffer or Uint8Array');if(I===v)return 0;for(var E=I.length,L=v.length,S=0,P=Math.min(E,L);S<P;++S)if(I[S]!==v[S]){E=I[S],L=v[S];break}return E<L?-1:L<E?1:0},f.isEncoding=function(I){switch(String(I).toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"latin1":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return!0;default:return!1}},f.concat=function(I,v){if(!Array.isArray(I))throw new TypeError('"list" argument must be an Array of Buffers');if(I.length===0)return f.alloc(0);var E;if(v===void 0)for(v=0,E=0;E<I.length;++E)v+=I[E].length;var L=f.allocUnsafe(v),S=0;for(E=0;E<I.length;++E){var P=I[E];if(Ie(P,Uint8Array))S+P.length>L.length?f.from(P).copy(L,S):Uint8Array.prototype.set.call(L,P,S);else if(f.isBuffer(P))P.copy(L,S);else throw new TypeError('"list" argument must be an Array of Buffers');S+=P.length}return L};function C(O,I){if(f.isBuffer(O))return O.length;if(ArrayBuffer.isView(O)||Ie(O,ArrayBuffer))return O.byteLength;if(typeof O!="string")throw new TypeError('The "string" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof O);var v=O.length,E=arguments.length>2&&arguments[2]===!0;if(!E&&v===0)return 0;for(var L=!1;;)switch(I){case"ascii":case"latin1":case"binary":return v;case"utf8":case"utf-8":return ne(O).length;case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return v*2;case"hex":return v>>>1;case"base64":return ve(O).length;default:if(L)return E?-1:ne(O).length;I=(""+I).toLowerCase(),L=!0}}f.byteLength=C;function k(O,I,v){var E=!1;if((I===void 0||I<0)&&(I=0),I>this.length||((v===void 0||v>this.length)&&(v=this.length),v<=0)||(v>>>=0,I>>>=0,v<=I))return"";for(O||(O="utf8");;)switch(O){case"hex":return ce(this,I,v);case"utf8":case"utf-8":return q(this,I,v);case"ascii":return re(this,I,v);case"latin1":case"binary":return le(this,I,v);case"base64":return B(this,I,v);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return de(this,I,v);default:if(E)throw new TypeError("Unknown encoding: "+O);O=(O+"").toLowerCase(),E=!0}}f.prototype._isBuffer=!0;function T(O,I,v){var E=O[I];O[I]=O[v],O[v]=E}f.prototype.swap16=function(){var I=this.length;if(I%2!==0)throw new RangeError("Buffer size must be a multiple of 16-bits");for(var v=0;v<I;v+=2)T(this,v,v+1);return this},f.prototype.swap32=function(){var I=this.length;if(I%4!==0)throw new RangeError("Buffer size must be a multiple of 32-bits");for(var v=0;v<I;v+=4)T(this,v,v+3),T(this,v+1,v+2);return this},f.prototype.swap64=function(){var I=this.length;if(I%8!==0)throw new RangeError("Buffer size must be a multiple of 64-bits");for(var v=0;v<I;v+=8)T(this,v,v+7),T(this,v+1,v+6),T(this,v+2,v+5),T(this,v+3,v+4);return this},f.prototype.toString=function(){var I=this.length;return I===0?"":arguments.length===0?q(this,0,I):k.apply(this,arguments)},f.prototype.toLocaleString=f.prototype.toString,f.prototype.equals=function(I){if(!f.isBuffer(I))throw new TypeError("Argument must be a Buffer");return this===I?!0:f.compare(this,I)===0},f.prototype.inspect=function(){var I="",v=t.INSPECT_MAX_BYTES;return I=this.toString("hex",0,v).replace(/(.{2})/g,"$1 ").trim(),this.length>v&&(I+=" ... "),"<Buffer "+I+">"},r&&(f.prototype[r]=f.prototype.inspect),f.prototype.compare=function(I,v,E,L,S){if(Ie(I,Uint8Array)&&(I=f.from(I,I.offset,I.byteLength)),!f.isBuffer(I))throw new TypeError('The "target" argument must be one of type Buffer or Uint8Array. Received type '+typeof I);if(v===void 0&&(v=0),E===void 0&&(E=I?I.length:0),L===void 0&&(L=0),S===void 0&&(S=this.length),v<0||E>I.length||L<0||S>this.length)throw new RangeError("out of range index");if(L>=S&&v>=E)return 0;if(L>=S)return-1;if(v>=E)return 1;if(v>>>=0,E>>>=0,L>>>=0,S>>>=0,this===I)return 0;for(var P=S-L,W=E-v,K=Math.min(P,W),V=this.slice(L,S),ee=I.slice(v,E),Q=0;Q<K;++Q)if(V[Q]!==ee[Q]){P=V[Q],W=ee[Q];break}return P<W?-1:W<P?1:0};function w(O,I,v,E,L){if(O.length===0)return-1;if(typeof v=="string"?(E=v,v=0):v>2147483647?v=2147483647:v<-2147483648&&(v=-2147483648),v=+v,z(v)&&(v=L?0:O.length-1),v<0&&(v=O.length+v),v>=O.length){if(L)return-1;v=O.length-1}else if(v<0)if(L)v=0;else return-1;if(typeof I=="string"&&(I=f.from(I,E)),f.isBuffer(I))return I.length===0?-1:A(O,I,v,E,L);if(typeof I=="number")return I=I&255,typeof Uint8Array.prototype.indexOf=="function"?L?Uint8Array.prototype.indexOf.call(O,I,v):Uint8Array.prototype.lastIndexOf.call(O,I,v):A(O,[I],v,E,L);throw new TypeError("val must be string, number or Buffer")}function A(O,I,v,E,L){var S=1,P=O.length,W=I.length;if(E!==void 0&&(E=String(E).toLowerCase(),E==="ucs2"||E==="ucs-2"||E==="utf16le"||E==="utf-16le")){if(O.length<2||I.length<2)return-1;S=2,P/=2,W/=2,v/=2}function K(oe,pe){return S===1?oe[pe]:oe.readUInt16BE(pe*S)}var V;if(L){var ee=-1;for(V=v;V<P;V++)if(K(O,V)===K(I,ee===-1?0:V-ee)){if(ee===-1&&(ee=V),V-ee+1===W)return ee*S}else ee!==-1&&(V-=V-ee),ee=-1}else for(v+W>P&&(v=P-W),V=v;V>=0;V--){for(var Q=!0,fe=0;fe<W;fe++)if(K(O,V+fe)!==K(I,fe)){Q=!1;break}if(Q)return V}return-1}f.prototype.includes=function(I,v,E){return this.indexOf(I,v,E)!==-1},f.prototype.indexOf=function(I,v,E){return w(this,I,v,E,!0)},f.prototype.lastIndexOf=function(I,v,E){return w(this,I,v,E,!1)};function M(O,I,v,E){v=Number(v)||0;var L=O.length-v;E?(E=Number(E),E>L&&(E=L)):E=L;var S=I.length;E>S/2&&(E=S/2);for(var P=0;P<E;++P){var W=parseInt(I.substr(P*2,2),16);if(z(W))return P;O[v+P]=W}return P}function x(O,I,v,E){return Pe(ne(I,O.length-v),O,v,E)}function R(O,I,v,E){return Pe(me(I),O,v,E)}function N(O,I,v,E){return Pe(ve(I),O,v,E)}function j(O,I,v,E){return Pe(se(I,O.length-v),O,v,E)}f.prototype.write=function(I,v,E,L){if(v===void 0)L="utf8",E=this.length,v=0;else if(E===void 0&&typeof v=="string")L=v,E=this.length,v=0;else if(isFinite(v))v=v>>>0,isFinite(E)?(E=E>>>0,L===void 0&&(L="utf8")):(L=E,E=void 0);else throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");var S=this.length-v;if((E===void 0||E>S)&&(E=S),I.length>0&&(E<0||v<0)||v>this.length)throw new RangeError("Attempt to write outside buffer bounds");L||(L="utf8");for(var P=!1;;)switch(L){case"hex":return M(this,I,v,E);case"utf8":case"utf-8":return x(this,I,v,E);case"ascii":case"latin1":case"binary":return R(this,I,v,E);case"base64":return N(this,I,v,E);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return j(this,I,v,E);default:if(P)throw new TypeError("Unknown encoding: "+L);L=(""+L).toLowerCase(),P=!0}},f.prototype.toJSON=function(){return{type:"Buffer",data:Array.prototype.slice.call(this._arr||this,0)}};function B(O,I,v){return I===0&&v===O.length?e.fromByteArray(O):e.fromByteArray(O.slice(I,v))}function q(O,I,v){v=Math.min(O.length,v);for(var E=[],L=I;L<v;){var S=O[L],P=null,W=S>239?4:S>223?3:S>191?2:1;if(L+W<=v){var K,V,ee,Q;switch(W){case 1:S<128&&(P=S);break;case 2:K=O[L+1],(K&192)===128&&(Q=(S&31)<<6|K&63,Q>127&&(P=Q));break;case 3:K=O[L+1],V=O[L+2],(K&192)===128&&(V&192)===128&&(Q=(S&15)<<12|(K&63)<<6|V&63,Q>2047&&(Q<55296||Q>57343)&&(P=Q));break;case 4:K=O[L+1],V=O[L+2],ee=O[L+3],(K&192)===128&&(V&192)===128&&(ee&192)===128&&(Q=(S&15)<<18|(K&63)<<12|(V&63)<<6|ee&63,Q>65535&&Q<1114112&&(P=Q))}}P===null?(P=65533,W=1):P>65535&&(P-=65536,E.push(P>>>10&1023|55296),P=56320|P&1023),E.push(P),L+=W}return Z(E)}var U=4096;function Z(O){var I=O.length;if(I<=U)return String.fromCharCode.apply(String,O);for(var v="",E=0;E<I;)v+=String.fromCharCode.apply(String,O.slice(E,E+=U));return v}function re(O,I,v){var E="";v=Math.min(O.length,v);for(var L=I;L<v;++L)E+=String.fromCharCode(O[L]&127);return E}function le(O,I,v){var E="";v=Math.min(O.length,v);for(var L=I;L<v;++L)E+=String.fromCharCode(O[L]);return E}function ce(O,I,v){var E=O.length;(!I||I<0)&&(I=0),(!v||v<0||v>E)&&(v=E);for(var L="",S=I;S<v;++S)L+=G[O[S]];return L}function de(O,I,v){for(var E=O.slice(I,v),L="",S=0;S<E.length-1;S+=2)L+=String.fromCharCode(E[S]+E[S+1]*256);return L}f.prototype.slice=function(I,v){var E=this.length;I=~~I,v=v===void 0?E:~~v,I<0?(I+=E,I<0&&(I=0)):I>E&&(I=E),v<0?(v+=E,v<0&&(v=0)):v>E&&(v=E),v<I&&(v=I);var L=this.subarray(I,v);return Object.setPrototypeOf(L,f.prototype),L};function he(O,I,v){if(O%1!==0||O<0)throw new RangeError("offset is not uint");if(O+I>v)throw new RangeError("Trying to access beyond buffer length")}f.prototype.readUintLE=f.prototype.readUIntLE=function(I,v,E){I=I>>>0,v=v>>>0,E||he(I,v,this.length);for(var L=this[I],S=1,P=0;++P<v&&(S*=256);)L+=this[I+P]*S;return L},f.prototype.readUintBE=f.prototype.readUIntBE=function(I,v,E){I=I>>>0,v=v>>>0,E||he(I,v,this.length);for(var L=this[I+--v],S=1;v>0&&(S*=256);)L+=this[I+--v]*S;return L},f.prototype.readUint8=f.prototype.readUInt8=function(I,v){return I=I>>>0,v||he(I,1,this.length),this[I]},f.prototype.readUint16LE=f.prototype.readUInt16LE=function(I,v){return I=I>>>0,v||he(I,2,this.length),this[I]|this[I+1]<<8},f.prototype.readUint16BE=f.prototype.readUInt16BE=function(I,v){return I=I>>>0,v||he(I,2,this.length),this[I]<<8|this[I+1]},f.prototype.readUint32LE=f.prototype.readUInt32LE=function(I,v){return I=I>>>0,v||he(I,4,this.length),(this[I]|this[I+1]<<8|this[I+2]<<16)+this[I+3]*16777216},f.prototype.readUint32BE=f.prototype.readUInt32BE=function(I,v){return I=I>>>0,v||he(I,4,this.length),this[I]*16777216+(this[I+1]<<16|this[I+2]<<8|this[I+3])},f.prototype.readIntLE=function(I,v,E){I=I>>>0,v=v>>>0,E||he(I,v,this.length);for(var L=this[I],S=1,P=0;++P<v&&(S*=256);)L+=this[I+P]*S;return S*=128,L>=S&&(L-=Math.pow(2,8*v)),L},f.prototype.readIntBE=function(I,v,E){I=I>>>0,v=v>>>0,E||he(I,v,this.length);for(var L=v,S=1,P=this[I+--L];L>0&&(S*=256);)P+=this[I+--L]*S;return S*=128,P>=S&&(P-=Math.pow(2,8*v)),P},f.prototype.readInt8=function(I,v){return I=I>>>0,v||he(I,1,this.length),this[I]&128?(255-this[I]+1)*-1:this[I]},f.prototype.readInt16LE=function(I,v){I=I>>>0,v||he(I,2,this.length);var E=this[I]|this[I+1]<<8;return E&32768?E|4294901760:E},f.prototype.readInt16BE=function(I,v){I=I>>>0,v||he(I,2,this.length);var E=this[I+1]|this[I]<<8;return E&32768?E|4294901760:E},f.prototype.readInt32LE=function(I,v){return I=I>>>0,v||he(I,4,this.length),this[I]|this[I+1]<<8|this[I+2]<<16|this[I+3]<<24},f.prototype.readInt32BE=function(I,v){return I=I>>>0,v||he(I,4,this.length),this[I]<<24|this[I+1]<<16|this[I+2]<<8|this[I+3]},f.prototype.readFloatLE=function(I,v){return I=I>>>0,v||he(I,4,this.length),u.read(this,I,!0,23,4)},f.prototype.readFloatBE=function(I,v){return I=I>>>0,v||he(I,4,this.length),u.read(this,I,!1,23,4)},f.prototype.readDoubleLE=function(I,v){return I=I>>>0,v||he(I,8,this.length),u.read(this,I,!0,52,8)},f.prototype.readDoubleBE=function(I,v){return I=I>>>0,v||he(I,8,this.length),u.read(this,I,!1,52,8)};function Fe(O,I,v,E,L,S){if(!f.isBuffer(O))throw new TypeError('"buffer" argument must be a Buffer instance');if(I>L||I<S)throw new RangeError('"value" argument is out of bounds');if(v+E>O.length)throw new RangeError("Index out of range")}f.prototype.writeUintLE=f.prototype.writeUIntLE=function(I,v,E,L){if(I=+I,v=v>>>0,E=E>>>0,!L){var S=Math.pow(2,8*E)-1;Fe(this,I,v,E,S,0)}var P=1,W=0;for(this[v]=I&255;++W<E&&(P*=256);)this[v+W]=I/P&255;return v+E},f.prototype.writeUintBE=f.prototype.writeUIntBE=function(I,v,E,L){if(I=+I,v=v>>>0,E=E>>>0,!L){var S=Math.pow(2,8*E)-1;Fe(this,I,v,E,S,0)}var P=E-1,W=1;for(this[v+P]=I&255;--P>=0&&(W*=256);)this[v+P]=I/W&255;return v+E},f.prototype.writeUint8=f.prototype.writeUInt8=function(I,v,E){return I=+I,v=v>>>0,E||Fe(this,I,v,1,255,0),this[v]=I&255,v+1},f.prototype.writeUint16LE=f.prototype.writeUInt16LE=function(I,v,E){return I=+I,v=v>>>0,E||Fe(this,I,v,2,65535,0),this[v]=I&255,this[v+1]=I>>>8,v+2},f.prototype.writeUint16BE=f.prototype.writeUInt16BE=function(I,v,E){return I=+I,v=v>>>0,E||Fe(this,I,v,2,65535,0),this[v]=I>>>8,this[v+1]=I&255,v+2},f.prototype.writeUint32LE=f.prototype.writeUInt32LE=function(I,v,E){return I=+I,v=v>>>0,E||Fe(this,I,v,4,4294967295,0),this[v+3]=I>>>24,this[v+2]=I>>>16,this[v+1]=I>>>8,this[v]=I&255,v+4},f.prototype.writeUint32BE=f.prototype.writeUInt32BE=function(I,v,E){return I=+I,v=v>>>0,E||Fe(this,I,v,4,4294967295,0),this[v]=I>>>24,this[v+1]=I>>>16,this[v+2]=I>>>8,this[v+3]=I&255,v+4},f.prototype.writeIntLE=function(I,v,E,L){if(I=+I,v=v>>>0,!L){var S=Math.pow(2,8*E-1);Fe(this,I,v,E,S-1,-S)}var P=0,W=1,K=0;for(this[v]=I&255;++P<E&&(W*=256);)I<0&&K===0&&this[v+P-1]!==0&&(K=1),this[v+P]=(I/W>>0)-K&255;return v+E},f.prototype.writeIntBE=function(I,v,E,L){if(I=+I,v=v>>>0,!L){var S=Math.pow(2,8*E-1);Fe(this,I,v,E,S-1,-S)}var P=E-1,W=1,K=0;for(this[v+P]=I&255;--P>=0&&(W*=256);)I<0&&K===0&&this[v+P+1]!==0&&(K=1),this[v+P]=(I/W>>0)-K&255;return v+E},f.prototype.writeInt8=function(I,v,E){return I=+I,v=v>>>0,E||Fe(this,I,v,1,127,-128),I<0&&(I=255+I+1),this[v]=I&255,v+1},f.prototype.writeInt16LE=function(I,v,E){return I=+I,v=v>>>0,E||Fe(this,I,v,2,32767,-32768),this[v]=I&255,this[v+1]=I>>>8,v+2},f.prototype.writeInt16BE=function(I,v,E){return I=+I,v=v>>>0,E||Fe(this,I,v,2,32767,-32768),this[v]=I>>>8,this[v+1]=I&255,v+2},f.prototype.writeInt32LE=function(I,v,E){return I=+I,v=v>>>0,E||Fe(this,I,v,4,2147483647,-2147483648),this[v]=I&255,this[v+1]=I>>>8,this[v+2]=I>>>16,this[v+3]=I>>>24,v+4},f.prototype.writeInt32BE=function(I,v,E){return I=+I,v=v>>>0,E||Fe(this,I,v,4,2147483647,-2147483648),I<0&&(I=4294967295+I+1),this[v]=I>>>24,this[v+1]=I>>>16,this[v+2]=I>>>8,this[v+3]=I&255,v+4};function ge(O,I,v,E,L,S){if(v+E>O.length)throw new RangeError("Index out of range");if(v<0)throw new RangeError("Index out of range")}function ye(O,I,v,E,L){return I=+I,v=v>>>0,L||ge(O,I,v,4),u.write(O,I,v,E,23,4),v+4}f.prototype.writeFloatLE=function(I,v,E){return ye(this,I,v,!0,E)},f.prototype.writeFloatBE=function(I,v,E){return ye(this,I,v,!1,E)};function Y(O,I,v,E,L){return I=+I,v=v>>>0,L||ge(O,I,v,8),u.write(O,I,v,E,52,8),v+8}f.prototype.writeDoubleLE=function(I,v,E){return Y(this,I,v,!0,E)},f.prototype.writeDoubleBE=function(I,v,E){return Y(this,I,v,!1,E)},f.prototype.copy=function(I,v,E,L){if(!f.isBuffer(I))throw new TypeError("argument should be a Buffer");if(E||(E=0),!L&&L!==0&&(L=this.length),v>=I.length&&(v=I.length),v||(v=0),L>0&&L<E&&(L=E),L===E||I.length===0||this.length===0)return 0;if(v<0)throw new RangeError("targetStart out of bounds");if(E<0||E>=this.length)throw new RangeError("Index out of range");if(L<0)throw new RangeError("sourceEnd out of bounds");L>this.length&&(L=this.length),I.length-v<L-E&&(L=I.length-v+E);var S=L-E;return this===I&&typeof Uint8Array.prototype.copyWithin=="function"?this.copyWithin(v,E,L):Uint8Array.prototype.set.call(I,this.subarray(E,L),v),S},f.prototype.fill=function(I,v,E,L){if(typeof I=="string"){if(typeof v=="string"?(L=v,v=0,E=this.length):typeof E=="string"&&(L=E,E=this.length),L!==void 0&&typeof L!="string")throw new TypeError("encoding must be a string");if(typeof L=="string"&&!f.isEncoding(L))throw new TypeError("Unknown encoding: "+L);if(I.length===1){var S=I.charCodeAt(0);(L==="utf8"&&S<128||L==="latin1")&&(I=S)}}else typeof I=="number"?I=I&255:typeof I=="boolean"&&(I=Number(I));if(v<0||this.length<v||this.length<E)throw new RangeError("Out of range index");if(E<=v)return this;v=v>>>0,E=E===void 0?this.length:E>>>0,I||(I=0);var P;if(typeof I=="number")for(P=v;P<E;++P)this[P]=I;else{var W=f.isBuffer(I)?I:f.from(I,L),K=W.length;if(K===0)throw new TypeError('The value "'+I+'" is invalid for argument "value"');for(P=0;P<E-v;++P)this[P+v]=W[P%K]}return this};var ue=/[^+/0-9A-Za-z-_]/g;function Ee(O){if(O=O.split("=")[0],O=O.trim().replace(ue,""),O.length<2)return"";for(;O.length%4!==0;)O=O+"=";return O}function ne(O,I){I=I||1/0;for(var v,E=O.length,L=null,S=[],P=0;P<E;++P){if(v=O.charCodeAt(P),v>55295&&v<57344){if(!L){if(v>56319){(I-=3)>-1&&S.push(239,191,189);continue}else if(P+1===E){(I-=3)>-1&&S.push(239,191,189);continue}L=v;continue}if(v<56320){(I-=3)>-1&&S.push(239,191,189),L=v;continue}v=(L-55296<<10|v-56320)+65536}else L&&(I-=3)>-1&&S.push(239,191,189);if(L=null,v<128){if((I-=1)<0)break;S.push(v)}else if(v<2048){if((I-=2)<0)break;S.push(v>>6|192,v&63|128)}else if(v<65536){if((I-=3)<0)break;S.push(v>>12|224,v>>6&63|128,v&63|128)}else if(v<1114112){if((I-=4)<0)break;S.push(v>>18|240,v>>12&63|128,v>>6&63|128,v&63|128)}else throw new Error("Invalid code point")}return S}function me(O){for(var I=[],v=0;v<O.length;++v)I.push(O.charCodeAt(v)&255);return I}function se(O,I){for(var v,E,L,S=[],P=0;P<O.length&&!((I-=2)<0);++P)v=O.charCodeAt(P),E=v>>8,L=v%256,S.push(L),S.push(E);return S}function ve(O){return e.toByteArray(Ee(O))}function Pe(O,I,v,E){for(var L=0;L<E&&!(L+v>=I.length||L>=O.length);++L)I[L+v]=O[L];return L}function Ie(O,I){return O instanceof I||O!=null&&O.constructor!=null&&O.constructor.name!=null&&O.constructor.name===I.name}function z(O){return O!==O}var G=function(){for(var O="0123456789abcdef",I=new Array(256),v=0;v<16;++v)for(var E=v*16,L=0;L<16;++L)I[E+L]=O[v]+O[L];return I}()})(Wf);var a2=mi,Uf=$f,zk=Wf.Buffer;function Rl(t){this.genPoly=void 0,this.degree=t,this.degree&&this.initialize(this.degree)}Rl.prototype.initialize=function(e){this.degree=e,this.genPoly=Uf.generateECPolynomial(this.degree)};Rl.prototype.encode=function(e){if(!this.genPoly)throw new Error("Encoder not initialized");var u=a2.alloc(this.degree),r=zk.concat([e,u],e.length+this.degree),i=Uf.mod(r,this.genPoly),s=this.degree-i.length;if(s>0){var o=a2.alloc(this.degree);return i.copy(o,s),o}return i};var Vk=Rl,qf={},vi={},Bl={};Bl.isValid=function(e){return!isNaN(e)&&e>=1&&e<=40};var _r={},zf="[0-9]+",Gk="[A-Z $%*+\\-./:]+",Ds="(?:[u3000-u303F]|[u3040-u309F]|[u30A0-u30FF]|[uFF00-uFFEF]|[u4E00-u9FAF]|[u2605-u2606]|[u2190-u2195]|u203B|[u2010u2015u2018u2019u2025u2026u201Cu201Du2225u2260]|[u0391-u0451]|[u00A7u00A8u00B1u00B4u00D7u00F7])+";Ds=Ds.replace(/u/g,"\\u");var Kk="(?:(?![A-Z0-9 $%*+\\-./:]|"+Ds+`)(?:.|[\r
]))+`;_r.KANJI=new RegExp(Ds,"g");_r.BYTE_KANJI=new RegExp("[^A-Z0-9 $%*+\\-./:]+","g");_r.BYTE=new RegExp(Kk,"g");_r.NUMERIC=new RegExp(zf,"g");_r.ALPHANUMERIC=new RegExp(Gk,"g");var Yk=new RegExp("^"+Ds+"$"),Jk=new RegExp("^"+zf+"$"),Qk=new RegExp("^[A-Z0-9 $%*+\\-./:]+$");_r.testKanji=function(e){return Yk.test(e)};_r.testNumeric=function(e){return Jk.test(e)};_r.testAlphanumeric=function(e){return Qk.test(e)};(function(t){var e=Bl,u=_r;t.NUMERIC={id:"Numeric",bit:1,ccBits:[10,12,14]},t.ALPHANUMERIC={id:"Alphanumeric",bit:2,ccBits:[9,11,13]},t.BYTE={id:"Byte",bit:4,ccBits:[8,16,16]},t.KANJI={id:"Kanji",bit:8,ccBits:[8,10,12]},t.MIXED={bit:-1},t.getCharCountIndicator=function(s,o){if(!s.ccBits)throw new Error("Invalid mode: "+s);if(!e.isValid(o))throw new Error("Invalid version: "+o);return o>=1&&o<10?s.ccBits[0]:o<27?s.ccBits[1]:s.ccBits[2]},t.getBestModeForData=function(s){return u.testNumeric(s)?t.NUMERIC:u.testAlphanumeric(s)?t.ALPHANUMERIC:u.testKanji(s)?t.KANJI:t.BYTE},t.toString=function(s){if(s&&s.id)return s.id;throw new Error("Invalid mode")},t.isValid=function(s){return s&&s.bit&&s.ccBits};function r(i){if(typeof i!="string")throw new Error("Param is not a string");var s=i.toLowerCase();switch(s){case"numeric":return t.NUMERIC;case"alphanumeric":return t.ALPHANUMERIC;case"kanji":return t.KANJI;case"byte":return t.BYTE;default:throw new Error("Unknown mode: "+i)}}t.from=function(s,o){if(t.isValid(s))return s;try{return r(s)}catch{return o}}})(vi);(function(t){var e=z0,u=Mo,r=Do,i=vi,s=Bl,o=Ml,f=7973,n=e.getBCHDigit(f);function h(c,a,F){for(var p=1;p<=40;p++)if(a<=t.getCapacity(p,F,c))return p}function g(c,a){return i.getCharCountIndicator(c,a)+4}function d(c,a){var F=0;return c.forEach(function(p){var m=g(p.mode,a);F+=m+p.getBitsLength()}),F}function l(c,a){for(var F=1;F<=40;F++){var p=d(c,F);if(p<=t.getCapacity(F,a,i.MIXED))return F}}t.from=function(a,F){return s.isValid(a)?parseInt(a,10):F},t.getCapacity=function(a,F,p){if(!s.isValid(a))throw new Error("Invalid QR Code version");typeof p>"u"&&(p=i.BYTE);var m=e.getSymbolTotalCodewords(a),b=u.getTotalCodewordsCount(a,F),C=(m-b)*8;if(p===i.MIXED)return C;var k=C-g(p,a);switch(p){case i.NUMERIC:return Math.floor(k/10*3);case i.ALPHANUMERIC:return Math.floor(k/11*2);case i.KANJI:return Math.floor(k/13);case i.BYTE:default:return Math.floor(k/8)}},t.getBestVersionForData=function(a,F){var p,m=r.from(F,r.M);if(o(a)){if(a.length>1)return l(a,m);if(a.length===0)return 1;p=a[0]}else p=a;return h(p.mode,p.getLength(),m)},t.getEncodedBits=function(a){if(!s.isValid(a)||a<7)throw new Error("Invalid QR Code version");for(var F=a<<12;e.getBCHDigit(F)-n>=0;)F^=f<<e.getBCHDigit(F)-n;return a<<12|F}})(qf);var Vf={},rc=z0,Gf=1335,Xk=21522,c2=rc.getBCHDigit(Gf);Vf.getEncodedBits=function(e,u){for(var r=e.bit<<3|u,i=r<<10;rc.getBCHDigit(i)-c2>=0;)i^=Gf<<rc.getBCHDigit(i)-c2;return(r<<10|i)^Xk};var Kf={},Zk=vi;function ju(t){this.mode=Zk.NUMERIC,this.data=t.toString()}ju.getBitsLength=function(e){return 10*Math.floor(e/3)+(e%3?e%3*3+1:0)};ju.prototype.getLength=function(){return this.data.length};ju.prototype.getBitsLength=function(){return ju.getBitsLength(this.data.length)};ju.prototype.write=function(e){var u,r,i;for(u=0;u+3<=this.data.length;u+=3)r=this.data.substr(u,3),i=parseInt(r,10),e.put(i,10);var s=this.data.length-u;s>0&&(r=this.data.substr(u),i=parseInt(r,10),e.put(i,s*3+1))};var ej=ju,tj=vi,Ca=["0","1","2","3","4","5","6","7","8","9","A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","V","W","X","Y","Z"," ","$","%","*","+","-",".","/",":"];function Su(t){this.mode=tj.ALPHANUMERIC,this.data=t}Su.getBitsLength=function(e){return 11*Math.floor(e/2)+6*(e%2)};Su.prototype.getLength=function(){return this.data.length};Su.prototype.getBitsLength=function(){return Su.getBitsLength(this.data.length)};Su.prototype.write=function(e){var u;for(u=0;u+2<=this.data.length;u+=2){var r=Ca.indexOf(this.data[u])*45;r+=Ca.indexOf(this.data[u+1]),e.put(r,11)}this.data.length%2&&e.put(Ca.indexOf(this.data[u]),6)};var rj=Su,ij=mi,uj=vi;function _u(t){this.mode=uj.BYTE,this.data=ij.from(t)}_u.getBitsLength=function(e){return e*8};_u.prototype.getLength=function(){return this.data.length};_u.prototype.getBitsLength=function(){return _u.getBitsLength(this.data.length)};_u.prototype.write=function(t){for(var e=0,u=this.data.length;e<u;e++)t.put(this.data[e],8)};var sj=_u,nj=vi,oj=z0;function Du(t){this.mode=nj.KANJI,this.data=t}Du.getBitsLength=function(e){return e*13};Du.prototype.getLength=function(){return this.data.length};Du.prototype.getBitsLength=function(){return Du.getBitsLength(this.data.length)};Du.prototype.write=function(t){var e;for(e=0;e<this.data.length;e++){var u=oj.toSJIS(this.data[e]);if(u>=33088&&u<=40956)u-=33088;else if(u>=57408&&u<=60351)u-=49472;else throw new Error("Invalid SJIS character: "+this.data[e]+`
Make sure your charset is UTF-8`);u=(u>>>8&255)*192+(u&255),t.put(u,13)}};var aj=Du,Yf={exports:{}};(function(t){var e={single_source_shortest_paths:function(u,r,i){var s={},o={};o[r]=0;var f=e.PriorityQueue.make();f.push(r,0);for(var n,h,g,d,l,c,a,F,p;!f.empty();){n=f.pop(),h=n.value,d=n.cost,l=u[h]||{};for(g in l)l.hasOwnProperty(g)&&(c=l[g],a=d+c,F=o[g],p=typeof o[g]>"u",(p||F>a)&&(o[g]=a,f.push(g,a),s[g]=h))}if(typeof i<"u"&&typeof o[i]>"u"){var m=["Could not find a path from ",r," to ",i,"."].join("");throw new Error(m)}return s},extract_shortest_path_from_predecessor_list:function(u,r){for(var i=[],s=r;s;)i.push(s),u[s],s=u[s];return i.reverse(),i},find_path:function(u,r,i){var s=e.single_source_shortest_paths(u,r,i);return e.extract_shortest_path_from_predecessor_list(s,i)},PriorityQueue:{make:function(u){var r=e.PriorityQueue,i={},s;u=u||{};for(s in r)r.hasOwnProperty(s)&&(i[s]=r[s]);return i.queue=[],i.sorter=u.sorter||r.default_sorter,i},default_sorter:function(u,r){return u.cost-r.cost},push:function(u,r){var i={value:u,cost:r};this.queue.push(i),this.queue.sort(this.sorter)},pop:function(){return this.queue.shift()},empty:function(){return this.queue.length===0}}};t.exports=e})(Yf);var cj=Yf.exports;(function(t){var e=vi,u=ej,r=rj,i=sj,s=aj,o=_r,f=z0,n=cj;function h(m){return unescape(encodeURIComponent(m)).length}function g(m,b,C){for(var k=[],T;(T=m.exec(C))!==null;)k.push({data:T[0],index:T.index,mode:b,length:T[0].length});return k}function d(m){var b=g(o.NUMERIC,e.NUMERIC,m),C=g(o.ALPHANUMERIC,e.ALPHANUMERIC,m),k,T;f.isKanjiModeEnabled()?(k=g(o.BYTE,e.BYTE,m),T=g(o.KANJI,e.KANJI,m)):(k=g(o.BYTE_KANJI,e.BYTE,m),T=[]);var w=b.concat(C,k,T);return w.sort(function(A,M){return A.index-M.index}).map(function(A){return{data:A.data,mode:A.mode,length:A.length}})}function l(m,b){switch(b){case e.NUMERIC:return u.getBitsLength(m);case e.ALPHANUMERIC:return r.getBitsLength(m);case e.KANJI:return s.getBitsLength(m);case e.BYTE:return i.getBitsLength(m)}}function c(m){return m.reduce(function(b,C){var k=b.length-1>=0?b[b.length-1]:null;return k&&k.mode===C.mode?(b[b.length-1].data+=C.data,b):(b.push(C),b)},[])}function a(m){for(var b=[],C=0;C<m.length;C++){var k=m[C];switch(k.mode){case e.NUMERIC:b.push([k,{data:k.data,mode:e.ALPHANUMERIC,length:k.length},{data:k.data,mode:e.BYTE,length:k.length}]);break;case e.ALPHANUMERIC:b.push([k,{data:k.data,mode:e.BYTE,length:k.length}]);break;case e.KANJI:b.push([k,{data:k.data,mode:e.BYTE,length:h(k.data)}]);break;case e.BYTE:b.push([{data:k.data,mode:e.BYTE,length:h(k.data)}])}}return b}function F(m,b){for(var C={},k={start:{}},T=["start"],w=0;w<m.length;w++){for(var A=m[w],M=[],x=0;x<A.length;x++){var R=A[x],N=""+w+x;M.push(N),C[N]={node:R,lastCount:0},k[N]={};for(var j=0;j<T.length;j++){var B=T[j];C[B]&&C[B].node.mode===R.mode?(k[B][N]=l(C[B].lastCount+R.length,R.mode)-l(C[B].lastCount,R.mode),C[B].lastCount+=R.length):(C[B]&&(C[B].lastCount=R.length),k[B][N]=l(R.length,R.mode)+4+e.getCharCountIndicator(R.mode,b))}}T=M}for(j=0;j<T.length;j++)k[T[j]].end=0;return{map:k,table:C}}function p(m,b){var C,k=e.getBestModeForData(m);if(C=e.from(b,k),C!==e.BYTE&&C.bit<k.bit)throw new Error('"'+m+'" cannot be encoded with mode '+e.toString(C)+`.
 Suggested mode is: `+e.toString(k));switch(C===e.KANJI&&!f.isKanjiModeEnabled()&&(C=e.BYTE),C){case e.NUMERIC:return new u(m);case e.ALPHANUMERIC:return new r(m);case e.KANJI:return new s(m);case e.BYTE:return new i(m)}}t.fromArray=function(b){return b.reduce(function(C,k){return typeof k=="string"?C.push(p(k,null)):k.data&&C.push(p(k.data,k.mode)),C},[])},t.fromString=function(b,C){for(var k=d(b,f.isKanjiModeEnabled()),T=a(k),w=F(T,C),A=n.find_path(w.map,"start","end"),M=[],x=1;x<A.length-1;x++)M.push(w.table[A[x]].node);return t.fromArray(c(M))},t.rawSplit=function(b){return t.fromArray(d(b,f.isKanjiModeEnabled()))}})(Kf);var l2=mi,Lo=z0,Ea=Do,lj=Lk,dj=Rk,Fj=Bf,hj=If,ic=Of,uc=Mo,gj=Vk,Hn=qf,pj=Vf,fj=vi,Aa=Kf,mj=Ml;function vj(t,e){for(var u=t.size,r=hj.getPositions(e),i=0;i<r.length;i++)for(var s=r[i][0],o=r[i][1],f=-1;f<=7;f++)if(!(s+f<=-1||u<=s+f))for(var n=-1;n<=7;n++)o+n<=-1||u<=o+n||(f>=0&&f<=6&&(n===0||n===6)||n>=0&&n<=6&&(f===0||f===6)||f>=2&&f<=4&&n>=2&&n<=4?t.set(s+f,o+n,!0,!0):t.set(s+f,o+n,!1,!0))}function bj(t){for(var e=t.size,u=8;u<e-8;u++){var r=u%2===0;t.set(u,6,r,!0),t.set(6,u,r,!0)}}function wj(t,e){for(var u=Fj.getPositions(e),r=0;r<u.length;r++)for(var i=u[r][0],s=u[r][1],o=-2;o<=2;o++)for(var f=-2;f<=2;f++)o===-2||o===2||f===-2||f===2||o===0&&f===0?t.set(i+o,s+f,!0,!0):t.set(i+o,s+f,!1,!0)}function yj(t,e){for(var u=t.size,r=Hn.getEncodedBits(e),i,s,o,f=0;f<18;f++)i=Math.floor(f/3),s=f%3+u-8-3,o=(r>>f&1)===1,t.set(i,s,o,!0),t.set(s,i,o,!0)}function xa(t,e,u){var r=t.size,i=pj.getEncodedBits(e,u),s,o;for(s=0;s<15;s++)o=(i>>s&1)===1,s<6?t.set(s,8,o,!0):s<8?t.set(s+1,8,o,!0):t.set(r-15+s,8,o,!0),s<8?t.set(8,r-s-1,o,!0):s<9?t.set(8,15-s-1+1,o,!0):t.set(8,15-s-1,o,!0);t.set(r-8,8,1,!0)}function Cj(t,e){for(var u=t.size,r=-1,i=u-1,s=7,o=0,f=u-1;f>0;f-=2)for(f===6&&f--;;){for(var n=0;n<2;n++)if(!t.isReserved(i,f-n)){var h=!1;o<e.length&&(h=(e[o]>>>s&1)===1),t.set(i,f-n,h),s--,s===-1&&(o++,s=7)}if(i+=r,i<0||u<=i){i-=r,r=-r;break}}}function Ej(t,e,u){var r=new lj;u.forEach(function(h){r.put(h.mode.bit,4),r.put(h.getLength(),fj.getCharCountIndicator(h.mode,t)),h.write(r)});var i=Lo.getSymbolTotalCodewords(t),s=uc.getTotalCodewordsCount(t,e),o=(i-s)*8;for(r.getLengthInBits()+4<=o&&r.put(0,4);r.getLengthInBits()%8!==0;)r.putBit(0);for(var f=(o-r.getLengthInBits())/8,n=0;n<f;n++)r.put(n%2?17:236,8);return Aj(r,t,e)}function Aj(t,e,u){for(var r=Lo.getSymbolTotalCodewords(e),i=uc.getTotalCodewordsCount(e,u),s=r-i,o=uc.getBlocksCount(e,u),f=r%o,n=o-f,h=Math.floor(r/o),g=Math.floor(s/o),d=g+1,l=h-g,c=new gj(l),a=0,F=new Array(o),p=new Array(o),m=0,b=l2.from(t.buffer),C=0;C<o;C++){var k=C<n?g:d;F[C]=b.slice(a,a+k),p[C]=c.encode(F[C]),a+=k,m=Math.max(m,k)}var T=l2.alloc(r),w=0,A,M;for(A=0;A<m;A++)for(M=0;M<o;M++)A<F[M].length&&(T[w++]=F[M][A]);for(A=0;A<l;A++)for(M=0;M<o;M++)T[w++]=p[M][A];return T}function xj(t,e,u,r){var i;if(mj(t))i=Aa.fromArray(t);else if(typeof t=="string"){var s=e;if(!s){var o=Aa.rawSplit(t);s=Hn.getBestVersionForData(o,u)}i=Aa.fromString(t,s||40)}else throw new Error("Invalid data");var f=Hn.getBestVersionForData(i,u);if(!f)throw new Error("The amount of data is too big to be stored in a QR Code");if(!e)e=f;else if(e<f)throw new Error(`
The chosen QR Code version cannot contain this amount of data.
Minimum version required to store current data is: `+f+`.
`);var n=Ej(e,u,i),h=Lo.getSymbolSize(e),g=new dj(h);return vj(g,e),bj(g),wj(g,e),xa(g,u,0),e>=7&&yj(g,e),Cj(g,n),isNaN(r)&&(r=ic.getBestMask(g,xa.bind(null,g,u))),ic.applyMask(r,g),xa(g,u,r),{modules:g,version:e,errorCorrectionLevel:u,maskPattern:r,segments:i}}Mf.create=function(e,u){if(typeof e>"u"||e==="")throw new Error("No input text");var r=Ea.M,i,s;return typeof u<"u"&&(r=Ea.from(u.errorCorrectionLevel,Ea.M),i=Hn.from(u.version),s=ic.from(u.maskPattern),u.toSJISFunc&&Lo.setToSJISFunction(u.toSJISFunc)),xj(e,i,r,s)};var Jf={},Il={};(function(t){function e(u){if(typeof u=="number"&&(u=u.toString()),typeof u!="string")throw new Error("Color should be defined as hex string");var r=u.slice().replace("#","").split("");if(r.length<3||r.length===5||r.length>8)throw new Error("Invalid hex color: "+u);(r.length===3||r.length===4)&&(r=Array.prototype.concat.apply([],r.map(function(s){return[s,s]}))),r.length===6&&r.push("F","F");var i=parseInt(r.join(""),16);return{r:i>>24&255,g:i>>16&255,b:i>>8&255,a:i&255,hex:"#"+r.slice(0,6).join("")}}t.getOptions=function(r){r||(r={}),r.color||(r.color={});var i=typeof r.margin>"u"||r.margin===null||r.margin<0?4:r.margin,s=r.width&&r.width>=21?r.width:void 0,o=r.scale||4;return{width:s,scale:s?4:o,margin:i,color:{dark:e(r.color.dark||"#000000ff"),light:e(r.color.light||"#ffffffff")},type:r.type,rendererOpts:r.rendererOpts||{}}},t.getScale=function(r,i){return i.width&&i.width>=r+i.margin*2?i.width/(r+i.margin*2):i.scale},t.getImageWidth=function(r,i){var s=t.getScale(r,i);return Math.floor((r+i.margin*2)*s)},t.qrToImageData=function(r,i,s){for(var o=i.modules.size,f=i.modules.data,n=t.getScale(o,s),h=Math.floor((o+s.margin*2)*n),g=s.margin*n,d=[s.color.light,s.color.dark],l=0;l<h;l++)for(var c=0;c<h;c++){var a=(l*h+c)*4,F=s.color.light;if(l>=g&&c>=g&&l<h-g&&c<h-g){var p=Math.floor((l-g)/n),m=Math.floor((c-g)/n);F=d[f[p*o+m]?1:0]}r[a++]=F.r,r[a++]=F.g,r[a++]=F.b,r[a]=F.a}}})(Il);(function(t){var e=Il;function u(i,s,o){i.clearRect(0,0,s.width,s.height),s.style||(s.style={}),s.height=o,s.width=o,s.style.height=o+"px",s.style.width=o+"px"}function r(){try{return document.createElement("canvas")}catch{throw new Error("You need to specify a canvas element")}}t.render=function(s,o,f){var n=f,h=o;typeof n>"u"&&(!o||!o.getContext)&&(n=o,o=void 0),o||(h=r()),n=e.getOptions(n);var g=e.getImageWidth(s.modules.size,n),d=h.getContext("2d"),l=d.createImageData(g,g);return e.qrToImageData(l.data,s,n),u(d,h,g),d.putImageData(l,0,0),h},t.renderToDataURL=function(s,o,f){var n=f;typeof n>"u"&&(!o||!o.getContext)&&(n=o,o=void 0),n||(n={});var h=t.render(s,o,n),g=n.type||"image/png",d=n.rendererOpts||{};return h.toDataURL(g,d.quality)}})(Jf);var Qf={},kj=Il;function d2(t,e){var u=t.a/255,r=e+'="'+t.hex+'"';return u<1?r+" "+e+'-opacity="'+u.toFixed(2).slice(1)+'"':r}function ka(t,e,u){var r=t+e;return typeof u<"u"&&(r+=" "+u),r}function jj(t,e,u){for(var r="",i=0,s=!1,o=0,f=0;f<t.length;f++){var n=Math.floor(f%e),h=Math.floor(f/e);!n&&!s&&(s=!0),t[f]?(o++,f>0&&n>0&&t[f-1]||(r+=s?ka("M",n+u,.5+h+u):ka("m",i,0),i=0,s=!1),n+1<e&&t[f+1]||(r+=ka("h",o),o=0)):i++}return r}Qf.render=function(e,u,r){var i=kj.getOptions(u),s=e.modules.size,o=e.modules.data,f=s+i.margin*2,n=i.color.light.a?"<path "+d2(i.color.light,"fill")+' d="M0 0h'+f+"v"+f+'H0z"/>':"",h="<path "+d2(i.color.dark,"stroke")+' d="'+jj(o,s,i.margin)+'"/>',g='viewBox="0 0 '+f+" "+f+'"',d=i.width?'width="'+i.width+'" height="'+i.width+'" ':"",l='<svg xmlns="http://www.w3.org/2000/svg" '+d+g+' shape-rendering="crispEdges">'+n+h+`</svg>
`;return typeof r=="function"&&r(null,l),l};var Sj=Ck,sc=Mf,Xf=Jf,_j=Qf;function Ol(t,e,u,r,i){var s=[].slice.call(arguments,1),o=s.length,f=typeof s[o-1]=="function";if(!f&&!Sj())throw new Error("Callback required as last argument");if(f){if(o<2)throw new Error("Too few arguments provided");o===2?(i=u,u=e,e=r=void 0):o===3&&(e.getContext&&typeof i>"u"?(i=r,r=void 0):(i=r,r=u,u=e,e=void 0))}else{if(o<1)throw new Error("Too few arguments provided");return o===1?(u=e,e=r=void 0):o===2&&!e.getContext&&(r=u,u=e,e=void 0),new Promise(function(h,g){try{var d=sc.create(u,r);h(t(d,e,r))}catch(l){g(l)}})}try{var n=sc.create(u,r);i(null,t(n,e,r))}catch(h){i(h)}}$s.create=sc.create;$s.toCanvas=Ol.bind(null,Xf.render);$s.toDataURL=Ol.bind(null,Xf.renderToDataURL);$s.toString=Ol.bind(null,function(t,e,u){return _j.render(t,u)});var Hu={},Un={exports:{}};/*! https://mths.be/punycode v1.3.2 by @mathias */Un.exports;(function(t,e){(function(u){var r=e&&!e.nodeType&&e,i=t&&!t.nodeType&&t,s=typeof yr=="object"&&yr;(s.global===s||s.window===s||s.self===s)&&(u=s);var o,f=2147483647,n=36,h=1,g=26,d=38,l=700,c=72,a=128,F="-",p=/^xn--/,m=/[^\x20-\x7E]/,b=/[\x2E\u3002\uFF0E\uFF61]/g,C={overflow:"Overflow: input needs wider integers to process","not-basic":"Illegal input >= 0x80 (not a basic code point)","invalid-input":"Invalid input"},k=n-h,T=Math.floor,w=String.fromCharCode,A;function M(de){throw RangeError(C[de])}function x(de,he){for(var Fe=de.length,ge=[];Fe--;)ge[Fe]=he(de[Fe]);return ge}function R(de,he){var Fe=de.split("@"),ge="";Fe.length>1&&(ge=Fe[0]+"@",de=Fe[1]),de=de.replace(b,".");var ye=de.split("."),Y=x(ye,he).join(".");return ge+Y}function N(de){for(var he=[],Fe=0,ge=de.length,ye,Y;Fe<ge;)ye=de.charCodeAt(Fe++),ye>=55296&&ye<=56319&&Fe<ge?(Y=de.charCodeAt(Fe++),(Y&64512)==56320?he.push(((ye&1023)<<10)+(Y&1023)+65536):(he.push(ye),Fe--)):he.push(ye);return he}function j(de){return x(de,function(he){var Fe="";return he>65535&&(he-=65536,Fe+=w(he>>>10&1023|55296),he=56320|he&1023),Fe+=w(he),Fe}).join("")}function B(de){return de-48<10?de-22:de-65<26?de-65:de-97<26?de-97:n}function q(de,he){return de+22+75*(de<26)-((he!=0)<<5)}function U(de,he,Fe){var ge=0;for(de=Fe?T(de/l):de>>1,de+=T(de/he);de>k*g>>1;ge+=n)de=T(de/k);return T(ge+(k+1)*de/(de+d))}function Z(de){var he=[],Fe=de.length,ge,ye=0,Y=a,ue=c,Ee,ne,me,se,ve,Pe,Ie,z,G;for(Ee=de.lastIndexOf(F),Ee<0&&(Ee=0),ne=0;ne<Ee;++ne)de.charCodeAt(ne)>=128&&M("not-basic"),he.push(de.charCodeAt(ne));for(me=Ee>0?Ee+1:0;me<Fe;){for(se=ye,ve=1,Pe=n;me>=Fe&&M("invalid-input"),Ie=B(de.charCodeAt(me++)),(Ie>=n||Ie>T((f-ye)/ve))&&M("overflow"),ye+=Ie*ve,z=Pe<=ue?h:Pe>=ue+g?g:Pe-ue,!(Ie<z);Pe+=n)G=n-z,ve>T(f/G)&&M("overflow"),ve*=G;ge=he.length+1,ue=U(ye-se,ge,se==0),T(ye/ge)>f-Y&&M("overflow"),Y+=T(ye/ge),ye%=ge,he.splice(ye++,0,Y)}return j(he)}function re(de){var he,Fe,ge,ye,Y,ue,Ee,ne,me,se,ve,Pe=[],Ie,z,G,O;for(de=N(de),Ie=de.length,he=a,Fe=0,Y=c,ue=0;ue<Ie;++ue)ve=de[ue],ve<128&&Pe.push(w(ve));for(ge=ye=Pe.length,ye&&Pe.push(F);ge<Ie;){for(Ee=f,ue=0;ue<Ie;++ue)ve=de[ue],ve>=he&&ve<Ee&&(Ee=ve);for(z=ge+1,Ee-he>T((f-Fe)/z)&&M("overflow"),Fe+=(Ee-he)*z,he=Ee,ue=0;ue<Ie;++ue)if(ve=de[ue],ve<he&&++Fe>f&&M("overflow"),ve==he){for(ne=Fe,me=n;se=me<=Y?h:me>=Y+g?g:me-Y,!(ne<se);me+=n)O=ne-se,G=n-se,Pe.push(w(q(se+O%G,0))),ne=T(O/G);Pe.push(w(q(ne,0))),Y=U(Fe,z,ge==ye),Fe=0,++ge}++Fe,++he}return Pe.join("")}function le(de){return R(de,function(he){return p.test(he)?Z(he.slice(4).toLowerCase()):he})}function ce(de){return R(de,function(he){return m.test(he)?"xn--"+re(he):he})}if(o={version:"1.3.2",ucs2:{decode:N,encode:j},decode:Z,encode:re,toASCII:ce,toUnicode:le},r&&i)if(t.exports==r)i.exports=o;else for(A in o)o.hasOwnProperty(A)&&(r[A]=o[A]);else u.punycode=o})(yr)})(Un,Un.exports);var Dj=Un.exports,Mj={isString:function(t){return typeof t=="string"},isObject:function(t){return typeof t=="object"&&t!==null},isNull:function(t){return t===null},isNullOrUndefined:function(t){return t==null}},Ms={};function Tj(t,e){return Object.prototype.hasOwnProperty.call(t,e)}var Pj=function(t,e,u,r){e=e||"&",u=u||"=";var i={};if(typeof t!="string"||t.length===0)return i;var s=/\+/g;t=t.split(e);var o=1e3;r&&typeof r.maxKeys=="number"&&(o=r.maxKeys);var f=t.length;o>0&&f>o&&(f=o);for(var n=0;n<f;++n){var h=t[n].replace(s,"%20"),g=h.indexOf(u),d,l,c,a;g>=0?(d=h.substr(0,g),l=h.substr(g+1)):(d=h,l=""),c=decodeURIComponent(d),a=decodeURIComponent(l),Tj(i,c)?Array.isArray(i[c])?i[c].push(a):i[c]=[i[c],a]:i[c]=a}return i},es=function(t){switch(typeof t){case"string":return t;case"boolean":return t?"true":"false";case"number":return isFinite(t)?t:"";default:return""}},Lj=function(t,e,u,r){return e=e||"&",u=u||"=",t===null&&(t=void 0),typeof t=="object"?Object.keys(t).map(function(i){var s=encodeURIComponent(es(i))+u;return Array.isArray(t[i])?t[i].map(function(o){return s+encodeURIComponent(es(o))}).join(e):s+encodeURIComponent(es(t[i]))}).join(e):r?encodeURIComponent(es(r))+u+encodeURIComponent(es(t)):""};Ms.decode=Ms.parse=Pj;Ms.encode=Ms.stringify=Lj;var Rj=Dj,vr=Mj;Hu.parse=Ws;Hu.resolve=zj;Hu.resolveObject=Vj;Hu.format=qj;Hu.Url=X0;function X0(){this.protocol=null,this.slashes=null,this.auth=null,this.host=null,this.port=null,this.hostname=null,this.hash=null,this.search=null,this.query=null,this.pathname=null,this.path=null,this.href=null}var Bj=/^([a-z0-9.+-]+:)/i,Ij=/:[0-9]*$/,Oj=/^(\/\/?(?!\/)[^\?\s]*)(\?[^\s]*)?$/,$j=["<",">",'"',"`"," ","\r",`
`,"	"],Nj=["{","}","|","\\","^","`"].concat($j),nc=["'"].concat(Nj),F2=["%","/","?",";","#"].concat(nc),h2=["/","?","#"],Wj=255,g2=/^[+a-z0-9A-Z_-]{0,63}$/,Hj=/^([+a-z0-9A-Z_-]{0,63})(.*)$/,Uj={javascript:!0,"javascript:":!0},oc={javascript:!0,"javascript:":!0},yu={http:!0,https:!0,ftp:!0,gopher:!0,file:!0,"http:":!0,"https:":!0,"ftp:":!0,"gopher:":!0,"file:":!0},ac=Ms;function Ws(t,e,u){if(t&&vr.isObject(t)&&t instanceof X0)return t;var r=new X0;return r.parse(t,e,u),r}X0.prototype.parse=function(t,e,u){if(!vr.isString(t))throw new TypeError("Parameter 'url' must be a string, not "+typeof t);var r=t.indexOf("?"),i=r!==-1&&r<t.indexOf("#")?"?":"#",s=t.split(i),o=/\\/g;s[0]=s[0].replace(o,"/"),t=s.join(i);var f=t;if(f=f.trim(),!u&&t.split("#").length===1){var n=Oj.exec(f);if(n)return this.path=f,this.href=f,this.pathname=n[1],n[2]?(this.search=n[2],e?this.query=ac.parse(this.search.substr(1)):this.query=this.search.substr(1)):e&&(this.search="",this.query={}),this}var h=Bj.exec(f);if(h){h=h[0];var g=h.toLowerCase();this.protocol=g,f=f.substr(h.length)}if(u||h||f.match(/^\/\/[^@\/]+@[^@\/]+/)){var d=f.substr(0,2)==="//";d&&!(h&&oc[h])&&(f=f.substr(2),this.slashes=!0)}if(!oc[h]&&(d||h&&!yu[h])){for(var l=-1,c=0;c<h2.length;c++){var a=f.indexOf(h2[c]);a!==-1&&(l===-1||a<l)&&(l=a)}var F,p;l===-1?p=f.lastIndexOf("@"):p=f.lastIndexOf("@",l),p!==-1&&(F=f.slice(0,p),f=f.slice(p+1),this.auth=decodeURIComponent(F)),l=-1;for(var c=0;c<F2.length;c++){var a=f.indexOf(F2[c]);a!==-1&&(l===-1||a<l)&&(l=a)}l===-1&&(l=f.length),this.host=f.slice(0,l),f=f.slice(l),this.parseHost(),this.hostname=this.hostname||"";var m=this.hostname[0]==="["&&this.hostname[this.hostname.length-1]==="]";if(!m)for(var b=this.hostname.split(/\./),c=0,C=b.length;c<C;c++){var k=b[c];if(k&&!k.match(g2)){for(var T="",w=0,A=k.length;w<A;w++)k.charCodeAt(w)>127?T+="x":T+=k[w];if(!T.match(g2)){var M=b.slice(0,c),x=b.slice(c+1),R=k.match(Hj);R&&(M.push(R[1]),x.unshift(R[2])),x.length&&(f="/"+x.join(".")+f),this.hostname=M.join(".");break}}}this.hostname.length>Wj?this.hostname="":this.hostname=this.hostname.toLowerCase(),m||(this.hostname=Rj.toASCII(this.hostname));var N=this.port?":"+this.port:"",j=this.hostname||"";this.host=j+N,this.href+=this.host,m&&(this.hostname=this.hostname.substr(1,this.hostname.length-2),f[0]!=="/"&&(f="/"+f))}if(!Uj[g])for(var c=0,C=nc.length;c<C;c++){var B=nc[c];if(f.indexOf(B)!==-1){var q=encodeURIComponent(B);q===B&&(q=escape(B)),f=f.split(B).join(q)}}var U=f.indexOf("#");U!==-1&&(this.hash=f.substr(U),f=f.slice(0,U));var Z=f.indexOf("?");if(Z!==-1?(this.search=f.substr(Z),this.query=f.substr(Z+1),e&&(this.query=ac.parse(this.query)),f=f.slice(0,Z)):e&&(this.search="",this.query={}),f&&(this.pathname=f),yu[g]&&this.hostname&&!this.pathname&&(this.pathname="/"),this.pathname||this.search){var N=this.pathname||"",re=this.search||"";this.path=N+re}return this.href=this.format(),this};function qj(t){return vr.isString(t)&&(t=Ws(t)),t instanceof X0?t.format():X0.prototype.format.call(t)}X0.prototype.format=function(){var t=this.auth||"";t&&(t=encodeURIComponent(t),t=t.replace(/%3A/i,":"),t+="@");var e=this.protocol||"",u=this.pathname||"",r=this.hash||"",i=!1,s="";this.host?i=t+this.host:this.hostname&&(i=t+(this.hostname.indexOf(":")===-1?this.hostname:"["+this.hostname+"]"),this.port&&(i+=":"+this.port)),this.query&&vr.isObject(this.query)&&Object.keys(this.query).length&&(s=ac.stringify(this.query));var o=this.search||s&&"?"+s||"";return e&&e.substr(-1)!==":"&&(e+=":"),this.slashes||(!e||yu[e])&&i!==!1?(i="//"+(i||""),u&&u.charAt(0)!=="/"&&(u="/"+u)):i||(i=""),r&&r.charAt(0)!=="#"&&(r="#"+r),o&&o.charAt(0)!=="?"&&(o="?"+o),u=u.replace(/[?#]/g,function(f){return encodeURIComponent(f)}),o=o.replace("#","%23"),e+i+u+o+r};function zj(t,e){return Ws(t,!1,!0).resolve(e)}X0.prototype.resolve=function(t){return this.resolveObject(Ws(t,!1,!0)).format()};function Vj(t,e){return t?Ws(t,!1,!0).resolveObject(e):e}X0.prototype.resolveObject=function(t){if(vr.isString(t)){var e=new X0;e.parse(t,!1,!0),t=e}for(var u=new X0,r=Object.keys(this),i=0;i<r.length;i++){var s=r[i];u[s]=this[s]}if(u.hash=t.hash,t.href==="")return u.href=u.format(),u;if(t.slashes&&!t.protocol){for(var o=Object.keys(t),f=0;f<o.length;f++){var n=o[f];n!=="protocol"&&(u[n]=t[n])}return yu[u.protocol]&&u.hostname&&!u.pathname&&(u.path=u.pathname="/"),u.href=u.format(),u}if(t.protocol&&t.protocol!==u.protocol){if(!yu[t.protocol]){for(var h=Object.keys(t),g=0;g<h.length;g++){var d=h[g];u[d]=t[d]}return u.href=u.format(),u}if(u.protocol=t.protocol,!t.host&&!oc[t.protocol]){for(var C=(t.pathname||"").split("/");C.length&&!(t.host=C.shift()););t.host||(t.host=""),t.hostname||(t.hostname=""),C[0]!==""&&C.unshift(""),C.length<2&&C.unshift(""),u.pathname=C.join("/")}else u.pathname=t.pathname;if(u.search=t.search,u.query=t.query,u.host=t.host||"",u.auth=t.auth,u.hostname=t.hostname||t.host,u.port=t.port,u.pathname||u.search){var l=u.pathname||"",c=u.search||"";u.path=l+c}return u.slashes=u.slashes||t.slashes,u.href=u.format(),u}var a=u.pathname&&u.pathname.charAt(0)==="/",F=t.host||t.pathname&&t.pathname.charAt(0)==="/",p=F||a||u.host&&t.pathname,m=p,b=u.pathname&&u.pathname.split("/")||[],C=t.pathname&&t.pathname.split("/")||[],k=u.protocol&&!yu[u.protocol];if(k&&(u.hostname="",u.port=null,u.host&&(b[0]===""?b[0]=u.host:b.unshift(u.host)),u.host="",t.protocol&&(t.hostname=null,t.port=null,t.host&&(C[0]===""?C[0]=t.host:C.unshift(t.host)),t.host=null),p=p&&(C[0]===""||b[0]==="")),F)u.host=t.host||t.host===""?t.host:u.host,u.hostname=t.hostname||t.hostname===""?t.hostname:u.hostname,u.search=t.search,u.query=t.query,b=C;else if(C.length)b||(b=[]),b.pop(),b=b.concat(C),u.search=t.search,u.query=t.query;else if(!vr.isNullOrUndefined(t.search)){if(k){u.hostname=u.host=b.shift();var T=u.host&&u.host.indexOf("@")>0?u.host.split("@"):!1;T&&(u.auth=T.shift(),u.host=u.hostname=T.shift())}return u.search=t.search,u.query=t.query,(!vr.isNull(u.pathname)||!vr.isNull(u.search))&&(u.path=(u.pathname?u.pathname:"")+(u.search?u.search:"")),u.href=u.format(),u}if(!b.length)return u.pathname=null,u.search?u.path="/"+u.search:u.path=null,u.href=u.format(),u;for(var w=b.slice(-1)[0],A=(u.host||t.host||b.length>1)&&(w==="."||w==="..")||w==="",M=0,x=b.length;x>=0;x--)w=b[x],w==="."?b.splice(x,1):w===".."?(b.splice(x,1),M++):M&&(b.splice(x,1),M--);if(!p&&!m)for(;M--;M)b.unshift("..");p&&b[0]!==""&&(!b[0]||b[0].charAt(0)!=="/")&&b.unshift(""),A&&b.join("/").substr(-1)!=="/"&&b.push("");var R=b[0]===""||b[0]&&b[0].charAt(0)==="/";if(k){u.hostname=u.host=R?"":b.length?b.shift():"";var T=u.host&&u.host.indexOf("@")>0?u.host.split("@"):!1;T&&(u.auth=T.shift(),u.host=u.hostname=T.shift())}return p=p||u.host&&b.length,p&&!R&&b.unshift(""),b.length?u.pathname=b.join("/"):(u.pathname=null,u.path=null),(!vr.isNull(u.pathname)||!vr.isNull(u.search))&&(u.path=(u.pathname?u.pathname:"")+(u.search?u.search:"")),u.auth=t.auth||u.auth,u.slashes=u.slashes||t.slashes,u.href=u.format(),u};X0.prototype.parseHost=function(){var t=this.host,e=Ij.exec(t);e&&(e=e[0],e!==":"&&(this.port=e.substr(1)),t=t.substr(0,t.length-e.length)),t&&(this.hostname=t)};var Gj=Hu,nr={INVALID_ISSUER:0,INVALID_LABEL:1,INVALID_PROTOCOL:2,MISSING_ACCOUNT_NAME:3,MISSING_COUNTER:4,MISSING_ISSUER:5,MISSING_SECRET_KEY:6,UNKNOWN_OTP:7,INVALID_DIGITS:8,UNKNOWN_ALGORITHM:9},Kj=[6,8],Yj=["SHA1","SHA256","SHA512","MD5"];function M0(t){this.name="OtpauthInvalidURL",this.message="Given otpauth:// URL is invalid. (Error "+t+")",this.errorType=t}M0.prototype=new Error;M0.prototype.constructor=M0;var Jj={parse:function(e){var u={},r=Gj.parse(e,!0);if(r.protocol!=="otpauth:")throw new M0(nr.INVALID_PROTOCOL);var i=decodeURIComponent(r.host);if(i!=="hotp"&&i!=="totp")throw new M0(nr.UNKNOWN_OTP);u.type=i;var s=decodeURIComponent(r.pathname.substring(1)),o=s.split(":"),f="",n="";if(o.length===1)n=o[0];else if(o.length===2)f=o[0],n=o[1];else throw new M0(nr.INVALID_LABEL);if(n.length<1)throw new M0(nr.MISSING_ACCOUNT_NAME);if(o.length===2&&f.length<1)throw new M0(nr.INVALID_ISSUER);u.account=n;var h=r.query;if(!h.secret)throw new M0(nr.MISSING_SECRET_KEY);if(u.key=h.secret,h.issuer&&f&&h.issuer!==f)throw new M0(nr.INVALID_ISSUER);if(u.issuer=f||h.issuer||"",u.digits=6,h.digits){var g=parseInt(h.digits,10);if(Kj.indexOf(g)==-1)throw new M0(nr.INVALID_DIGITS);u.digits=g}if(h.algorithm){if(Yj.indexOf(h.algorithm)==-1)throw new M0(nr.UNKNOWN_ALGORITHM);u.algorithm=h.algorithm}if(i==="totp"&&h.period&&(u.period=parseFloat(h.period)),i==="hotp")if(h.counter)u.counter=parseInt(h.counter,10);else throw new M0(nr.MISSING_COUNTER);return u},ErrorType:nr,OtpauthInvalidURL:M0};const Qj=zn(Jj);function Zf(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Zf(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function Xj(t){var e="",u,r;try{r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpBegin.pug",e=e+"<h2>",r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpBegin.pug",e=e+"Enable Two-factor authentication</h2>",r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpBegin.pug",e=e+'<button class="btn btn-primary" id="g-user-otp-initialize-enable" type="submit">',r=4,u="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpBegin.pug",e=e+" Begin</button>"}catch(i){Zf(i,u,r)}return e}function ja(t){var e=""+t,u=Zj.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var Zj=/["&<>]/;function em(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void em(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function eS(t){var e="",u,r,i;try{var s=t||{};(function(o){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<h2>",i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Enable Two-factor authentication</h2>",i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<ol class="g-account-otp-steps">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<li class="g-account-otp-step">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<h3>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Install an authenticator app on your mobile device.</h3>",i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<div>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"There are many compatible apps, including, but not limited to",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+`
`,i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<a href="https://support.google.com/accounts/answer/1066447?hl=en" target="_blank" rel="noopener">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Google Authenticator</a>",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+",",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+`
`,i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<a href="https://guide.duo.com/third-party-accounts" target="_blank" rel="noopener">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Duo Mobile</a>",i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+", and",i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+`
`,i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"",i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<a href="https://freeotp.github.io/" target="_blank" rel="noopener">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"FreeOTP</a>",i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+".</div></li>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<li class="g-account-otp-step">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<h3>",i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Enter your key into the authenticator app</h3>",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<div class="g-account-otp-scan-qr">',i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<h4>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Scan with your mobile device's camera:</h4>",i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<canvas id="g-user-otp-qr"></canvas></div>',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<div class="g-account-otp-enter-manual">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<h4>",i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Advanced Users:",i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<span>",i=18,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"You may enter your information manually, instead:</span></h4>",i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<table>",i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<tr>",i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<th>",i=21,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Service</th>",i=22,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<td>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<code>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+ja((u=o.issuer)==null?"":u)+"</code></td></tr>",i=24,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<tr>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<th>",i=25,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Account</th>",i=26,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<td>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<code>",i=27,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+ja((u=o.account)==null?"":u)+"</code></td></tr>",i=28,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<tr>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<th>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Key</th>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<td>",i=31,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<!-- Split into 4-character chunks for human readability-->",i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<code>",i=32,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+ja((u=o.key.match(/.{1,4}/g).join("-"))==null?"":u)+"</code></td></tr>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<tr>",i=34,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<th>",i=34,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Type</th>",i=35,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<td>",i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<span>",i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"",i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<code>",i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Time-based</code>",i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+" / ",i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<code>",i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"TOTP</code>",i=36,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"</span></td></tr></table></div></li>",i=37,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<li class="g-account-otp-step">',i=38,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<h3>",i=38,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Enter the authentication code from your app</h3>",i=39,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<input id="g-user-otp-token" type="text" minlength="6" maxlength="6" placeholder="Your 6-digit code"/>',i=40,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"<div>",i=41,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<span class="g-validation-failed-message" id="g-account-otp-error"></span></div></li></ol>',i=42,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<div class="g-user-otp-footer">',i=43,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<a class="btn btn-default" id="g-user-otp-cancel-enable">',i=43,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Cancel</a>",i=44,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+'<button class="btn btn-primary btn-success" id="g-user-otp-finalize-enable" type="submit">',i=44,r="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpEnable.pug",e=e+"Enable Two-Factor</button></div>"}).call(this,"totpInfo"in s?s.totpInfo:typeof totpInfo<"u"?totpInfo:void 0)}catch(o){em(o,r,i)}return e}function tm(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void tm(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function tS(t){var e="",u,r;try{r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpDisable.pug",e=e+'<h2 class="g-user-otp-heading-enable">',r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpDisable.pug",e=e+"Two-factor authentication is currently enabled</h2>",r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpDisable.pug",e=e+'<h3 class="g-user-otp-heading-disable">',r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpDisable.pug",e=e+"Disable Two-factor authentication</h3>",r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpDisable.pug",e=e+'<button class="btn btn-primary" id="g-user-otp-disable" type="submit">',r=6,u="/home/circleci/project/girder/girder/web/src/templates/widgets/userOtpDisable.pug",e=e+" Disable</button>"}catch(i){tm(i,u,r)}return e}const rS=Xe.extend({events:{"click #g-user-otp-initialize-enable":function(){this.model.initializeEnableOtp().done(t=>{this.totpUri=t,this.render()})},"click #g-user-otp-finalize-enable":function(){const t=this.$("#g-user-otp-token").val().trim();if(t.length!==6){this.$("#g-account-otp-error").text("Enter a 6-digit token.");return}else this.$("#g-account-otp-error").text("");this.model.finializeEnableOtp(t).done(()=>{this.totpUri=void 0,this.render()}).fail(e=>{this.$("#g-account-otp-error").text(e.responseJSON.message)})},"click #g-user-otp-cancel-enable":function(){this.totpUri=void 0,this.render()},"click #g-user-otp-disable":function(){this.model.disableOtp().done(()=>{this.render()})}},initialize:function(t){this.model=t.user},render:function(){return this.model.get("otp")?this._renderDisable():this.totpUri?this._renderConfirmation():this._renderBegin(),this},_renderBegin:function(){this.$el.html(Xj())},_renderConfirmation:function(){const t=Qj.parse(this.totpUri);this.$el.html(eS({totpInfo:t})),$s.toCanvas(this.$("#g-user-otp-qr")[0],this.totpUri,{errorCorrectionLevel:"H"})},_renderDisable:function(){this.$el.html(tS())}});function ts(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=En(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function En(t){var e=""+t,u=iS.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var iS=/["&<>]/;function rm(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void rm(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function uS(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="g-account-header">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="g-user-name g-body-title">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+En((u=h.name())==null?"":u)+"</div>",i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="g-user-description g-body-subtitle">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+En((u=h.get("login"))==null?"":u)+"</div></div>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<ul class="g-account-tabs nav nav-tabs">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<li class="active">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<a href="#g-account-tab-info" data-toggle="tab" name="info">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<i class="icon-info-circled"></i>',i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+" Profile</a></li>",i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"<li>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<a href="#g-account-tab-password" data-toggle="tab" name="password">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<i class="icon-lock"></i>',i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"Password</a></li>",i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"<li>",i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<a href="#g-account-tab-api-keys" data-toggle="tab" name="apikeys">',i=16,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<i class="icon-key-inv"></i>',i=17,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"API keys</a></li>",i=18,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"<li>",i=19,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<a href="#g-account-tab-otp" data-toggle="tab" name="otp">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<i class="icon-mobile"></i>',i=21,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"Two-factor authentication</a></li></ul>",i=23,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="tab-content">',i=24,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="tab-pane active" id="g-account-tab-info">',i=25,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="g-user-info-container g-user-settings-container">',i=26,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<form id="g-user-info-form" role="form">',i=27,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="form-group">',i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<label for="g-login">',i=28,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"Login</label>",i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<p class="form-control-static">',i=29,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+En((u=h.get("login"))==null?"":u)+"</p></div>",i=30,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="form-group">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<label for="g-email">',i=31,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"Email</label>",i=32,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"<input"+(' class="input-sm form-control" id="g-email" type="text"'+ts("value",h.get("email"),!0,!1))+"/></div>",i=33,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="form-group">',i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<label for="g-firstName">',i=34,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"First name</label>",i=35,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"<input"+(' class="input-sm form-control" id="g-firstName" type="text"'+ts("value",h.get("firstName"),!0,!1))+"/></div>",i=36,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="form-group">',i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<label for="g-lastName">',i=37,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"Last name</label>",i=38,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"<input"+(' class="input-sm form-control" id="g-lastName" type="text"'+ts("value",h.get("lastName"),!0,!1))+"/></div>",i=39,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",o().get("admin")&&(i=40,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="form-group">',i=41,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<label for="g-admin">',i=41,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"User is site admin</label>",i=42,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"<input"+(' class="input-sm-form-control" id="g-admin" type="checkbox"'+ts("checked",h.get("admin"),!0,!1))+"/></div>"),i=43,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<button class="btn btn-default btn-sm" type="submit">',i=44,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<i class="icon-edit"></i>',i=45,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"Save</button>",i=46,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="g-validation-failed-message" id="g-user-info-error-msg"></div></form></div></div>',i=48,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="tab-pane" id="g-account-tab-password">',i=49,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="g-password-change-container g-user-settings-container">',i=50,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<form id="g-password-change-form" role="form">',i=51,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",n?(i=52,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"<input"+(' class="input-sm form-control" id="g-password-old" type="hidden"'+ts("value",n,!0,!1))+"/>"):f&&(i=54,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="form-group">',i=55,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<label for="g-password-old">',i=55,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"Current password</label>",i=56,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<input class="input-sm form-control" id="g-password-old" type="password" placeholder="Enter current password"/></div>'),i=57,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="form-group">',i=58,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<label for="g-password-new">',i=58,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"New password</label>",i=59,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<input class="input-sm form-control" id="g-password-new" type="password" placeholder="Enter new password"/></div>',i=60,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="form-group">',i=61,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<label for="g-password-retype">',i=61,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"Retype new password</label>",i=62,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<input class="input-sm form-control" id="g-password-retype" type="password" placeholder="Retype new password"/></div>',i=63,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<button class="btn btn-default btn-sm" type="submit">',i=64,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<i class="icon-lock"></i>',i=65,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"Change</button>",i=66,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="g-validation-failed-message" id="g-password-change-error-msg"></div></form></div></div>',i=67,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="tab-pane" id="g-account-tab-api-keys">',i=68,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="g-api-keys-container g-user-settings-container">',i=69,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="g-api-keys-info-text">',i=70,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"API keys can be used to grant limited or total access to client applications on your behalf.",i=71,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+`
`,i=71,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"Clients can use these keys to create tokens that can be used for authenticated access. You may",i=72,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+`
`,i=72,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"limit the tokens created with a given key to certain authorization scopes, or allow the tokens",i=73,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+`
`,i=73,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"complete access to everything your user can do. You may also choose the maximum time that",i=74,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+`
`,i=74,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"tokens created with a given key will last before expiration. If you do not specify a duration,",i=75,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+`
`,i=75,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"the default expiration for user login sessions will be used.",i=76,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+`
`,i=76,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"</div>",i=77,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="g-api-keys-list-container"></div></div></div>',i=78,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="tab-pane" id="g-account-tab-otp">',i=79,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="g-user-settings-container">',i=80,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="g-account-otp-info-text">',i=81,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"Two-factor authentication adds another level of authentication to your account log-in.",i=82,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+`
`,i=82,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+"</div>",i=83,r="/home/circleci/project/girder/girder/web/src/templates/body/userAccount.pug",e=e+'<div class="g-account-otp-container"></div></div></div></div>'}).call(this,"getCurrentUser"in s?s.getCurrentUser:typeof getCurrentUser<"u"?getCurrentUser:void 0,"isCurrentUser"in s?s.isCurrentUser:typeof isCurrentUser<"u"?isCurrentUser:void 0,"temporaryToken"in s?s.temporaryToken:typeof temporaryToken<"u"?temporaryToken:void 0,"user"in s?s.user:typeof user<"u"?user:void 0)}catch(o){rm(o,r,i)}return e}var Ro=Xe.extend({events:{"submit #g-user-info-form":function(t){t.preventDefault(),this.$("#g-user-info-error-msg").empty();var e={email:this.$("#g-email").val(),firstName:this.$("#g-firstName").val(),lastName:this.$("#g-lastName").val()};this.$("#g-admin").length>0&&(e.admin=this.$("#g-admin").is(":checked")),this.user.set(e),this.user.off("g:error").on("g:error",function(u){var r=u.responseJSON.message;this.$("#g-"+u.responseJSON.field).trigger("focus"),this.$("#g-user-info-error-msg").text(r)},this).off("g:saved").on("g:saved",function(){He.trigger("g:alert",{icon:"ok",text:"Info saved.",type:"success",timeout:4e3})},this).save()},"submit #g-password-change-form":function(t){if(t.preventDefault(),this.$("#g-password-change-error-msg").empty(),this.$("#g-password-new").val()!==this.$("#g-password-retype").val()){this.$("#g-password-change-error-msg").text("Passwords do not match, try again."),this.$("#g-password-retype,#g-password-new").val(""),this.$("#g-password-new").trigger("focus");return}this.user.off("g:error").on("g:error",function(e){var u=e.responseJSON.message;this.$("#g-password-change-error-msg").text(u)},this).off("g:passwordChanged").on("g:passwordChanged",function(){He.trigger("g:alert",{icon:"ok",text:"Password changed.",type:"success",timeout:4e3}),this.$("#g-password-old,#g-password-new,#g-password-retype").val("")},this),this.isCurrentUser?this.user.changePassword(this.$("#g-password-old").val(),this.$("#g-password-new").val()):this.user.adminChangePassword(this.$("#g-password-new").val())}},initialize:function(t){if(this.tab=t.tab||"info",this.user=t.user||ft(),this.isCurrentUser=ft()&&t.user.id===ft().id,this.model=this.user,this.temporary=t.temporary,!this.user||this.user.getAccessLevel()<nt.WRITE){tt.navigate("",{trigger:!0});return}x0("fetch"),this.apiKeyListWidget=new Df({user:this.user,parentView:this}),this.userOtpManagementWidget=new rS({user:this.user,parentView:this}),this.render()},render:function(){if(ft()===null){tt.navigate("",{trigger:!0});return}return this.$el.html(uS({user:this.model,isCurrentUser:this.isCurrentUser,getCurrentUser:ft,temporaryToken:this.temporary})),xe.each(ke(".g-account-tabs>li>a"),function(t){var e=ke(t);e.tab().on("shown.bs.tab",u=>{this.tab=ke(u.currentTarget).attr("name"),tt.navigate("useraccount/"+this.model.id+"/"+this.tab),this.tab==="apikeys"?this.apiKeyListWidget.setElement(this.$(".g-api-keys-list-container")).render():this.tab==="otp"&&this.userOtpManagementWidget.setElement(this.$(".g-account-otp-container")).render()}),e.attr("name")===this.tab&&e.tab("show")},this),this}},{fetchAndInit:function(t,e){var u=new p0;u.set({_id:t}).on("g:fetched",function(){He.trigger("g:navigateTo",Ro,{user:u,tab:e})},this).on("g:error",function(){tt.navigate("",{trigger:!0})},this).fetch()}}),sS=Xe.extend({events:{"click .g-page-next:not(.disabled)":function(){this._updateHasNextPage(!0)},"click .g-page-prev:not(.disabled)":function(){this._updateHasPreviousPage(!0)}},initialize:function(t){this._type=t.type,this._query=t.query,this._mode=t.mode,this._limit=t.limit,this._offset=0,this._currentPage=0,this._hasNextPage=!1,this._hasPreviousPage=!1,this.results=null,this._updateHasNextPage()},render:function(){return this.$el.html(Up({collection:this})),this.$(".g-page-next").girderEnable(this._hasNextPage),this.$(".g-page-prev").girderEnable(this._hasPreviousPage),!this._hasNextPage&&!this._hasPreviousPage?this.$el.hide():this.$el.show(),this},pageNum:function(){return this._currentPage},_updateHasPreviousPage:function(t=!1){return this._currentPage?t?this._fetchPreviousPage(t).done(()=>this._fetchPreviousPage()):this._fetchPreviousPage():this._fetchPreviousPage()},_updateHasNextPage:function(t=!1){return t?this._fetchNextPage(t).done(()=>this._fetchNextPage()):this._fetchNextPage()},_fetchPreviousPage:function(t=!1){var e=this._limit*(this._currentPage-1);if(e<0)this._hasPreviousPage=!1,this.render();else return this._fetch(e).done(u=>{var r=u[this._type];r.length?(this._hasPreviousPage=!0,t&&(this.results=r,this.trigger("g:changed"),this._currentPage--,this._updateHasNextPage())):this._hasPreviousPage=!1,this.render()})},_fetchNextPage:function(t=!1){var e=this._limit*(this._currentPage+1);return this._fetch(e).done(u=>{var r=u[this._type];r.length?(this._hasNextPage=!0,t&&(this.results=r,this.trigger("g:changed"),this._currentPage++,this._updateHasPreviousPage())):this._hasNextPage=!1,this.render()})},_fetch:function(t){return ut({url:"resource/search",data:{q:this._query,mode:this._mode,types:JSON.stringify(xe.intersection([this._type],Xt.getModeTypes(this._mode))),limit:this._limit,offset:t}})}});function nS(t){var e=""+t,u=oS.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var oS=/["&<>]/;function im(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void im(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function aS(t){var e="",u,r,i;try{var s=t||{};(function(o){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+'<div class="g-search-results-header-container">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+'<div class="g-search-results-title-container">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+'<i class="g-search-results-title-element icon-search"></i>',i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+'<span class="g-search-results-title g-search-results-title-element">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+"Results : ",i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+nS((u=o)==null?"":u)+"</span></div>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+'<div class="g-search-results-header">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+'<div class="g-search-results-advance-search"></div></div></div>',i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+'<div class="g-search-results-container"></div>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+'<div class="g-search-pending">',i=11,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+'<i class="icon-spin4 animate-spin"></i></div>',i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+'<div class="g-search-no-results" style="display: none;">',i=14,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+'<i class="icon-block"></i>',i=15,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResults.pug",e=e+" No results found</div>"}).call(this,"query"in s?s.query:typeof query<"u"?query:void 0)}catch(o){im(o,r,i)}return e}function fn(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=or(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function um(t,e){return Array.isArray(t)?cS(t,e):t&&typeof t=="object"?lS(t):t||""}function cS(t,e){for(var u,r="",i="",s=Array.isArray(e),o=0;o<t.length;o++)(u=um(t[o]))&&(s&&e[o]&&(u=or(u)),r=r+i+u,i=" ");return r}function lS(t){var e="",u="";for(var r in t)r&&t[r]&&dS.call(t,r)&&(e=e+u+r,u=" ");return e}function or(t){var e=""+t,u=FS.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var dS=Object.prototype.hasOwnProperty,FS=/["&<>]/;function sm(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void sm(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function hS(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h){i=1,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+'<div class="g-search-result-type-header-container">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+"<i"+fn("class",um(["g-search-result-type-header","g-search-result-type-icon",`icon-${f}`],[!1,!1,!0]),!1,!1)+"></i>",i=3,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+'<div class="g-search-result-type-header g-search-results-type-title">',i=4,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+or((u=o)==null?"":u)+"</div></div>",i=5,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+'<ul class="g-search-results-type">',i=6,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",function(){var g=n;if(typeof g.length=="number")for(var d=0,l=g.length;d<l;d++){var c=g[d];i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+'<li class="g-search-result">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+"<a"+fn("href",`#${h}/${c._id}`,!0,!1)+">",i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",h==="user"?(i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+or((u=c.firstName)==null?"":u),i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+" ",i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+or((u=c.lastName)==null?"":u),i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+" (",i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+or((u=c.login)==null?"":u),i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+")"):(i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+or((u=c.name)==null?"":u)),e=e+"</a></li>"}else{var l=0;for(var d in g){l++;var c=g[d];i=7,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+'<li class="g-search-result">',i=8,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+"<a"+fn("href",`#${h}/${c._id}`,!0,!1)+">",i=9,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",h==="user"?(i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+or((u=c.firstName)==null?"":u),i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+" ",i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+or((u=c.lastName)==null?"":u),i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+" (",i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+or((u=c.login)==null?"":u),i=10,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+")"):(i=12,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+or((u=c.name)==null?"":u)),e=e+"</a></li>"}}}.call(this),e=e+"</ul>",i=13,r="/home/circleci/project/girder/girder/web/src/templates/body/searchResultsType.pug",e=e+"<div"+(' class="g-search-results-paginate"'+fn("id",`${h}Paginate`,!0,!1))+"></div>"}).call(this,"collectionName"in s?s.collectionName:typeof collectionName<"u"?collectionName:void 0,"icon"in s?s.icon:typeof icon<"u"?icon:void 0,"results"in s?s.results:typeof results<"u"?results:void 0,"type"in s?s.type:typeof type<"u"?type:void 0)}catch(o){sm(o,r,i)}return e}var nm=Xe.extend({initialize:function(t){this._query=t.query||"",this._mode=t.mode||"text",this._sizeOneElement=28,this.pageLimit=10,this._request=ut({url:"resource/search",data:{q:this._query,mode:this._mode,types:JSON.stringify(Xt.getModeTypes(this._mode)),limit:this.pageLimit}}),this.render()},_getTypeOrdering:function(t){const e=["collection","folder","item","group","user"],u=xe.intersection(e,t),r=xe.difference(t,e).sort();return u.concat(r)},render:function(){return this.$el.html(aS({query:this._query})),this._subviews={},this._request.done(t=>{this.$(".g-search-pending").hide();const e=xe.keys(t),u=this._getTypeOrdering(e);xe.each(u,r=>{t[r].length&&(this._subviews[r]=new gS({parentView:this,query:this._query,mode:this._mode,type:r,limit:this.pageLimit,initResults:t[r],sizeOneElement:this._sizeOneElement}).render(),this._subviews[r].$el.appendTo(this.$(".g-search-results-container")))}),xe.isEmpty(this._subviews)&&this.$(".g-search-no-results").show()}),this}}),gS=Xe.extend({className:"g-search-results-type-container",initialize:function(t){this._query=t.query,this._mode=t.mode,this._type=t.type,this._initResults=t.initResults||[],this._pageLimit=t.limit||10,this._sizeOneElement=t.sizeOneElement||30,this._paginateWidget=new sS({parentView:this,type:this._type,query:this._query,mode:this._mode,limit:this._pageLimit}).on("g:changed",()=>{this._results=this._paginateWidget.results,this.render()}),this._results=this._initResults},_getTypeName:function(t){return{collection:"Collections",group:"Groups",user:"Users",folder:"Folders",item:"Items"}[t]||t},_getTypeIcon:function(t){return{user:"user",group:"users",collection:"sitemap",folder:"folder",item:"doc-text-inv"}[t]||"icon-attention-alt"},render:function(){return this.$el.html(hS({results:this._results,collectionName:this._getTypeName(this._type),type:this._type,icon:this._getTypeIcon(this._type)})),this.$(".g-search-results-type").css("min-height",`${this._initResults.length*this._sizeOneElement}px`),this._paginateWidget.setElement(this.$(`#${this._type}Paginate`)).render(),this}});tt.route("admin","admin",function(){He.trigger("g:navigateTo",Qg)});tt.route("assetstores","assetstores",function(t){He.trigger("g:navigateTo",kl,{assetstoreEdit:t.dialog==="assetstoreedit"?t.dialogid:!1})});tt.route("assetstore/:id/import","assetstoreImport",function(t){kl.import(t)});tt.route("collections","collections",function(t){He.trigger("g:navigateTo",zp,t||{}),He.trigger("g:highlightItem","CollectionsView")});tt.route("collection/:id","collectionAccess",function(t,e){So.fetchAndInit(t,{access:e.dialog==="access",edit:e.dialog==="edit",folderCreate:e.dialog==="foldercreate",dialog:e.dialog})});tt.route("collection/:id/folder/:id","collectionFolder",function(t,e,u){So.fetchAndInit(t,{folderId:e,upload:u.dialog==="upload",access:u.dialog==="access",edit:u.dialog==="edit",folderAccess:u.dialog==="folderaccess",folderCreate:u.dialog==="foldercreate",folderEdit:u.dialog==="folderedit",itemCreate:u.dialog==="itemcreate"})});tt.route("folder/:id","folder",function(t,e){jl.fetchAndInit(t,{upload:e.dialog==="upload",folderAccess:e.dialog==="folderaccess",folderCreate:e.dialog==="foldercreate",folderEdit:e.dialog==="folderedit",itemCreate:e.dialog==="itemcreate"})});tt.route("","index",function(){He.trigger("g:navigateTo",Nn)});tt.route("groups","groups",function(t){He.trigger("g:navigateTo",Xp,t||{}),He.trigger("g:highlightItem","GroupsView")});tt.route("group/:id","groupView",function(t,e){_o.fetchAndInit(t,{edit:e.dialog==="edit"})});tt.route("group/:id/:tab","groupView",function(t,e,u){_o.fetchAndInit(t,{edit:u.dialog==="edit",tab:e})});tt.route("item/:id","item",function(t,e){Dl.fetchAndInit(t,{edit:e.dialog==="itemedit",fileEdit:e.dialog==="fileedit"?e.dialogid:!1,upload:e.dialog==="upload"?e.dialogid:!1})});tt.route("plugins","plugins",function(){He.trigger("g:navigateTo",Ef)});tt.route("settings","settings",function(){He.trigger("g:navigateTo",kf)});tt.route("useraccount/:id/:tab","accountTab",function(t,e){Ro.fetchAndInit(t,e)});tt.route("useraccount/:id/token/:token","accountToken",function(t,e){p0.fromTemporaryToken(t,e).done(()=>{He.trigger("g:navigateTo",Ro,{user:ft(),tab:"password",temporary:e})}).fail(()=>{tt.navigate("",{trigger:!0})})});tt.route("useraccount/:id/verification/:token","accountVerify",function(t,e){ut({url:`user/${t}/verification`,method:"PUT",data:{token:e},error:null}).done(u=>{u.authToken&&(u.user.token=u.authToken.token,Cr.close(),hi(new p0(u.user)),Cr.open(),He.trigger("g:login-changed")),He.trigger("g:navigateTo",Nn),He.trigger("g:alert",{icon:"ok",text:"Email verified.",type:"success",timeout:4e3})}).fail(()=>{He.trigger("g:navigateTo",Nn),He.trigger("g:alert",{icon:"cancel",text:"Could not verify email.",type:"danger",timeout:4e3})})});tt.route("users","users",function(t){He.trigger("g:navigateTo",_l,t||{}),He.trigger("g:highlightItem","UsersView")});tt.route("user/:id","user",function(t,e){Wu.fetchAndInit(t,{folderCreate:e.dialog==="foldercreate",dialog:e.dialog})});tt.route("user/:id/folder/:id","userFolder",function(t,e,u){Wu.fetchAndInit(t,{folderId:e,upload:u.dialog==="upload",folderAccess:u.dialog==="folderaccess",folderCreate:u.dialog==="foldercreate",folderEdit:u.dialog==="folderedit",itemCreate:u.dialog==="itemcreate"})});tt.route("search/results","SearchResults",function(t){He.trigger("g:navigateTo",nm,{query:t.query,mode:t.mode})});var om=Xe.extend({initialize:function(t){this._started=!1,t=t||{},this.contactEmail=t.contactEmail||null,this.privacyNoticeHref=t.privacyNoticeHref||null,this.brandName=t.brandName||null,this.bannerColor=t.bannerColor||null,this.registrationPolicy=t.registrationPolicy||null,this.enablePasswordLogin=xe.has(t,"enablePasswordLogin")?t.enablePasswordLogin:!0,(t.start===void 0||t.start)&&this.start()},start:function(t){var e=new ke.Deferred().resolve(null).promise();if(this._started)return e;t=xe.defaults(t||{},{fetch:!0,render:!0,history:!0});var u=r=>{this._createLayout(),r&&(hi(new p0(r)),Cr.open()),this._started=!0,t.render&&this.render(),t.history&&(s0.history.stop(),s0.history.start({pushState:!1}))};return t.fetch?e=dl().done(u):u(null),this.bindGirderEvents(),e},bindGirderEvents:function(){He.off(null,null,this),He.on("g:navigateTo",this.navigateTo,this),He.on("g:loginUi",this.loginDialog,this),He.on("g:registerUi",this.registerDialog,this),He.on("g:resetPasswordUi",this.resetPasswordDialog,this),He.on("g:alert",this.alert,this),He.on("g:login",this.login,this)},_createLayout:function(){this.headerView=new Ig({parentView:this,brandName:this.brandName,bannerColor:this.bannerColor,registrationPolicy:this.registrationPolicy}),this.globalNavView=new jg({parentView:this}),this.footerView=new xg({parentView:this,contactEmail:this.contactEmail,privacyNoticeHref:this.privacyNoticeHref}),this.progressListView=new qg({eventStream:Cr,parentView:this}),this.layoutRenderMap={},this.layoutRenderMap[rs.DEFAULT]=this._defaultLayout,this.layoutRenderMap[rs.EMPTY]=this._emptyLayout},_layout:"default",_defaultLayout:{show:function(){this.$("#g-app-header-container,#g-global-nav-container,#g-app-footer-container").show(),this.$("#g-app-body-container").addClass("g-default-layout")},hide:function(){this.$("#g-app-header-container,#g-global-nav-container,#g-app-footer-container").hide(),this.$("#g-app-body-container").removeClass("g-default-layout")}},_emptyLayout:{show:function(){this.$("#g-app-body-container").addClass("g-empty-layout")},hide:function(){this.$("#g-app-body-container").removeClass("g-empty-layout")}},render:function(){if(this._started)return this.$el.html(G1()),this.globalNavView.setElement(this.$("#g-global-nav-container")).render(),this.headerView.setElement(this.$("#g-app-header-container")).render(),this.footerView.setElement(this.$("#g-app-footer-container")).render(),this.progressListView.setElement(this.$("#g-app-progress-container")).render(),this},navigateTo:function(t,e,u){return this.globalNavView.deactivateAll(),e=e||{},u=u||{},u.layout?this._layout!==u.layout&&(xe.has(this.layoutRenderMap,u.layout)?(this.layoutRenderMap[this._layout].hide.call(this,u),this._layout=u.layout,this.layoutRenderMap[this._layout].show.call(this,u)):console.error("Attempting to set unknown layout type: "+u.layout)):this._layout!==rs.DEFAULT&&(this.layoutRenderMap[this._layout].hide.call(this,u),this._layout=rs.DEFAULT,this.layoutRenderMap[this._layout].show.call(this,u)),t?(this.bodyView&&this.bodyView.destroy(),e=xe.extend(e,{el:this.$("#g-app-body-container"),parentView:this,brandName:this.brandName}),this.bodyView=new t(e),u.renderNow&&this.bodyView.render()):console.error("Undefined page."),this},closeDialogIfUser:function(){return ft()?(ke(".modal").girderModal("close"),!0):!1},loginDialog:function(){this.closeDialogIfUser()||(this.loginView||(this.loginView=new $g({el:this.$("#g-dialog-container"),parentView:this,registrationPolicy:this.registrationPolicy,enablePasswordLogin:this.enablePasswordLogin})),this.loginView.render())},registerDialog:function(){this.closeDialogIfUser()||(this.registerView||(this.registerView=new wl({el:this.$("#g-dialog-container"),parentView:this})),this.registerView.render())},resetPasswordDialog:function(){this.closeDialogIfUser()||(this.resetPasswordView||(this.resetPasswordView=new Gg({el:this.$("#g-dialog-container"),parentView:this,registrationPolicy:this.registrationPolicy})),this.resetPasswordView.render())},alert:function(t){var e=ke(V1({text:t.text,type:t.type||"info",icon:t.icon}));ke("#g-alerts-container").append(e),e.fadeIn(500),t.timeout===void 0&&(t.timeout=6e3),t.timeout>0&&window.setTimeout(function(){e.fadeOut(750,function(){ke(this).remove()})},t.timeout)},login:function(){var t=wo(s0.history.fragment).base;s0.history.fragment=null,Cr.close(),ft()?(Cr.open(),tt.navigate(t,{trigger:!0})):tt.navigate("/",{trigger:!0})}});const pS=Object.freeze(Object.defineProperty({__proto__:null,AdminView:Qg,AssetstoresView:kl,CollectionView:So,CollectionsView:zp,FilesystemImportView:$p,FolderView:jl,FrontPageView:Nn,GroupView:_o,GroupsView:Xp,ItemView:Dl,PluginsView:Ef,S3ImportView:Wp,SearchResultsView:nm,SystemConfigurationView:kf,UserAccountView:Ro,UserView:Wu,UsersView:_l},Symbol.toStringTag,{value:"Module"})),fS=Object.freeze(Object.defineProperty({__proto__:null,FooterView:xg,GlobalNavView:jg,HeaderUserView:Dg,HeaderView:Ig,LoginView:$g,ProgressListView:qg,RegisterView:wl,ResetPasswordView:Gg},Symbol.toStringTag,{value:"Module"}));function p2(t){var e=""+t,u=mS.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var mS=/["&<>]/;function am(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void am(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function vS(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<div class="form-group">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<label class="control-label">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+p2((u=o)==null?"":u)+"</label>",i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",f?(i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<div class="input-group date g-datetime-widget-from">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<input class="input-sm form-control" type="text"/>',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<div class="input-group-addon">',i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<span class="icon-calendar"></span></div></div>'):(i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<div class="input-group date">',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<input class="input-sm form-control g-datetime-widget-from" type="text"/></div>'),e=e+"</div>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<div class="form-group">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<label class="control-label">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+p2((u=n)==null?"":u)+"</label>",i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",f?(i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<div class="input-group date g-datetime-widget-to">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<input class="input-sm form-control" type="text"/>',i=16,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<div class="input-group-addon">',i=17,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<span class="icon-calendar"></span></div></div>'):(i=19,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<div class="input-group date">',i=20,r="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeRangeWidget.pug",e=e+'<input class="input-sm form-control g-datetime-widget-to" type="text"/></div>'),e=e+"</div>"}).call(this,"fromLabel"in s?s.fromLabel:typeof fromLabel<"u"?fromLabel:void 0,"showIcon"in s?s.showIcon:typeof showIcon<"u"?showIcon:void 0,"toLabel"in s?s.toLabel:typeof toLabel<"u"?toLabel:void 0)}catch(o){am(o,r,i)}return e}var bS=Xe.extend({initialize:function(t){this.defaultFromDate=t.defaultFromDate||!1,this.defaultToDate=t.defaultToDate||!1,this.showIcon=xe.has(t,"showIcon")?t.showIcon:!0,this.fromLabel=t.fromLabel||"Start date",this.toLabel=t.toLabel||"End date"},render:function(){this.$el.html(vS({showIcon:this.showIcon,fromLabel:this.fromLabel,toLabel:this.toLabel}));var t={showClear:!0,showTodayButton:!0,icons:{time:"icon-clock",date:"icon-calendar",up:"icon-up-open",down:"icon-down-open",previous:"icon-left-open",next:"icon-right-open",clear:"icon-trash",close:"icon-cancel",today:"icon-target"}};return t.useCurrent="day",t.defaultDate=this.defaultFromDate,this.$(".g-datetime-widget-from").datetimepicker(t),t.useCurrent=!1,t.defaultDate=this.defaultToDate,this.$(".g-datetime-widget-to").datetimepicker(t),this.$(".g-datetime-widget-from").on("dp.change",e=>{var u=this._picker(".g-datetime-widget-to");u.minDate(e.date)}),this.$(".g-datetime-widget-to").on("dp.change",e=>{var u=this._picker(".g-datetime-widget-from");u.maxDate(e.date)}),this},setFromDate:function(t){this._setDate(".g-datetime-widget-from",t)},setToDate:function(t){this._setDate(".g-datetime-widget-to",t)},_setDate:function(t,e){var u=this._picker(t);if(xe.isEmpty(e))u.clear();else if(xe.isString(e)){var r=Ze.utc(e).local();u.date(r)}else u.date(e)},fromDate:function(){return this._date(".g-datetime-widget-from")},toDate:function(){return this._date(".g-datetime-widget-to")},fromDateString:function(){return this._dateString(".g-datetime-widget-from")},toDateString:function(){return this._dateString(".g-datetime-widget-to")},_picker:function(t){var e=this.$(t).data("DateTimePicker");return e},_date:function(t){var e=this._picker(t),u=e.date();return u!==null&&(u=Ze(u),u.utc()),u},_dateString:function(t){var e=this._date(t);return e===null?"":e.format()}});function cm(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void cm(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function wS(t){var e="",u,r;try{var i=t||{};(function(s){r=1,u="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeWidget.pug",s?(r=2,u="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeWidget.pug",e=e+'<div class="input-group date g-datetime-widget">',r=3,u="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeWidget.pug",e=e+'<input class="input-sm form-control" type="text"/>',r=4,u="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeWidget.pug",e=e+'<span class="input-group-addon">',r=5,u="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeWidget.pug",e=e+'<span class="icon-calendar"></span></span></div>'):(r=7,u="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeWidget.pug",e=e+'<div class="input-group">',r=8,u="/home/circleci/project/girder/girder/web/src/templates/widgets/dateTimeWidget.pug",e=e+'<input class="input-sm form-control g-datetime-widget" type="text"/></div>')}).call(this,"showIcon"in i?i.showIcon:typeof showIcon<"u"?showIcon:void 0)}catch(s){cm(s,u,r)}return e}var yS=Xe.extend({initialize:function(t){this.defaultDate=t.defaultDate||!1,this.showIcon=xe.has(t,"showIcon")?t.showIcon:!0},render:function(){return this.$el.html(wS({showIcon:this.showIcon})),this.$(".g-datetime-widget").datetimepicker({showClear:!0,showTodayButton:!0,useCurrent:"day",icons:{time:"icon-clock",date:"icon-calendar",up:"icon-up-open",down:"icon-down-open",previous:"icon-left-open",next:"icon-right-open",clear:"icon-trash",close:"icon-cancel",today:"icon-target"},defaultDate:this.defaultDate}),this},setDate:function(t){var e=this._picker();if(xe.isEmpty(t))e.clear();else if(xe.isString(t)){var u=Ze.utc(t).local();e.date(u)}else e.date(t)},date:function(){var t=this._picker(),e=t.date();return e!==null&&(e=Ze(e),e.utc()),e},dateString:function(){var t=this.date();return t===null?"":t.format()},_picker:function(){var t=this.$(".g-datetime-widget").data("DateTimePicker");return t}});function CS(t){var e=""+t,u=ES.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var ES=/["&<>]/;function lm(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void lm(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function AS(t){var e="",u,r,i;try{var s=t||{};(function(o){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/pluginConfigBreadcrumb.pug",e=e+'<div class="g-plugin-config-breadcrumbs">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/pluginConfigBreadcrumb.pug",e=e+'<ol class="breadcrumb">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/pluginConfigBreadcrumb.pug",e=e+"<li>",i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/pluginConfigBreadcrumb.pug",e=e+'<a class="g-admin-console-link">',i=5,r="/home/circleci/project/girder/girder/web/src/templates/widgets/pluginConfigBreadcrumb.pug",e=e+'<i class="icon-wrench"></i>',i=6,r="/home/circleci/project/girder/girder/web/src/templates/widgets/pluginConfigBreadcrumb.pug",e=e+"Admin console</a></li>",i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/pluginConfigBreadcrumb.pug",e=e+"<li>",i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/pluginConfigBreadcrumb.pug",e=e+'<a class="g-plugins-link">',i=9,r="/home/circleci/project/girder/girder/web/src/templates/widgets/pluginConfigBreadcrumb.pug",e=e+'<i class="icon-puzzle"></i>',i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/pluginConfigBreadcrumb.pug",e=e+"Plugins</a></li>",i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/pluginConfigBreadcrumb.pug",e=e+'<li class="active">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/pluginConfigBreadcrumb.pug",e=e+'<i class="icon-cog"></i>',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/pluginConfigBreadcrumb.pug",e=e+CS((u=o)==null?"":u)+"</li></ol></div>"}).call(this,"pluginName"in s?s.pluginName:typeof pluginName<"u"?pluginName:void 0)}catch(o){lm(o,r,i)}return e}var xS=Xe.extend({events:{"click a.g-admin-console-link":function(){tt.navigate("admin",{trigger:!0})},"click a.g-plugins-link":function(){tt.navigate("plugins",{trigger:!0})}},initialize:function(t){this.pluginName=t.pluginName},render:function(){return this.$el.html(AS({pluginName:this.pluginName})),this}});function K0(t,e,u,r){if(e===!1||e==null||!e&&(t==="class"||t==="style"))return"";if(e===!0)return" "+(r?t:t+'="'+t+'"');var i=typeof e;return i!=="object"&&i!=="function"||typeof e.toJSON!="function"||(e=e.toJSON()),typeof e=="string"||(e=JSON.stringify(e),u||e.indexOf('"')===-1)?(u&&(e=qn(e))," "+t+'="'+e+'"'):" "+t+"='"+e.replace(/'/g,"&#39;")+"'"}function Fs(t,e){return Array.isArray(t)?kS(t,e):t&&typeof t=="object"?jS(t):t||""}function kS(t,e){for(var u,r="",i="",s=Array.isArray(e),o=0;o<t.length;o++)(u=Fs(t[o]))&&(s&&e[o]&&(u=qn(u)),r=r+i+u,i=" ");return r}function jS(t){var e="",u="";for(var r in t)r&&t[r]&&dm.call(t,r)&&(e=e+u+r,u=" ");return e}function qn(t){var e=""+t,u=SS.exec(e);if(!u)return t;var r,i,s,o="";for(r=u.index,i=0;r<e.length;r++){switch(e.charCodeAt(r)){case 34:s="&quot;";break;case 38:s="&amp;";break;case 60:s="&lt;";break;case 62:s="&gt;";break;default:continue}i!==r&&(o+=e.substring(i,r)),i=r+1,o+=s}return i!==r?o+e.substring(i,r):o}var dm=Object.prototype.hasOwnProperty,SS=/["&<>]/;function Fm(t,e,u,r){if(!(t instanceof Error))throw t;if(!(typeof window>"u"&&e||r))throw t.message+=" on line "+u,t;var i,s,o,f;try{r=r||require("fs").readFileSync(e,{encoding:"utf8"}),i=3,s=r.split(`
`),o=Math.max(u-i,0),f=Math.min(s.length,u+i)}catch(n){return t.message+=" - could not read from "+e+" ("+n.message+")",void Fm(t,null,u)}i=s.slice(o,f).map(function(n,h){var g=h+o+1;return(g==u?"  > ":"    ")+g+"| "+n}).join(`
`),t.path=e;try{t.message=(e||"Pug")+":"+u+`
`+i+`

`+t.message}catch{}throw t}function mn(t){if(!t)return"";if(typeof t=="object"){var e="";for(var u in t)dm.call(t,u)&&(e=e+u+":"+t[u]+";");return e}return t+""}function _S(t){var e="",u,r,i;try{var s=t||{};(function(o,f,n,h){i=1,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",e=e+'<div class="g-timeline-widget-wrapper">',i=2,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",e=e+'<div class="g-timeline-container">',i=3,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",function(){var g=n;if(typeof g.length=="number")for(var d=0,l=g.length;d<l;d++){var c=g[d];i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",e=e+"<div"+(K0("class",Fs(["g-timeline-segment",c.class],[!1,!0]),!1,!1)+K0("title",c.tooltip,!0,!1)+K0("style",mn(`left: ${c.left}; width: ${c.width}; ${c.color}`),!0,!1))+"></div>"}else{var l=0;for(var d in g){l++;var c=g[d];i=4,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",e=e+"<div"+(K0("class",Fs(["g-timeline-segment",c.class],[!1,!0]),!1,!1)+K0("title",c.tooltip,!0,!1)+K0("style",mn(`left: ${c.left}; width: ${c.width}; ${c.color}`),!0,!1))+"></div>"}}}.call(this),i=7,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",function(){var g=f;if(typeof g.length=="number")for(var d=0,l=g.length;d<l;d++){var c=g[d];i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",e=e+"<div"+(K0("class",Fs(["g-timeline-point",c.class],[!1,!0]),!1,!1)+K0("title",c.tooltip,!0,!1)+K0("style",mn(`left: calc(${c.left} - 10px); ${c.color}`),!0,!1))+"></div>"}else{var l=0;for(var d in g){l++;var c=g[d];i=8,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",e=e+"<div"+(K0("class",Fs(["g-timeline-point",c.class],[!1,!0]),!1,!1)+K0("title",c.tooltip,!0,!1)+K0("style",mn(`left: calc(${c.left} - 10px); ${c.color}`),!0,!1))+"></div>"}}}.call(this),e=e+"</div>",i=10,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",(h!==void 0||o!==void 0)&&(i=11,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",e=e+'<div class="g-timeline-labels-container">',i=12,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",h!==void 0&&(i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",e=e+'<div class="g-timeline-start-label">',i=13,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",e=e+qn((u=h)==null?"":u)+"</div>"),i=14,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",o!==void 0&&(i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",e=e+'<div class="g-timeline-end-label">',i=15,r="/home/circleci/project/girder/girder/web/src/templates/widgets/timeline.pug",e=e+qn((u=o)==null?"":u)+"</div>"),e=e+"</div>"),e=e+"</div>"}).call(this,"endLabel"in s?s.endLabel:typeof endLabel<"u"?endLabel:void 0,"points"in s?s.points:typeof points<"u"?points:void 0,"segments"in s?s.segments:typeof segments<"u"?segments:void 0,"startLabel"in s?s.startLabel:typeof startLabel<"u"?startLabel:void 0)}catch(o){Fm(o,r,i)}return e}var DS=Xe.extend({initialize:function(t){this.startTime=t.startTime,this.endTime=t.endTime,this.segments=t.segments||[],this.points=t.points||[],this.numeric=!!t.numeric,this.startLabel=t.startLabel,this.endLabel=t.endLabel,this.defaultSegmentClass=t.defaultSegmentClass||"g-segment-default",this.defaultPointClass=t.defaultPointClass||"g-point-default",this._processData()},_processData:function(){if(this.numeric||(this.startTime=new Date(this.startTime),this.endTime=new Date(this.endTime)),this.endTime<=this.startTime){console.error("Timeline widget: end time must be after start time."),this._processedSegments=[],this._processedPoints=[];return}var t=this.endTime-this.startTime;this._processedSegments=xe.map(this.segments,function(e){var u=this.numeric?e.start:new Date(e.start),r=this.numeric?e.end:new Date(e.end),i=e.class?[e.class]:[this.defaultSegmentClass],s=e.color?`background-color: ${e.color}`:"";return{class:i.join(" "),left:(100*(u-this.startTime)/t).toFixed(1)+"%",width:(100*(r-u)/t).toFixed(1)+"%",tooltip:this._segmentTooltip(e,{range:this.numeric?r-u:(r-u)/1e3}),color:s}},this),this._processedPoints=xe.map(this.points,function(e){var u=this.numeric?e.time:new Date(e.time),r=e.class?[e.class]:[this.defaultPointClass],i=e.color?`background-color: ${e.color}`:"";return{class:r.join(" "),left:(100*(u-this.startTime)/t).toFixed(1)+"%",tooltip:this._pointTooltip(e,{time:u}),color:i}},this)},_segmentTooltip:function(t,e){return t.tooltip?t.tooltip.replace("%r",e.range):null},_pointTooltip:function(t,e){return t.tooltip?this.numeric?t.tooltip.replace("%t",e.time):t.tooltip.replace("%t",e.time.toISOString()):null},render:function(){return this.$el.html(_S({segments:this._processedSegments,points:this._processedPoints,startLabel:this.startLabel,endLabel:this.endLabel})),this}});const MS=Object.freeze(Object.defineProperty({__proto__:null,AccessWidget:Ao,ApiKeyListWidget:Df,BrowserWidget:Al,CheckedMenuWidget:ap,CollectionInfoWidget:lp,DateTimeRangeWidget:bS,DateTimeWidget:yS,EditApiKeyWidget:Sf,EditAssetstoreWidget:Cl,EditCollectionWidget:ko,EditFileWidget:gf,EditFolderWidget:Ja,EditGroupWidget:Sl,EditItemWidget:El,FileInfoWidget:ff,FileListWidget:vf,FolderInfoWidget:mp,FolderListWidget:bp,GroupAdminsWidget:uf,GroupInvitesWidget:nf,GroupMembersWidget:cf,GroupModsWidget:df,HierarchyWidget:$u,ItemBreadcrumbWidget:wf,ItemListWidget:yp,LoadingAnimation:Os,MarkdownWidget:xo,MetadataWidget:$n,NewAssetstoreWidget:tp,PaginateWidget:Nu,PluginConfigBreadcrumbWidget:xS,RootSelectorWidget:Bp,SearchFieldWidget:Xt,TaskProgressWidget:Hg,TimelineWidget:DS,UploadWidget:jo},Symbol.toStringTag,{value:"Module"})),TS=Object.freeze(Object.defineProperty({__proto__:null,App:om,View:Xe,body:pS,layout:fS,widgets:MS},Symbol.toStringTag,{value:"Module"})),PS=async(t,e="body")=>new Promise((u,r)=>{ke(()=>{Ih(t),He.trigger("g:appload.before"),ut({url:"system/public_settings",method:"GET"}).done(i=>{const s=new om({el:e,parentView:null,contactEmail:i["core.contact_email_address"],privacyNoticeHref:i["core.privacy_notice"],brandName:i["core.brand_name"],bannerColor:i["core.banner_color"],registrationPolicy:i["core.registration_policy"],enablePasswordLogin:i["core.enable_password_login"]});s.render(),document.title=i["core.brand_name"],He.trigger("g:appload.after",s),u(s)}).fail(i=>{He.trigger("g:error",i),r(new Error("Could not retrieve public settings from server."))})})}),hm={$:ke,_:xe,Backbone:s0,moment:Ze,initializeDefaultApp:PS,auth:my,collections:HE,constants:vy,dialog:JE,events:He,misc:$E,models:yg,plugins:{},pluginUtils:XE,rest:gy,router:tt,utilities:r1,version:Kp,views:TS};window.girder=hm;const vn={}.VITE_API_ROOT??"/api/v1";(async()=>{const t=vn.startsWith("/")?window.origin:new URL(vn).origin,u=await(await fetch(`${vn}/system/plugin_static_files`)).json();u.css.forEach(r=>{const i=document.createElement("link");i.rel="stylesheet",i.type="text/css",i.href=new URL(r,t).href,document.head.appendChild(i)});for(const r of u.js)await new Promise(i=>{const s=document.createElement("script");s.type="text/javascript",s.src=new URL(r,t).href,document.head.appendChild(s),s.addEventListener("load",function(){i()})});await hm.initializeDefaultApp(vn)})()});export default LS();
//# sourceMappingURL=index-42d603b6.js.map
